@@ -1,23 +1,12 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAxis.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkAxis.h"
 
 #include "vtkAxisExtended.h"
 #include "vtkChart.h"
 #include "vtkContext2D.h"
+#include "vtkContextMouseEvent.h"
 #include "vtkContextScene.h"
 #include "vtkDoubleArray.h"
 #include "vtkFloatArray.h"
@@ -39,10 +28,11 @@
 #include <cstdio>
 #include <limits>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAxis);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAxis::vtkAxis()
 {
   this->Position = -1;
@@ -90,14 +80,14 @@ vtkAxis::vtkAxis()
   this->RangeLabelFormat = "%g";
   this->Notation = vtkAxis::STANDARD_NOTATION;
   this->Behavior = vtkAxis::AUTO;
-  this->Pen = vtkPen::New();
   this->TitleAppended = false;
   this->ScalingFactor = 1.0;
   this->Shift = 0.0;
 
+  this->Pen = vtkSmartPointer<vtkPen>::New();
   this->Pen->SetColor(0, 0, 0);
   this->Pen->SetWidth(1.0);
-  this->GridPen = vtkPen::New();
+  this->GridPen = vtkSmartPointer<vtkPen>::New();
   this->GridPen->SetColor(242, 242, 242);
   this->GridPen->SetWidth(1.0);
   this->TickPositions = vtkSmartPointer<vtkDoubleArray>::New();
@@ -112,13 +102,11 @@ vtkAxis::vtkAxis()
   this->CustomTickLabels = false;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAxis::~vtkAxis()
 {
   this->TitleProperties->Delete();
   this->LabelProperties->Delete();
-  this->Pen->Delete();
-  this->GridPen->Delete();
 }
 
 void vtkAxis::SetPosition(int position)
@@ -163,7 +151,7 @@ void vtkAxis::SetPosition(int position)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetPoint1(const vtkVector2f& pos)
 {
   if (this->Position1 != pos)
@@ -174,19 +162,19 @@ void vtkAxis::SetPoint1(const vtkVector2f& pos)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetPoint1(float x, float y)
 {
   this->SetPoint1(vtkVector2f(x, y));
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVector2f vtkAxis::GetPosition1()
 {
   return this->Position1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetPoint2(const vtkVector2f& pos)
 {
   if (this->Position2 != pos)
@@ -197,19 +185,19 @@ void vtkAxis::SetPoint2(const vtkVector2f& pos)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetPoint2(float x, float y)
 {
   this->SetPoint2(vtkVector2f(x, y));
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVector2f vtkAxis::GetPosition2()
 {
   return this->Position2;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetNumberOfTicks(int numberOfTicks)
 {
   if (this->NumberOfTicks != numberOfTicks)
@@ -221,7 +209,7 @@ void vtkAxis::SetNumberOfTicks(int numberOfTicks)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::Update()
 {
   if (!this->Visible || this->BuildTime > this->MTime)
@@ -294,7 +282,7 @@ void vtkAxis::Update()
   this->BuildTime.Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkAxis::Paint(vtkContext2D* painter)
 {
   // This is where everything should be drawn, or dispatched to other methods.
@@ -319,39 +307,10 @@ bool vtkAxis::Paint(vtkContext2D* painter)
   // Draw the axis title if there is one
   if (!this->Title.empty() && this->TitleVisible)
   {
-    int x = 0;
-    int y = 0;
+    vtkVector2f titlePosition;
+    CalculateTitlePosition(titlePosition);
     painter->ApplyTextProp(this->TitleProperties);
-
-    // Draw the axis label
-    if (this->Position == vtkAxis::LEFT)
-    {
-      // Draw the axis label
-      x = vtkContext2D::FloatToInt(this->Point1[0] - this->MaxLabel[0] - 10);
-      y = vtkContext2D::FloatToInt(this->Point1[1] + this->Point2[1]) / 2;
-    }
-    else if (this->Position == vtkAxis::RIGHT)
-    {
-      // Draw the axis label
-      x = vtkContext2D::FloatToInt(this->Point1[0] + this->MaxLabel[0] + 10);
-      y = vtkContext2D::FloatToInt(this->Point1[1] + this->Point2[1]) / 2;
-    }
-    else if (this->Position == vtkAxis::BOTTOM)
-    {
-      x = vtkContext2D::FloatToInt(this->Point1[0] + this->Point2[0]) / 2;
-      y = vtkContext2D::FloatToInt(this->Point1[1] - this->MaxLabel[1] - 10);
-    }
-    else if (this->Position == vtkAxis::TOP)
-    {
-      x = vtkContext2D::FloatToInt(this->Point1[0] + this->Point2[0]) / 2;
-      y = vtkContext2D::FloatToInt(this->Point1[1] + this->MaxLabel[1] + 10);
-    }
-    else if (this->Position == vtkAxis::PARALLEL)
-    {
-      x = vtkContext2D::FloatToInt(this->Point1[0]);
-      y = vtkContext2D::FloatToInt(this->Point1[1] - this->MaxLabel[1] - 15);
-    }
-    painter->DrawString(x, y, this->Title);
+    painter->DrawString(titlePosition.GetX(), titlePosition.GetY(), this->Title);
   }
 
   // Now draw the tick marks
@@ -411,8 +370,8 @@ bool vtkAxis::Paint(vtkContext2D* painter)
     vtkStdString maxString =
       this->GenerateSprintfLabel(this->UnscaledMaximum, this->RangeLabelFormat);
 
-    painter->ComputeJustifiedStringBounds(minString, minLabelBounds);
-    painter->ComputeJustifiedStringBounds(maxString, maxLabelBounds);
+    painter->ComputeJustifiedStringBounds(minString.c_str(), minLabelBounds);
+    painter->ComputeJustifiedStringBounds(maxString.c_str(), maxLabelBounds);
 
     float minLabelShift[2] = { 0, 0 };
     float maxLabelShift[2] = { 0, 0 };
@@ -488,7 +447,7 @@ bool vtkAxis::Paint(vtkContext2D* painter)
       if (this->LabelsVisible)
       {
         float bounds[4];
-        painter->ComputeJustifiedStringBounds(tickLabel[i], bounds);
+        painter->ComputeJustifiedStringBounds(tickLabel[i].c_str(), bounds);
         float pos[2] = { this->Point1[0] + labelOffset, tickPos[i] };
         bounds[0] += pos[0];
         bounds[1] += pos[1];
@@ -522,7 +481,7 @@ bool vtkAxis::Paint(vtkContext2D* painter)
       if (this->LabelsVisible)
       {
         float bounds[4];
-        painter->ComputeJustifiedStringBounds(tickLabel[i], bounds);
+        painter->ComputeJustifiedStringBounds(tickLabel[i].c_str(), bounds);
         float pos[2] = { tickPos[i], this->Point1[1] + labelOffset };
         bounds[0] += pos[0];
         bounds[1] += pos[1];
@@ -548,7 +507,7 @@ bool vtkAxis::Paint(vtkContext2D* painter)
   return true;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetMinimum(double minimum)
 {
   minimum = std::max(minimum, this->MinimumLimit);
@@ -564,7 +523,7 @@ void vtkAxis::SetMinimum(double minimum)
   this->InvokeEvent(vtkChart::UpdateRange);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetUnscaledMinimum(double minimum)
 {
   minimum = std::max(minimum, this->UnscaledMinimumLimit);
@@ -580,7 +539,7 @@ void vtkAxis::SetUnscaledMinimum(double minimum)
   this->InvokeEvent(vtkChart::UpdateRange);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetMinimumLimit(double lowest)
 {
   if (this->MinimumLimit == lowest)
@@ -609,7 +568,7 @@ void vtkAxis::SetMinimumLimit(double lowest)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetUnscaledMinimumLimit(double lowest)
 {
   if (this->UnscaledMinimumLimit == lowest)
@@ -626,7 +585,7 @@ void vtkAxis::SetUnscaledMinimumLimit(double lowest)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetMaximum(double maximum)
 {
   maximum = std::min(maximum, this->MaximumLimit);
@@ -642,7 +601,7 @@ void vtkAxis::SetMaximum(double maximum)
   this->InvokeEvent(vtkChart::UpdateRange);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetUnscaledMaximum(double maximum)
 {
   maximum = std::min(maximum, this->UnscaledMaximumLimit);
@@ -658,7 +617,7 @@ void vtkAxis::SetUnscaledMaximum(double maximum)
   this->InvokeEvent(vtkChart::UpdateRange);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetMaximumLimit(double highest)
 {
   if (this->MaximumLimit == highest)
@@ -687,7 +646,7 @@ void vtkAxis::SetMaximumLimit(double highest)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetUnscaledMaximumLimit(double highest)
 {
   if (this->UnscaledMaximumLimit == highest)
@@ -704,7 +663,7 @@ void vtkAxis::SetUnscaledMaximumLimit(double highest)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetRange(double minimum, double maximum)
 {
   bool rangeModified = false;
@@ -733,7 +692,7 @@ void vtkAxis::SetRange(double minimum, double maximum)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetRange(double* range)
 {
   if (range)
@@ -742,7 +701,7 @@ void vtkAxis::SetRange(double* range)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetUnscaledRange(double minimum, double maximum)
 {
   bool rangeModified = false;
@@ -772,7 +731,7 @@ void vtkAxis::SetUnscaledRange(double minimum, double maximum)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetUnscaledRange(double* range)
 {
   if (range)
@@ -781,7 +740,7 @@ void vtkAxis::SetUnscaledRange(double* range)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::GetRange(double* range)
 {
   if (range)
@@ -791,7 +750,7 @@ void vtkAxis::GetRange(double* range)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::GetUnscaledRange(double* range)
 {
   if (range)
@@ -801,7 +760,7 @@ void vtkAxis::GetUnscaledRange(double* range)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetTitle(const vtkStdString& title)
 {
   if (this->Title != title)
@@ -811,13 +770,13 @@ void vtkAxis::SetTitle(const vtkStdString& title)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStdString vtkAxis::GetTitle()
 {
   return this->Title;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetPrecision(int precision)
 {
   if (this->Precision == precision)
@@ -829,7 +788,7 @@ void vtkAxis::SetPrecision(int precision)
   this->Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetLabelFormat(const std::string& fmt)
 {
   vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting LabelFormat to " << fmt);
@@ -841,7 +800,7 @@ void vtkAxis::SetLabelFormat(const std::string& fmt)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetLogScale(bool logScale)
 {
   if (this->LogScale == logScale)
@@ -853,7 +812,7 @@ void vtkAxis::SetLogScale(bool logScale)
   this->Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::SetNotation(int notation)
 {
   if (this->Notation == notation)
@@ -865,7 +824,7 @@ void vtkAxis::SetNotation(int notation)
   this->Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::AutoScale()
 {
   if (this->Behavior != vtkAxis::AUTO)
@@ -886,7 +845,7 @@ void vtkAxis::AutoScale()
   this->GenerateTickLabels(this->Minimum, this->Maximum);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::RecalculateTickSpacing()
 {
   // Calculate the min and max, set the number of ticks and the tick spacing,
@@ -944,25 +903,25 @@ void vtkAxis::RecalculateTickSpacing()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDoubleArray* vtkAxis::GetTickPositions()
 {
   return this->TickPositions;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkFloatArray* vtkAxis::GetTickScenePositions()
 {
   return this->TickScenePositions;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStringArray* vtkAxis::GetTickLabels()
 {
   return this->TickLabels;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkAxis::SetCustomTickPositions(vtkDoubleArray* positions, vtkStringArray* labels)
 {
   if (!positions && !labels)
@@ -1002,7 +961,7 @@ bool vtkAxis::SetCustomTickPositions(vtkDoubleArray* positions, vtkStringArray*
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkRectf vtkAxis::GetBoundingRect(vtkContext2D* painter)
 {
   bool vertical = false;
@@ -1049,7 +1008,7 @@ vtkRectf vtkAxis::GetBoundingRect(vtkContext2D* painter)
 
   // Then, if there is an axis label, add that in.
   vtkRectf titleBounds(0, 0, 0, 0);
-  if (this->Title && !this->Title.empty())
+  if (!this->Title.empty())
   {
     painter->ApplyTextProp(this->TitleProperties);
     painter->ComputeStringBounds(this->Title, titleBounds.GetData());
@@ -1072,7 +1031,7 @@ vtkRectf vtkAxis::GetBoundingRect(vtkContext2D* painter)
   return bounds;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::UpdateLogScaleActive(bool alwaysUpdateMinMaxFromUnscaled)
 {
   bool needUpdate = false;
@@ -1161,10 +1120,10 @@ void vtkAxis::UpdateLogScaleActive(bool alwaysUpdateMinMaxFromUnscaled)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::GenerateTickLabels(double min, double max)
 {
-  if (this->CustomTickLabels == true)
+  if (this->CustomTickLabels)
   {
     // Never generate new tick labels if custom tick labels are being used.
     return;
@@ -1343,7 +1302,7 @@ void vtkAxis::GenerateTickLabels(double min, double max)
   this->TickMarksDirty = false;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::GenerateTickLabels()
 {
   this->TickLabels->SetNumberOfTuples(0);
@@ -1359,7 +1318,7 @@ void vtkAxis::GenerateTickLabels()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStdString vtkAxis::GenerateSimpleLabel(double val)
 {
   vtkStdString result;
@@ -1427,7 +1386,31 @@ vtkStdString vtkAxis::GenerateSimpleLabel(double val)
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+bool vtkAxis::Hit(const vtkContextMouseEvent& mouse)
+{
+  if (!this->Interactive || !this->Visible)
+  {
+    return false;
+  }
+
+  vtkVector2f textDistance;
+  CalculateTitlePosition(textDistance);
+  vtkVector2f vpos = mouse.GetPos();
+  if (this->Position == vtkAxis::LEFT || this->Position == vtkAxis::RIGHT ||
+    this->Position == vtkAxis::PARALLEL)
+  {
+    return vpos.GetX() < vtkMath::Max(this->Point1[0], textDistance.GetX()) &&
+      vpos.GetX() > vtkMath::Min(this->Point1[0], textDistance.GetX());
+  }
+  else
+  {
+    return vpos.GetY() < vtkMath::Max(this->Point1[1], textDistance.GetY()) &&
+      vpos.GetY() > vtkMath::Min(this->Point1[1], textDistance.GetY());
+  }
+}
+
+//------------------------------------------------------------------------------
 // This methods generates tick labels for 8 different format notations
 //   1 - Scientific 5 * 10^6
 //   2 - Decimal e.g. 5000
@@ -1534,7 +1517,7 @@ void vtkAxis::GenerateLabelFormat(int notation, double n)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStdString vtkAxis::GenerateSprintfLabel(double value, const std::string& format)
 {
   // Use the C-style printf specification:
@@ -1548,7 +1531,7 @@ vtkStdString vtkAxis::GenerateSprintfLabel(double value, const std::string& form
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkAxis::NiceMinMax(double& min, double& max, float pixelRange, float tickPixelSpacing)
 {
   // First get the order of the range of the numbers
@@ -1608,7 +1591,7 @@ double vtkAxis::NiceMinMax(double& min, double& max, float pixelRange, float tic
   return niceTickSpacing;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkAxis::CalculateNiceMinMax(double& min, double& max)
 {
   if (this->NumberOfTicks > 0)
@@ -1658,7 +1641,7 @@ double vtkAxis::CalculateNiceMinMax(double& min, double& max)
   return niceTickSpacing;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkAxis::NiceNumber(double n, bool roundUp)
 {
   if (roundUp)
@@ -1701,7 +1684,7 @@ double vtkAxis::NiceNumber(double n, bool roundUp)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkAxis::LogScaleTickMark(double number, bool roundUp, bool& niceValue, int& order)
 {
   // We need to retrieve the order of our number.
@@ -1721,7 +1704,7 @@ double vtkAxis::LogScaleTickMark(double number, bool roundUp, bool& niceValue, i
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::GenerateLogSpacedLinearTicks(int order, double min, double max)
 {
   // Log-scale axis, but zoomed in too far to show an order of magnitude in
@@ -1776,7 +1759,7 @@ void vtkAxis::GenerateLogSpacedLinearTicks(int order, double min, double max)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::GenerateLogScaleTickMarks(int order, double min, double max, bool detailLabels)
 {
   // If the values min and max are not within limits we set defaults
@@ -1836,8 +1819,40 @@ void vtkAxis::GenerateLogScaleTickMarks(int order, double min, double max, bool
   }
 }
 
-//-----------------------------------------------------------------------------
-inline bool vtkAxis::InRange(double value)
+void vtkAxis::CalculateTitlePosition(vtkVector2f& out)
+{
+  // Draw the axis label
+  if (this->Position == vtkAxis::LEFT)
+  {
+    // Draw the axis label
+    out.SetX(vtkContext2D::FloatToInt(this->Point1[0] - this->MaxLabel[0] - 10));
+    out.SetY(vtkContext2D::FloatToInt(this->Point1[1] + this->Point2[1]) / 2);
+  }
+  else if (this->Position == vtkAxis::RIGHT)
+  {
+    // Draw the axis label
+    out.SetX(vtkContext2D::FloatToInt(this->Point1[0] + this->MaxLabel[0] + 10));
+    out.SetY(vtkContext2D::FloatToInt(this->Point1[1] + this->Point2[1]) / 2);
+  }
+  else if (this->Position == vtkAxis::BOTTOM)
+  {
+    out.SetX(vtkContext2D::FloatToInt(this->Point1[0] + this->Point2[0]) / 2);
+    out.SetY(vtkContext2D::FloatToInt(this->Point1[1] - this->MaxLabel[1] - 10));
+  }
+  else if (this->Position == vtkAxis::TOP)
+  {
+    out.SetX(vtkContext2D::FloatToInt(this->Point1[0] + this->Point2[0]) / 2);
+    out.SetY(vtkContext2D::FloatToInt(this->Point1[1] + this->MaxLabel[1] + 10));
+  }
+  else if (this->Position == vtkAxis::PARALLEL)
+  {
+    out.SetX(vtkContext2D::FloatToInt(this->Point1[0]));
+    out.SetY(vtkContext2D::FloatToInt(this->Point1[1] - this->MaxLabel[1] - 15));
+  }
+}
+
+//------------------------------------------------------------------------------
+bool vtkAxis::InRange(double value)
 {
   // Figure out which way around the axes are, then see if the value is inside.
   double min(this->Minimum);
@@ -1847,25 +1862,14 @@ inline bool vtkAxis::InRange(double value)
     min = max;
     max = this->Minimum;
   }
-  if (value < min || value > max)
-  {
-    return false;
-  }
-  else
-  {
-    return true;
-  }
+  return min <= value && value <= max;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAxis::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  if (this->Title)
-  {
-    os << indent << "Title: \"" << *this->Title << "\""
-       << "\n";
-  }
+  os << indent << "Title: \"" << this->Title << "\"\n";
   os << indent << "Point1: " << this->Point1[0] << ", " << this->Point1[1] << "\n";
   os << indent << "Point2: " << this->Point2[0] << ", " << this->Point2[1] << "\n";
   os << indent << "Minimum: " << this->Minimum << "\n";
@@ -1937,3 +1941,4 @@ void vtkAxis::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "ScalingFactor: " << this->ScalingFactor << "\n";
   os << indent << "Shift: " << this->Shift << "\n";
 }
+VTK_ABI_NAMESPACE_END
