@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPlotBar.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 /**
  * @class   vtkPlotBar
@@ -29,6 +17,7 @@
 #include "vtkPlot.h"
 #include "vtkSmartPointer.h" // Needed to hold ColorSeries
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContext2D;
 class vtkTable;
 class vtkPoints2D;
@@ -59,11 +48,6 @@ public:
    */
   static vtkPlotBar* New();
 
-  /**
-   * Perform any updates to the item that may be necessary before rendering.
-   */
-  void Update() override;
-
   /**
    * Paint event for the XY plot, called whenever the chart needs to be drawn
    */
@@ -77,16 +61,33 @@ public:
    */
   bool PaintLegend(vtkContext2D* painter, const vtkRectf& rect, int legendIndex) override;
 
-  //@{
   /**
-   * Set the plot color
+   * Set the plot color with integer values (comprised between 0 and 255)
    */
   void SetColor(unsigned char r, unsigned char g, unsigned char b, unsigned char a) override;
-  void SetColor(double r, double g, double b) override;
-  void GetColor(double rgb[3]) override;
-  //@}
 
-  //@{
+  ///@{
+  /**
+   * Set the plot color with floating values (comprised between 0.0 and 1.0)
+   */
+  void SetColorF(double r, double g, double b, double a) override;
+  void SetColorF(double r, double g, double b) override;
+
+  VTK_DEPRECATED_IN_9_3_0("Please use unambiguous SetColorF method instead.")
+  void SetColor(double r, double g, double b) override { this->SetColorF(r, g, b); };
+  ///@}
+
+  ///@{
+  /**
+   * Get the plot color as floating rgb values (comprised between 0.0 and 1.0)
+   */
+  void GetColorF(double rgb[3]) override;
+
+  VTK_DEPRECATED_IN_9_3_0("Please use unambiguous GetColorF method instead.")
+  void GetColor(double rgb[3]) override { this->GetColorF(rgb); };
+  ///@}
+
+  ///@{
   /**
    * Set the width of the line.
    */
@@ -99,9 +100,9 @@ public:
       this->Modified();
     }
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the width of the line.
    */
@@ -111,9 +112,9 @@ public:
                   << this->Width);
     return this->Width;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the horizontal offset of the bars.
    * Positive values move the bars leftward.
@@ -122,16 +123,16 @@ public:
    */
   vtkSetMacro(Offset, float);
   vtkGetMacro(Offset, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the orientation of the bars.
    * Valid orientations are VERTICAL (default) and HORIZONTAL.
    */
   virtual void SetOrientation(int orientation);
   vtkGetMacro(Orientation, int);
-  //@}
+  ///@}
 
   /**
    * A helper used by both GetUnscaledBounds and GetBounds(double[4]).
@@ -163,13 +164,13 @@ public:
    */
   vtkColorSeries* GetColorSeries();
 
-  //@{
+  ///@{
   /**
    * Specify a lookup table for the mapper to use.
    */
   virtual void SetLookupTable(vtkScalarsToColors* lut);
   virtual vtkScalarsToColors* GetLookupTable();
-  //@}
+  ///@}
 
   /**
    * Create default lookup table. Generally used to create one when none
@@ -177,25 +178,25 @@ public:
    */
   virtual void CreateDefaultLookupTable();
 
-  //@{
+  ///@{
   /**
    * Turn on/off flag to control whether scalar data is used to color objects.
    */
   vtkSetMacro(ScalarVisibility, bool);
   vtkGetMacro(ScalarVisibility, bool);
   vtkBooleanMacro(ScalarVisibility, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable mapping of the opacity values. Default is set to true.
    */
   vtkSetMacro(EnableOpacityMapping, bool);
   vtkGetMacro(EnableOpacityMapping, bool);
   vtkBooleanMacro(EnableOpacityMapping, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * When ScalarMode is set to UsePointFieldData or UseCellFieldData,
    * you can specify which array to use for coloring using these methods.
@@ -203,7 +204,7 @@ public:
    */
   void SelectColorArray(vtkIdType arrayNum);
   void SelectColorArray(const vtkStdString& arrayName);
-  //@}
+  ///@}
 
   /**
    * Get the array name to color by.
@@ -244,17 +245,9 @@ public:
    * If a vtkIdType* is passed, its referent will be set to index of the bar
    * segment with which a point is associated, or -1.
    */
-  virtual vtkIdType GetNearestPoint(const vtkVector2f& point, const vtkVector2f&,
-    vtkVector2f* location,
-#ifndef VTK_LEGACY_REMOVE
-    vtkIdType* segmentId) override;
-#else
-    vtkIdType* segmentId = nullptr) override;
-#endif // VTK_LEGACY_REMOVE
-
-#ifndef VTK_LEGACY_REMOVE
+  vtkIdType GetNearestPoint(const vtkVector2f& point, const vtkVector2f&, vtkVector2f* location,
+    vtkIdType* segmentIndex) override;
   using vtkPlot::GetNearestPoint;
-#endif // VTK_LEGACY_REMOVE
 
   /**
    * Get amount of plotted bars.
@@ -266,14 +259,22 @@ public:
    */
   void GetDataBounds(double bounds[2]);
 
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  bool UpdateCache() override;
+
 protected:
   vtkPlotBar();
   ~vtkPlotBar() override;
 
   /**
-   * Update the table cache.
+   * Test if the internal cache requires an update.
    */
-  bool UpdateTableCache(vtkTable* table);
+  bool CacheRequiresUpdate() override;
 
   /**
    * Store a well packed set of XY coordinates for this data series.
@@ -285,17 +286,12 @@ protected:
 
   int Orientation;
 
-  /**
-   * The point cache is marked dirty until it has been initialized.
-   */
-  vtkTimeStamp BuildTime;
-
   /**
    * The color series to use if this becomes a stacked bar
    */
   vtkSmartPointer<vtkColorSeries> ColorSeries;
 
-  //@{
+  ///@{
   /**
    * Lookup Table for coloring bars by scalar value
    */
@@ -304,7 +300,7 @@ protected:
   bool ScalarVisibility;
   bool EnableOpacityMapping;
   vtkStdString ColorArrayName;
-  //@}
+  ///@}
 
   bool LogX;
   bool LogY;
@@ -316,4 +312,5 @@ private:
   vtkPlotBarPrivate* Private;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPlotBar_h
