@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPlotPie.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 /**
  * @class   vtkPlotPie
@@ -27,6 +15,7 @@
 #include "vtkPlot.h"
 #include "vtkSmartPointer.h" // To hold ColorSeries etc.
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContext2D;
 class vtkColorSeries;
 class vtkPoints2D;
@@ -66,13 +55,13 @@ public:
    */
   void SetDimensions(const int arg[4]);
 
-  //@{
+  ///@{
   /**
    * Get the dimensions of the pie, elements 0 and 1 are the x and y coordinate
    * of the bottom corner. Elements 2 and 3 are the width and height.
    */
   vtkGetVector4Macro(Dimensions, int);
-  //@}
+  ///@}
 
   /**
    * Set the color series to use for the Pie.
@@ -90,26 +79,21 @@ public:
    * -1.
    */
   vtkIdType GetNearestPoint(const vtkVector2f& point, const vtkVector2f& tolerance,
-    vtkVector2f* location,
-#ifndef VTK_LEGACY_REMOVE
-    vtkIdType* segmentId) override;
-#else
-    vtkIdType* segmentId = nullptr) override;
-#endif // VTK_LEGACY_REMOVE
-
-#ifndef VTK_LEGACY_REMOVE
+    vtkVector2f* location, vtkIdType* segmentId) override;
   using vtkPlot::GetNearestPoint;
-#endif // VTK_LEGACY_REMOVE
+
+  /**
+   * Update the internal cache. Returns true if cache was successfully updated. Default does
+   * nothing.
+   * This method is called by Update() when either the plot's data has changed or
+   * CacheRequiresUpdate() returns true. It is not necessary to call this method explicitly.
+   */
+  bool UpdateCache() override;
 
 protected:
   vtkPlotPie();
   ~vtkPlotPie() override;
 
-  /**
-   * Update the table cache.
-   */
-  bool UpdateTableCache(vtkTable* table);
-
   int Dimensions[4];
 
   /**
@@ -122,11 +106,6 @@ protected:
    */
   vtkPoints2D* Points;
 
-  /**
-   * The point cache is marked dirty until it has been initialized.
-   */
-  vtkTimeStamp BuildTime;
-
 private:
   vtkPlotPie(const vtkPlotPie&) = delete;
   void operator=(const vtkPlotPie&) = delete;
@@ -134,4 +113,5 @@ private:
   vtkPlotPiePrivate* Private;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkPlotPie_h
