@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkAbstractArray.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkAbstractArray.h"
 
 #include "vtkBitArray.h"
@@ -21,160 +10,175 @@
 #include "vtkIdList.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
+#include "vtkInformationDoubleVectorKey.h"
+#include "vtkInformationInformationVectorKey.h"
+#include "vtkInformationIntegerKey.h"
+#include "vtkInformationVariantVectorKey.h"
+#include "vtkInformationVector.h"
 #include "vtkIntArray.h"
 #include "vtkLongArray.h"
 #include "vtkLongLongArray.h"
 #include "vtkMath.h"
 #include "vtkMinimalStandardRandomSequence.h"
+#include "vtkNew.h"
 #include "vtkShortArray.h"
 #include "vtkSignedCharArray.h"
 #include "vtkStringArray.h"
-#include "vtkUnicodeStringArray.h"
+#include "vtkTypeFloat32Array.h"
+#include "vtkTypeFloat64Array.h"
+#include "vtkTypeInt16Array.h"
+#include "vtkTypeInt32Array.h"
+#include "vtkTypeInt64Array.h"
+#include "vtkTypeInt8Array.h"
+#include "vtkTypeUInt16Array.h"
+#include "vtkTypeUInt32Array.h"
+#include "vtkTypeUInt64Array.h"
+#include "vtkTypeUInt8Array.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
 #include "vtkUnsignedLongLongArray.h"
 #include "vtkUnsignedShortArray.h"
 #include "vtkVariantArray.h"
-#include "vtkInformationVector.h"
-#include "vtkInformationDoubleVectorKey.h"
-#include "vtkInformationIntegerKey.h"
-#include "vtkInformationInformationVectorKey.h"
-#include "vtkInformationVariantVectorKey.h"
-#include "vtkNew.h"
-#include "vtkUnicodeString.h" // for vtkSuperExtraExtendedTemplateMacro
 
 #include <algorithm>
+#include <cmath>
 #include <iterator>
 #include <set>
-#include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkInformationKeyMacro(vtkAbstractArray, GUI_HIDE, Integer);
 vtkInformationKeyMacro(vtkAbstractArray, PER_COMPONENT, InformationVector);
+vtkInformationKeyMacro(vtkAbstractArray, PER_FINITE_COMPONENT, InformationVector);
 vtkInformationKeyMacro(vtkAbstractArray, DISCRETE_VALUES, VariantVector);
-vtkInformationKeyRestrictedMacro(vtkAbstractArray, DISCRETE_VALUE_SAMPLE_PARAMETERS, DoubleVector, 2);
+vtkInformationKeyRestrictedMacro(
+  vtkAbstractArray, DISCRETE_VALUE_SAMPLE_PARAMETERS, DoubleVector, 2);
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
-  typedef  std::vector< vtkStdString* > vtkInternalComponentNameBase;
+typedef std::vector<std::string*> vtkInternalComponentNameBase;
 }
-class vtkAbstractArray::vtkInternalComponentNames : public vtkInternalComponentNameBase {};
 
-//----------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
+class vtkAbstractArray::vtkInternalComponentNames : public vtkInternalComponentNameBase
+{
+};
+
+//------------------------------------------------------------------------------
 // Construct object with sane defaults.
 vtkAbstractArray::vtkAbstractArray()
 {
   this->Size = 0;
   this->MaxId = -1;
   this->NumberOfComponents = 1;
-  this->Name = NULL;
+  this->Name = nullptr;
   this->RebuildArray = false;
-  this->Information = NULL;
-  this->ComponentNames = NULL;
+  this->Information = nullptr;
+  this->ComponentNames = nullptr;
 
-  this->MaxDiscreteValues = vtkAbstractArray::MAX_DISCRETE_VALUES; //32
+  this->MaxDiscreteValues = vtkAbstractArray::MAX_DISCRETE_VALUES; // 32
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractArray::~vtkAbstractArray()
 {
-  if ( this->ComponentNames )
+  if (this->ComponentNames)
   {
-    for ( unsigned int i=0; i < this->ComponentNames->size(); ++i)
+    for (unsigned int i = 0; i < this->ComponentNames->size(); ++i)
     {
       delete this->ComponentNames->at(i);
     }
     this->ComponentNames->clear();
     delete this->ComponentNames;
-    this->ComponentNames = NULL;
+    this->ComponentNames = nullptr;
   }
 
-  this->SetName(NULL);
-  this->SetInformation(NULL);
+  this->SetName(nullptr);
+  this->SetInformation(nullptr);
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractArray::SetComponentName( vtkIdType component, const char *name )
+//------------------------------------------------------------------------------
+void vtkAbstractArray::SetComponentName(vtkIdType component, const char* name)
 {
-  if ( component < 0 || name == NULL )
+  if (component < 0 || name == nullptr)
   {
     return;
   }
-  unsigned int index = static_cast<unsigned int>( component );
-  if ( this->ComponentNames == NULL )
+  unsigned int index = static_cast<unsigned int>(component);
+  if (this->ComponentNames == nullptr)
   {
-    //delayed allocate
+    // delayed allocate
     this->ComponentNames = new vtkAbstractArray::vtkInternalComponentNames();
   }
 
-  if ( index == this->ComponentNames->size() )
+  if (index == this->ComponentNames->size())
   {
-    //the array isn't large enough, so we will resize
-    this->ComponentNames->push_back( new vtkStdString(name) );
+    // the array isn't large enough, so we will resize
+    this->ComponentNames->push_back(new std::string(name));
     return;
   }
-  else if ( index > this->ComponentNames->size() )
+  else if (index > this->ComponentNames->size())
   {
-    this->ComponentNames->resize( index+1, NULL );
+    this->ComponentNames->resize(index + 1, nullptr);
   }
 
-  //replace an exisiting element
-  vtkStdString *compName = this->ComponentNames->at(index);
-  if ( !compName )
+  // replace an existing element
+  std::string* compName = this->ComponentNames->at(index);
+  if (!compName)
   {
-    compName = new vtkStdString(name);
+    compName = new std::string(name);
     this->ComponentNames->at(index) = compName;
   }
   else
   {
-    compName->assign( name );
+    compName->assign(name);
   }
 }
 
-//----------------------------------------------------------------------------
-const char* vtkAbstractArray::GetComponentName( vtkIdType component )
+//------------------------------------------------------------------------------
+const char* vtkAbstractArray::GetComponentName(vtkIdType component) const
 {
-  unsigned int index = static_cast<unsigned int>( component );
-  if ( !this->ComponentNames || component < 0 ||
-    index >= this->ComponentNames->size() )
+  unsigned int index = static_cast<unsigned int>(component);
+  if (!this->ComponentNames || component < 0 || index >= this->ComponentNames->size())
   {
-    //make sure we have valid vector
-    return NULL;
+    // make sure we have valid vector
+    return nullptr;
   }
 
-  vtkStdString *compName = this->ComponentNames->at( index );
-  return ( compName ) ? compName->c_str() : NULL;
+  std::string* compName = this->ComponentNames->at(index);
+  return (compName) ? compName->c_str() : nullptr;
 }
 
-//----------------------------------------------------------------------------
-bool vtkAbstractArray::HasAComponentName()
+//------------------------------------------------------------------------------
+bool vtkAbstractArray::HasAComponentName() const
 {
-  return (this->ComponentNames) ? ( this->ComponentNames->size() > 0 ) : 0;
+  return this->ComponentNames && !this->ComponentNames->empty();
 }
 
-//----------------------------------------------------------------------------
-int vtkAbstractArray::CopyComponentNames( vtkAbstractArray *da )
+//------------------------------------------------------------------------------
+int vtkAbstractArray::CopyComponentNames(vtkAbstractArray* da)
 {
-  if (  da && da != this && da->ComponentNames )
+  if (da && da != this && da->ComponentNames)
   {
-    //clear the vector of the all data
-    if ( !this->ComponentNames )
+    // clear the vector of the all data
+    if (!this->ComponentNames)
     {
       this->ComponentNames = new vtkAbstractArray::vtkInternalComponentNames();
     }
 
-    //copy the passed in components
-    for ( unsigned int i=0; i < this->ComponentNames->size(); ++i)
+    // copy the passed in components
+    for (unsigned int i = 0; i < this->ComponentNames->size(); ++i)
     {
       delete this->ComponentNames->at(i);
     }
     this->ComponentNames->clear();
-    this->ComponentNames->reserve( da->ComponentNames->size() );
-    const char *name;
-    for ( unsigned int i = 0; i < da->ComponentNames->size(); ++i )
+    this->ComponentNames->reserve(da->ComponentNames->size());
+    const char* name;
+    for (unsigned int i = 0; i < da->ComponentNames->size(); ++i)
     {
       name = da->GetComponentName(i);
-      if ( name )
+      if (name)
       {
         this->SetComponentName(i, name);
       }
@@ -184,36 +188,44 @@ int vtkAbstractArray::CopyComponentNames( vtkAbstractArray *da )
   return 0;
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractArray::SetNumberOfValues(vtkIdType numValues)
+//------------------------------------------------------------------------------
+bool vtkAbstractArray::SetNumberOfValues(vtkIdType numValues)
 {
-  if (this->Resize(std::ceil(numValues /
-                             static_cast<float>(this->NumberOfComponents))))
+  vtkIdType numTuples = numValues / this->NumberOfComponents;
+  if (numValues % this->NumberOfComponents)
   {
-    this->MaxId = numValues - 1;
+    ++numTuples;
   }
+  if (!this->Resize(numTuples))
+  {
+    return false;
+  }
+  this->MaxId = numValues - 1;
+  return true;
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractArray::SetInformation(vtkInformation *args)
+//------------------------------------------------------------------------------
+void vtkAbstractArray::SetInformation(vtkInformation* args)
 {
   // Same as in vtkCxxSetObjectMacro, but no Modified() so that
   // this doesn't cause extra pipeline updates.
-  vtkDebugMacro(<< this->GetClassName() << " (" << this
-      << "): setting Information to " << args );
+  vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting Information to " << args);
   if (this->Information != args)
   {
     vtkInformation* tempSGMacroVar = this->Information;
     this->Information = args;
-    if (this->Information != NULL) { this->Information->Register(this); }
-    if (tempSGMacroVar != NULL)
+    if (this->Information != nullptr)
+    {
+      this->Information->Register(this);
+    }
+    if (tempSGMacroVar != nullptr)
     {
       tempSGMacroVar->UnRegister(this);
     }
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAbstractArray::GetTuples(vtkIdList* tupleIds, vtkAbstractArray* aa)
 {
   if (aa->GetNumberOfComponents() != this->GetNumberOfComponents())
@@ -230,9 +242,8 @@ void vtkAbstractArray::GetTuples(vtkIdList* tupleIds, vtkAbstractArray* aa)
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractArray::GetTuples(vtkIdType p1, vtkIdType p2,
-  vtkAbstractArray* aa)
+//------------------------------------------------------------------------------
+void vtkAbstractArray::GetTuples(vtkIdType p1, vtkIdType p2, vtkAbstractArray* aa)
 {
   if (aa->GetNumberOfComponents() != this->GetNumberOfComponents())
   {
@@ -245,18 +256,18 @@ void vtkAbstractArray::GetTuples(vtkIdType p1, vtkIdType p2,
   vtkIdType num = p2 - p1 + 1;
   for (vtkIdType i = 0; i < num; i++)
   {
-    aa->SetTuple(i, (p1+i), this);
+    aa->SetTuple(i, (p1 + i), this);
   }
 }
 
-//----------------------------------------------------------------------------
-bool vtkAbstractArray::HasStandardMemoryLayout()
+//------------------------------------------------------------------------------
+bool vtkAbstractArray::HasStandardMemoryLayout() const
 {
   return true;
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractArray::DeepCopy( vtkAbstractArray* da )
+//------------------------------------------------------------------------------
+void vtkAbstractArray::DeepCopy(vtkAbstractArray* da)
 {
   if (!da || da == this)
   {
@@ -265,62 +276,71 @@ void vtkAbstractArray::DeepCopy( vtkAbstractArray* da )
 
   if (da->HasInformation())
   {
-    this->CopyInformation(da->GetInformation(),/*deep=*/1);
+    this->CopyInformation(da->GetInformation(), /*deep=*/1);
   }
   else
   {
-    this->SetInformation(NULL);
+    this->SetInformation(nullptr);
   }
 
   this->SetName(da->Name);
 
-  this->CopyComponentNames( da );
+  this->CopyComponentNames(da);
 }
 
-//----------------------------------------------------------------------------
-void vtkAbstractArray::ExportToVoidPointer(void *dest)
+//------------------------------------------------------------------------------
+void vtkAbstractArray::ExportToVoidPointer(void* dest)
 {
   if (this->MaxId > 0 && this->GetDataTypeSize() > 0)
   {
-    void *src = this->GetVoidPointer(0);
+    void* src = this->GetVoidPointer(0);
     memcpy(dest, src, ((this->MaxId + 1) * this->GetDataTypeSize()));
   }
 }
 
-//----------------------------------------------------------------------------
-int vtkAbstractArray::CopyInformation(vtkInformation* infoFrom, int deep)
+//------------------------------------------------------------------------------
+int vtkAbstractArray::CopyInformation(vtkInformation* infoFrom, vtkTypeBool deep)
 {
   // Copy all keys. NOTE: subclasses rely on this.
-  vtkInformation* myInfo=this->GetInformation();
-  myInfo->Copy(infoFrom,deep);
+  vtkInformation* myInfo = this->GetInformation();
+  myInfo->Copy(infoFrom, deep);
 
   // Remove any keys we own that are not to be copied here.
   // For now, remove per-component metadata.
-  if (myInfo->Has(PER_COMPONENT()))
-  {
-    myInfo->Remove(PER_COMPONENT());
-  }
-  if (myInfo->Has(DISCRETE_VALUES()))
-  {
-    myInfo->Remove(DISCRETE_VALUES());
-  }
+  myInfo->Remove(PER_COMPONENT());
+  myInfo->Remove(PER_FINITE_COMPONENT());
+  myInfo->Remove(DISCRETE_VALUES());
 
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+// call modified on superclass
+void vtkAbstractArray::Modified()
+{
+  if (this->HasInformation())
+  {
+    vtkInformation* info = this->GetInformation();
+    // Clear key-value pairs that are now out of date.
+    info->Remove(PER_COMPONENT());
+    info->Remove(PER_FINITE_COMPONENT());
+  }
+  this->Superclass::Modified();
+}
+
+//------------------------------------------------------------------------------
 vtkInformation* vtkAbstractArray::GetInformation()
 {
-  if ( ! this->Information )
+  if (!this->Information)
   {
     vtkInformation* info = vtkInformation::New();
-    this->SetInformation( info );
+    this->SetInformation(info);
     info->FastDelete();
   }
   return this->Information;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 int vtkAbstractArrayGetDataTypeSize(T*)
 {
@@ -331,25 +351,60 @@ int vtkAbstractArray::GetDataTypeSize(int type)
 {
   switch (type)
   {
-    vtkTemplateMacro(
-      return vtkAbstractArrayGetDataTypeSize(static_cast<VTK_TT*>(0))
-      );
+    vtkTemplateMacro(return vtkAbstractArrayGetDataTypeSize(static_cast<VTK_TT*>(nullptr)));
 
     case VTK_BIT:
     case VTK_STRING:
-    case VTK_UNICODE_STRING:
       return 0;
 
     default:
-      vtkGenericWarningMacro(<<"Unsupported data type!");
+      vtkGenericWarningMacro(<< "Unsupported data type!");
   }
 
   return 1;
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractArray* vtkAbstractArray::CreateArray(int dataType)
 {
+  // First we check IntT and FloatN type to allow downcasting to such array types.
+  switch (dataType)
+  {
+    case VTK_TYPE_UINT8:
+      return vtkTypeUInt8Array::New();
+
+    case VTK_TYPE_INT8:
+      return vtkTypeInt8Array::New();
+
+    case VTK_TYPE_UINT16:
+      return vtkTypeUInt16Array::New();
+
+    case VTK_TYPE_INT16:
+      return vtkTypeInt16Array::New();
+
+    case VTK_TYPE_UINT32:
+      return vtkTypeUInt32Array::New();
+
+    case VTK_TYPE_INT32:
+      return vtkTypeInt32Array::New();
+
+    case VTK_TYPE_UINT64:
+      return vtkTypeUInt64Array::New();
+
+    case VTK_TYPE_INT64:
+      return vtkTypeInt64Array::New();
+
+    case VTK_TYPE_FLOAT32:
+      return vtkTypeFloat32Array::New();
+
+    case VTK_TYPE_FLOAT64:
+      return vtkTypeFloat64Array::New();
+
+    default:
+      break;
+  }
+
+  // Didn't find any IntN or FloatN? The array we want should be down there.
   switch (dataType)
   {
     case VTK_BIT:
@@ -400,9 +455,6 @@ vtkAbstractArray* vtkAbstractArray::CreateArray(int dataType)
     case VTK_STRING:
       return vtkStringArray::New();
 
-    case VTK_UNICODE_STRING:
-      return vtkUnicodeStringArray::New();
-
     case VTK_VARIANT:
       return vtkVariantArray::New();
 
@@ -410,34 +462,33 @@ vtkAbstractArray* vtkAbstractArray::CreateArray(int dataType)
       break;
   }
 
-  vtkGenericWarningMacro("Unsupported data type: " << dataType
-                         << "! Setting to VTK_DOUBLE");
+  vtkGenericWarningMacro("Unsupported data type: " << dataType << "! Setting to VTK_DOUBLE");
   return vtkDoubleArray::New();
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
 vtkVariant vtkAbstractArrayGetVariantValue(T* arr, vtkIdType index)
 {
   return vtkVariant(arr[index]);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVariant vtkAbstractArray::GetVariantValue(vtkIdType valueIdx)
 {
   vtkVariant val;
-  switch(this->GetDataType())
+  switch (this->GetDataType())
   {
     vtkExtraExtendedTemplateMacro(val = vtkAbstractArrayGetVariantValue(
-      static_cast<VTK_TT*>(this->GetVoidPointer(0)), valueIdx));
+                                    static_cast<VTK_TT*>(this->GetVoidPointer(0)), valueIdx));
   }
   return val;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAbstractArray::PrintSelf(ostream& os, vtkIndent indent)
 {
-  this->Superclass::PrintSelf(os,indent);
+  this->Superclass::PrintSelf(os, indent);
 
   const char* name = this->GetName();
   if (name)
@@ -452,26 +503,50 @@ void vtkAbstractArray::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Size: " << this->Size << "\n";
   os << indent << "MaxId: " << this->MaxId << "\n";
   os << indent << "NumberOfComponents: " << this->NumberOfComponents << endl;
-  if ( this->ComponentNames )
+  if (this->ComponentNames)
   {
     os << indent << "ComponentNames: " << endl;
     vtkIndent nextIndent = indent.GetNextIndent();
-    for ( unsigned int i=0; i < this->ComponentNames->size(); ++i )
+    for (unsigned int i = 0; i < this->ComponentNames->size(); ++i)
     {
       os << nextIndent << i << " : " << this->ComponentNames->at(i) << endl;
     }
   }
   os << indent << "Information: " << this->Information << endl;
-  if ( this->Information )
+  if (this->Information)
   {
-    this->Information->PrintSelf( os, indent.GetNextIndent() );
+    this->Information->PrintSelf(os, indent.GetNextIndent());
   }
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+const char* vtkAbstractArray::GetArrayTypeAsString() const
+{
+  switch (this->GetArrayType())
+  {
+    case AbstractArray:
+      return "AbstractArray";
+    case DataArray:
+      return "DataArray";
+    case AoSDataArrayTemplate:
+      return "AoSDataArrayTemplate";
+    case SoADataArrayTemplate:
+      return "SoADataArrayTemplate";
+    case TypedDataArray:
+      return "TypedDataArray";
+    case MappedDataArray:
+      return "MappedDataArray";
+    case ScaleSoADataArrayTemplate:
+      return "ScaleSoADataArrayTemplate";
+    case ImplicitArray:
+      return "ImplicitArray";
+  }
+  return "Unknown";
+}
+
+//------------------------------------------------------------------------------
 void vtkAbstractArray::GetProminentComponentValues(
-  int comp, vtkVariantArray* values,
-  double uncertainty, double minimumProminence)
+  int comp, vtkVariantArray* values, double uncertainty, double minimumProminence)
 {
   if (!values || comp < -1 || comp >= this->NumberOfComponents)
   {
@@ -483,14 +558,14 @@ void vtkAbstractArray::GetProminentComponentValues(
 
   bool justCreated = false;
   vtkInformation* info = this->GetInformation();
-  const double* lastParams = info ?
-    (info->Has(DISCRETE_VALUE_SAMPLE_PARAMETERS()) ?
-     info->Get(DISCRETE_VALUE_SAMPLE_PARAMETERS()) : 0) : 0;
+  const double* lastParams = info
+    ? (info->Has(DISCRETE_VALUE_SAMPLE_PARAMETERS()) ? info->Get(DISCRETE_VALUE_SAMPLE_PARAMETERS())
+                                                     : nullptr)
+    : nullptr;
   if (comp >= 0 && info)
   {
     vtkInformationVector* infoVec = info->Get(PER_COMPONENT());
-    if (!infoVec ||
-      infoVec->GetNumberOfInformationObjects() < this->NumberOfComponents)
+    if (!infoVec || infoVec->GetNumberOfInformationObjects() < this->NumberOfComponents)
     {
       infoVec = vtkInformationVector::New();
       infoVec->SetNumberOfInformationObjects(this->NumberOfComponents);
@@ -515,17 +590,12 @@ void vtkAbstractArray::GetProminentComponentValues(
     }
     // Are parameter values requesting more certainty in reporting or
     // that less-prominent values be reported? If so, recompute.
-    bool tighterParams = lastParams ?
-      (lastParams[0] > uncertainty ||
-       lastParams[1] > minimumProminence ?
-       true :
-       false)
-      : true;
+    bool tighterParams =
+      lastParams ? (lastParams[0] > uncertainty || lastParams[1] > minimumProminence) : true;
     // Recompute discrete value set when the array has been
     // modified since the information was written.
-    if (
-      !info->Has(DISCRETE_VALUES()) || tighterParams ||
-      this->GetMTime() > info->GetMTime() || justCreated)
+    if (!info->Has(DISCRETE_VALUES()) || tighterParams || this->GetMTime() > info->GetMTime() ||
+      justCreated)
     {
       this->UpdateDiscreteValueSet(uncertainty, minimumProminence);
     }
@@ -537,7 +607,7 @@ void vtkAbstractArray::GetProminentComponentValues(
 
   vtkIdType len;
   const vtkVariant* vals = info->Get(DISCRETE_VALUES());
-  if (vals != NULL)
+  if (vals != nullptr)
   {
     len = info->Length(DISCRETE_VALUES());
     values->SetNumberOfTuples(len / values->GetNumberOfComponents());
@@ -547,20 +617,43 @@ void vtkAbstractArray::GetProminentComponentValues(
     }
   }
 }
+VTK_ABI_NAMESPACE_END
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
-template<typename T>
-bool AccumulateSampleValues(
-  T* array, int nc, vtkIdType begin, vtkIdType end,
-  std::vector<std::set<T> >& uniques, std::set<std::vector<T> >& tupleUniques,
+template <typename T, bool U = std::numeric_limits<T>::has_quiet_NaN>
+struct CompareWithNaN
+{
+  bool operator()(T a, T b) const
+  {
+    if (std::isnan(a))
+    {
+      return false;
+    }
+    if (std::isnan(b))
+    {
+      return true;
+    }
+    return a < b;
+  }
+};
+
+template <typename T>
+struct CompareWithNaN<T, false>
+{
+  bool operator()(T a, T b) const { return a < b; }
+};
+
+template <typename T>
+bool AccumulateSampleValues(T* array, int nc, vtkIdType begin, vtkIdType end,
+  std::vector<std::set<T, CompareWithNaN<T>>>& uniques, std::set<std::vector<T>>& tupleUniques,
   unsigned int maxDiscreteValues)
 {
   // number of discrete components remaining (tracked during iteration):
   int ndc = nc;
-  std::pair<typename std::set<T>::iterator,bool> result;
-  std::pair<typename std::set<std::vector<T> >::iterator,bool> tresult;
+  std::pair<typename std::set<T>::iterator, bool> result;
+  std::pair<typename std::set<std::vector<T>>::iterator, bool> tresult;
   std::vector<T> tuple;
   tuple.resize(nc);
   // Here we iterate over the components and add to their respective lists
@@ -571,7 +664,7 @@ bool AccumulateSampleValues(
   for (vtkIdType i = begin; i < end && ndc; ++i)
   {
     // First, attempt a per-component insert.
-    for (int j = 0; j < nc; ++ j)
+    for (int j = 0; j < nc; ++j)
     {
       if (uniques[j].size() > maxDiscreteValues)
         continue;
@@ -582,13 +675,13 @@ bool AccumulateSampleValues(
       {
         if (uniques[j].size() == maxDiscreteValues + 1)
         {
-          -- ndc;
+          --ndc;
         }
       }
     }
     // Now, as long as no component has exceeded maxDiscreteValues unique
     // values, it is worth seeing whether the tuple as a whole is unique:
-    if ( nc > 1 && ndc == nc )
+    if (nc > 1 && ndc == nc)
     {
       tresult = tupleUniques.insert(tuple);
       (void)tresult; // nice to have when debugging.
@@ -597,38 +690,32 @@ bool AccumulateSampleValues(
   return ndc == 0;
 }
 
-//-----------------------------------------------------------------------------
-template<typename U>
-void SampleProminentValues(
-  std::vector<std::vector<vtkVariant> >& uniques, vtkIdType maxId,
-  int nc, vtkIdType nt, int blockSize, vtkIdType numberOfBlocks, U* ptr,
-  unsigned int maxDiscreteValues)
+//------------------------------------------------------------------------------
+template <typename U>
+void SampleProminentValues(std::vector<std::vector<vtkVariant>>& uniques, vtkIdType maxId, int nc,
+  vtkIdType nt, int blockSize, vtkIdType numberOfBlocks, U* ptr, unsigned int maxDiscreteValues)
 {
-  std::vector<std::set<U> > typeSpecificUniques;
-  std::set<std::vector<U> > typeSpecificUniqueTuples;
+  std::vector<std::set<U, CompareWithNaN<U>>> typeSpecificUniques;
+  std::set<std::vector<U>> typeSpecificUniqueTuples;
   typeSpecificUniques.resize(nc);
   // I. Accumulate samples for all components plus the tuple,
   //    either for the full array or a random subset.
   if (numberOfBlocks * blockSize > maxId / 2)
   { // Awwww, just do the whole array already!
     AccumulateSampleValues(
-      ptr, nc, 0, nt,
-      typeSpecificUniques, typeSpecificUniqueTuples, maxDiscreteValues);
+      ptr, nc, 0, nt, typeSpecificUniques, typeSpecificUniqueTuples, maxDiscreteValues);
   }
   else
   { // Choose random blocks
     vtkNew<vtkMinimalStandardRandomSequence> seq;
     // test different blocks each time we're called:
     seq->SetSeed(static_cast<int>(seq->GetMTime()) ^ 0xdeadbeef);
-    vtkIdType totalBlockCount =
-      nt / blockSize +
-      (nt % blockSize ? 1 : 0);
+    vtkIdType totalBlockCount = nt / blockSize + (nt % blockSize ? 1 : 0);
     std::set<vtkIdType> startTuples;
     // Sort the list of blocks we'll search to maintain cache coherence.
-    for (int i = 0; i < numberOfBlocks; ++ i, seq->Next())
+    for (int i = 0; i < numberOfBlocks; ++i, seq->Next())
     {
-      vtkIdType startTuple =
-        static_cast<vtkIdType>(seq->GetValue() * totalBlockCount) * blockSize;
+      vtkIdType startTuple = static_cast<vtkIdType>(seq->GetValue() * totalBlockCount) * blockSize;
       startTuples.insert(startTuple);
     }
     // Now iterate over the blocks, accumulating unique values and tuples.
@@ -638,9 +725,8 @@ void SampleProminentValues(
       vtkIdType startTuple = *blkIt;
       vtkIdType endTuple = startTuple + blockSize;
       endTuple = endTuple < nt ? endTuple : nt;
-      bool endEarly = AccumulateSampleValues(
-        ptr, nc, startTuple, endTuple,
-        typeSpecificUniques, typeSpecificUniqueTuples, maxDiscreteValues);
+      bool endEarly = AccumulateSampleValues(ptr, nc, startTuple, endTuple, typeSpecificUniques,
+        typeSpecificUniqueTuples, maxDiscreteValues);
       if (endEarly)
         break;
     }
@@ -652,27 +738,24 @@ void SampleProminentValues(
   // Handle per-component uniques first
   for (int i = 0; i < nc; ++i)
   {
-    std::back_insert_iterator<std::vector<vtkVariant> > bi(uniques[i]);
+    std::back_insert_iterator<std::vector<vtkVariant>> bi(uniques[i]);
     std::copy(typeSpecificUniques[i].begin(), typeSpecificUniques[i].end(), bi);
   }
 
   // Now squash any tuple-wide uniques into
   // the final entry of the outer vector.
-  typename std::set<std::vector<U> >::iterator si;
-  for (
-    si = typeSpecificUniqueTuples.begin();
-    si != typeSpecificUniqueTuples.end();
-    ++si)
+  typename std::set<std::vector<U>>::iterator si;
+  for (si = typeSpecificUniqueTuples.begin(); si != typeSpecificUniqueTuples.end(); ++si)
   {
-    std::back_insert_iterator<std::vector<vtkVariant> > bi(uniques[nc]);
+    std::back_insert_iterator<std::vector<vtkVariant>> bi(uniques[nc]);
     std::copy(si->begin(), si->end(), bi);
   }
 }
 } // End anonymous namespace.
 
-//-----------------------------------------------------------------------------
-void vtkAbstractArray::UpdateDiscreteValueSet(
-  double uncertainty, double minimumProminence)
+VTK_ABI_NAMESPACE_BEGIN
+//------------------------------------------------------------------------------
+void vtkAbstractArray::UpdateDiscreteValueSet(double uncertainty, double minimumProminence)
 {
   // For an array with T tuples and given uncertainty U and mininumum
   // prominence P, we sample N blocks of M tuples each, with
@@ -685,31 +768,30 @@ void vtkAbstractArray::UpdateDiscreteValueSet(
   //
   // N is chosen to satisfy the requested uncertainty and prominence criteria
   // specified.
-#define VTK_CACHE_LINE_SIZE 64
-#define VTK_SAMPLE_FACTOR 5
+  constexpr int cacheLineSize = 64;
+  constexpr int sampleFactor = 5;
+
   // I. Determine the granularity at which the array should be sampled.
-  int numberOfComponentsWithProminentValues = 0;
   int nc = this->NumberOfComponents;
-  int blockSize = VTK_CACHE_LINE_SIZE / (this->GetDataTypeSize() * nc);
-  if (!blockSize) blockSize = 4;
+  int blockSize = cacheLineSize / (this->GetDataTypeSize() * nc);
+  if (!blockSize)
+  {
+    blockSize = 4;
+  }
   double logfac = 1.;
   vtkIdType nt = this->GetNumberOfTuples();
-  if (this->MaxId > 0)
+  vtkIdType numberOfSampleTuples = nt;
+  if (this->MaxId > 0 && minimumProminence > 0.0)
   {
     logfac = -log(uncertainty * minimumProminence) / minimumProminence;
     if (logfac < 0)
     {
       logfac = -logfac;
     }
-  }
-  vtkIdType numberOfSampleTuples;
-  if (vtkMath::IsInf(logfac))
-  {
-    numberOfSampleTuples = nt;
-  }
-  else
-  {
-    numberOfSampleTuples = static_cast<vtkIdType>(VTK_SAMPLE_FACTOR * logfac);
+    if (!vtkMath::IsInf(logfac))
+    {
+      numberOfSampleTuples = static_cast<vtkIdType>(sampleFactor * logfac);
+    }
   }
   /*
   // Theoretically, we should discard values or tuples that recur fewer
@@ -719,27 +801,21 @@ void vtkAbstractArray::UpdateDiscreteValueSet(
     numberOfSampleTuples * minimumProminence / 2);
     */
   vtkIdType numberOfBlocks =
-    numberOfSampleTuples / blockSize +
-    (numberOfSampleTuples % blockSize ? 1 : 0);
-  if (static_cast<unsigned int>(numberOfBlocks * blockSize) <
-      2 * this->MaxDiscreteValues)
+    numberOfSampleTuples / blockSize + (numberOfSampleTuples % blockSize ? 1 : 0);
+  if (static_cast<unsigned int>(numberOfBlocks * blockSize) < 2 * this->MaxDiscreteValues)
   {
     numberOfBlocks =
-      2 * this->MaxDiscreteValues / blockSize +
-      (2 * this->MaxDiscreteValues % blockSize ? 1 : 0);
+      2 * this->MaxDiscreteValues / blockSize + (2 * this->MaxDiscreteValues % blockSize ? 1 : 0);
   }
   // II. Sample the array.
-  std::vector<std::vector<vtkVariant> > uniques(nc > 1 ? nc + 1 : nc);
-  switch(this->GetDataType())
+  std::vector<std::vector<vtkVariant>> uniques(nc > 1 ? nc + 1 : nc);
+  switch (this->GetDataType())
   {
-    vtkSuperExtraExtendedTemplateMacro(
-      SampleProminentValues(
-        uniques, this->MaxId, nc, nt, blockSize, numberOfBlocks,
-        static_cast<VTK_TT*>(this->GetVoidPointer(0)),
-        this->MaxDiscreteValues));
-  default:
-    vtkErrorMacro("Array type " << this->GetClassName() << " not supported.");
-    break;
+    vtkExtraExtendedTemplateMacro(SampleProminentValues(uniques, this->MaxId, nc, nt, blockSize,
+      numberOfBlocks, static_cast<VTK_TT*>(this->GetVoidPointer(0)), this->MaxDiscreteValues));
+    default:
+      vtkErrorMacro("Array type " << this->GetClassName() << " not supported.");
+      break;
   }
 
   // III. Store the results in the array's vtkInformation.
@@ -747,38 +823,32 @@ void vtkAbstractArray::UpdateDiscreteValueSet(
   vtkInformationVector* iv;
   for (c = 0; c < nc; ++c)
   {
-    if (uniques[c].size() <= this->MaxDiscreteValues)
+    if (!uniques[c].empty() && uniques[c].size() <= this->MaxDiscreteValues)
     {
-      ++ numberOfComponentsWithProminentValues;
       iv = this->GetInformation()->Get(PER_COMPONENT());
       if (!iv)
       {
         vtkNew<vtkInformationVector> infoVec;
         infoVec->SetNumberOfInformationObjects(this->NumberOfComponents);
-        this->GetInformation()->Set(PER_COMPONENT(), infoVec.GetPointer());
+        this->GetInformation()->Set(PER_COMPONENT(), infoVec);
         iv = this->GetInformation()->Get(PER_COMPONENT());
       }
       iv->GetInformationObject(c)->Set(
-        DISCRETE_VALUES(), &uniques[c][0],
-        static_cast<int>(uniques[c].size()));
+        DISCRETE_VALUES(), uniques[c].data(), static_cast<int>(uniques[c].size()));
     }
     else
     {
       iv = this->GetInformation()->Get(PER_COMPONENT());
       if (iv)
       {
-        iv->GetInformationObject(c)->Remove(
-          DISCRETE_VALUES());
+        iv->GetInformationObject(c)->Remove(DISCRETE_VALUES());
       }
     }
   }
-  if (nc > 1 &&
-    uniques[nc].size() <= this->MaxDiscreteValues * nc)
+  if (nc > 1 && uniques[nc].size() <= this->MaxDiscreteValues * nc)
   {
-    ++ numberOfComponentsWithProminentValues;
     this->GetInformation()->Set(
-      DISCRETE_VALUES(), &uniques[nc][0],
-      static_cast<int>(uniques[nc].size()));
+      DISCRETE_VALUES(), uniques[nc].data(), static_cast<int>(uniques[nc].size()));
   }
   else
   { // Remove the key
@@ -790,6 +860,6 @@ void vtkAbstractArray::UpdateDiscreteValueSet(
   double params[2];
   params[0] = uncertainty;
   params[1] = minimumProminence;
-  this->GetInformation()->Set(
-    DISCRETE_VALUE_SAMPLE_PARAMETERS(), params, 2);
+  this->GetInformation()->Set(DISCRETE_VALUE_SAMPLE_PARAMETERS(), params, 2);
 }
+VTK_ABI_NAMESPACE_END
