@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkDataArrayTupleRange_AOS.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * Specialization of tuple ranges and iterators for vtkAOSDataArrayTemplate.
  */
@@ -22,14 +10,13 @@
 #include "vtkAOSDataArrayTemplate.h"
 #include "vtkDataArrayMeta.h"
 #include "vtkDataArrayTupleRange_Generic.h"
+#include "vtkDebugRangeIterators.h"
 
 #include <algorithm>
 #include <cassert>
 #include <iterator>
 #include <type_traits>
 
-#ifndef __VTK_WRAP__
-
 // Disable this specialization when iterator debugging is requested:
 #ifndef VTK_DEBUG_RANGE_ITERATORS
 
@@ -37,9 +24,9 @@ VTK_ITER_OPTIMIZE_START
 
 namespace vtk
 {
-
 namespace detail
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 // Forward decs for friends/args
 template <typename ArrayType, ComponentIdType>
@@ -71,7 +58,10 @@ public:
   using const_iterator = const ValueType*;
 
   VTK_ITER_INLINE
-  ConstTupleReference() noexcept : Tuple{ nullptr } {}
+  ConstTupleReference() noexcept
+    : Tuple{ nullptr }
+  {
+  }
 
   VTK_ITER_INLINE
   ConstTupleReference(const ValueType* tuple, NumCompsType numComps) noexcept
@@ -253,7 +243,10 @@ public:
   using const_reference = ValueType const&;
 
   VTK_ITER_INLINE
-  TupleReference() noexcept : Tuple{ nullptr } {}
+  TupleReference() noexcept
+    : Tuple{ nullptr }
+  {
+  }
 
   VTK_ITER_INLINE
   TupleReference(ValueType* tuple, NumCompsType numComps) noexcept
@@ -542,35 +535,32 @@ protected:
 // Const tuple iterator
 template <typename ValueType, ComponentIdType TupleSize>
 struct ConstTupleIterator<vtkAOSDataArrayTemplate<ValueType>, TupleSize>
-  : public std::iterator<std::random_access_iterator_tag,
-      ConstTupleReference<vtkAOSDataArrayTemplate<ValueType>, TupleSize>, TupleIdType,
-      ConstTupleReference<vtkAOSDataArrayTemplate<ValueType>, TupleSize>,
-      ConstTupleReference<vtkAOSDataArrayTemplate<ValueType>, TupleSize> >
 {
 private:
   using ArrayType = vtkAOSDataArrayTemplate<ValueType>;
   using NumCompsType = GenericTupleSize<TupleSize>;
-  using Superclass = std::iterator<std::random_access_iterator_tag,
-    ConstTupleReference<ArrayType, TupleSize>, TupleIdType,
-    ConstTupleReference<ArrayType, TupleSize>, ConstTupleReference<ArrayType, TupleSize> >;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = ConstTupleReference<ArrayType, TupleSize>;
+  using difference_type = TupleIdType;
+  using pointer = ConstTupleReference<ArrayType, TupleSize>;
+  using reference = ConstTupleReference<ArrayType, TupleSize>;
 
   VTK_ITER_INLINE
   ConstTupleIterator() noexcept = default;
 
   VTK_ITER_INLINE
-  ConstTupleIterator(const ValueType* tuple, NumCompsType numComps) noexcept : Ref(tuple, numComps)
+  ConstTupleIterator(const ValueType* tuple, NumCompsType numComps) noexcept
+    : Ref(tuple, numComps)
   {
   }
 
   VTK_ITER_INLINE
-  ConstTupleIterator(const TupleIterator<ArrayType, TupleSize>& o) noexcept : Ref{ o.Ref } {}
+  ConstTupleIterator(const TupleIterator<ArrayType, TupleSize>& o) noexcept
+    : Ref{ o.Ref }
+  {
+  }
 
   VTK_ITER_INLINE
   ConstTupleIterator(const ConstTupleIterator& o) noexcept = default;
@@ -698,30 +688,26 @@ private:
 // Tuple iterator
 template <typename ValueType, ComponentIdType TupleSize>
 struct TupleIterator<vtkAOSDataArrayTemplate<ValueType>, TupleSize>
-  : public std::iterator<std::random_access_iterator_tag,
-      TupleReference<vtkAOSDataArrayTemplate<ValueType>, TupleSize>, TupleIdType,
-      TupleReference<vtkAOSDataArrayTemplate<ValueType>, TupleSize>,
-      TupleReference<vtkAOSDataArrayTemplate<ValueType>, TupleSize> >
 {
 private:
   using ArrayType = vtkAOSDataArrayTemplate<ValueType>;
   using NumCompsType = GenericTupleSize<TupleSize>;
-  using Superclass =
-    std::iterator<std::random_access_iterator_tag, TupleReference<ArrayType, TupleSize>,
-      TupleIdType, TupleReference<ArrayType, TupleSize>, TupleReference<ArrayType, TupleSize> >;
 
 public:
-  using iterator_category = typename Superclass::iterator_category;
-  using value_type = typename Superclass::value_type;
-  using difference_type = typename Superclass::difference_type;
-  using pointer = typename Superclass::pointer;
-  using reference = typename Superclass::reference;
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = TupleReference<ArrayType, TupleSize>;
+  using difference_type = TupleIdType;
+  using pointer = TupleReference<ArrayType, TupleSize>;
+  using reference = TupleReference<ArrayType, TupleSize>;
 
   VTK_ITER_INLINE
   TupleIterator() noexcept = default;
 
   VTK_ITER_INLINE
-  TupleIterator(ValueType* tuple, NumCompsType numComps) noexcept : Ref(tuple, numComps) {}
+  TupleIterator(ValueType* tuple, NumCompsType numComps) noexcept
+    : Ref(tuple, numComps)
+  {
+  }
 
   VTK_ITER_INLINE
   TupleIterator(const TupleIterator& o) noexcept = default;
@@ -774,8 +760,8 @@ public:
   pointer& operator->() noexcept { return this->Ref; }
 
 #define VTK_TMP_MAKE_OPERATOR(OP)                                                                  \
-  friend VTK_ITER_INLINE bool operator OP(const TupleIterator& lhs, const TupleIterator& rhs)      \
-    noexcept                                                                                       \
+  friend VTK_ITER_INLINE bool operator OP(                                                         \
+    const TupleIterator& lhs, const TupleIterator& rhs) noexcept                                   \
   {                                                                                                \
     return lhs.GetTuple() OP rhs.GetTuple();                                                       \
   }
@@ -990,13 +976,13 @@ template <typename ArrayType, ComponentIdType TupleSize,
   typename = typename std::enable_if<IsAOSDataArray<ArrayType>::value>::type>
 TupleRange<AOSArrayType, TupleSize> DeclareTupleRangeSpecialization(ArrayType*);
 
+VTK_ABI_NAMESPACE_END
 } // end namespace detail
 } // end namespace vtk
 
 VTK_ITER_OPTIMIZE_END
 
 #endif // VTK_DEBUG_RANGE_ITERATORS
-#endif // __VTK_WRAP__
 #endif // vtkDataArrayTupleRange_AOS_h
 
 // VTK-HeaderTest-Exclude: vtkDataArrayTupleRange_AOS.h
