@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkDebugLeaksManager.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkDebugLeaksManager
  * @brief   Manages the vtkDebugLeaks singleton.
@@ -28,6 +16,7 @@
 #include "vtkCommonCoreModule.h" // For export macro
 #include "vtkSystemIncludes.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKCOMMONCORE_EXPORT vtkDebugLeaksManager
 {
 public:
@@ -35,8 +24,8 @@ public:
   ~vtkDebugLeaksManager();
 
 private:
-  vtkDebugLeaksManager(const vtkDebugLeaksManager&);
-  vtkDebugLeaksManager& operator=(const vtkDebugLeaksManager&);
+  vtkDebugLeaksManager(const vtkDebugLeaksManager&) = delete;
+  vtkDebugLeaksManager& operator=(const vtkDebugLeaksManager&) = delete;
 };
 
 // This instance will show up in any translation unit that uses
@@ -45,5 +34,6 @@ private:
 // static object destroyed.
 static vtkDebugLeaksManager vtkDebugLeaksManagerInstance;
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkDebugLeaksManager.h
