@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkInformation.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkInformation.h"
 
 #include "vtkCommand.h"
@@ -45,9 +33,10 @@
 
 #include "vtkInformationInternals.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInformation);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformation::vtkInformation()
 {
   // Allocate the internal representation.
@@ -57,14 +46,14 @@ vtkInformation::vtkInformation()
   this->Request = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformation::~vtkInformation()
 {
   // Delete the internal representation.
   delete this->Internal;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -77,7 +66,7 @@ void vtkInformation::PrintSelf(ostream& os, vtkIndent indent)
   this->PrintKeys(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::PrintKeys(ostream& os, vtkIndent indent)
 {
   typedef vtkInformationInternals::MapType MapType;
@@ -93,14 +82,14 @@ void vtkInformation::PrintKeys(ostream& os, vtkIndent indent)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // call modified on superclass
 void vtkInformation::Modified()
 {
   this->Superclass::Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Update MTime and invoke a modified event with
 // the information key as call data
 void vtkInformation::Modified(vtkInformationKey* key)
@@ -109,7 +98,7 @@ void vtkInformation::Modified(vtkInformationKey* key)
   this->InvokeEvent(vtkCommand::ModifiedEvent, key);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Return the number of keys as a result of iteration.
 int vtkInformation::GetNumberOfKeys()
 {
@@ -126,7 +115,7 @@ int vtkInformation::GetNumberOfKeys()
   return numberOfKeys;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::SetAsObjectBase(vtkInformationKey* key, vtkObjectBase* newvalue)
 {
   if (!key)
@@ -158,7 +147,7 @@ void vtkInformation::SetAsObjectBase(vtkInformationKey* key, vtkObjectBase* newv
   this->Modified(key);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkObjectBase* vtkInformation::GetAsObjectBase(const vtkInformationKey* key) const
 {
   if (key)
@@ -173,7 +162,7 @@ const vtkObjectBase* vtkInformation::GetAsObjectBase(const vtkInformationKey* ke
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkObjectBase* vtkInformation::GetAsObjectBase(vtkInformationKey* key)
 {
   if (key)
@@ -188,14 +177,14 @@ vtkObjectBase* vtkInformation::GetAsObjectBase(vtkInformationKey* key)
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Clear()
 {
   this->Copy(nullptr);
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::Copy(vtkInformation* from, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::Copy(vtkInformation* from, vtkTypeBool deep)
 {
   vtkInformationInternals* oldInternal = this->Internal;
   this->Internal = new vtkInformationInternals;
@@ -211,8 +200,8 @@ void vtkInformation::Copy(vtkInformation* from, int deep)
   delete oldInternal;
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::Append(vtkInformation* from, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::Append(vtkInformation* from, vtkTypeBool deep)
 {
   if (from)
   {
@@ -225,8 +214,8 @@ void vtkInformation::Append(vtkInformation* from, int deep)
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -238,35 +227,9 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationKey* key, int
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationDataObjectKey* key, int deep)
-{
-  if (!deep)
-  {
-    key->ShallowCopy(from, this);
-  }
-  else
-  {
-    key->DeepCopy(from, this);
-  }
-}
-
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationInformationKey* key, int deep)
-{
-  if (!deep)
-  {
-    key->ShallowCopy(from, this);
-  }
-  else
-  {
-    key->DeepCopy(from, this);
-  }
-}
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::CopyEntry(
-  vtkInformation* from, vtkInformationInformationVectorKey* key, int deep)
+  vtkInformation* from, vtkInformationDataObjectKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -278,48 +241,9 @@ void vtkInformation::CopyEntry(
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationIntegerKey* key, int deep)
-{
-  if (!deep)
-  {
-    key->ShallowCopy(from, this);
-  }
-  else
-  {
-    key->DeepCopy(from, this);
-  }
-}
-
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationRequestKey* key, int deep)
-{
-  if (!deep)
-  {
-    key->ShallowCopy(from, this);
-  }
-  else
-  {
-    key->DeepCopy(from, this);
-  }
-}
-
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationIntegerVectorKey* key, int deep)
-{
-  if (!deep)
-  {
-    key->ShallowCopy(from, this);
-  }
-  else
-  {
-    key->DeepCopy(from, this);
-  }
-}
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::CopyEntry(
-  vtkInformation* from, vtkInformationObjectBaseVectorKey* key, int deep)
+  vtkInformation* from, vtkInformationInformationKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -331,8 +255,9 @@ void vtkInformation::CopyEntry(
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationDoubleVectorKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationInformationVectorKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -344,8 +269,9 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationDoubleVectorK
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationVariantKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationIntegerKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -357,8 +283,9 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationVariantKey* k
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationVariantVectorKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationRequestKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -370,8 +297,9 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationVariantVector
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationStringKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationIntegerVectorKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -383,8 +311,9 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationStringKey* ke
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationUnsignedLongKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationObjectBaseVectorKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -396,8 +325,9 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationUnsignedLongK
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationStringVectorKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationDoubleVectorKey* key, vtkTypeBool deep)
 {
   if (!deep)
   {
@@ -409,8 +339,78 @@ void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationStringVectorK
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::CopyEntries(vtkInformation* from, vtkInformationKeyVectorKey* key, int deep)
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationVariantKey* key, vtkTypeBool deep)
+{
+  if (!deep)
+  {
+    key->ShallowCopy(from, this);
+  }
+  else
+  {
+    key->DeepCopy(from, this);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationVariantVectorKey* key, vtkTypeBool deep)
+{
+  if (!deep)
+  {
+    key->ShallowCopy(from, this);
+  }
+  else
+  {
+    key->DeepCopy(from, this);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(vtkInformation* from, vtkInformationStringKey* key, vtkTypeBool deep)
+{
+  if (!deep)
+  {
+    key->ShallowCopy(from, this);
+  }
+  else
+  {
+    key->DeepCopy(from, this);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationUnsignedLongKey* key, vtkTypeBool deep)
+{
+  if (!deep)
+  {
+    key->ShallowCopy(from, this);
+  }
+  else
+  {
+    key->DeepCopy(from, this);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntry(
+  vtkInformation* from, vtkInformationStringVectorKey* key, vtkTypeBool deep)
+{
+  if (!deep)
+  {
+    key->ShallowCopy(from, this);
+  }
+  else
+  {
+    key->DeepCopy(from, this);
+  }
+}
+
+//------------------------------------------------------------------------------
+void vtkInformation::CopyEntries(
+  vtkInformation* from, vtkInformationKeyVectorKey* key, vtkTypeBool deep)
 {
   int numberOfKeys = from->Length(key);
   vtkInformationKey** keys = from->Get(key);
@@ -420,14 +420,14 @@ void vtkInformation::CopyEntries(vtkInformation* from, vtkInformationKeyVectorKe
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkInformation::Has(vtkInformationKey* key)
 {
   // Use the virtual interface in case this is a special-cased key.
   return key->Has(this) ? 1 : 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Remove(vtkInformationKey* key)
 {
   // Use the virtual interface in case this is a special-cased key.
@@ -447,7 +447,7 @@ int vtkInformation::Has(vtkInformationRequestKey* key)
   return key->vtkInformationRequestKey::Has(this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 #define VTK_INFORMATION_DEFINE_SCALAR_PROPERTY(name, type)                                         \
   void vtkInformation::Set(vtkInformation##name##Key* key, type value) { key->Set(this, value); }  \
   void vtkInformation::Remove(vtkInformation##name##Key* key)                                      \
@@ -471,7 +471,7 @@ VTK_INFORMATION_DEFINE_SCALAR_PROPERTY(ObjectBase, vtkObjectBase*);
 VTK_INFORMATION_DEFINE_SCALAR_PROPERTY(Variant, const vtkVariant&);
 #undef VTK_INFORMATION_DEFINE_SCALAR_PROPERTY
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 #define VTK_INFORMATION_DEFINE_VECTOR_PROPERTY(name, type)                                         \
   void vtkInformation::Append(vtkInformation##name##VectorKey* key, type value)                    \
   {                                                                                                \
@@ -658,7 +658,7 @@ VTK_INFORMATION_DEFINE_VECTOR_VALUE2_PROPERTY(Variant, vtkVariant, const vtkVari
 
 #undef VTK_INFORMATION_DEFINE_VECTOR_PROPERTY
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 #define VTK_INFORMATION_DEFINE_POINTER_PROPERTY(name, type)                                        \
   void vtkInformation::Set(vtkInformation##name##PointerKey* key, type* value, int length)         \
   {                                                                                                \
@@ -681,256 +681,244 @@ VTK_INFORMATION_DEFINE_VECTOR_VALUE2_PROPERTY(Variant, vtkVariant, const vtkVari
 VTK_INFORMATION_DEFINE_POINTER_PROPERTY(Integer, int);
 #undef VTK_INFORMATION_DEFINE_POINTER_PROPERTY
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationDataObjectKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationDoubleKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationDoubleVectorKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationInformationKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Remove(vtkInformationKeyVectorKey* key, vtkInformationKey* value)
 {
   key->RemoveItem(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(
   vtkInformationKeyVectorKey* key, vtkInformationInformationVectorKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationIntegerKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationIntegerVectorKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationStringKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationUnsignedLongKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationObjectBaseKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::Append(vtkInformationKeyVectorKey* key, vtkInformationStringVectorKey* value)
 {
   key->Append(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationDataObjectKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(vtkInformationKeyVectorKey* key, vtkInformationKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(vtkInformationKeyVectorKey* key, vtkInformationDoubleKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationDoubleVectorKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationInformationKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationInformationVectorKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(vtkInformationKeyVectorKey* key, vtkInformationIntegerKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationIntegerVectorKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(vtkInformationKeyVectorKey* key, vtkInformationStringKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationUnsignedLongKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationObjectBaseKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::AppendUnique(
   vtkInformationKeyVectorKey* key, vtkInformationStringVectorKey* value)
 {
   key->AppendUnique(this, value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationDataObjectKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationInformationKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationInformationVectorKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationIntegerKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationRequestKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationDoubleKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationIntegerVectorKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationDoubleVectorKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationStringKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationStringVectorKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationUnsignedLongKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationVariantKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationKey* vtkInformation::GetKey(vtkInformationVariantVectorKey* key)
 {
   return key;
 }
 
-//----------------------------------------------------------------------------
-void vtkInformation::Register(vtkObjectBase* o)
-{
-  this->RegisterInternal(o, 1);
-}
-
-//----------------------------------------------------------------------------
-void vtkInformation::UnRegister(vtkObjectBase* o)
-{
-  this->UnRegisterInternal(o, 1);
-}
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::ReportReferences(vtkGarbageCollector* collector)
 {
   this->Superclass::ReportReferences(collector);
@@ -942,7 +930,7 @@ void vtkInformation::ReportReferences(vtkGarbageCollector* collector)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::ReportAsObjectBase(vtkInformationKey* key, vtkGarbageCollector* collector)
 {
   if (key)
@@ -956,14 +944,15 @@ void vtkInformation::ReportAsObjectBase(vtkInformationKey* key, vtkGarbageCollec
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInformation::SetRequest(vtkInformationRequestKey* request)
 {
   this->Request = request;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInformationRequestKey* vtkInformation::GetRequest()
 {
   return this->Request;
 }
+VTK_ABI_NAMESPACE_END
