@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkScalarsToColors.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkScalarsToColors.h"
 
 #include "vtkAbstractArray.h"
@@ -22,18 +10,22 @@
 #include "vtkUnsignedCharArray.h"
 #include "vtkVariantArray.h"
 
-#include <map>
-
+#include <algorithm>
 #include <cmath>
+#include <list>
 
-// A helper map for quick lookups of annotated values.
-class vtkScalarsToColors::vtkInternalAnnotatedValueMap : public std::map<vtkVariant, vtkIdType>
+// A helper list lookups of annotated values.
+// Note you cannot use a map or sort etc as the
+// comparison operator for vtkVariant is not suitable
+// for strict sorting.
+VTK_ABI_NAMESPACE_BEGIN
+class vtkScalarsToColors::vtkInternalAnnotatedValueList : public std::list<vtkVariant>
 {
 };
 
 vtkStandardNewMacro(vtkScalarsToColors);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScalarsToColors::vtkScalarsToColors()
 {
   this->Alpha = 1.0;
@@ -49,14 +41,16 @@ vtkScalarsToColors::vtkScalarsToColors()
   // should be indexed by annotated value.
   this->AnnotatedValues = nullptr;
   this->Annotations = nullptr;
-  this->AnnotatedValueMap = new vtkInternalAnnotatedValueMap;
+  this->AnnotatedValueList = new vtkInternalAnnotatedValueList;
   this->IndexedLookup = 0;
 
+#if !defined(VTK_LEGACY_REMOVE)
   // obsolete, kept for backwards compatibility
   this->UseMagnitude = 0;
+#endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScalarsToColors::~vtkScalarsToColors()
 {
   if (this->AnnotatedValues)
@@ -67,23 +61,33 @@ vtkScalarsToColors::~vtkScalarsToColors()
   {
     this->Annotations->UnRegister(this);
   }
-  delete this->AnnotatedValueMap;
+  delete this->AnnotatedValueList;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Return true if all of the values defining the mapping have an opacity
 // equal to 1. Default implementation return true.
-int vtkScalarsToColors::IsOpaque()
+vtkTypeBool vtkScalarsToColors::IsOpaque()
 {
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Return true if all of the values defining the mapping have an opacity
-// equal to 1. Default implementation return true.
-int vtkScalarsToColors::IsOpaque(vtkAbstractArray* scalars, int colorMode, int /*component*/)
+// equal to 1.
+vtkTypeBool vtkScalarsToColors::IsOpaque(vtkAbstractArray* scalars, int colorMode, int component)
+{
+  return this->IsOpaque(scalars, colorMode, component, nullptr);
+}
+
+//------------------------------------------------------------------------------
+// Description:
+// Return true if all of the values defining the mapping have an opacity
+// equal to 1.
+vtkTypeBool vtkScalarsToColors::IsOpaque(vtkAbstractArray* scalars, int colorMode, int,
+  vtkUnsignedCharArray* ghosts, unsigned char ghostsToSkip)
 {
   if (!scalars)
   {
@@ -107,10 +111,12 @@ int vtkScalarsToColors::IsOpaque(vtkAbstractArray* scalars, int colorMode, int /
     }
     // otherwise look at the range of the alpha channel
     unsigned char opacity = 0;
+    double range[2];
+    dataArray->GetRange(
+      range, numberOfComponents - 1, ghosts ? ghosts->GetPointer(0) : nullptr, ghostsToSkip);
     switch (scalars->GetDataType())
     {
-      vtkTemplateMacro(vtkScalarsToColors::ColorToUChar(
-        static_cast<VTK_TT>(dataArray->GetRange(numberOfComponents - 1)[0]), &opacity));
+      vtkTemplateMacro(vtkScalarsToColors::ColorToUChar(static_cast<VTK_TT>(range[0]), &opacity));
     }
     return ((opacity == 255) ? 1 : 0);
   }
@@ -118,32 +124,32 @@ int vtkScalarsToColors::IsOpaque(vtkAbstractArray* scalars, int colorMode, int /
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::SetVectorModeToComponent()
 {
   this->SetVectorMode(vtkScalarsToColors::COMPONENT);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::SetVectorModeToMagnitude()
 {
   this->SetVectorMode(vtkScalarsToColors::MAGNITUDE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::SetVectorModeToRGBColors()
 {
   this->SetVectorMode(vtkScalarsToColors::RGBCOLORS);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // do not use SetMacro() because we do not want the table to rebuild.
 void vtkScalarsToColors::SetAlpha(double alpha)
 {
   this->Alpha = (alpha < 0.0 ? 0.0 : (alpha > 1.0 ? 1.0 : alpha));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::SetRange(double minval, double maxval)
 {
   if (this->InputRange[0] != minval || this->InputRange[1] != maxval)
@@ -154,20 +160,20 @@ void vtkScalarsToColors::SetRange(double minval, double maxval)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double* vtkScalarsToColors::GetRange()
 {
   return this->InputRange;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColors::GetNumberOfAvailableColors()
 {
   // return total possible RGB colors
   return 256 * 256 * 256;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::DeepCopy(vtkScalarsToColors* obj)
 {
   if (obj)
@@ -197,12 +203,12 @@ void vtkScalarsToColors::DeepCopy(vtkScalarsToColors* obj)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 inline void vtkScalarsToColorsComputeShiftScale(
   vtkScalarsToColors* self, double& shift, double& scale)
 {
-  static const double minscale = -1e17;
-  static const double maxscale = 1e17;
+  constexpr double minscale = -1e17;
+  constexpr double maxscale = 1e17;
 
   const double* range = self->GetRange();
   shift = -range[0];
@@ -217,11 +223,11 @@ inline void vtkScalarsToColorsComputeShiftScale(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::GetColor(double v, double rgb[3])
 {
-  static double minval = 0.0;
-  static double maxval = 1.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 1.0;
 
   double shift, scale;
   vtkScalarsToColorsComputeShiftScale(this, shift, scale);
@@ -235,13 +241,13 @@ void vtkScalarsToColors::GetColor(double v, double rgb[3])
   rgb[2] = val;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkScalarsToColors::GetOpacity(double vtkNotUsed(v))
 {
   return 1.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const unsigned char* vtkScalarsToColors::MapValue(double v)
 {
   double rgb[3];
@@ -257,7 +263,7 @@ const unsigned char* vtkScalarsToColors::MapValue(double v)
   return this->RGBABytes;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedCharArray* vtkScalarsToColors::MapScalars(
   vtkDataArray* scalars, int colorMode, int component, int outputFormat)
 {
@@ -265,7 +271,7 @@ vtkUnsignedCharArray* vtkScalarsToColors::MapScalars(
     static_cast<vtkAbstractArray*>(scalars), colorMode, component, outputFormat);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedCharArray* vtkScalarsToColors::MapScalars(
   vtkAbstractArray* scalars, int colorMode, int component, int outputFormat)
 {
@@ -316,7 +322,7 @@ vtkUnsignedCharArray* vtkScalarsToColors::MapScalars(
   return newColors;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Map a set of vector values through the table
 void vtkScalarsToColors::MapVectorsThroughTable(void* input, unsigned char* output, int scalarType,
   int numValues, int inComponents, int outputFormat, int vectorComponent, int vectorSize)
@@ -401,12 +407,12 @@ void vtkScalarsToColors::MapVectorsThroughTable(void* input, unsigned char* outp
     {
       // convert to magnitude in blocks of 300 values
       int inInc = vtkDataArray::GetDataTypeSize(scalarType) * inComponents;
-      double magValues[300];
-      int blockSize = 300;
+      constexpr int blockSize = 300;
+      double magValues[blockSize];
       int numBlocks = (numValues + blockSize - 1) / blockSize;
       int lastBlockSize = numValues - blockSize * (numBlocks - 1);
 
-      for (int i = 0; i < numBlocks; i++)
+      for (int i = 0; i < numBlocks; ++i)
       {
         int numMagValues = ((i < numBlocks - 1) ? blockSize : lastBlockSize);
         this->MapVectorsToMagnitude(
@@ -427,7 +433,7 @@ void vtkScalarsToColors::MapVectorsThroughTable(void* input, unsigned char* outp
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Map a set of scalar values through the table
 void vtkScalarsToColors::MapScalarsThroughTable(
   vtkDataArray* scalars, unsigned char* output, int outputFormat)
@@ -441,15 +447,16 @@ void vtkScalarsToColors::MapScalarsThroughTable(
   this->MapScalarsThroughTable(scalars->GetVoidPointer(0), output, scalars->GetDataType(),
     scalars->GetNumberOfTuples(), scalars->GetNumberOfComponents(), outputFormat);
 }
+VTK_ABI_NAMESPACE_END
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Color type converters in anonymous namespace
 namespace
 {
 
 #define vtkScalarsToColorsLuminance(r, g, b) ((r)*0.30 + (g)*0.59 + (b)*0.11)
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsLuminanceToLuminance(
   const unsigned char* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents)
 {
@@ -460,7 +467,7 @@ void vtkScalarsToColorsLuminanceToLuminance(
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsLuminanceToRGB(
   const unsigned char* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents)
 {
@@ -475,7 +482,7 @@ void vtkScalarsToColorsLuminanceToRGB(
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsRGBToLuminance(
   const unsigned char* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents)
 {
@@ -489,7 +496,7 @@ void vtkScalarsToColorsRGBToLuminance(
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsRGBToRGB(
   const unsigned char* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents)
 {
@@ -503,7 +510,7 @@ void vtkScalarsToColorsRGBToRGB(
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsLuminanceToLuminanceAlpha(const unsigned char* inPtr, unsigned char* outPtr,
   vtkIdType count, int numComponents, double alpha)
 {
@@ -518,7 +525,7 @@ void vtkScalarsToColorsLuminanceToLuminanceAlpha(const unsigned char* inPtr, uns
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
 void vtkScalarsToColorsLuminanceToRGBA(
   const T* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents, double alpha)
@@ -537,7 +544,7 @@ void vtkScalarsToColorsLuminanceToRGBA(
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsRGBToLuminanceAlpha(const unsigned char* inPtr, unsigned char* outPtr,
   vtkIdType count, int numComponents, double alpha)
 {
@@ -555,7 +562,7 @@ void vtkScalarsToColorsRGBToLuminanceAlpha(const unsigned char* inPtr, unsigned
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
 void vtkScalarsToColorsRGBToRGBA(
   const T* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents, double alpha)
@@ -573,7 +580,7 @@ void vtkScalarsToColorsRGBToRGBA(
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsLuminanceAlphaToLuminanceAlpha(const unsigned char* inPtr,
   unsigned char* outPtr, vtkIdType count, int numComponents, double alpha)
 {
@@ -599,7 +606,7 @@ void vtkScalarsToColorsLuminanceAlphaToLuminanceAlpha(const unsigned char* inPtr
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
 void vtkScalarsToColorsLuminanceAlphaToRGBA(
   const T* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents, double alpha)
@@ -634,7 +641,7 @@ void vtkScalarsToColorsLuminanceAlphaToRGBA(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColorsRGBAToLuminanceAlpha(const unsigned char* inPtr, unsigned char* outPtr,
   vtkIdType count, int numComponents, double alpha)
 {
@@ -651,7 +658,7 @@ void vtkScalarsToColorsRGBAToLuminanceAlpha(const unsigned char* inPtr, unsigned
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
 void vtkScalarsToColorsRGBAToRGBA(
   const T* inPtr, unsigned char* outPtr, vtkIdType count, int numComponents, double alpha)
@@ -682,13 +689,13 @@ void vtkScalarsToColorsRGBAToRGBA(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsLuminanceToLuminance(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -703,13 +710,13 @@ void vtkScalarsToColorsLuminanceToLuminance(const T* inPtr, unsigned char* outPt
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsLuminanceToRGB(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -726,13 +733,13 @@ void vtkScalarsToColorsLuminanceToRGB(const T* inPtr, unsigned char* outPtr, vtk
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsRGBToLuminance(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -755,13 +762,13 @@ void vtkScalarsToColorsRGBToLuminance(const T* inPtr, unsigned char* outPtr, vtk
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsRGBToRGB(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -788,14 +795,14 @@ void vtkScalarsToColorsRGBToRGB(const T* inPtr, unsigned char* outPtr, vtkIdType
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsLuminanceToLuminanceAlpha(const T* inPtr, unsigned char* outPtr,
   vtkIdType count, int numComponents, double shift, double scale, double alpha)
 {
   unsigned char a = vtkScalarsToColors::ColorToUChar(alpha);
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -811,14 +818,14 @@ void vtkScalarsToColorsLuminanceToLuminanceAlpha(const T* inPtr, unsigned char*
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsLuminanceToRGBA(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale, double alpha)
 {
   unsigned char a = vtkScalarsToColors::ColorToUChar(alpha);
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -836,14 +843,14 @@ void vtkScalarsToColorsLuminanceToRGBA(const T* inPtr, unsigned char* outPtr, vt
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsRGBToLuminanceAlpha(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale, double alpha)
 {
   unsigned char a = vtkScalarsToColors::ColorToUChar(alpha);
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -867,14 +874,14 @@ void vtkScalarsToColorsRGBToLuminanceAlpha(const T* inPtr, unsigned char* outPtr
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsRGBToRGBA(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale, double alpha)
 {
   unsigned char a = vtkScalarsToColors::ColorToUChar(alpha);
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -902,13 +909,13 @@ void vtkScalarsToColorsRGBToRGBA(const T* inPtr, unsigned char* outPtr, vtkIdTyp
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsLuminanceAlphaToLuminanceAlpha(const T* inPtr, unsigned char* outPtr,
   vtkIdType count, int numComponents, double shift, double scale, double alpha)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -929,13 +936,13 @@ void vtkScalarsToColorsLuminanceAlphaToLuminanceAlpha(const T* inPtr, unsigned c
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsLuminanceAlphaToRGBA(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale, double alpha)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -958,13 +965,13 @@ void vtkScalarsToColorsLuminanceAlphaToRGBA(const T* inPtr, unsigned char* outPt
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsRGBAToLuminanceAlpha(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale, double alpha)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -993,13 +1000,13 @@ void vtkScalarsToColorsRGBAToLuminanceAlpha(const T* inPtr, unsigned char* outPt
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsRGBAToRGBA(const T* inPtr, unsigned char* outPtr, vtkIdType count,
   int numComponents, double shift, double scale, double alpha)
 {
-  static const double minval = 0;
-  static const double maxval = 255.0;
+  constexpr double minval = 0.0;
+  constexpr double maxval = 255.0;
 
   do
   {
@@ -1032,18 +1039,18 @@ void vtkScalarsToColorsRGBAToRGBA(const T* inPtr, unsigned char* outPtr, vtkIdTy
   } while (--count);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+// Unpack an array of bits into an array of `unsigned char`.
 unsigned char* vtkScalarsToColorsUnpackBits(void* inPtr, vtkIdType numValues)
 {
-  vtkIdType n = (numValues + 7) % 8;
-  unsigned char* newPtr = new unsigned char[n];
+  unsigned char* newPtr = new unsigned char[numValues];
 
   unsigned char* tmpPtr = newPtr;
   unsigned char* bitdata = static_cast<unsigned char*>(inPtr);
-  for (vtkIdType i = 0; i < n; i += 8)
+  for (vtkIdType i = 0; i < numValues; i += 8)
   {
     unsigned char b = *bitdata++;
-    int j = 8;
+    vtkIdType j = std::min(static_cast<vtkIdType>(8), numValues - i);
     do
     {
       *tmpPtr++ = ((b >> (--j)) & 0x01);
@@ -1056,7 +1063,8 @@ unsigned char* vtkScalarsToColorsUnpackBits(void* inPtr, vtkIdType numValues)
 // end anonymous namespace
 }
 
-//----------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::MapColorsToColors(void* inPtr, unsigned char* outPtr, int inputDataType,
   int numberOfTuples, int numberOfComponents, int inputFormat, int outputFormat)
 {
@@ -1089,13 +1097,13 @@ void vtkScalarsToColors::MapColorsToColors(void* inPtr, unsigned char* outPtr, i
   scale *= 255.0;
 
   double alpha = this->Alpha;
-  if (alpha < 0)
+  if (alpha < 0.0)
   {
-    alpha = 0;
+    alpha = 0.0;
   }
-  if (alpha > 1)
+  if (alpha > 1.0)
   {
-    alpha = 1;
+    alpha = 1.0;
   }
 
   if (inputDataType == VTK_UNSIGNED_CHAR && static_cast<int>(shift * scale + 0.5) == 0 &&
@@ -1292,7 +1300,7 @@ void vtkScalarsToColors::MapColorsToColors(void* inPtr, unsigned char* outPtr, i
   delete[] newPtr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkScalarsToColorsMapVectorsToMagnitude(
   const T* inPtr, double* outPtr, int numTuples, int vectorSize, int inInc)
@@ -1311,7 +1319,7 @@ void vtkScalarsToColorsMapVectorsToMagnitude(
   } while (--numTuples);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::MapVectorsToMagnitude(void* inPtr, double* outPtr, int inputDataType,
   int numberOfTuples, int numberOfComponents, int vectorSize)
 {
@@ -1343,7 +1351,7 @@ void vtkScalarsToColors::MapVectorsToMagnitude(void* inPtr, double* outPtr, int
   delete[] newPtr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::MapScalarsThroughTable2(void* inPtr, unsigned char* outPtr,
   int inputDataType, int numberOfTuples, int numberOfComponents, int outputFormat)
 {
@@ -1371,13 +1379,13 @@ void vtkScalarsToColors::MapScalarsThroughTable2(void* inPtr, unsigned char* out
   scale *= 255.0;
 
   double alpha = this->Alpha;
-  if (alpha < 0)
+  if (alpha < 0.0)
   {
-    alpha = 0;
+    alpha = 0.0;
   }
-  if (alpha > 1)
+  if (alpha > 1.0)
   {
-    alpha = 1;
+    alpha = 1.0;
   }
 
   if (inputDataType == VTK_UNSIGNED_CHAR && static_cast<int>(shift * scale + 0.5) == 0 &&
@@ -1470,12 +1478,15 @@ void vtkScalarsToColors::MapScalarsThroughTable2(void* inPtr, unsigned char* out
 // where 'array' is a vtkDataArray and
 //       'data' could be: array->GetVoidPointer(0)
 #define callForAnyType(array, call)                                                                \
-  switch (array->GetDataType())                                                                    \
+  do                                                                                               \
   {                                                                                                \
-    vtkTemplateMacro(call);                                                                        \
-  }
+    switch (array->GetDataType())                                                                  \
+    {                                                                                              \
+      vtkTemplateMacro(call);                                                                      \
+    }                                                                                              \
+  } while (false)
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedCharArray* vtkScalarsToColors::ConvertToRGBA(
   vtkDataArray* colors, int numComp, int numTuples)
 {
@@ -1498,8 +1509,8 @@ vtkUnsignedCharArray* vtkScalarsToColors::ConvertToRGBA(
   newColors->SetNumberOfTuples(numTuples);
   unsigned char* nptr = newColors->GetPointer(0);
   double alpha = this->Alpha;
-  alpha = (alpha > 0 ? alpha : 0);
-  alpha = (alpha < 1 ? alpha : 1);
+  alpha = (alpha > 0.0 ? alpha : 0.0);
+  alpha = (alpha < 1.0 ? alpha : 1.0);
 
   if (numTuples <= 0)
   {
@@ -1540,7 +1551,7 @@ vtkUnsignedCharArray* vtkScalarsToColors::ConvertToRGBA(
   return newColors;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -1571,7 +1582,7 @@ void vtkScalarsToColors::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::SetAnnotations(vtkAbstractArray* values, vtkStringArray* annotations)
 {
   if ((values && !annotations) || (!values && annotations))
@@ -1629,7 +1640,7 @@ void vtkScalarsToColors::SetAnnotations(vtkAbstractArray* values, vtkStringArray
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColors::SetAnnotation(vtkVariant value, vtkStdString annotation)
 {
   vtkIdType i = this->CheckForAnnotatedValue(value);
@@ -1656,7 +1667,7 @@ vtkIdType vtkScalarsToColors::SetAnnotation(vtkVariant value, vtkStdString annot
   return i;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColors::SetAnnotation(vtkStdString value, vtkStdString annotation)
 {
   bool valid;
@@ -1669,13 +1680,13 @@ vtkIdType vtkScalarsToColors::SetAnnotation(vtkStdString value, vtkStdString ann
   return this->SetAnnotation(val, annotation);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColors::GetNumberOfAnnotatedValues()
 {
   return this->AnnotatedValues ? this->AnnotatedValues->GetNumberOfTuples() : 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVariant vtkScalarsToColors::GetAnnotatedValue(vtkIdType idx)
 {
   if (!this->AnnotatedValues || idx < 0 || idx >= this->AnnotatedValues->GetNumberOfTuples())
@@ -1686,27 +1697,23 @@ vtkVariant vtkScalarsToColors::GetAnnotatedValue(vtkIdType idx)
   return this->AnnotatedValues->GetVariantValue(idx);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStdString vtkScalarsToColors::GetAnnotation(vtkIdType idx)
 {
-  if (!this->Annotations)
-  /* Don't check idx as Annotations->GetValue() does:
-   * || idx < 0 || idx >= this->Annotations->GetNumberOfTuples())
-   */
+  if (!this->AnnotatedValues || idx < 0 || idx >= this->AnnotatedValues->GetNumberOfTuples())
   {
-    vtkStdString empty;
-    return empty;
+    return {};
   }
   return this->Annotations->GetValue(idx);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColors::GetAnnotatedValueIndex(vtkVariant val)
 {
   return (this->AnnotatedValues ? this->CheckForAnnotatedValue(val) : -1);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkScalarsToColors::RemoveAnnotation(vtkVariant value)
 {
   vtkIdType i = this->CheckForAnnotatedValue(value);
@@ -1728,7 +1735,7 @@ bool vtkScalarsToColors::RemoveAnnotation(vtkVariant value)
   return needToRemove;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::ResetAnnotations()
 {
   if (!this->Annotations)
@@ -1741,11 +1748,11 @@ void vtkScalarsToColors::ResetAnnotations()
   }
   this->AnnotatedValues->Reset();
   this->Annotations->Reset();
-  this->AnnotatedValueMap->clear();
+  this->AnnotatedValueList->clear();
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::GetAnnotationColor(const vtkVariant& val, double rgba[4])
 {
   if (this->IndexedLookup)
@@ -1756,11 +1763,11 @@ void vtkScalarsToColors::GetAnnotationColor(const vtkVariant& val, double rgba[4
   else
   {
     this->GetColor(val.ToDouble(), rgba);
-    rgba[3] = 1.;
+    rgba[3] = 1.0;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScalarsToColors::CheckForAnnotatedValue(vtkVariant value)
 {
   if (!this->Annotations)
@@ -1774,31 +1781,50 @@ vtkIdType vtkScalarsToColors::CheckForAnnotatedValue(vtkVariant value)
   return this->GetAnnotatedValueIndexInternal(value);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // An unsafe version of vtkScalarsToColors::CheckForAnnotatedValue for
 // internal use (no pointer checks performed)
 vtkIdType vtkScalarsToColors::GetAnnotatedValueIndexInternal(const vtkVariant& value)
 {
-  vtkInternalAnnotatedValueMap::iterator it = this->AnnotatedValueMap->find(value);
+  auto it = this->AnnotatedValueList->begin();
+  size_t idx = 0;
+  for (; idx < this->AnnotatedValueList->size(); ++idx, it++)
+  {
+    if (*it == value)
+    {
+      break;
+    }
+  }
   vtkIdType nv = this->GetNumberOfAvailableColors();
-  vtkIdType i = (it == this->AnnotatedValueMap->end() ? -1 : (nv ? it->second % nv : it->second));
-  return i;
+  vtkIdType result = static_cast<vtkIdType>(idx);
+
+  // if not found return -1
+  if (it == this->AnnotatedValueList->end())
+  {
+    result = -1;
+  }
+  else if (nv > 0)
+  {
+    result = result % nv;
+  }
+  return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::GetIndexedColor(vtkIdType, double rgba[4])
 {
-  rgba[0] = rgba[1] = rgba[2] = rgba[3] = 0.;
+  rgba[0] = rgba[1] = rgba[2] = rgba[3] = 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarsToColors::UpdateAnnotatedValueMap()
 {
-  this->AnnotatedValueMap->clear();
+  this->AnnotatedValueList->clear();
 
   vtkIdType na = this->AnnotatedValues ? this->AnnotatedValues->GetMaxId() + 1 : 0;
   for (vtkIdType i = 0; i < na; ++i)
   {
-    (*this->AnnotatedValueMap)[this->AnnotatedValues->GetVariantValue(i)] = i;
+    this->AnnotatedValueList->push_back(this->AnnotatedValues->GetVariantValue(i));
   }
 }
+VTK_ABI_NAMESPACE_END
