@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestPolyhedron3.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkPlane.h"
 #include "vtkPolyData.h"
@@ -20,7 +8,6 @@
 
 #include "vtkClipDataSet.h"
 #include "vtkNew.h"
-#include "vtkPlane.h"
 #include "vtkTestUtilities.h"
 
 #include "vtkUnstructuredGridReader.h"
@@ -41,7 +28,7 @@ const char inputDataStream[] =
   "42\n";
 
 // Test of contour/clip of vtkPolyhedron. uses input from
-// https://gitlab.kitware.com/vtk/vtk/issues/15026
+// https://gitlab.kitware.com/vtk/vtk/-/issues/15026
 int TestPolyhedron3(int argc, char* argv[])
 {
   (void)argc;
