@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestPolyhedronConvexity.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include <vector>
 
@@ -362,7 +350,7 @@ bool IsConvex(Shape shape)
   vtkSmartPointer<vtkUnstructuredGrid> ugrid = vtkSmartPointer<vtkUnstructuredGrid>::New();
   ugrid->SetPoints(polyhedronPoints);
   ugrid->InsertNextCell(VTK_POLYHEDRON, polyhedronPoints->GetNumberOfPoints(),
-    &polyhedronPointsIds[0], polyhedronFaces->GetNumberOfCells(), legacyFaces->GetPointer(0));
+    polyhedronPointsIds.data(), polyhedronFaces->GetNumberOfCells(), legacyFaces->GetPointer(0));
 
   vtkPolyhedron* polyhedron = static_cast<vtkPolyhedron*>(ugrid->GetCell(0));
 
@@ -374,43 +362,43 @@ int TestPolyhedronConvexity(int argc, char* argv[])
   (void)argc;
   (void)argv;
 
-  if (IsConvex(dodecahedron) != true)
+  if (!IsConvex(dodecahedron))
   {
     cerr << "convex dodehecahedron incorrectly classified as non-convex" << std::endl;
     return EXIT_FAILURE;
   }
 
-  if (IsConvex(u_shape) != false)
+  if (IsConvex(u_shape))
   {
     cerr << "non-convex u-shape incorrectly classified as convex" << std::endl;
     return EXIT_FAILURE;
   }
 
-  if (IsConvex(cube) != true)
+  if (!IsConvex(cube))
   {
     cerr << "convex cube incorrectly classified as non-convex" << std::endl;
     return EXIT_FAILURE;
   }
 
-  if (IsConvex(colinear_cube) != true)
+  if (!IsConvex(colinear_cube))
   {
     cerr << "convex colinear cube incorrectly classified as non-convex" << std::endl;
     return EXIT_FAILURE;
   }
 
-  if (IsConvex(degenerate_cube) != true)
+  if (!IsConvex(degenerate_cube))
   {
     cerr << "convex degenerate cube incorrectly classified as non-convex" << std::endl;
     return EXIT_FAILURE;
   }
 
-  if (IsConvex(convex_pyramid) != true)
+  if (!IsConvex(convex_pyramid))
   {
     cerr << "convex pyramid incorrectly classified as non-convex" << std::endl;
     return EXIT_FAILURE;
   }
 
-  if (IsConvex(nonconvex_pyramid) != false)
+  if (IsConvex(nonconvex_pyramid))
   {
     cerr << "non-convex pyramid incorrectly classified as convex" << std::endl;
     return EXIT_FAILURE;
