@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    UnitTestCells.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkCellType.h"
 #include "vtkSmartPointer.h"
@@ -51,6 +39,7 @@
 #include "vtkBiQuadraticQuadraticWedge.h"
 #include "vtkBiQuadraticTriangle.h"
 #include "vtkTriQuadraticHexahedron.h"
+#include "vtkTriQuadraticPyramid.h"
 
 #include "vtkCubicLine.h"
 
@@ -99,11 +88,12 @@ static vtkSmartPointer<vtkBiQuadraticQuadraticHexahedron> MakeBiQuadraticQuadrat
 static vtkSmartPointer<vtkBiQuadraticQuadraticWedge> MakeBiQuadraticQuadraticWedge();
 static vtkSmartPointer<vtkBiQuadraticTriangle> MakeBiQuadraticTriangle();
 static vtkSmartPointer<vtkTriQuadraticHexahedron> MakeTriQuadraticHexahedron();
+static vtkSmartPointer<vtkTriQuadraticPyramid> MakeTriQuadraticPyramid();
 static vtkSmartPointer<vtkCubicLine> MakeCubicLine();
 
 template <typename T>
-int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> cell, int linear = 1);
-//----------------------------------------------------------------------------
+int TestOneCell(VTKCellType cellType, vtkSmartPointer<T> cell, int linear = 1);
+//------------------------------------------------------------------------------
 int UnitTestCells(int, char*[])
 {
   std::map<std::string, int> results;
@@ -164,6 +154,8 @@ int UnitTestCells(int, char*[])
 
   results["TriQuadraticHexahedron"] = TestOneCell<vtkTriQuadraticHexahedron>(
     VTK_TRIQUADRATIC_HEXAHEDRON, MakeTriQuadraticHexahedron(), 0);
+  results["TriQuadraticPyramid"] =
+    TestOneCell<vtkTriQuadraticPyramid>(VTK_TRIQUADRATIC_PYRAMID, MakeTriQuadraticPyramid(), 0);
 
   int status = 0;
   std::cout << "----- Unit Test Summary -----" << std::endl;
@@ -180,18 +172,21 @@ int UnitTestCells(int, char*[])
   {
     return EXIT_FAILURE;
   }
+
   return EXIT_SUCCESS;
 }
 
 vtkSmartPointer<vtkEmptyCell> MakeEmptyCell()
 {
-  vtkSmartPointer<vtkEmptyCell> anEmptyCell = vtkSmartPointer<vtkEmptyCell>::New();
+  auto anEmptyCell = vtkSmartPointer<vtkEmptyCell>::New();
+
   return anEmptyCell;
 }
 
 vtkSmartPointer<vtkVertex> MakeVertex()
 {
-  vtkSmartPointer<vtkVertex> aVertex = vtkSmartPointer<vtkVertex>::New();
+  auto aVertex = vtkSmartPointer<vtkVertex>::New();
+
   aVertex->GetPointIds()->SetId(0, 0);
   aVertex->GetPoints()->SetPoint(0, 10.0, 20.0, 30.0);
 
@@ -200,7 +195,8 @@ vtkSmartPointer<vtkVertex> MakeVertex()
 
 vtkSmartPointer<vtkPolyVertex> MakePolyVertex()
 {
-  vtkSmartPointer<vtkPolyVertex> aPolyVertex = vtkSmartPointer<vtkPolyVertex>::New();
+  auto aPolyVertex = vtkSmartPointer<vtkPolyVertex>::New();
+
   aPolyVertex->GetPointIds()->SetNumberOfIds(2);
   aPolyVertex->GetPointIds()->SetId(0, 0);
   aPolyVertex->GetPointIds()->SetId(1, 1);
@@ -214,17 +210,20 @@ vtkSmartPointer<vtkPolyVertex> MakePolyVertex()
 
 vtkSmartPointer<vtkLine> MakeLine()
 {
-  vtkSmartPointer<vtkLine> aLine = vtkSmartPointer<vtkLine>::New();
+  auto aLine = vtkSmartPointer<vtkLine>::New();
+
   aLine->GetPointIds()->SetId(0, 0);
   aLine->GetPointIds()->SetId(1, 1);
   aLine->GetPoints()->SetPoint(0, 10.0, 20.0, 30.0);
   aLine->GetPoints()->SetPoint(1, 30.0, 20.0, 10.0);
+
   return aLine;
 }
 
 vtkSmartPointer<vtkPolyLine> MakePolyLine()
 {
-  vtkSmartPointer<vtkPolyLine> aPolyLine = vtkSmartPointer<vtkPolyLine>::New();
+  auto aPolyLine = vtkSmartPointer<vtkPolyLine>::New();
+
   aPolyLine->GetPointIds()->SetNumberOfIds(3);
   aPolyLine->GetPointIds()->SetId(0, 0);
   aPolyLine->GetPointIds()->SetId(1, 1);
@@ -240,19 +239,24 @@ vtkSmartPointer<vtkPolyLine> MakePolyLine()
 
 vtkSmartPointer<vtkTriangle> MakeTriangle()
 {
-  vtkSmartPointer<vtkTriangle> aTriangle = vtkSmartPointer<vtkTriangle>::New();
+  auto aTriangle = vtkSmartPointer<vtkTriangle>::New();
+
+  for (int i = 0; i < aTriangle->GetNumberOfPoints(); ++i)
+  {
+    aTriangle->GetPointIds()->SetId(i, i);
+  }
+
   aTriangle->GetPoints()->SetPoint(0, -10.0, -10.0, 0.0);
   aTriangle->GetPoints()->SetPoint(1, 10.0, -10.0, 0.0);
   aTriangle->GetPoints()->SetPoint(2, 10.0, 10.0, 0.0);
-  aTriangle->GetPointIds()->SetId(0, 0);
-  aTriangle->GetPointIds()->SetId(1, 1);
-  aTriangle->GetPointIds()->SetId(2, 2);
+
   return aTriangle;
 }
 
 vtkSmartPointer<vtkTriangleStrip> MakeTriangleStrip()
 {
-  vtkSmartPointer<vtkTriangleStrip> aTriangleStrip = vtkSmartPointer<vtkTriangleStrip>::New();
+  auto aTriangleStrip = vtkSmartPointer<vtkTriangleStrip>::New();
+
   aTriangleStrip->GetPointIds()->SetNumberOfIds(4);
   aTriangleStrip->GetPointIds()->SetId(0, 0);
   aTriangleStrip->GetPointIds()->SetId(1, 1);
@@ -270,7 +274,8 @@ vtkSmartPointer<vtkTriangleStrip> MakeTriangleStrip()
 
 vtkSmartPointer<vtkPolygon> MakePolygon()
 {
-  vtkSmartPointer<vtkPolygon> aPolygon = vtkSmartPointer<vtkPolygon>::New();
+  auto aPolygon = vtkSmartPointer<vtkPolygon>::New();
+
   aPolygon->GetPointIds()->SetNumberOfIds(4);
   aPolygon->GetPointIds()->SetId(0, 0);
   aPolygon->GetPointIds()->SetId(1, 1);
@@ -288,67 +293,67 @@ vtkSmartPointer<vtkPolygon> MakePolygon()
 
 vtkSmartPointer<vtkQuad> MakeQuad()
 {
-  vtkSmartPointer<vtkQuad> aQuad = vtkSmartPointer<vtkQuad>::New();
+  auto aQuad = vtkSmartPointer<vtkQuad>::New();
+
+  for (int i = 0; i < aQuad->GetNumberOfPoints(); ++i)
+  {
+    aQuad->GetPointIds()->SetId(i, i);
+  }
+
   aQuad->GetPoints()->SetPoint(0, -10.0, -10.0, 0.0);
   aQuad->GetPoints()->SetPoint(1, 10.0, -10.0, 0.0);
   aQuad->GetPoints()->SetPoint(2, 10.0, 10.0, 0.0);
   aQuad->GetPoints()->SetPoint(3, -10.0, 10.0, 0.0);
-  aQuad->GetPointIds()->SetId(0, 0);
-  aQuad->GetPointIds()->SetId(1, 1);
-  aQuad->GetPointIds()->SetId(2, 2);
-  aQuad->GetPointIds()->SetId(2, 3);
+
   return aQuad;
 }
 
 vtkSmartPointer<vtkPixel> MakePixel()
 {
-  vtkSmartPointer<vtkPixel> aPixel = vtkSmartPointer<vtkPixel>::New();
-  aPixel->GetPointIds()->SetId(0, 0);
-  aPixel->GetPointIds()->SetId(1, 1);
-  aPixel->GetPointIds()->SetId(2, 3);
-  aPixel->GetPointIds()->SetId(3, 2);
+  auto aPixel = vtkSmartPointer<vtkPixel>::New();
+
+  for (int i = 0; i < aPixel->GetNumberOfPoints(); ++i)
+  {
+    aPixel->GetPointIds()->SetId(i, i);
+  }
 
   aPixel->GetPoints()->SetPoint(0, 10.0, 10.0, 10.0);
   aPixel->GetPoints()->SetPoint(1, 12.0, 10.0, 10.0);
-  aPixel->GetPoints()->SetPoint(3, 12.0, 12.0, 10.0);
   aPixel->GetPoints()->SetPoint(2, 10.0, 12.0, 10.0);
+  aPixel->GetPoints()->SetPoint(3, 12.0, 12.0, 10.0);
+
   return aPixel;
 }
 
 vtkSmartPointer<vtkVoxel> MakeVoxel()
 {
-  vtkSmartPointer<vtkVoxel> aVoxel = vtkSmartPointer<vtkVoxel>::New();
-  aVoxel->GetPointIds()->SetId(0, 0);
-  aVoxel->GetPointIds()->SetId(1, 1);
-  aVoxel->GetPointIds()->SetId(2, 3);
-  aVoxel->GetPointIds()->SetId(3, 2);
-  aVoxel->GetPointIds()->SetId(4, 4);
-  aVoxel->GetPointIds()->SetId(5, 5);
-  aVoxel->GetPointIds()->SetId(6, 7);
-  aVoxel->GetPointIds()->SetId(7, 6);
+  auto aVoxel = vtkSmartPointer<vtkVoxel>::New();
+
+  for (int i = 0; i < aVoxel->GetNumberOfPoints(); ++i)
+  {
+    aVoxel->GetPointIds()->SetId(i, i);
+  }
 
   aVoxel->GetPoints()->SetPoint(0, 10, 10, 10);
   aVoxel->GetPoints()->SetPoint(1, 12, 10, 10);
-  aVoxel->GetPoints()->SetPoint(3, 12, 12, 10);
   aVoxel->GetPoints()->SetPoint(2, 10, 12, 10);
+  aVoxel->GetPoints()->SetPoint(3, 12, 12, 10);
   aVoxel->GetPoints()->SetPoint(4, 10, 10, 12);
   aVoxel->GetPoints()->SetPoint(5, 12, 10, 12);
-  aVoxel->GetPoints()->SetPoint(7, 12, 12, 12);
   aVoxel->GetPoints()->SetPoint(6, 10, 12, 12);
+  aVoxel->GetPoints()->SetPoint(7, 12, 12, 12);
+
   return aVoxel;
 }
 
 vtkSmartPointer<vtkHexahedron> MakeHexahedron()
 {
-  vtkSmartPointer<vtkHexahedron> aHexahedron = vtkSmartPointer<vtkHexahedron>::New();
-  aHexahedron->GetPointIds()->SetId(0, 0);
-  aHexahedron->GetPointIds()->SetId(1, 1);
-  aHexahedron->GetPointIds()->SetId(2, 2);
-  aHexahedron->GetPointIds()->SetId(3, 3);
-  aHexahedron->GetPointIds()->SetId(4, 4);
-  aHexahedron->GetPointIds()->SetId(5, 5);
-  aHexahedron->GetPointIds()->SetId(6, 6);
-  aHexahedron->GetPointIds()->SetId(7, 7);
+  auto aHexahedron = vtkSmartPointer<vtkHexahedron>::New();
+
+  for (int i = 0; i < aHexahedron->GetNumberOfPoints(); ++i)
+  {
+    aHexahedron->GetPointIds()->SetId(i, i);
+  }
 
   aHexahedron->GetPoints()->SetPoint(0, 10, 10, 10);
   aHexahedron->GetPoints()->SetPoint(1, 12, 10, 10);
@@ -364,53 +369,89 @@ vtkSmartPointer<vtkHexahedron> MakeHexahedron()
 
 vtkSmartPointer<vtkPyramid> MakePyramid()
 {
-  vtkSmartPointer<vtkPyramid> aPyramid = vtkSmartPointer<vtkPyramid>::New();
-  aPyramid->GetPointIds()->SetId(0, 0);
-  aPyramid->GetPointIds()->SetId(1, 1);
-  aPyramid->GetPointIds()->SetId(2, 2);
-  aPyramid->GetPointIds()->SetId(3, 3);
-  aPyramid->GetPointIds()->SetId(4, 4);
+  auto aPyramid = vtkSmartPointer<vtkPyramid>::New();
 
-  aPyramid->GetPoints()->SetPoint(0, 0, 0, 0);
-  aPyramid->GetPoints()->SetPoint(1, 1, 0, 0);
-  aPyramid->GetPoints()->SetPoint(2, 1, 1, 0);
-  aPyramid->GetPoints()->SetPoint(3, 0, 1, 0);
-  aPyramid->GetPoints()->SetPoint(4, .5, .5, 1);
+  for (int i = 0; i < aPyramid->GetNumberOfPoints(); ++i)
+  {
+    aPyramid->GetPointIds()->SetId(i, i);
+  }
+
+  aPyramid->GetPoints()->SetPoint(0, 0.0, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(1, 1.0, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(2, 1.0, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(3, 0.0, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(4, 0.5, 0.5, 1.0);
 
   return aPyramid;
 }
 
 vtkSmartPointer<vtkQuadraticPyramid> MakeQuadraticPyramid()
 {
-  vtkSmartPointer<vtkQuadraticPyramid> aPyramid = vtkSmartPointer<vtkQuadraticPyramid>::New();
-  for (int i = 0; i < 13; ++i)
+  auto aPyramid = vtkSmartPointer<vtkQuadraticPyramid>::New();
+
+  for (int i = 0; i < aPyramid->GetNumberOfPoints(); ++i)
   {
     aPyramid->GetPointIds()->SetId(i, i);
   }
 
-  aPyramid->GetPoints()->SetPoint(0, 0, 0, 0);
-  aPyramid->GetPoints()->SetPoint(1, 1, 0, 0);
-  aPyramid->GetPoints()->SetPoint(2, 1, 1, 0);
-  aPyramid->GetPoints()->SetPoint(3, 0, 1, 0);
-  aPyramid->GetPoints()->SetPoint(4, .5, .5, 1);
+  aPyramid->GetPoints()->SetPoint(0, 0.0, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(1, 1.0, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(2, 1.0, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(3, 0.0, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(4, 0.5, 0.5, 1.0);
 
   aPyramid->GetPoints()->SetPoint(5, 0.5, 0.0, 0.0);
   aPyramid->GetPoints()->SetPoint(6, 1.0, 0.5, 0.0);
   aPyramid->GetPoints()->SetPoint(7, 0.5, 1.0, 0.0);
   aPyramid->GetPoints()->SetPoint(8, 0.0, 0.5, 0.0);
-
-  aPyramid->GetPoints()->SetPoint(9, 0.5, 0.5, 0.5);
-  aPyramid->GetPoints()->SetPoint(10, 0.75, 0.5, 0.5);
+  aPyramid->GetPoints()->SetPoint(9, 0.25, 0.25, 0.5);
+  aPyramid->GetPoints()->SetPoint(10, 0.75, 0.25, 0.5);
   aPyramid->GetPoints()->SetPoint(11, 0.75, 0.75, 0.5);
-  aPyramid->GetPoints()->SetPoint(12, 0.5, 0.75, 0.5);
+  aPyramid->GetPoints()->SetPoint(12, 0.25, 0.75, 0.5);
+
+  return aPyramid;
+}
+
+vtkSmartPointer<vtkTriQuadraticPyramid> MakeTriQuadraticPyramid()
+{
+  auto aPyramid = vtkSmartPointer<vtkTriQuadraticPyramid>::New();
+
+  for (int i = 0; i < aPyramid->GetNumberOfPoints(); ++i)
+  {
+    aPyramid->GetPointIds()->SetId(i, i);
+  }
+
+  aPyramid->GetPoints()->SetPoint(0, 0.0, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(1, 1.0, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(2, 1.0, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(3, 0.0, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(4, 0.5, 0.5, 1.0);
+
+  aPyramid->GetPoints()->SetPoint(5, 0.5, 0.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(6, 1.0, 0.5, 0.0);
+  aPyramid->GetPoints()->SetPoint(7, 0.5, 1.0, 0.0);
+  aPyramid->GetPoints()->SetPoint(8, 0.0, 0.5, 0.0);
+  aPyramid->GetPoints()->SetPoint(9, 0.25, 0.25, 0.5);
+  aPyramid->GetPoints()->SetPoint(10, 0.75, 0.25, 0.5);
+  aPyramid->GetPoints()->SetPoint(11, 0.75, 0.75, 0.5);
+  aPyramid->GetPoints()->SetPoint(12, 0.25, 0.75, 0.5);
+
+  aPyramid->GetPoints()->SetPoint(13, 0.5, 0.5, 0);
+  aPyramid->GetPoints()->SetPoint(14, 0.5, 1.0 / 6.0, 1.0 / 3.0);
+  aPyramid->GetPoints()->SetPoint(15, 5.0 / 6.0, 0.5, 1.0 / 3.0);
+  aPyramid->GetPoints()->SetPoint(16, 0.5, 5.0 / 6.0, 1.0 / 3.0);
+  aPyramid->GetPoints()->SetPoint(17, 1.0 / 6.0, 0.5, 1.0 / 3.0);
+
+  aPyramid->GetPoints()->SetPoint(18, 0.5, 0.5, 0.2);
 
   return aPyramid;
 }
 
 vtkSmartPointer<vtkQuadraticEdge> MakeQuadraticEdge()
 {
-  vtkSmartPointer<vtkQuadraticEdge> anEdge = vtkSmartPointer<vtkQuadraticEdge>::New();
-  for (int i = 0; i < 3; ++i)
+  auto anEdge = vtkSmartPointer<vtkQuadraticEdge>::New();
+
+  for (int i = 0; i < anEdge->GetNumberOfPoints(); ++i)
   {
     anEdge->GetPointIds()->SetId(i, i);
   }
@@ -424,8 +465,8 @@ vtkSmartPointer<vtkQuadraticEdge> MakeQuadraticEdge()
 
 vtkSmartPointer<vtkQuadraticHexahedron> MakeQuadraticHexahedron()
 {
-  vtkSmartPointer<vtkQuadraticHexahedron> aHexahedron =
-    vtkSmartPointer<vtkQuadraticHexahedron>::New();
+  auto aHexahedron = vtkSmartPointer<vtkQuadraticHexahedron>::New();
+
   double* pcoords = aHexahedron->GetParametricCoords();
   for (int i = 0; i < aHexahedron->GetNumberOfPoints(); ++i)
   {
@@ -434,13 +475,14 @@ vtkSmartPointer<vtkQuadraticHexahedron> MakeQuadraticHexahedron()
       *(pcoords + 3 * i + 1) + vtkMath::Random(-.1, .1),
       *(pcoords + 3 * i + 2) + vtkMath::Random(-.1, .1));
   }
+
   return aHexahedron;
 }
 
 vtkSmartPointer<vtkBiQuadraticQuadraticHexahedron> MakeBiQuadraticQuadraticHexahedron()
 {
-  vtkSmartPointer<vtkBiQuadraticQuadraticHexahedron> aHexahedron =
-    vtkSmartPointer<vtkBiQuadraticQuadraticHexahedron>::New();
+  auto aHexahedron = vtkSmartPointer<vtkBiQuadraticQuadraticHexahedron>::New();
+
   double* pcoords = aHexahedron->GetParametricCoords();
   for (int i = 0; i < aHexahedron->GetNumberOfPoints(); ++i)
   {
@@ -449,13 +491,14 @@ vtkSmartPointer<vtkBiQuadraticQuadraticHexahedron> MakeBiQuadraticQuadraticHexah
       *(pcoords + 3 * i + 1) + vtkMath::Random(-.1, .1),
       *(pcoords + 3 * i + 2) + vtkMath::Random(-.1, .1));
   }
+
   return aHexahedron;
 }
 
 vtkSmartPointer<vtkTriQuadraticHexahedron> MakeTriQuadraticHexahedron()
 {
-  vtkSmartPointer<vtkTriQuadraticHexahedron> aHexahedron =
-    vtkSmartPointer<vtkTriQuadraticHexahedron>::New();
+  auto aHexahedron = vtkSmartPointer<vtkTriQuadraticHexahedron>::New();
+
   double* pcoords = aHexahedron->GetParametricCoords();
   for (int i = 0; i < aHexahedron->GetNumberOfPoints(); ++i)
   {
@@ -464,12 +507,13 @@ vtkSmartPointer<vtkTriQuadraticHexahedron> MakeTriQuadraticHexahedron()
       *(pcoords + 3 * i + 1) + vtkMath::Random(-.1, .1),
       *(pcoords + 3 * i + 2) + vtkMath::Random(-.1, .1));
   }
+
   return aHexahedron;
 }
 
 vtkSmartPointer<vtkQuadraticPolygon> MakeQuadraticPolygon()
 {
-  vtkSmartPointer<vtkQuadraticPolygon> aPolygon = vtkSmartPointer<vtkQuadraticPolygon>::New();
+  auto aPolygon = vtkSmartPointer<vtkQuadraticPolygon>::New();
 
   aPolygon->GetPointIds()->SetNumberOfIds(8);
   aPolygon->GetPointIds()->SetId(0, 0);
@@ -491,13 +535,14 @@ vtkSmartPointer<vtkQuadraticPolygon> MakeQuadraticPolygon()
   aPolygon->GetPoints()->SetPoint(6, 1.0, 2.0, 0.0);
   aPolygon->GetPoints()->SetPoint(7, 0.0, 1.0, 0.0);
   aPolygon->GetPoints()->SetPoint(5, 3.0, 1.0, 0.0);
+
   return aPolygon;
 }
 
 vtkSmartPointer<vtkQuadraticLinearQuad> MakeQuadraticLinearQuad()
 {
-  vtkSmartPointer<vtkQuadraticLinearQuad> aLinearQuad =
-    vtkSmartPointer<vtkQuadraticLinearQuad>::New();
+  auto aLinearQuad = vtkSmartPointer<vtkQuadraticLinearQuad>::New();
+
   double* pcoords = aLinearQuad->GetParametricCoords();
   for (int i = 0; i < aLinearQuad->GetNumberOfPoints(); ++i)
   {
@@ -505,13 +550,14 @@ vtkSmartPointer<vtkQuadraticLinearQuad> MakeQuadraticLinearQuad()
     aLinearQuad->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aLinearQuad;
 }
 
 vtkSmartPointer<vtkQuadraticLinearWedge> MakeQuadraticLinearWedge()
 {
-  vtkSmartPointer<vtkQuadraticLinearWedge> aLinearWedge =
-    vtkSmartPointer<vtkQuadraticLinearWedge>::New();
+  auto aLinearWedge = vtkSmartPointer<vtkQuadraticLinearWedge>::New();
+
   double* pcoords = aLinearWedge->GetParametricCoords();
   for (int i = 0; i < 12; ++i)
   {
@@ -519,12 +565,14 @@ vtkSmartPointer<vtkQuadraticLinearWedge> MakeQuadraticLinearWedge()
     aLinearWedge->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aLinearWedge;
 }
 
 vtkSmartPointer<vtkQuadraticQuad> MakeQuadraticQuad()
 {
-  vtkSmartPointer<vtkQuadraticQuad> aQuad = vtkSmartPointer<vtkQuadraticQuad>::New();
+  auto aQuad = vtkSmartPointer<vtkQuadraticQuad>::New();
+
   double* pcoords = aQuad->GetParametricCoords();
   for (int i = 0; i < 8; ++i)
   {
@@ -532,12 +580,14 @@ vtkSmartPointer<vtkQuadraticQuad> MakeQuadraticQuad()
     aQuad->GetPoints()->SetPoint(i, *(pcoords + 3 * i) + vtkMath::Random(-.1, .1),
       *(pcoords + 3 * i + 1) + vtkMath::Random(-.1, .1), *(pcoords + 3 * i + 2));
   }
+
   return aQuad;
 }
 
 vtkSmartPointer<vtkQuadraticTetra> MakeQuadraticTetra()
 {
-  vtkSmartPointer<vtkQuadraticTetra> aTetra = vtkSmartPointer<vtkQuadraticTetra>::New();
+  auto aTetra = vtkSmartPointer<vtkQuadraticTetra>::New();
+
   double* pcoords = aTetra->GetParametricCoords();
   for (int i = 0; i < 10; ++i)
   {
@@ -546,12 +596,14 @@ vtkSmartPointer<vtkQuadraticTetra> MakeQuadraticTetra()
       *(pcoords + 3 * i + 1) + vtkMath::Random(-.1, .1),
       *(pcoords + 3 * i + 2) + vtkMath::Random(-.1, .1));
   }
+
   return aTetra;
 }
 
 vtkSmartPointer<vtkQuadraticTriangle> MakeQuadraticTriangle()
 {
-  vtkSmartPointer<vtkQuadraticTriangle> aTriangle = vtkSmartPointer<vtkQuadraticTriangle>::New();
+  auto aTriangle = vtkSmartPointer<vtkQuadraticTriangle>::New();
+
   double* pcoords = aTriangle->GetParametricCoords();
   for (int i = 0; i < aTriangle->GetNumberOfPoints(); ++i)
   {
@@ -559,13 +611,14 @@ vtkSmartPointer<vtkQuadraticTriangle> MakeQuadraticTriangle()
     aTriangle->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aTriangle;
 }
 
 vtkSmartPointer<vtkBiQuadraticTriangle> MakeBiQuadraticTriangle()
 {
-  vtkSmartPointer<vtkBiQuadraticTriangle> aTriangle =
-    vtkSmartPointer<vtkBiQuadraticTriangle>::New();
+  auto aTriangle = vtkSmartPointer<vtkBiQuadraticTriangle>::New();
+
   double* pcoords = aTriangle->GetParametricCoords();
   for (int i = 0; i < aTriangle->GetNumberOfPoints(); ++i)
   {
@@ -573,12 +626,14 @@ vtkSmartPointer<vtkBiQuadraticTriangle> MakeBiQuadraticTriangle()
     aTriangle->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aTriangle;
 }
 
 vtkSmartPointer<vtkBiQuadraticQuad> MakeBiQuadraticQuad()
 {
-  vtkSmartPointer<vtkBiQuadraticQuad> aQuad = vtkSmartPointer<vtkBiQuadraticQuad>::New();
+  auto aQuad = vtkSmartPointer<vtkBiQuadraticQuad>::New();
+
   double* pcoords = aQuad->GetParametricCoords();
   for (int i = 0; i < aQuad->GetNumberOfPoints(); ++i)
   {
@@ -586,12 +641,14 @@ vtkSmartPointer<vtkBiQuadraticQuad> MakeBiQuadraticQuad()
     aQuad->GetPoints()->SetPoint(i, *(pcoords + 3 * i) + vtkMath::Random(-.1, .1),
       *(pcoords + 3 * i + 1) + vtkMath::Random(-.1, .1), *(pcoords + 3 * i + 2));
   }
+
   return aQuad;
 }
 
 vtkSmartPointer<vtkCubicLine> MakeCubicLine()
 {
-  vtkSmartPointer<vtkCubicLine> aLine = vtkSmartPointer<vtkCubicLine>::New();
+  auto aLine = vtkSmartPointer<vtkCubicLine>::New();
+
   double* pcoords = aLine->GetParametricCoords();
   for (int i = 0; i < aLine->GetNumberOfPoints(); ++i)
   {
@@ -599,12 +656,14 @@ vtkSmartPointer<vtkCubicLine> MakeCubicLine()
     aLine->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aLine;
 }
 
 vtkSmartPointer<vtkQuadraticWedge> MakeQuadraticWedge()
 {
-  vtkSmartPointer<vtkQuadraticWedge> aWedge = vtkSmartPointer<vtkQuadraticWedge>::New();
+  auto aWedge = vtkSmartPointer<vtkQuadraticWedge>::New();
+
   double* pcoords = aWedge->GetParametricCoords();
   for (int i = 0; i < aWedge->GetNumberOfPoints(); ++i)
   {
@@ -612,13 +671,14 @@ vtkSmartPointer<vtkQuadraticWedge> MakeQuadraticWedge()
     aWedge->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aWedge;
 }
 
 vtkSmartPointer<vtkBiQuadraticQuadraticWedge> MakeBiQuadraticQuadraticWedge()
 {
-  vtkSmartPointer<vtkBiQuadraticQuadraticWedge> aWedge =
-    vtkSmartPointer<vtkBiQuadraticQuadraticWedge>::New();
+  auto aWedge = vtkSmartPointer<vtkBiQuadraticQuadraticWedge>::New();
+
   double* pcoords = aWedge->GetParametricCoords();
   for (int i = 0; i < aWedge->GetNumberOfPoints(); ++i)
   {
@@ -626,48 +686,52 @@ vtkSmartPointer<vtkBiQuadraticQuadraticWedge> MakeBiQuadraticQuadraticWedge()
     aWedge->GetPoints()->SetPoint(
       i, *(pcoords + 3 * i), *(pcoords + 3 * i + 1), *(pcoords + 3 * i + 2));
   }
+
   return aWedge;
 }
 
 vtkSmartPointer<vtkTetra> MakeTetra()
 {
-  vtkSmartPointer<vtkTetra> aTetra = vtkSmartPointer<vtkTetra>::New();
-  aTetra->GetPointIds()->SetId(0, 0);
-  aTetra->GetPointIds()->SetId(1, 1);
-  aTetra->GetPointIds()->SetId(2, 2);
-  aTetra->GetPointIds()->SetId(3, 3);
+  auto aTetra = vtkSmartPointer<vtkTetra>::New();
+
+  for (int i = 0; i < aTetra->GetNumberOfPoints(); ++i)
+  {
+    aTetra->GetPointIds()->SetId(i, i);
+  }
+
   aTetra->GetPoints()->SetPoint(0, 10.0, 10.0, 10.0);
   aTetra->GetPoints()->SetPoint(1, 12.0, 10.0, 10.0);
   aTetra->GetPoints()->SetPoint(2, 11.0, 12.0, 10.0);
   aTetra->GetPoints()->SetPoint(3, 11.0, 11.0, 12.0);
+
   return aTetra;
 }
 
 vtkSmartPointer<vtkWedge> MakeWedge()
 {
-  vtkSmartPointer<vtkWedge> aWedge = vtkSmartPointer<vtkWedge>::New();
-  aWedge->GetPointIds()->SetId(0, 0);
-  aWedge->GetPointIds()->SetId(1, 1);
-  aWedge->GetPointIds()->SetId(2, 2);
-  aWedge->GetPointIds()->SetId(3, 3);
-  aWedge->GetPointIds()->SetId(4, 4);
-  aWedge->GetPointIds()->SetId(5, 5);
+  auto aWedge = vtkSmartPointer<vtkWedge>::New();
+
+  for (int i = 0; i < aWedge->GetNumberOfPoints(); ++i)
+  {
+    aWedge->GetPointIds()->SetId(i, i);
+  }
+
+  aWedge->GetPoints()->SetPoint(0, 0.0, 1.0, 0.0);
+  aWedge->GetPoints()->SetPoint(1, 0.0, 0.0, 0.0);
+  aWedge->GetPoints()->SetPoint(2, 0.0, 0.5, 0.5);
+  aWedge->GetPoints()->SetPoint(3, 1.0, 1.0, 0.0);
+  aWedge->GetPoints()->SetPoint(4, 1.0, 0.0, 0.0);
+  aWedge->GetPoints()->SetPoint(5, 1.0, 0.5, 0.5);
 
-  aWedge->GetPoints()->SetPoint(0, 10, 10, 10);
-  aWedge->GetPoints()->SetPoint(1, 12, 10, 10);
-  aWedge->GetPoints()->SetPoint(2, 11, 12, 10);
-  aWedge->GetPoints()->SetPoint(3, 10, 10, 12);
-  aWedge->GetPoints()->SetPoint(4, 12, 10, 12);
-  aWedge->GetPoints()->SetPoint(5, 11, 12, 12);
   return aWedge;
 }
 
 vtkSmartPointer<vtkPolyhedron> MakeCube()
 {
-  vtkSmartPointer<vtkPolyhedron> aCube = vtkSmartPointer<vtkPolyhedron>::New();
+  auto aCube = vtkSmartPointer<vtkPolyhedron>::New();
 
   // create polyhedron (cube)
-  vtkSmartPointer<vtkPoints> points = vtkSmartPointer<vtkPoints>::New();
+  auto points = vtkSmartPointer<vtkPoints>::New();
 
   aCube->GetPointIds()->SetNumberOfIds(8);
   aCube->GetPointIds()->SetId(0, 0);
@@ -701,15 +765,16 @@ vtkSmartPointer<vtkPolyhedron> MakeCube()
 
   aCube->SetFaces(faces);
   aCube->Initialize();
+
   return aCube;
 }
 
 vtkSmartPointer<vtkPolyhedron> MakeDodecahedron()
 {
-  vtkSmartPointer<vtkPolyhedron> aDodecahedron = vtkSmartPointer<vtkPolyhedron>::New();
+  auto aDodecahedron = vtkSmartPointer<vtkPolyhedron>::New();
 
   // create polyhedron (dodecahedron)
-  vtkSmartPointer<vtkPoints> points = vtkSmartPointer<vtkPoints>::New();
+  auto points = vtkSmartPointer<vtkPoints>::New();
 
   for (int i = 0; i < 20; ++i)
   {
@@ -761,18 +826,12 @@ vtkSmartPointer<vtkPolyhedron> MakeDodecahedron()
 
 vtkSmartPointer<vtkPentagonalPrism> MakePentagonalPrism()
 {
-  vtkSmartPointer<vtkPentagonalPrism> aPentagonalPrism = vtkSmartPointer<vtkPentagonalPrism>::New();
+  auto aPentagonalPrism = vtkSmartPointer<vtkPentagonalPrism>::New();
 
-  aPentagonalPrism->GetPointIds()->SetId(0, 0);
-  aPentagonalPrism->GetPointIds()->SetId(1, 1);
-  aPentagonalPrism->GetPointIds()->SetId(2, 2);
-  aPentagonalPrism->GetPointIds()->SetId(3, 3);
-  aPentagonalPrism->GetPointIds()->SetId(4, 4);
-  aPentagonalPrism->GetPointIds()->SetId(5, 5);
-  aPentagonalPrism->GetPointIds()->SetId(6, 6);
-  aPentagonalPrism->GetPointIds()->SetId(7, 7);
-  aPentagonalPrism->GetPointIds()->SetId(8, 8);
-  aPentagonalPrism->GetPointIds()->SetId(9, 9);
+  for (int i = 0; i < aPentagonalPrism->GetNumberOfPoints(); ++i)
+  {
+    aPentagonalPrism->GetPointIds()->SetId(i, i);
+  }
 
   aPentagonalPrism->GetPoints()->SetPoint(0, 11, 10, 10);
   aPentagonalPrism->GetPoints()->SetPoint(1, 13, 10, 10);
@@ -790,19 +849,12 @@ vtkSmartPointer<vtkPentagonalPrism> MakePentagonalPrism()
 
 vtkSmartPointer<vtkHexagonalPrism> MakeHexagonalPrism()
 {
-  vtkSmartPointer<vtkHexagonalPrism> aHexagonalPrism = vtkSmartPointer<vtkHexagonalPrism>::New();
-  aHexagonalPrism->GetPointIds()->SetId(0, 0);
-  aHexagonalPrism->GetPointIds()->SetId(1, 1);
-  aHexagonalPrism->GetPointIds()->SetId(2, 2);
-  aHexagonalPrism->GetPointIds()->SetId(3, 3);
-  aHexagonalPrism->GetPointIds()->SetId(4, 4);
-  aHexagonalPrism->GetPointIds()->SetId(5, 5);
-  aHexagonalPrism->GetPointIds()->SetId(6, 6);
-  aHexagonalPrism->GetPointIds()->SetId(7, 7);
-  aHexagonalPrism->GetPointIds()->SetId(8, 8);
-  aHexagonalPrism->GetPointIds()->SetId(9, 9);
-  aHexagonalPrism->GetPointIds()->SetId(10, 10);
-  aHexagonalPrism->GetPointIds()->SetId(11, 11);
+  auto aHexagonalPrism = vtkSmartPointer<vtkHexagonalPrism>::New();
+
+  for (int i = 0; i < aHexagonalPrism->GetNumberOfPoints(); ++i)
+  {
+    aHexagonalPrism->GetPointIds()->SetId(i, i);
+  }
 
   aHexagonalPrism->GetPoints()->SetPoint(0, 11, 10, 10);
   aHexagonalPrism->GetPoints()->SetPoint(1, 13, 10, 10);
@@ -821,7 +873,7 @@ vtkSmartPointer<vtkHexagonalPrism> MakeHexagonalPrism()
 }
 
 template <typename T>
-int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear)
+int TestOneCell(VTKCellType cellType, vtkSmartPointer<T> aCell, int linear)
 {
   int status = 0;
   std::cout << "Testing " << aCell->GetClassName() << std::endl;
@@ -911,7 +963,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
         aCell->GetPoints()->GetPoint(p, vertex);
         int subId = 0;
         double x[3];
-        aCell->EvaluateLocation(subId, parametricCoords + 3 * p, x, &(*pweights.begin()));
+        aCell->EvaluateLocation(subId, parametricCoords + 3 * p, x, pweights.data());
         if (!vtkMathUtilities::FuzzyCompare(x[0], vertex[0], 1.e-3) ||
           !vtkMathUtilities::FuzzyCompare(x[1], vertex[1], 1.e-3) ||
           !vtkMathUtilities::FuzzyCompare(x[2], vertex[2], 1.e-3))
@@ -944,7 +996,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
     std::cout << pcenter[0] << ", " << pcenter[1] << ", " << pcenter[2];
     std::vector<double> cweights(aCell->GetNumberOfPoints());
     int pSubId = 0;
-    aCell->EvaluateLocation(pSubId, pcenter, center, &(*cweights.begin()));
+    aCell->EvaluateLocation(pSubId, pcenter, center, cweights.data());
     std::cout << " -> " << center[0] << ", " << center[1] << ", " << center[2];
     if (center[0] < bounds[0] || center[0] > bounds[1] || center[1] < bounds[2] ||
       center[1] > bounds[3] || center[2] < bounds[4] || center[2] > bounds[5])
@@ -1029,7 +1081,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
       double vertex[3];
       aCell->GetPoints()->GetPoint(l, vertex);
       int subId = 0;
-      aCell->EvaluateLocation(subId, locations + 3 * l, point, &(*lweights.begin()));
+      aCell->EvaluateLocation(subId, locations + 3 * l, point, lweights.data());
       for (int v = 0; v < 3; ++v)
       {
         if (!vtkMathUtilities::FuzzyCompare(point[v], vertex[v], 1.e-3))
@@ -1056,7 +1108,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
   }
 
   std::cout << "  Testing EvaluatePosition pcoord matches vertex...";
-  // Each vertex should corrrespond to a pcoord.
+  // Each vertex should correspond to a pcoord.
   int subId = 0;
   int status6 = 0;
   std::vector<double> weights(aCell->GetNumberOfPoints());
@@ -1071,7 +1123,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
       double pcoords[3];
       double dist2;
       aCell->GetPoints()->GetPoint(i, point);
-      aCell->EvaluatePosition(point, closestPoint, subId, pcoords, dist2, &(*weights.begin()));
+      aCell->EvaluatePosition(point, closestPoint, subId, pcoords, dist2, weights.data());
       for (int v = 0; v < 3; ++v)
       {
         if (!vtkMathUtilities::FuzzyCompare(*(vlocations + 3 * i + v), pcoords[v], 1.e-3))
@@ -1082,9 +1134,9 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
       if (status61)
       {
         std::cout << std::endl
-                  << *(vlocations + 3 * i + 0) << ", " << *(vlocations + 3 * i + 1) << ", "
-                  << *(vlocations + 3 * i + 2) << " != " << pcoords[0] << ", " << pcoords[1] << ", "
-                  << pcoords[2] << " ";
+                  << "Point id: " << i << ": " << *(vlocations + 3 * i + 0) << ", "
+                  << *(vlocations + 3 * i + 1) << ", " << *(vlocations + 3 * i + 2)
+                  << " != " << pcoords[0] << ", " << pcoords[1] << ", " << pcoords[2] << " ";
         ++status6;
       }
     }
@@ -1102,7 +1154,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
   std::cout << "  Testing EvaluatePosition in/out test...";
 
   int status2 = 0;
-  std::vector<std::vector<double> > testPoints;
+  std::vector<std::vector<double>> testPoints;
   std::vector<int> inOuts;
   std::vector<std::string> typePoint;
 
@@ -1113,16 +1165,16 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
     aCell->GetPoints()->GetPoint(i, &(*point.begin()));
     testPoints.push_back(point);
     inOuts.push_back(1);
-    typePoint.push_back("cell point");
+    typePoint.emplace_back("cell point");
   }
   // Then test center of cell
   if (aCell->GetNumberOfPoints() > 0)
   {
     std::vector<double> tCenter(3);
-    aCell->EvaluateLocation(subId, pcenter, &(*tCenter.begin()), &(*weights.begin()));
+    aCell->EvaluateLocation(subId, pcenter, &(*tCenter.begin()), weights.data());
     testPoints.push_back(tCenter);
     inOuts.push_back(1);
-    typePoint.push_back("cell center");
+    typePoint.emplace_back("cell center");
     // Test a point above the cell
     if (aCell->GetCellDimension() == 2)
     {
@@ -1132,7 +1184,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
       above[2] = tCenter[2] + aCell->GetLength2();
       testPoints.push_back(above);
       inOuts.push_back(0);
-      typePoint.push_back("point above cell");
+      typePoint.emplace_back("point above cell");
     }
   }
 
@@ -1142,9 +1194,9 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
     std::vector<double> eCenter(3);
     vtkCell* c = aCell->GetEdge(e);
     c->GetParametricCenter(pcenter);
-    c->EvaluateLocation(subId, pcenter, &(*eCenter.begin()), &(*weights.begin()));
+    c->EvaluateLocation(subId, pcenter, &(*eCenter.begin()), weights.data());
     testPoints.push_back(eCenter);
-    typePoint.push_back("edge center");
+    typePoint.emplace_back("edge center");
     inOuts.push_back(1);
   }
 
@@ -1154,10 +1206,10 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
     std::vector<double> fCenter(3);
     vtkCell* c = aCell->GetFace(f);
     c->GetParametricCenter(pcenter);
-    c->EvaluateLocation(subId, pcenter, &(*fCenter.begin()), &(*weights.begin()));
+    c->EvaluateLocation(subId, pcenter, &(*fCenter.begin()), weights.data());
     testPoints.push_back(fCenter);
     inOuts.push_back(1);
-    typePoint.push_back("face center");
+    typePoint.emplace_back("face center");
   }
 
   // Test a point outside the cell
@@ -1166,13 +1218,13 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
     std::vector<double> outside(3, -12345.0);
     testPoints.push_back(outside);
     inOuts.push_back(0);
-    typePoint.push_back("outside point");
+    typePoint.emplace_back("outside point");
   }
   for (size_t p = 0; p < testPoints.size(); ++p)
   {
     double closestPoint[3], pcoords[3], dist2;
     int inOut = aCell->EvaluatePosition(
-      &(*testPoints[p].begin()), closestPoint, subId, pcoords, dist2, &(*weights.begin()));
+      &(*testPoints[p].begin()), closestPoint, subId, pcoords, dist2, weights.data());
     if ((inOut == 0 || inOut == -1) && inOuts[p] == 0)
     {
       continue;
@@ -1220,7 +1272,7 @@ int TestOneCell(const VTKCellType cellType, vtkSmartPointer<T> aCell, int linear
     double endPoint[3];
     double intersection[3], pintersection[3];
     aCell->GetParametricCenter(pcenter);
-    aCell->EvaluateLocation(subId, pcenter, startPoint, &(*weights.begin()));
+    aCell->EvaluateLocation(subId, pcenter, startPoint, weights.data());
     endPoint[0] = startPoint[0];
     endPoint[1] = startPoint[1];
     endPoint[2] = startPoint[2] + aCell->GetLength2();
