@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkBiQuadraticQuad.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 // Thanks to Soeren Gebbert  who developed this class and
 // integrated it into VTK 5.0.
@@ -26,9 +14,10 @@
 #include "vtkQuad.h"
 #include "vtkQuadraticEdge.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBiQuadraticQuad);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct the quad with nine points.
 vtkBiQuadraticQuad::vtkBiQuadraticQuad()
 {
@@ -45,7 +34,7 @@ vtkBiQuadraticQuad::vtkBiQuadraticQuad()
   this->Scalars->SetNumberOfTuples(4);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkBiQuadraticQuad::~vtkBiQuadraticQuad()
 {
   this->Edge->Delete();
@@ -54,7 +43,7 @@ vtkBiQuadraticQuad::~vtkBiQuadraticQuad()
   this->Scalars->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCell* vtkBiQuadraticQuad::GetEdge(int edgeId)
 {
   edgeId = (edgeId < 0 ? 0 : (edgeId > 3 ? 3 : edgeId));
@@ -73,10 +62,10 @@ vtkCell* vtkBiQuadraticQuad::GetEdge(int edgeId)
   return this->Edge;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static int LinearQuads[4][4] = { { 0, 4, 8, 7 }, { 4, 1, 5, 8 }, { 8, 5, 2, 6 }, { 7, 8, 6, 3 } };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkBiQuadraticQuad::EvaluatePosition(const double x[3], double* closestPoint, int& subId,
   double pcoords[3], double& minDist2, double* weights)
 {
@@ -85,13 +74,22 @@ int vtkBiQuadraticQuad::EvaluatePosition(const double x[3], double* closestPoint
   double tempWeights[4];
   double closest[3];
 
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return 0;
+  }
+  const double* pts = pointsArray->GetPointer(0);
+
   // four linear quads are used
   for (minDist2 = VTK_DOUBLE_MAX, i = 0; i < 4; i++)
   {
-    this->Quad->Points->SetPoint(0, this->Points->GetPoint(LinearQuads[i][0]));
-    this->Quad->Points->SetPoint(1, this->Points->GetPoint(LinearQuads[i][1]));
-    this->Quad->Points->SetPoint(2, this->Points->GetPoint(LinearQuads[i][2]));
-    this->Quad->Points->SetPoint(3, this->Points->GetPoint(LinearQuads[i][3]));
+    this->Quad->Points->SetPoint(0, pts + 3 * LinearQuads[i][0]);
+    this->Quad->Points->SetPoint(1, pts + 3 * LinearQuads[i][1]);
+    this->Quad->Points->SetPoint(2, pts + 3 * LinearQuads[i][2]);
+    this->Quad->Points->SetPoint(3, pts + 3 * LinearQuads[i][3]);
 
     status = this->Quad->EvaluatePosition(x, closest, ignoreId, pc, dist2, tempWeights);
     if (status != -1 && dist2 < minDist2)
@@ -136,26 +134,35 @@ int vtkBiQuadraticQuad::EvaluatePosition(const double x[3], double* closestPoint
     else
     {
       // Compute weights only
-      this->InterpolationFunctionsPrivate(pcoords, weights);
+      vtkBiQuadraticQuad::InterpolationFunctionsPrivate(pcoords, weights);
     }
   }
 
   return returnStatus;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticQuad::EvaluateLocation(
   int& vtkNotUsed(subId), const double pcoords[3], double x[3], double* weights)
 {
   int i, j;
-  double pt[3];
+  const double* pt;
 
-  this->InterpolationFunctionsPrivate(pcoords, weights);
+  vtkBiQuadraticQuad::InterpolationFunctionsPrivate(pcoords, weights);
+
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return;
+  }
+  const double* pts = pointsArray->GetPointer(0);
 
   x[0] = x[1] = x[2] = 0.0;
   for (i = 0; i < 9; i++)
   {
-    this->Points->GetPoint(i, pt);
+    pt = pts + 3 * i;
     for (j = 0; j < 3; j++)
     {
       x[j] += pt[j] * weights[i];
@@ -163,13 +170,13 @@ void vtkBiQuadraticQuad::EvaluateLocation(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkBiQuadraticQuad::CellBoundary(int subId, const double pcoords[3], vtkIdList* pts)
 {
   return this->Quad->CellBoundary(subId, pcoords, pts);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticQuad::Contour(double value, vtkDataArray* cellScalars,
   vtkIncrementalPointLocator* locator, vtkCellArray* verts, vtkCellArray* lines,
   vtkCellArray* polys, vtkPointData* inPd, vtkPointData* outPd, vtkCellData* inCd, vtkIdType cellId,
@@ -190,7 +197,7 @@ void vtkBiQuadraticQuad::Contour(double value, vtkDataArray* cellScalars,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Clip this quadratic quad using scalar value provided. Like contouring,
 // except that it cuts the quad to produce other quads and triangles.
 void vtkBiQuadraticQuad::Clip(double value, vtkDataArray* cellScalars,
@@ -212,7 +219,7 @@ void vtkBiQuadraticQuad::Clip(double value, vtkDataArray* cellScalars,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Line-line intersection. Intersection has to occur within [0,1] parametric
 // coordinates and with specified tolerance.
 int vtkBiQuadraticQuad::IntersectWithLine(
@@ -238,7 +245,7 @@ int vtkBiQuadraticQuad::IntersectWithLine(
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkBiQuadraticQuad::Triangulate(int vtkNotUsed(index), vtkIdList* ptIds, vtkPoints* pts)
 {
   pts->SetNumberOfPoints(24);
@@ -305,7 +312,7 @@ int vtkBiQuadraticQuad::Triangulate(int vtkNotUsed(index), vtkIdList* ptIds, vtk
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticQuad::Derivatives(
   int vtkNotUsed(subId), const double pcoords[3], const double* values, int dim, double* derivs)
 {
@@ -314,8 +321,8 @@ void vtkBiQuadraticQuad::Derivatives(
   double *J[3], J0[3], J1[3], J2[3];
   double *JI[3], JI0[3], JI1[3], JI2[3];
 
-  this->InterpolationFunctionsPrivate(pcoords, weights);
-  this->InterpolationDerivsPrivate(pcoords, functionDerivs);
+  vtkBiQuadraticQuad::InterpolationFunctionsPrivate(pcoords, weights);
+  vtkBiQuadraticQuad::InterpolationDerivsPrivate(pcoords, functionDerivs);
 
   // Compute transposed Jacobian and inverse Jacobian
   J[0] = J0;
@@ -378,7 +385,7 @@ void vtkBiQuadraticQuad::Derivatives(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute interpolation functions. The first four nodes are the corner
 // vertices; the others are mid-edge nodes, the last one is the mid-center
 // node.
@@ -404,7 +411,7 @@ void vtkBiQuadraticQuad::InterpolationFunctionsPrivate(const double pcoords[3],
   weights[8] = 16.0 * (x) * (1.0 - x) * (1.0 - y) * (y);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Derivatives in parametric space.
 void vtkBiQuadraticQuad::InterpolationDerivsPrivate(const double pcoords[3], double derivs[18])
 {
@@ -441,7 +448,7 @@ void vtkBiQuadraticQuad::InterpolationDerivsPrivate(const double pcoords[3], dou
   derivs[17] = 16.0 * (x) * (1.0 - x) * (1.0 - 2.0 * y);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static double vtkQQuadCellPCoords[27] = { 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 1.0, 1.0, 0.0, 0.0, 1.0,
   0.0, 0.5, 0.0, 0.0, 1.0, 0.5, 0.0, 0.5, 1.0, 0.0, 0.0, 0.5, 0.0, 0.5, 0.5, 0.0 };
 
@@ -450,7 +457,7 @@ double* vtkBiQuadraticQuad::GetParametricCoords()
   return vtkQQuadCellPCoords;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticQuad::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -462,3 +469,4 @@ void vtkBiQuadraticQuad::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Scalars:\n";
   this->Scalars->PrintSelf(os, indent.GetNextIndent());
 }
+VTK_ABI_NAMESPACE_END
