@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkBiQuadraticTriangle.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkBiQuadraticTriangle.h"
 
 #include "vtkDoubleArray.h"
@@ -22,9 +10,10 @@
 #include "vtkQuadraticEdge.h"
 #include "vtkTriangle.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBiQuadraticTriangle);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct the line with two points.
 vtkBiQuadraticTriangle::vtkBiQuadraticTriangle()
 {
@@ -42,7 +31,7 @@ vtkBiQuadraticTriangle::vtkBiQuadraticTriangle()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkBiQuadraticTriangle::~vtkBiQuadraticTriangle()
 {
   this->Edge->Delete();
@@ -50,7 +39,7 @@ vtkBiQuadraticTriangle::~vtkBiQuadraticTriangle()
   this->Scalars->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCell* vtkBiQuadraticTriangle::GetEdge(int edgeId)
 {
   edgeId = (edgeId < 0 ? 0 : (edgeId > 2 ? 2 : edgeId));
@@ -69,7 +58,7 @@ vtkCell* vtkBiQuadraticTriangle::GetEdge(int edgeId)
   return this->Edge;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // order picked carefully for parametric coordinate conversion
 static int LinearTris[6][3] = {
   { 0, 3, 6 },
@@ -90,12 +79,21 @@ int vtkBiQuadraticTriangle::EvaluatePosition(const double x[3], double closestPo
 
   pc0 = pc1 = 0;
 
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return 0;
+  }
+  const double* pts = pointsArray->GetPointer(0);
+
   // six linear triangles are used
   for (minDist2 = VTK_DOUBLE_MAX, i = 0; i < 6; i++)
   {
-    this->Face->Points->SetPoint(0, this->Points->GetPoint(LinearTris[i][0]));
-    this->Face->Points->SetPoint(1, this->Points->GetPoint(LinearTris[i][1]));
-    this->Face->Points->SetPoint(2, this->Points->GetPoint(LinearTris[i][2]));
+    this->Face->Points->SetPoint(0, pts + 3 * LinearTris[i][0]);
+    this->Face->Points->SetPoint(1, pts + 3 * LinearTris[i][1]);
+    this->Face->Points->SetPoint(2, pts + 3 * LinearTris[i][2]);
 
     status = this->Face->EvaluatePosition(x, closest, ignoreId, pc, dist2, tempWeights);
     if (status != -1 && dist2 < minDist2)
@@ -149,27 +147,36 @@ int vtkBiQuadraticTriangle::EvaluatePosition(const double x[3], double closestPo
       pcoords[1] = 0.5 + 0.5 * pc1;
     }
     pcoords[2] = 0.0;
-    this->InterpolationFunctions(pcoords, weights);
+    vtkBiQuadraticTriangle::InterpolationFunctions(pcoords, weights);
   }
 
   return returnStatus;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticTriangle::EvaluateLocation(
   int& vtkNotUsed(subId), const double pcoords[3], double x[3], double* weights)
 {
-  int i;
-  double a0[3], a1[3], a2[3], a3[3], a4[3], a5[3], a6[3];
-  this->Points->GetPoint(0, a0);
-  this->Points->GetPoint(1, a1);
-  this->Points->GetPoint(2, a2);
-  this->Points->GetPoint(3, a3);
-  this->Points->GetPoint(4, a4);
-  this->Points->GetPoint(5, a5);
-  this->Points->GetPoint(6, a6);
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return;
+  }
+  const double* pts = pointsArray->GetPointer(0);
 
-  this->InterpolationFunctions(pcoords, weights);
+  int i;
+  const double *a0, *a1, *a2, *a3, *a4, *a5, *a6;
+  a0 = pts;
+  a1 = pts + 3;
+  a2 = pts + 6;
+  a3 = pts + 9;
+  a4 = pts + 12;
+  a5 = pts + 15;
+  a6 = pts + 18;
+
+  vtkBiQuadraticTriangle::InterpolationFunctions(pcoords, weights);
 
   for (i = 0; i < 3; i++)
   {
@@ -178,13 +185,13 @@ void vtkBiQuadraticTriangle::EvaluateLocation(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkBiQuadraticTriangle::CellBoundary(int subId, const double pcoords[3], vtkIdList* pts)
 {
   return this->Face->CellBoundary(subId, pcoords, pts);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticTriangle::Contour(double value, vtkDataArray* cellScalars,
   vtkIncrementalPointLocator* locator, vtkCellArray* verts, vtkCellArray* lines,
   vtkCellArray* polys, vtkPointData* inPd, vtkPointData* outPd, vtkCellData* inCd, vtkIdType cellId,
@@ -212,7 +219,7 @@ void vtkBiQuadraticTriangle::Contour(double value, vtkDataArray* cellScalars,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Line-line intersection. Intersection has to occur within [0,1] parametric
 // coordinates and with specified tolerance.
 int vtkBiQuadraticTriangle::IntersectWithLine(
@@ -236,7 +243,7 @@ int vtkBiQuadraticTriangle::IntersectWithLine(
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkBiQuadraticTriangle::Triangulate(int vtkNotUsed(index), vtkIdList* ptIds, vtkPoints* pts)
 {
   pts->Reset();
@@ -256,7 +263,7 @@ int vtkBiQuadraticTriangle::Triangulate(int vtkNotUsed(index), vtkIdList* ptIds,
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticTriangle::Derivatives(
   int vtkNotUsed(subId), const double pcoords[3], const double* values, int dim, double* derivs)
 {
@@ -321,7 +328,7 @@ void vtkBiQuadraticTriangle::Derivatives(
   v6[0] = vtkMath::Dot(vec60, v10);
   v6[1] = vtkMath::Dot(vec60, v20);
 
-  this->InterpolationDerivs(pcoords, funcDerivs);
+  vtkBiQuadraticTriangle::InterpolationDerivs(pcoords, funcDerivs);
 
   // Compute Jacobian and inverse Jacobian
   J[0] = J0;
@@ -375,7 +382,7 @@ void vtkBiQuadraticTriangle::Derivatives(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Clip this quadratic triangle using the scalar value provided. Like
 // contouring, except that it cuts the triangle to produce other quads
 // and triangles.
@@ -402,7 +409,7 @@ void vtkBiQuadraticTriangle::Clip(double value, vtkDataArray* cellScalars,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute maximum parametric distance to cell
 double vtkBiQuadraticTriangle::GetParametricDistance(const double pcoords[3])
 {
@@ -437,7 +444,7 @@ double vtkBiQuadraticTriangle::GetParametricDistance(const double pcoords[3])
   return pDistMax;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute interpolation functions. The first three nodes are the triangle
 // vertices; the next three nodes are mid-edge nodes; the last node is the mid-cell node.
 void vtkBiQuadraticTriangle::InterpolationFunctions(const double pcoords[3], double weights[7])
@@ -454,7 +461,7 @@ void vtkBiQuadraticTriangle::InterpolationFunctions(const double pcoords[3], dou
   weights[6] = 27.0 * r * s * (1.0 - r - s);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Derivatives in parametric space.
 void vtkBiQuadraticTriangle::InterpolationDerivs(const double pcoords[3], double derivs[14])
 {
@@ -480,7 +487,7 @@ void vtkBiQuadraticTriangle::InterpolationDerivs(const double pcoords[3], double
   derivs[13] = 27.0 * r * (1.0 - r - 2.0 * s);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static double vtkBiQTriangleCellPCoords[21] = {
   0.0, 0.0, 0.0,                //
   1.0, 0.0, 0.0,                //
@@ -495,7 +502,7 @@ double* vtkBiQuadraticTriangle::GetParametricCoords()
   return vtkBiQTriangleCellPCoords;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkBiQuadraticTriangle::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -504,3 +511,4 @@ void vtkBiQuadraticTriangle::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Face: " << this->Face << endl;
   os << indent << "Scalars: " << this->Scalars << endl;
 }
+VTK_ABI_NAMESPACE_END
