@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCellTypes.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkCellTypes
  * @brief   object provides direct access to cells in vtkCellArray and type information
@@ -39,11 +27,15 @@
 #include "vtkCommonDataModelModule.h" // For export macro
 #include "vtkObject.h"
 
-#include "vtkCellType.h"          // Needed for VTK_EMPTY_CELL
+#include "vtkCellType.h"          // Needed for inline methods
+#include "vtkDeprecation.h"       // For VTK_DEPRECATED_IN_9_2_0
 #include "vtkIdTypeArray.h"       // Needed for inline methods
-#include "vtkIntArray.h"          // Needed for inline methods
+#include "vtkSmartPointer.h"      // Needed for internals
 #include "vtkUnsignedCharArray.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
+class vtkIntArray;
+
 class VTKCOMMONDATAMODEL_EXPORT vtkCellTypes : public vtkObject
 {
 public:
@@ -68,19 +60,28 @@ public:
 
   /**
    * Specify a group of cell types.
+   *
+   * \deprecated Please use method version that doesn't use `cellLocations` instead.
    */
+  VTK_DEPRECATED_IN_9_2_0("Please use version without cellLocations.")
   void SetCellTypes(
     vtkIdType ncells, vtkUnsignedCharArray* cellTypes, vtkIdTypeArray* cellLocations);
 
   /**
-   * Specify a group of cell types. This version is provided to maintain
-   * backwards compatibility and does a copy of the cellLocations
+   * Specify a group of cell types.
    */
+  void SetCellTypes(vtkIdType ncells, vtkUnsignedCharArray* cellTypes);
+
+  VTK_DEPRECATED_IN_9_2_0("Please use version without cellLocations.")
   void SetCellTypes(vtkIdType ncells, vtkUnsignedCharArray* cellTypes, vtkIntArray* cellLocations);
 
   /**
    * Return the location of the cell in the associated vtkCellArray.
+   *
+   * \deprecated This method will go away in future releases.
+   * Please do not rely on `CellLocation` in this class.
    */
+  VTK_DEPRECATED_IN_9_2_0("The Location API will disappear.")
   vtkIdType GetCellLocation(vtkIdType cellId) { return this->LocationArray->GetValue(cellId); }
 
   /**
@@ -154,23 +155,31 @@ public:
    */
   static int IsLinear(unsigned char type);
 
-  //@{
+  /**
+   * Get the dimension of a cell.
+   */
+  static int GetDimension(unsigned char type);
+
+  ///@{
   /**
    * Methods for obtaining the arrays representing types and locations.
    */
   vtkUnsignedCharArray* GetCellTypesArray() { return this->TypeArray; }
   vtkIdTypeArray* GetCellLocationsArray() { return this->LocationArray; }
-  //@}
+  ///@}
 
 protected:
   vtkCellTypes();
-  ~vtkCellTypes() override;
+  ~vtkCellTypes() override = default;
 
-  vtkUnsignedCharArray* TypeArray; // pointer to types array
-  vtkIdTypeArray* LocationArray;   // pointer to array of offsets
-  vtkIdType Size;                  // allocated size of data
-  vtkIdType MaxId;                 // maximum index inserted thus far
-  vtkIdType Extend;                // grow array by this point
+  vtkSmartPointer<vtkUnsignedCharArray> TypeArray; // pointer to types array
+
+  // DEPRECATION_IN_9_2_0 Note for whoever is in deprecation duties:
+  // The attribute LocationArray needs to be deleted, and any code in this class that would fail
+  // compiling because of its removal deleted as well.
+  vtkSmartPointer<vtkIdTypeArray> LocationArray; // pointer to array of offsets
+
+  vtkIdType MaxId; // maximum index inserted thus far
 
 private:
   vtkCellTypes(const vtkCellTypes&) = delete;
@@ -198,4 +207,5 @@ inline int vtkCellTypes::IsLinear(unsigned char type)
   return ((type <= 20) || (type == VTK_CONVEX_POINT_SET) || (type == VTK_POLYHEDRON));
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
