@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkGenericCellTessellator.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkGenericCellTessellator.h"
 #include "vtkObjectFactory.h"
 
@@ -32,9 +20,10 @@
 
 #include "vtkMath.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkGenericCellTessellator, ErrorMetrics, vtkCollection);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Create the tessellator helper with a default of 0.25 for threshold
 vtkGenericCellTessellator::vtkGenericCellTessellator()
 {
@@ -45,14 +34,14 @@ vtkGenericCellTessellator::vtkGenericCellTessellator()
   this->Measurement = 0;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGenericCellTessellator::~vtkGenericCellTessellator()
 {
   this->SetErrorMetrics(nullptr);
   delete[] this->MaxErrors;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGenericCellTessellator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -63,7 +52,7 @@ void vtkGenericCellTessellator::PrintSelf(ostream& os, vtkIndent indent)
   /* this->MaxErrors */
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Does the edge need to be subdivided according to at least one error
 // metric? The edge is defined by its `leftPoint' and its `rightPoint'.
@@ -105,7 +94,7 @@ int vtkGenericCellTessellator::RequiresEdgeSubdivision(
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Update the max error of each error metric according to the error at the
 // mid-point. The type of error depends on the state
@@ -145,7 +134,7 @@ void vtkGenericCellTessellator::UpdateMaxError(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Init the error metric with the dataset. Should be called in each filter
 // before any tessellation of any cell.
@@ -168,7 +157,7 @@ void vtkGenericCellTessellator::InitErrorMetrics(vtkGenericDataSet* ds)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Reset the maximal error of each error metric. The purpose of the maximal
 // error is to measure the quality of a fixed subdivision.
@@ -190,7 +179,7 @@ void vtkGenericCellTessellator::ResetMaxErrors()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Get the maximum error measured after the fixed subdivision.
 // \pre errors_exists: errors!=0
@@ -206,7 +195,7 @@ void vtkGenericCellTessellator::GetMaxErrors(double* errors)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Send the current cell to error metrics. Should be called at the beginning
 // of the implementation of Tessellate(), Triangulate()
@@ -226,3 +215,4 @@ void vtkGenericCellTessellator::SetGenericCell(vtkGenericAdaptorCell* cell)
     e = static_cast<vtkGenericSubdivisionErrorMetric*>(this->ErrorMetrics->GetNextItemAsObject());
   }
 }
+VTK_ABI_NAMESPACE_END
