@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkHigherOrderQuadrilateral.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkHigherOrderQuadrilateral.h"
 
 #include "vtkCellData.h"
@@ -28,6 +17,7 @@
 #include "vtkVector.h"
 #include "vtkVectorOperators.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkHigherOrderQuadrilateral::vtkHigherOrderQuadrilateral()
 {
   this->Approx = nullptr;
@@ -190,12 +180,21 @@ void vtkHigherOrderQuadrilateral::EvaluateLocation(
   subId = 0; // TODO: Should this be -1?
   this->InterpolateFunctions(pcoords, weights);
 
-  double p[3];
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return;
+  }
+  const double* pts = pointsArray->GetPointer(0);
+
+  const double* p;
   x[0] = x[1] = x[2] = 0.;
   vtkIdType nPoints = this->GetPoints()->GetNumberOfPoints();
   for (vtkIdType idx = 0; idx < nPoints; ++idx)
   {
-    this->Points->GetPoint(idx, p);
+    p = pts + 3 * idx;
     for (vtkIdType jdx = 0; jdx < 3; ++jdx)
     {
       x[jdx] += p[jdx] * weights[idx];
@@ -489,7 +488,7 @@ bool vtkHigherOrderQuadrilateral::SubCellCoordinatesFromId(int& i, int& j, int&
   i = subId % this->Order[0];
   j = (subId / this->Order[0]) % this->Order[1];
   k = 0;
-  return i + this->Order[0] * j == subId ? true : false;
+  return i + this->Order[0] * j == subId;
 }
 
 /**\brief A convenience function to get a connectivity offset from a control-point tuple.
@@ -562,13 +561,12 @@ bool vtkHigherOrderQuadrilateral::TransformApproxToCellParams(int subCell, doubl
 /**\brief Set the degree  of the cell, given a vtkDataSet and cellId
  */
 void vtkHigherOrderQuadrilateral::SetOrderFromCellData(
-  vtkCellData* cell_data, const vtkIdType numPts, const vtkIdType cell_id)
+  vtkCellData* cell_data, vtkIdType numPts, vtkIdType cell_id)
 {
-  if (cell_data->SetActiveAttribute(
-        "HigherOrderDegrees", vtkDataSetAttributes::AttributeTypes::HIGHERORDERDEGREES) != -1)
+  vtkDataArray* v = cell_data->GetHigherOrderDegrees();
+  if (v)
   {
     double degs[3];
-    vtkDataArray* v = cell_data->GetHigherOrderDegrees();
     v->GetTuple(cell_id, degs);
     this->SetOrder(degs[0], degs[1]);
     if (this->Order[2] != numPts)
@@ -580,7 +578,7 @@ void vtkHigherOrderQuadrilateral::SetOrderFromCellData(
   }
 }
 
-void vtkHigherOrderQuadrilateral::SetUniformOrderFromNumPoints(const vtkIdType numPts)
+void vtkHigherOrderQuadrilateral::SetUniformOrderFromNumPoints(vtkIdType numPts)
 {
   int deg = static_cast<int>(round(std::sqrt(static_cast<int>(numPts)))) - 1;
   this->SetOrder(deg, deg);
@@ -588,7 +586,7 @@ void vtkHigherOrderQuadrilateral::SetUniformOrderFromNumPoints(const vtkIdType n
     vtkErrorMacro("The degrees are direction dependents, and should be set in the input file.");
 }
 
-void vtkHigherOrderQuadrilateral::SetOrder(const int s, const int t)
+void vtkHigherOrderQuadrilateral::SetOrder(int s, int t)
 {
   if (this->PointParametricCoordinates && (Order[0] != s || Order[1] != t))
     this->PointParametricCoordinates->Reset();
@@ -614,3 +612,23 @@ const int* vtkHigherOrderQuadrilateral::GetOrder()
   }
   return this->Order;
 }
+
+bool vtkHigherOrderQuadrilateral::PointCountSupportsUniformOrder(vtkIdType pointsPerCell)
+{
+  // Determine if sqrt(N) is integral (and if so, what is it?).
+  vtkIdType nn = pointsPerCell;
+  int h = nn % 0x0f; // Perfect squares in base 16 must end in 0, 1, 4, or 9.
+  if (h > 9 || (h > 1 && h < 4) || (h > 4 && h < 9))
+  {
+    // Trivially reject numbers with a bad final digit.
+    return false;
+  }
+  // There's a chance we have a perfect square, do the hard work.
+  int root = std::floor(std::sqrt(nn) + 0.5);
+  if (root * root != nn)
+  {
+    return false;
+  }
+  return root >= 4;
+}
+VTK_ABI_NAMESPACE_END
