@@ -1,24 +1,11 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkMeanValueCoordinatesInterpolator.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkMeanValueCoordinatesInterpolator.h"
 #include "vtkObjectFactory.h"
 
 #include "vtkArrayDispatch.h"
 #include "vtkCellArray.h"
 #include "vtkCellArrayIterator.h"
-#include "vtkConfigure.h"
 #include "vtkDataArrayRange.h"
 #include "vtkDoubleArray.h"
 #include "vtkFloatArray.h"
@@ -30,6 +17,7 @@
 #include <numeric>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkMeanValueCoordinatesInterpolator);
 
 // Special class that can iterate over different type of triangle representations
@@ -107,17 +95,17 @@ public:
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct object with default tuple dimension (number of components) of 1.
 vtkMeanValueCoordinatesInterpolator::vtkMeanValueCoordinatesInterpolator() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMeanValueCoordinatesInterpolator::~vtkMeanValueCoordinatesInterpolator() = default;
 
 namespace
 {
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Templated function to generate weights of a general polygonal mesh.
 // This class actually implements the algorithm.
 struct ComputeWeightsForPolygonMesh
@@ -170,6 +158,12 @@ struct ComputeWeightsForPolygonMesh
     {
       int nPolyPts = iter.CurrentPolygonSize;
 
+      if (nPolyPts == 0)
+      {
+        poly = ++iter;
+        continue;
+      }
+
       for (int j = 0; j < nPolyPts; j++)
       {
         u[j] = uVec.data() + 3 * poly[j];
@@ -342,7 +336,7 @@ struct ComputeWeightsForPolygonMesh
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Templated function to generate weights of a triangle mesh.
 // This class actually implements the algorithm.
 struct ComputeWeightsForTriangleMesh
@@ -504,7 +498,7 @@ struct ComputeWeightsForTriangleMesh
 
 } // end anon namespace
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Static function to compute weights for triangle mesh (with vtkIdList)
 // Satisfy classes' public API.
 void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeights(
@@ -525,7 +519,7 @@ void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeights(
     x, pts, iter, weights);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Static function to compute weights for triangle or polygonal mesh
 // (with vtkCellArray). Satisfy classes' public API.
 void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeights(
@@ -576,7 +570,7 @@ void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeights(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeightsForTriangleMesh(
   const double x[3], vtkPoints* pts, vtkMVCTriIterator& iter, double* weights)
 {
@@ -605,7 +599,7 @@ void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeightsForTriangle
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeightsForPolygonMesh(
   const double x[3], vtkPoints* pts, vtkMVCPolyIterator& iter, double* weights)
 {
@@ -634,8 +628,9 @@ void vtkMeanValueCoordinatesInterpolator::ComputeInterpolationWeightsForPolygonM
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMeanValueCoordinatesInterpolator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
