@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkRectilinearGrid.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkRectilinearGrid
  * @brief   a dataset that is topologically regular with variable spacing in the three coordinate
@@ -41,6 +29,7 @@
 #include "vtkDataSet.h"
 #include "vtkStructuredData.h" // For inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkVertex;
 class vtkLine;
 class vtkPixel;
@@ -52,6 +41,7 @@ class VTKCOMMONDATAMODEL_EXPORT vtkRectilinearGrid : public vtkDataSet
 {
 public:
   static vtkRectilinearGrid* New();
+  static vtkRectilinearGrid* ExtendedNew();
 
   vtkTypeMacro(vtkRectilinearGrid, vtkDataSet);
   void PrintSelf(ostream& os, vtkIndent indent) override;
@@ -72,7 +62,7 @@ public:
    */
   void Initialize() override;
 
-  //@{
+  ///@{
   /**
    * Standard vtkDataSet API methods. See vtkDataSet for more information.
    */
@@ -93,6 +83,8 @@ public:
   vtkCell* FindAndGetCell(double x[3], vtkCell* cell, vtkIdType cellId, double tol2, int& subId,
     double pcoords[3], double* weights) override;
   int GetCellType(vtkIdType cellId) override;
+  vtkIdType GetCellSize(vtkIdType cellId) override;
+  using vtkDataSet::GetCellPoints;
   void GetCellPoints(vtkIdType cellId, vtkIdList* ptIds) override
   {
     vtkStructuredData::GetCellPoints(cellId, ptIds, this->DataDescription, this->Dimensions);
@@ -104,7 +96,41 @@ public:
   void ComputeBounds() override;
   int GetMaxCellSize() override { return 8; } // voxel is the largest
   void GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds) override;
-  //@}
+  void GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds, int* seedLoc);
+  ///@}
+
+  /**
+   * Return non-zero value if specified point is visible.
+   * These methods should be called only after the dimensions of the
+   * grid are set.
+   */
+  unsigned char IsPointVisible(vtkIdType ptId);
+
+  /**
+   * Return non-zero value if specified point is visible.
+   * These methods should be called only after the dimensions of the
+   * grid are set.
+   */
+  unsigned char IsCellVisible(vtkIdType cellId);
+
+  /**
+   * Returns 1 if there is any visibility constraint on the points,
+   * 0 otherwise.
+   */
+  bool HasAnyBlankPoints() override;
+  /**
+   * Returns 1 if there is any visibility constraint on the cells,
+   * 0 otherwise.
+   */
+  bool HasAnyBlankCells() override;
+
+  /**
+   * Given the node dimensions of this grid instance, this method computes the
+   * node dimensions. The value in each dimension can will have a lowest value
+   * of "1" such that computing the total number of cells can be achieved by
+   * simply by cellDims[0]*cellDims[1]*cellDims[2].
+   */
+  void GetCellDims(int cellDims[3]);
 
   /**
    * Given a user-supplied vtkPoints container object, this method fills in all
@@ -112,21 +138,21 @@ public:
    */
   void GetPoints(vtkPoints* pnts);
 
-  //@{
+  ///@{
   /**
    * Set dimensions of rectilinear grid dataset.
    * This also sets the extent.
    */
   void SetDimensions(int i, int j, int k);
   void SetDimensions(const int dim[3]);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get dimensions of this rectilinear grid dataset.
    */
   vtkGetVectorMacro(Dimensions, int, 3);
-  //@}
+  ///@}
 
   /**
    * Return the dimensionality of the data.
@@ -156,42 +182,42 @@ public:
    * xyz-coordinates. The xyz coordinates are stored in the user-supplied
    * array p.
    */
-  void GetPoint(const int i, const int j, const int k, double p[3]);
+  void GetPoint(int i, int j, int k, double p[3]);
 
-  //@{
+  ///@{
   /**
    * Specify the grid coordinates in the x-direction.
    */
   virtual void SetXCoordinates(vtkDataArray*);
   vtkGetObjectMacro(XCoordinates, vtkDataArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the grid coordinates in the y-direction.
    */
   virtual void SetYCoordinates(vtkDataArray*);
   vtkGetObjectMacro(YCoordinates, vtkDataArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the grid coordinates in the z-direction.
    */
   virtual void SetZCoordinates(vtkDataArray*);
   vtkGetObjectMacro(ZCoordinates, vtkDataArray);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Different ways to set the extent of the data array.  The extent
    * should be set before the "Scalars" are set or allocated.
    * The Extent is stored in the order (X, Y, Z).
    */
   void SetExtent(int extent[6]);
-  void SetExtent(int x1, int x2, int y1, int y2, int z1, int z2);
+  void SetExtent(int xMin, int xMax, int yMin, int yMax, int zMin, int zMax);
   vtkGetVector6Macro(Extent, int);
-  //@}
+  ///@}
 
   /**
    * Return the actual size of the data in kibibytes (1024 bytes). This number
@@ -203,13 +229,13 @@ public:
    */
   unsigned long GetActualMemorySize() override;
 
-  //@{
+  ///@{
   /**
    * Shallow and Deep copy.
    */
   void ShallowCopy(vtkDataObject* src) override;
   void DeepCopy(vtkDataObject* src) override;
-  //@}
+  ///@}
 
   /**
    * Structured extent. The extent type is a 3D extent
@@ -223,13 +249,35 @@ public:
    */
   void Crop(const int* updateExtent) override;
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkRectilinearGrid* GetData(vtkInformation* info);
   static vtkRectilinearGrid* GetData(vtkInformationVector* v, int i = 0);
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * Set/Get the scalar data type for the points. This is setting pipeline info.
+   */
+  static void SetScalarType(int, vtkInformation* meta_data);
+  static int GetScalarType(vtkInformation* meta_data);
+  static bool HasScalarType(vtkInformation* meta_data);
+  int GetScalarType();
+  const char* GetScalarTypeAsString() { return vtkImageScalarTypeNameMacro(this->GetScalarType()); }
+  ///@}
+
+  ///@{
+  /**
+   * Set/Get the number of scalar components for points. As with the
+   * SetScalarType method this is setting pipeline info.
+   */
+  static void SetNumberOfScalarComponents(int n, vtkInformation* meta_data);
+  static int GetNumberOfScalarComponents(vtkInformation* meta_data);
+  static bool HasNumberOfScalarComponents(vtkInformation* meta_data);
+  int GetNumberOfScalarComponents();
+  ///@}
 
 protected:
   vtkRectilinearGrid();
@@ -256,7 +304,6 @@ protected:
 private:
   void Cleanup();
 
-private:
   vtkRectilinearGrid(const vtkRectilinearGrid&) = delete;
   void operator=(const vtkRectilinearGrid&) = delete;
 };
@@ -306,4 +353,5 @@ inline vtkIdType vtkRectilinearGrid::ComputeCellId(int ijk[3])
   return vtkStructuredData::ComputeCellId(this->Dimensions, ijk);
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
