@@ -1,20 +1,7 @@
-/*=========================================================================
-
-  Program:   ParaView
-  Module:    vtkSelection.cxx
-
-  Copyright (c) Kitware, Inc.
-  All rights reserved.
-  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSelection.h"
 
-#include "vtkAbstractArray.h"
 #include "vtkFieldData.h"
 #include "vtkInformation.h"
 #include "vtkInformationIntegerKey.h"
@@ -30,33 +17,20 @@
 #include "vtkTable.h"
 
 #include <vtksys/RegularExpression.hxx>
-#include <vtksys/SystemTools.hxx>
 
 #include <atomic>
 #include <cassert>
 #include <cctype>
-#include <iterator>
 #include <map>
 #include <memory>
 #include <sstream>
 #include <string>
 #include <vector>
 
-namespace
-{
-// since certain compilers don't support std::to_string yet
-template <typename T>
-std::string convert_to_string(const T& val)
-{
-  std::ostringstream str;
-  str << val;
-  return str.str();
-}
-}
-
 //============================================================================
 namespace parser
 {
+VTK_ABI_NAMESPACE_BEGIN
 class Node
 {
 public:
@@ -68,19 +42,18 @@ public:
 
 class NodeVariable : public Node
 {
-  vtkSignedCharArray* Data;
+  signed char* Data;
   std::string Name;
 
 public:
   NodeVariable(vtkSignedCharArray* data, const std::string& name)
-    : Data(data)
+    : Data(data ? data->GetPointer(0) : nullptr)
     , Name(name)
   {
   }
   bool Evaluate(vtkIdType offset) const override
   {
-    assert(this->Data == nullptr || this->Data->GetNumberOfValues() > offset);
-    return this->Data ? (this->Data->GetValue(offset) != 0) : false;
+    return this->Data ? this->Data[offset] != 0 : false;
   }
   void Print(ostream& os) const override { os << this->Name; }
 };
@@ -157,15 +130,43 @@ public:
     os << ")";
   }
 };
+
+class NodeXor : public Node
+{
+  std::shared_ptr<Node> ChildA;
+  std::shared_ptr<Node> ChildB;
+
+public:
+  NodeXor(const std::shared_ptr<Node>& nodeA, const std::shared_ptr<Node>& nodeB)
+    : ChildA(nodeA)
+    , ChildB(nodeB)
+  {
+  }
+  bool Evaluate(vtkIdType offset) const override
+  {
+    assert(this->ChildA && this->ChildB);
+    return this->ChildA->Evaluate(offset) ^ this->ChildB->Evaluate(offset);
+  }
+  void Print(ostream& os) const override
+  {
+    os << "(";
+    this->ChildA->Print(os);
+    os << " ^ ";
+    this->ChildB->Print(os);
+    os << ")";
+  }
+};
+VTK_ABI_NAMESPACE_END
 } // namespace parser
 
+VTK_ABI_NAMESPACE_BEGIN
 //============================================================================
 class vtkSelection::vtkInternals
 {
   // applies the operator on the "top" (aka back) of the op_stack to the
   // variables on the var_stack and pushes the result on the var_stack.
   bool ApplyBack(
-    std::vector<char>& op_stack, std::vector<std::shared_ptr<parser::Node> >& var_stack) const
+    std::vector<char>& op_stack, std::vector<std::shared_ptr<parser::Node>>& var_stack) const
   {
     assert(!op_stack.empty());
 
@@ -183,7 +184,7 @@ class vtkSelection::vtkInternals
       op_stack.pop_back();
       return true;
     }
-    else if (op_stack.back() == '|' || op_stack.back() == '&')
+    else if (op_stack.back() == '|' || op_stack.back() == '^' || op_stack.back() == '&')
     {
       if (var_stack.size() < 2)
       {
@@ -199,7 +200,11 @@ class vtkSelection::vtkInternals
       {
         var_stack.push_back(std::make_shared<parser::NodeOr>(a, b));
       }
-      else
+      else if (op_stack.back() == '^')
+      {
+        var_stack.push_back(std::make_shared<parser::NodeXor>(a, b));
+      }
+      else // if (op_stack.back() == '&')
       {
         var_stack.push_back(std::make_shared<parser::NodeAnd>(a, b));
       }
@@ -216,7 +221,9 @@ class vtkSelection::vtkInternals
     switch (op)
     {
       case '|':
-        return -15;
+        return -16;
+      case '^':
+        return -15; // https://stackoverflow.com/a/36320208
       case '&':
         return -14;
       case '!':
@@ -230,7 +237,7 @@ class vtkSelection::vtkInternals
   }
 
 public:
-  std::map<std::string, vtkSmartPointer<vtkSelectionNode> > Items;
+  std::map<std::string, vtkSmartPointer<vtkSelectionNode>> Items;
   vtksys::RegularExpression RegExID;
 
   vtkInternals()
@@ -254,6 +261,7 @@ public:
         case '(':
         case ')':
         case '|':
+        case '^':
         case '&':
         case '!':
           if (!accumated_text.empty())
@@ -261,7 +269,7 @@ public:
             parts.push_back(accumated_text);
             accumated_text.clear();
           }
-          parts.push_back(std::string(1, ch));
+          parts.emplace_back(1, ch);
           break;
 
         default:
@@ -277,7 +285,7 @@ public:
       parts.push_back(accumated_text);
     }
 
-    std::vector<std::shared_ptr<parser::Node> > var_stack;
+    std::vector<std::shared_ptr<parser::Node>> var_stack;
     std::vector<char> op_stack;
     for (const auto& term : parts)
     {
@@ -300,7 +308,7 @@ public:
         // pop the opening paren.
         op_stack.pop_back();
       }
-      else if (term[0] == '&' || term[0] == '|' || term[0] == '!')
+      else if (term[0] == '&' || term[0] == '^' || term[0] == '|' || term[0] == '!')
       {
         while (!op_stack.empty() && (precedence(term[0]) < precedence(op_stack.back())) &&
           this->ApplyBack(op_stack, var_stack))
@@ -324,13 +332,12 @@ public:
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkSelection);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSelection::vtkSelection()
-  : Expression()
-  , Internals(new vtkSelection::vtkInternals())
+  : Internals(new vtkSelection::vtkInternals())
 {
   this->Information->Set(vtkDataObject::DATA_EXTENT_TYPE(), VTK_PIECES_EXTENT);
   this->Information->Set(vtkDataObject::DATA_PIECE_NUMBER(), -1);
@@ -338,13 +345,13 @@ vtkSelection::vtkSelection()
   this->Information->Set(vtkDataObject::DATA_NUMBER_OF_GHOST_LEVELS(), 0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSelection::~vtkSelection()
 {
   delete this->Internals;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Initialize()
 {
   this->Superclass::Initialize();
@@ -352,13 +359,13 @@ void vtkSelection::Initialize()
   this->Expression.clear();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkSelection::GetNumberOfNodes() const
 {
   return static_cast<unsigned int>(this->Internals->Items.size());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSelectionNode* vtkSelection::GetNode(unsigned int idx) const
 {
   const vtkInternals& internals = (*this->Internals);
@@ -371,7 +378,7 @@ vtkSelectionNode* vtkSelection::GetNode(unsigned int idx) const
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSelectionNode* vtkSelection::GetNode(const std::string& name) const
 {
   const vtkInternals& internals = (*this->Internals);
@@ -383,7 +390,7 @@ vtkSelectionNode* vtkSelection::GetNode(const std::string& name) const
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string vtkSelection::AddNode(vtkSelectionNode* node)
 {
   if (!node)
@@ -403,17 +410,17 @@ std::string vtkSelection::AddNode(vtkSelectionNode* node)
   }
 
   static std::atomic<uint64_t> counter(0U);
-  std::string name = std::string("node") + convert_to_string(++counter);
+  std::string name = std::string("node") + std::to_string(++counter);
   while (internals.Items.find(name) != internals.Items.end())
   {
-    name = std::string("node") + convert_to_string(++counter);
+    name = std::string("node") + std::to_string(++counter);
   }
 
   this->SetNode(name, node);
   return name;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::SetNode(const std::string& name, vtkSelectionNode* node)
 {
   vtkInternals& internals = (*this->Internals);
@@ -432,7 +439,7 @@ void vtkSelection::SetNode(const std::string& name, vtkSelectionNode* node)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string vtkSelection::GetNodeNameAtIndex(unsigned int idx) const
 {
   const vtkInternals& internals = (*this->Internals);
@@ -445,7 +452,7 @@ std::string vtkSelection::GetNodeNameAtIndex(unsigned int idx) const
   return std::string();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::RemoveNode(unsigned int idx)
 {
   vtkInternals& internals = (*this->Internals);
@@ -458,7 +465,7 @@ void vtkSelection::RemoveNode(unsigned int idx)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::RemoveNode(const std::string& name)
 {
   vtkInternals& internals = (*this->Internals);
@@ -468,7 +475,7 @@ void vtkSelection::RemoveNode(const std::string& name)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::RemoveNode(vtkSelectionNode* node)
 {
   vtkInternals& internals = (*this->Internals);
@@ -483,7 +490,7 @@ void vtkSelection::RemoveNode(vtkSelectionNode* node)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::RemoveAllNodes()
 {
   vtkInternals& internals = (*this->Internals);
@@ -494,21 +501,22 @@ void vtkSelection::RemoveAllNodes()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   unsigned int numNodes = this->GetNumberOfNodes();
   os << indent << "Number of nodes: " << numNodes << endl;
   os << indent << "Nodes: " << endl;
-  for (unsigned int i = 0; i < numNodes; i++)
+  size_t counter = 0;
+  for (const auto& nodePair : this->Internals->Items)
   {
-    os << indent << "Node #" << i << endl;
-    this->GetNode(i)->PrintSelf(os, indent.GetNextIndent());
+    os << indent << "Node #" << counter++ << endl;
+    nodePair.second->PrintSelf(os, indent.GetNextIndent());
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::ShallowCopy(vtkDataObject* src)
 {
   if (auto* ssrc = vtkSelection::SafeDownCast(src))
@@ -520,7 +528,7 @@ void vtkSelection::ShallowCopy(vtkDataObject* src)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::DeepCopy(vtkDataObject* src)
 {
   if (auto* ssrc = vtkSelection::SafeDownCast(src))
@@ -541,25 +549,25 @@ void vtkSelection::DeepCopy(vtkDataObject* src)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Union(vtkSelection* s)
 {
-  for (unsigned int n = 0; n < s->GetNumberOfNodes(); ++n)
+  for (const auto& nodePair : s->Internals->Items)
   {
-    this->Union(s->GetNode(n));
+    this->Union(nodePair.second);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Union(vtkSelectionNode* node)
 {
   bool merged = false;
-  for (unsigned int tn = 0; tn < this->GetNumberOfNodes(); ++tn)
+  for (const auto& nodePair : this->Internals->Items)
   {
-    vtkSelectionNode* tnode = this->GetNode(tn);
-    if (tnode->EqualProperties(node))
+    auto& selNode = nodePair.second;
+    if (selNode->EqualProperties(node))
     {
-      tnode->UnionSelectionList(node);
+      selNode->UnionSelectionList(node);
       merged = true;
       break;
     }
@@ -572,26 +580,26 @@ void vtkSelection::Union(vtkSelectionNode* node)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Subtract(vtkSelection* s)
 {
-  for (unsigned int n = 0; n < s->GetNumberOfNodes(); ++n)
+  for (const auto& nodePair : s->Internals->Items)
   {
-    this->Subtract(s->GetNode(n));
+    this->Subtract(nodePair.second);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Subtract(vtkSelectionNode* node)
 {
   bool subtracted = false;
-  for (unsigned int tn = 0; tn < this->GetNumberOfNodes(); ++tn)
+  for (const auto& nodePair : this->Internals->Items)
   {
-    vtkSelectionNode* tnode = this->GetNode(tn);
+    vtkSelectionNode* selNode = nodePair.second;
 
-    if (tnode->EqualProperties(node))
+    if (selNode->EqualProperties(node))
     {
-      tnode->SubtractSelectionList(node);
+      selNode->SubtractSelectionList(node);
       subtracted = true;
     }
   }
@@ -601,7 +609,7 @@ void vtkSelection::Subtract(vtkSelectionNode* node)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMTimeType vtkSelection::GetMTime()
 {
   vtkMTimeType mtime = this->Superclass::GetMTime();
@@ -613,21 +621,75 @@ vtkMTimeType vtkSelection::GetMTime()
   return mtime;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSelection* vtkSelection::GetData(vtkInformation* info)
 {
   return info ? vtkSelection::SafeDownCast(info->Get(DATA_OBJECT())) : nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSelection* vtkSelection::GetData(vtkInformationVector* v, int i)
 {
   return vtkSelection::GetData(v->GetInformationObject(i));
 }
 
-//----------------------------------------------------------------------------
-vtkSmartPointer<vtkSignedCharArray> vtkSelection::Evaluate(
-  vtkSignedCharArray* const* values, unsigned int num_values) const
+//------------------------------------------------------------------------------
+struct vtkSelection::EvaluateFunctor
+{
+  std::array<signed char, 2>& Range;
+  std::shared_ptr<parser::Node> Tree;
+  signed char* Result;
+
+  EvaluateFunctor(std::array<signed char, 2>& range, std::shared_ptr<parser::Node> tree,
+    vtkSignedCharArray* result)
+    : Range(range)
+    , Tree(tree)
+    , Result(result->GetPointer(0))
+  {
+    this->Range = { VTK_SIGNED_CHAR_MAX, VTK_SIGNED_CHAR_MIN };
+  }
+
+  void Initialize(){};
+
+  void operator()(vtkIdType begin, vtkIdType end)
+  {
+    for (vtkIdType i = begin; i < end; ++i)
+    {
+      this->Result[i] = static_cast<signed char>(this->Tree->Evaluate(i));
+      if (this->Range[0] == VTK_SIGNED_CHAR_MAX && this->Result[i] == 0)
+      {
+        this->Range[0] = 0;
+      }
+      else if (this->Range[1] == VTK_SIGNED_CHAR_MIN && this->Result[i] == 1)
+      {
+        this->Range[1] = 1;
+      }
+    }
+  }
+
+  void Reduce()
+  {
+    if (this->Range[0] == VTK_SIGNED_CHAR_MAX)
+    {
+      if (this->Range[1] == VTK_SIGNED_CHAR_MIN)
+      {
+        this->Range[0] = 0;
+      }
+      else
+      {
+        this->Range[0] = this->Range[1];
+      }
+    }
+    if (this->Range[1] == VTK_SIGNED_CHAR_MIN)
+    {
+      this->Range[1] = 0;
+    }
+  }
+};
+
+//------------------------------------------------------------------------------
+vtkSmartPointer<vtkSignedCharArray> vtkSelection::Evaluate(vtkSignedCharArray* const* values,
+  unsigned int num_values, std::array<signed char, 2>& range) const
 {
   std::map<std::string, vtkSignedCharArray*> values_map;
 
@@ -673,41 +735,42 @@ vtkSmartPointer<vtkSignedCharArray> vtkSelection::Evaluate(
   }
 
   auto tree = this->Internals->BuildExpressionTree(expr, values_map);
-  if (tree && (!values_map.empty()))
+  if (tree && (!values_map.empty()) && numVals != -1)
   {
     auto result = vtkSmartPointer<vtkSignedCharArray>::New();
-    result->SetNumberOfComponents(1);
-    result->SetNumberOfTuples(numVals);
-    vtkSMPTools::For(0, numVals, [&](vtkIdType start, vtkIdType end) {
-      for (vtkIdType idx = start; idx < end; ++idx)
-      {
-        result->SetTypedComponent(idx, 0, tree->Evaluate(idx));
-      }
-    });
+    result->SetNumberOfValues(numVals);
+    EvaluateFunctor functor(range, tree, result);
+    vtkSMPTools::For(0, numVals, functor);
     return result;
   }
   else if (!tree)
   {
     vtkGenericWarningMacro("Failed to parse expression: " << this->Expression);
   }
+  else if (numVals == -1)
+  {
+    vtkGenericWarningMacro(
+      "No values to evaluate because there was an error in the selection evaluator.");
+  }
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Dump()
 {
   this->Dump(cout);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSelection::Dump(ostream& os)
 {
   vtkSmartPointer<vtkTable> tmpTable = vtkSmartPointer<vtkTable>::New();
   cerr << "==Selection==" << endl;
-  for (unsigned int i = 0; i < this->GetNumberOfNodes(); ++i)
+  size_t counter = 0;
+  for (const auto& nodePair : this->Internals->Items)
   {
-    os << "===Node " << i << "===" << endl;
-    vtkSelectionNode* node = this->GetNode(i);
+    os << "===Node " << counter++ << "===" << endl;
+    vtkSelectionNode* node = nodePair.second;
     os << "ContentType: ";
     switch (node->GetContentType())
     {
@@ -776,3 +839,4 @@ void vtkSelection::Dump(ostream& os)
     }
   }
 }
+VTK_ABI_NAMESPACE_END
