@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkStructuredGrid.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkStructuredGrid
  * @brief   topologically regular array of data
@@ -43,10 +31,12 @@
 #define vtkStructuredGrid_h
 
 #include "vtkCommonDataModelModule.h" // For export macro
+#include "vtkDeprecation.h"           // For VTK_DEPRECATED_IN_9_3_0
 #include "vtkPointSet.h"
 
 #include "vtkStructuredData.h" // Needed for inline methods
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkEmptyCell;
 class vtkHexahedron;
 class vtkLine;
@@ -58,6 +48,7 @@ class VTKCOMMONDATAMODEL_EXPORT vtkStructuredGrid : public vtkPointSet
 {
 public:
   static vtkStructuredGrid* New();
+  static vtkStructuredGrid* ExtendedNew();
 
   vtkTypeMacro(vtkStructuredGrid, vtkPointSet);
   void PrintSelf(ostream& os, vtkIndent indent) override;
@@ -72,7 +63,7 @@ public:
    */
   void CopyStructure(vtkDataSet* ds) override;
 
-  //@{
+  ///@{
   /**
    * Standard vtkDataSet API methods. See vtkDataSet for more information.
    */
@@ -87,49 +78,62 @@ public:
   void GetCell(vtkIdType cellId, vtkGenericCell* cell) override;
   void GetCellBounds(vtkIdType cellId, double bounds[6]) override;
   int GetCellType(vtkIdType cellId) override;
+  vtkIdType GetCellSize(vtkIdType cellId) override;
   vtkIdType GetNumberOfCells() override;
+  using vtkDataSet::GetCellPoints;
   void GetCellPoints(vtkIdType cellId, vtkIdList* ptIds) override;
   void GetPointCells(vtkIdType ptId, vtkIdList* cellIds) override
   {
-    vtkStructuredData::GetPointCells(ptId, cellIds, this->GetDimensions());
+    int dims[3];
+    this->GetDimensions(dims);
+    vtkStructuredData::GetPointCells(ptId, cellIds, dims);
   }
   void Initialize() override;
   int GetMaxCellSize() override { return 8; } // hexahedron is the largest
   void GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds) override;
   void GetCellNeighbors(vtkIdType cellId, vtkIdList* ptIds, vtkIdList* cellIds, int* seedLoc);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
-   * following methods are specific to structured grid
+   * Sets the extent to be 0 to i-1, 0 to j-1, and 0 to k-1.
    */
   void SetDimensions(int i, int j, int k);
-  void SetDimensions(const int dim[3]);
-  //@}
 
-  //@{
   /**
-   * Get dimensions of this structured points dataset.
+   * Sets the extent to be 0 to dim[i]-1 in all 3 dimensions.
    */
+  void SetDimensions(const int dims[3]);
+  ///@}
+
+  ///@{
+  /**
+   * Get dimensions of this structured grid.
+   */
+  VTK_DEPRECATED_IN_9_3_0("Please use GetDimensions(int dims[3]) instead.")
   virtual int* GetDimensions() VTK_SIZEHINT(3);
-  virtual void GetDimensions(int dim[3]);
-  //@}
+
+  /**
+   * Get dimensions of this structured grid based on its extent.
+   */
+  virtual void GetDimensions(int dims[3]);
+  ///@}
 
   /**
    * Return the dimensionality of the data.
    */
   int GetDataDimension();
 
-  //@{
+  ///@{
   /**
    * Different ways to set the extent of the data array.  The extent
    * should be set before the "Scalars" are set or allocated.
    * The Extent is stored in the order (X, Y, Z).
    */
-  void SetExtent(int extent[6]);
-  void SetExtent(int x1, int x2, int y1, int y2, int z1, int z2);
+  void SetExtent(VTK_FUTURE_CONST int extent[6]);
+  void SetExtent(int xMin, int xMax, int yMin, int yMax, int zMin, int zMax);
   vtkGetVector6Macro(Extent, int);
-  //@}
+  ///@}
 
   /**
    * Return the actual size of the data in kibibytes (1024 bytes). This number
@@ -141,20 +145,20 @@ public:
    */
   unsigned long GetActualMemorySize() override;
 
-  //@{
+  ///@{
   /**
    * Shallow and Deep copy.
    */
   void ShallowCopy(vtkDataObject* src) override;
   void DeepCopy(vtkDataObject* src) override;
-  //@}
+  ///@}
 
   /**
    * The extent type is a 3D extent
    */
   int GetExtentType() override { return VTK_3D_EXTENT; }
 
-  //@{
+  ///@{
   /**
    * Methods for supporting blanking of cells. Blanking turns on or off
    * points in the structured grid, and hence the cells connected to them.
@@ -163,9 +167,9 @@ public:
    */
   void BlankPoint(vtkIdType ptId);
   void UnBlankPoint(vtkIdType ptId);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Methods for supporting blanking of cells. Blanking turns on or off
    * cells in the structured grid, and hence the points connected to them.
@@ -174,7 +178,7 @@ public:
    */
   void BlankCell(vtkIdType ptId);
   void UnBlankCell(vtkIdType ptId);
-  //@}
+  ///@}
 
   /**
    * Return non-zero value if specified point is visible.
@@ -216,13 +220,13 @@ public:
    */
   void Crop(const int* updateExtent) override;
 
-  //@{
+  ///@{
   /**
    * Retrieve an instance of this class from an information object.
    */
   static vtkStructuredGrid* GetData(vtkInformation* info);
   static vtkStructuredGrid* GetData(vtkInformationVector* v, int i = 0);
-  //@}
+  ///@}
 
   /**
    * Get a point in the grid. If adjustForExtent is true, (i,j,k) is
@@ -246,7 +250,9 @@ protected:
   vtkHexahedron* Hexahedron;
   vtkEmptyCell* EmptyCell;
 
+#if !defined(VTK_LEGACY_REMOVE)
   int Dimensions[3];
+#endif
   int DataDescription;
 
   int Extent[6];
@@ -258,20 +264,9 @@ protected:
   void ComputeScalarRange() override;
 
 private:
-  /**
-   * For legacy compatibility. Do not use.
-   */
-  void GetCellNeighbors(vtkIdType cellId, vtkIdList& ptIds, vtkIdList& cellIds)
-  {
-    this->GetCellNeighbors(cellId, &ptIds, &cellIds);
-  }
-
   // Internal method used by DeepCopy and ShallowCopy.
   void InternalStructuredGridCopy(vtkStructuredGrid* src);
 
-  static unsigned char MASKED_CELL_VALUE;
-
-private:
   vtkStructuredGrid(const vtkStructuredGrid&) = delete;
   void operator=(const vtkStructuredGrid&) = delete;
 };
@@ -303,4 +298,5 @@ inline int vtkStructuredGrid::GetDataDimension()
   return vtkStructuredData::GetDataDimension(this->DataDescription);
 }
 
+VTK_ABI_NAMESPACE_END
 #endif
