@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkVectorOperators.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #ifndef vtkVectorOperators_h
 #define vtkVectorOperators_h
@@ -22,6 +10,7 @@
 
 // Description:
 // Unary minus / negation of vector.
+VTK_ABI_NAMESPACE_BEGIN
 template <typename A, int Size>
 vtkVector<A, Size> operator-(const vtkVector<A, Size>& v)
 {
@@ -46,6 +35,19 @@ vtkVector<A, Size> operator+(const vtkVector<A, Size>& v1, const vtkVector<A, Si
   return ret;
 }
 
+// Description:
+// Add the vector b to the vector a of the same basic type.
+template <typename T, int Size>
+vtkVector<T, Size>& operator+=(vtkVector<T, Size>& a, const vtkVector<T, Size>& b)
+{
+  for (int dim = 0; dim < Size; ++dim)
+  {
+    a[dim] += b[dim];
+  }
+
+  return a;
+}
+
 // Description:
 // Performs subtraction of vectors of the same basic type.
 template <typename A, int Size>
@@ -59,6 +61,19 @@ vtkVector<A, Size> operator-(const vtkVector<A, Size>& v1, const vtkVector<A, Si
   return ret;
 }
 
+// Description:
+// Substract the vector b to the vector a of the same basic type.
+template <typename T, int Size>
+vtkVector<T, Size>& operator-=(vtkVector<T, Size>& a, const vtkVector<T, Size>& b)
+{
+  for (int dim = 0; dim < Size; ++dim)
+  {
+    a[dim] -= b[dim];
+  }
+
+  return a;
+}
+
 // Description:
 // Performs multiplication of vectors of the same basic type.
 template <typename A, int Size>
@@ -103,46 +118,46 @@ vtkVector<A, Size> operator/(const vtkVector<A, Size>& v1, const vtkVector<A, Si
 #define vtkVectorOperatorNegate(vectorType, type, size)                                            \
   inline vectorType operator-(const vectorType& v)                                                 \
   {                                                                                                \
-    return vectorType((-static_cast<vtkVector<type, size> >(v)).GetData());                        \
+    return vectorType((-static_cast<vtkVector<type, size>>(v)).GetData());                         \
   }
 #define vtkVectorOperatorPlus(vectorType, type, size)                                              \
   inline vectorType operator+(const vectorType& v1, const vectorType& v2)                          \
   {                                                                                                \
     return vectorType(                                                                             \
-      (static_cast<vtkVector<type, size> >(v1) + static_cast<vtkVector<type, size> >(v2))          \
+      (static_cast<vtkVector<type, size>>(v1) + static_cast<vtkVector<type, size>>(v2))            \
         .GetData());                                                                               \
   }
 #define vtkVectorOperatorMinus(vectorType, type, size)                                             \
   inline vectorType operator-(const vectorType& v1, const vectorType& v2)                          \
   {                                                                                                \
     return vectorType(                                                                             \
-      (static_cast<vtkVector<type, size> >(v1) - static_cast<vtkVector<type, size> >(v2))          \
+      (static_cast<vtkVector<type, size>>(v1) - static_cast<vtkVector<type, size>>(v2))            \
         .GetData());                                                                               \
   }
 #define vtkVectorOperatorMultiply(vectorType, type, size)                                          \
   inline vectorType operator*(const vectorType& v1, const vectorType& v2)                          \
   {                                                                                                \
     return vectorType(                                                                             \
-      (static_cast<vtkVector<type, size> >(v1) * static_cast<vtkVector<type, size> >(v2))          \
+      (static_cast<vtkVector<type, size>>(v1) * static_cast<vtkVector<type, size>>(v2))            \
         .GetData());                                                                               \
   }
 #define vtkVectorOperatorMultiplyScalar(vectorType, type, size)                                    \
   template <typename B>                                                                            \
   inline vectorType operator*(const vectorType& v1, const B& scalar)                               \
   {                                                                                                \
-    return vectorType((static_cast<vtkVector<type, size> >(v1) * scalar).GetData());               \
+    return vectorType((static_cast<vtkVector<type, size>>(v1) * scalar).GetData());                \
   }
 #define vtkVectorOperatorMultiplyScalarPre(vectorType, type, size)                                 \
   template <typename B>                                                                            \
   inline vectorType operator*(const B& scalar, const vectorType& v1)                               \
   {                                                                                                \
-    return vectorType((static_cast<vtkVector<type, size> >(v1) * scalar).GetData());               \
+    return vectorType((static_cast<vtkVector<type, size>>(v1) * scalar).GetData());                \
   }
 #define vtkVectorOperatorDivide(vectorType, type, size)                                            \
   inline vectorType operator/(const vectorType& v1, const vectorType& v2)                          \
   {                                                                                                \
     return vectorType(                                                                             \
-      (static_cast<vtkVector<type, size> >(v1) / static_cast<vtkVector<type, size> >(v2))          \
+      (static_cast<vtkVector<type, size>>(v1) / static_cast<vtkVector<type, size>>(v2))            \
         .GetData());                                                                               \
   }
 
@@ -164,5 +179,6 @@ vtkVectorOperatorMacro(vtkVector3i, int, 3);
 vtkVectorOperatorMacro(vtkVector3f, float, 3);
 vtkVectorOperatorMacro(vtkVector3d, double, 3);
 
+VTK_ABI_NAMESPACE_END
 #endif
 // VTK-HeaderTest-Exclude: vtkVectorOperators.h
