@@ -1,25 +1,15 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkVoxel.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkVoxel.h"
 
 #include "vtkBox.h"
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
+#include "vtkDataArrayRange.h"
+#include "vtkDoubleArray.h"
 #include "vtkIncrementalPointLocator.h"
 #include "vtkLine.h"
-#include "vtkMarchingCubesTriangleCases.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPixel.h"
@@ -27,13 +17,12 @@
 #include "vtkPoints.h"
 
 #include <cassert>
-#ifndef VTK_LEGACY_REMOVE // needed temporarily in deprecated methods
 #include <vector>
-#endif
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkVoxel);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct the voxel with eight points.
 vtkVoxel::vtkVoxel()
 {
@@ -53,7 +42,7 @@ vtkVoxel::vtkVoxel()
   this->Pixel = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVoxel::~vtkVoxel()
 {
   if (this->Line)
@@ -66,13 +55,13 @@ vtkVoxel::~vtkVoxel()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkVoxel::GetCentroid(double centroid[3]) const
 {
   return vtkVoxel::ComputeCentroid(this->Points, nullptr, centroid);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkVoxel::ComputeCentroid(vtkPoints* points, const vtkIdType* pointIds, double centroid[3])
 {
   double p[3];
@@ -95,7 +84,7 @@ bool vtkVoxel::ComputeCentroid(vtkPoints* points, const vtkIdType* pointIds, dou
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkVoxel::IsInsideOut()
 {
   double pt1[3], pt2[3];
@@ -104,21 +93,41 @@ bool vtkVoxel::IsInsideOut()
   return (pt2[0] - pt1[0]) * (pt2[1] - pt1[1]) * (pt2[2] - pt1[2]) < 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+double vtkVoxel::ComputeBoundingSphere(double center[3]) const
+{
+  auto points = vtk::DataArrayTupleRange(this->Points->GetData());
+  auto p0 = points[0], p7 = points[7];
+  center[0] = 0.5 * (p0[0] + p7[0]);
+  center[1] = 0.5 * (p0[1] + p7[1]);
+  center[2] = 0.5 * (p0[2] + p7[2]);
+  return vtkMath::Distance2BetweenPoints(center, p0);
+}
+
+//------------------------------------------------------------------------------
 int vtkVoxel::EvaluatePosition(const double x[3], double closestPoint[3], int& subId,
   double pcoords[3], double& dist2, double weights[])
 {
-  double pt1[3], pt2[3], pt3[3], pt4[3];
+  const double *pt1, *pt2, *pt3, *pt4;
   int i;
 
   subId = 0;
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return 0;
+  }
+  const double* pts = pointsArray->GetPointer(0);
+
   //
   // Get coordinate system
   //
-  this->Points->GetPoint(0, pt1);
-  this->Points->GetPoint(1, pt2);
-  this->Points->GetPoint(2, pt3);
-  this->Points->GetPoint(4, pt4);
+  pt1 = pts;
+  pt2 = pts + 3;
+  pt3 = pts + 6;
+  pt4 = pts + 12;
   //
   // Develop parametric coordinates
   //
@@ -136,7 +145,7 @@ int vtkVoxel::EvaluatePosition(const double x[3], double closestPoint[3], int& s
       closestPoint[2] = x[2];
     }
     dist2 = 0.0; // inside voxel
-    this->InterpolationFunctions(pcoords, weights);
+    vtkVoxel::InterpolationFunctions(pcoords, weights);
     return 1;
   }
   else
@@ -166,25 +175,49 @@ int vtkVoxel::EvaluatePosition(const double x[3], double closestPoint[3], int& s
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkVoxel::EvaluateLocation(
   int& vtkNotUsed(subId), const double pcoords[3], double x[3], double* weights)
 {
-  double pt1[3], pt2[3], pt3[3], pt4[3];
-  int i;
+  const double *pt1, *pt2, *pt3, *pt4;
 
-  this->Points->GetPoint(0, pt1);
-  this->Points->GetPoint(1, pt2);
-  this->Points->GetPoint(2, pt3);
-  this->Points->GetPoint(4, pt4);
+  // Efficient point access
+  const auto pointsArray = vtkDoubleArray::FastDownCast(this->Points->GetData());
+  if (!pointsArray)
+  {
+    vtkErrorMacro(<< "Points should be double type");
+    return;
+  }
+  const double* pts = pointsArray->GetPointer(0);
 
-  for (i = 0; i < 3; i++)
+  pt1 = pts;
+  pt2 = pts + 3;
+  pt3 = pts + 6;
+  pt4 = pts + 12;
+
+  for (int i = 0; i < 3; i++)
   {
     x[i] = pt1[i] + pcoords[0] * (pt2[i] - pt1[i]) + pcoords[1] * (pt3[i] - pt1[i]) +
       pcoords[2] * (pt4[i] - pt1[i]);
   }
 
-  this->InterpolationFunctions(pcoords, weights);
+  vtkVoxel::InterpolationFunctions(pcoords, weights);
+}
+
+//------------------------------------------------------------------------------
+int vtkVoxel::Inflate(double dist)
+{
+  int index = 0;
+  auto range = vtk::DataArrayTupleRange<3>(this->Points->GetData());
+  using TupleRef = typename decltype(range)::TupleReferenceType;
+  for (TupleRef point : range)
+  {
+    point[0] += dist * (index % 2 ? 1.0 : -1.0);
+    point[1] += dist * ((index / 2) % 2 ? 1.0 : -1.0);
+    point[2] += dist * (index / 4 ? 1.0 : -1.0);
+    ++index;
+  }
+  return 1;
 }
 
 //----------------------------------------------------------------------------
@@ -211,7 +244,7 @@ void vtkVoxel::InterpolationFunctions(const double pcoords[3], double sf[8])
   sf[7] = r * s * t;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkVoxel::InterpolationDerivs(const double pcoords[3], double derivs[24])
 {
   double rm, sm, tm;
@@ -251,7 +284,7 @@ void vtkVoxel::InterpolationDerivs(const double pcoords[3], double derivs[24])
   derivs[23] = pcoords[0] * pcoords[1];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkVoxel::CellBoundary(int vtkNotUsed(subId), const double pcoords[3], vtkIdList* pts)
 {
   double t1 = pcoords[0] - pcoords[1];
@@ -326,7 +359,7 @@ int vtkVoxel::CellBoundary(int vtkNotUsed(subId), const double pcoords[3], vtkId
 
 namespace
 {
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Voxel topology
 //
 //  2_______3
@@ -339,7 +372,7 @@ namespace
 //  0       1
 //
 
-static constexpr vtkIdType edges[vtkVoxel::NumberOfEdges][2] = {
+constexpr vtkIdType edges[vtkVoxel::NumberOfEdges][2] = {
   { 0, 1 }, // 0
   { 1, 3 }, // 1
   { 2, 3 }, // 2
@@ -354,7 +387,7 @@ static constexpr vtkIdType edges[vtkVoxel::NumberOfEdges][2] = {
   { 3, 7 }, // 11
 };
 // define in terms vtkPixel understands
-static constexpr vtkIdType faces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize + 1] = {
+constexpr vtkIdType faces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize + 1] = {
   { 2, 0, 6, 4, -1 }, // 0
   { 1, 3, 5, 7, -1 }, // 1
   { 0, 1, 4, 5, -1 }, // 2
@@ -362,7 +395,7 @@ static constexpr vtkIdType faces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceS
   { 1, 0, 3, 2, -1 }, // 4
   { 4, 5, 6, 7, -1 }, // 5
 };
-static constexpr vtkIdType edgeToAdjacentFaces[vtkVoxel::NumberOfEdges][2] = {
+constexpr vtkIdType edgeToAdjacentFaces[vtkVoxel::NumberOfEdges][2] = {
   { 2, 4 }, // 0
   { 1, 4 }, // 1
   { 3, 4 }, // 2
@@ -376,63 +409,61 @@ static constexpr vtkIdType edgeToAdjacentFaces[vtkVoxel::NumberOfEdges][2] = {
   { 0, 3 }, // 10
   { 1, 3 }, // 11
 };
-static constexpr vtkIdType
-  faceToAdjacentFaces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize] = {
-    { 5, 3, 4, 2 }, // 0
-    { 4, 3, 5, 2 }, // 1
-    { 4, 1, 5, 0 }, // 2
-    { 4, 0, 5, 1 }, // 3
-    { 2, 0, 3, 1 }, // 4
-    { 2, 1, 3, 0 }, // 5
-  };
-static constexpr vtkIdType
-  pointToIncidentEdges[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
-    { 0, 8, 3 },  // 0
-    { 0, 1, 9 },  // 1
-    { 2, 3, 10 }, // 2
-    { 1, 2, 11 }, // 3
-    { 4, 7, 8 },  // 4
-    { 4, 9, 5 },  // 5
-    { 6, 10, 7 }, // 6
-    { 5, 11, 6 }, // 7
-  };
-static constexpr vtkIdType
-  pointToIncidentFaces[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
-    { 2, 0, 4 }, // 0
-    { 4, 1, 2 }, // 1
-    { 4, 0, 3 }, // 2
-    { 4, 3, 1 }, // 3
-    { 5, 0, 2 }, // 4
-    { 2, 1, 5 }, // 5
-    { 3, 0, 5 }, // 6
-    { 1, 3, 5 }, // 7
-  };
-static constexpr vtkIdType
-  pointToOneRingPoints[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
-    { 1, 4, 2 }, // 0
-    { 0, 3, 5 }, // 1
-    { 3, 0, 6 }, // 2
-    { 1, 2, 7 }, // 3
-    { 5, 6, 0 }, // 4
-    { 4, 1, 7 }, // 5
-    { 7, 2, 4 }, // 6
-    { 5, 3, 6 }, // 7
-  };
+constexpr vtkIdType faceToAdjacentFaces[vtkVoxel::NumberOfFaces][vtkVoxel::MaximumFaceSize] = {
+  { 5, 3, 4, 2 }, // 0
+  { 4, 3, 5, 2 }, // 1
+  { 4, 1, 5, 0 }, // 2
+  { 4, 0, 5, 1 }, // 3
+  { 2, 0, 3, 1 }, // 4
+  { 2, 1, 3, 0 }, // 5
+};
+constexpr vtkIdType pointToIncidentEdges[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
+  { 0, 8, 3 },  // 0
+  { 0, 1, 9 },  // 1
+  { 2, 3, 10 }, // 2
+  { 1, 2, 11 }, // 3
+  { 4, 7, 8 },  // 4
+  { 4, 9, 5 },  // 5
+  { 6, 10, 7 }, // 6
+  { 5, 11, 6 }, // 7
+};
+constexpr vtkIdType pointToIncidentFaces[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
+  { 2, 0, 4 }, // 0
+  { 4, 1, 2 }, // 1
+  { 4, 0, 3 }, // 2
+  { 4, 3, 1 }, // 3
+  { 5, 0, 2 }, // 4
+  { 2, 1, 5 }, // 5
+  { 3, 0, 5 }, // 6
+  { 1, 3, 5 }, // 7
+};
+constexpr vtkIdType pointToOneRingPoints[vtkVoxel::NumberOfPoints][vtkVoxel::MaximumValence] = {
+  { 1, 4, 2 }, // 0
+  { 0, 3, 5 }, // 1
+  { 3, 0, 6 }, // 2
+  { 1, 2, 7 }, // 3
+  { 5, 6, 0 }, // 4
+  { 4, 1, 7 }, // 5
+  { 7, 2, 4 }, // 6
+  { 5, 3, 6 }, // 7
+};
 }
 
 //----------------------------------------------------------------------------
 //
 // Marching cubes case table
 //
+VTK_ABI_NAMESPACE_END
 #include "vtkMarchingCubesTriangleCases.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 void vtkVoxel::Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPointLocator* locator,
   vtkCellArray* verts, vtkCellArray* lines, vtkCellArray* polys, vtkPointData* inPd,
   vtkPointData* outPd, vtkCellData* inCd, vtkIdType cellId, vtkCellData* outCd)
 {
   static const int CASE_MASK[8] = { 1, 2, 4, 8, 16, 32, 64, 128 };
   vtkMarchingCubesTriangleCases* triCase;
-  EDGE_LIST* edge;
+  int* edge;
   int i, j, index;
   const vtkIdType* vert;
   static const int vertMap[8] = { 0, 1, 3, 2, 4, 5, 7, 6 };
@@ -488,13 +519,13 @@ void vtkVoxel::Contour(double value, vtkDataArray* cellScalars, vtkIncrementalPo
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetEdgeArray(vtkIdType edgeId)
 {
   return edges[edgeId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Return the case table for table-based isocontouring (aka marching cubes
 // style implementations). A linear 3D cell with N vertices will have 2**N
 // cases. The cases list three edges in order to produce one output triangle.
@@ -503,7 +534,7 @@ int* vtkVoxel::GetTriangleCases(int caseId)
   return &(*(vtkMarchingCubesTriangleCases::GetCases() + caseId)->edges);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCell* vtkVoxel::GetEdge(int edgeId)
 {
   if (!this->Line)
@@ -526,13 +557,13 @@ vtkCell* vtkVoxel::GetEdge(int edgeId)
   return this->Line;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetFaceArray(vtkIdType faceId)
 {
   return faces[faceId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCell* vtkVoxel::GetFace(int faceId)
 {
   if (!this->Pixel)
@@ -554,12 +585,12 @@ vtkCell* vtkVoxel::GetFace(int faceId)
   return this->Pixel;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 //
 // Intersect voxel with line using "bounding box" intersection.
 //
-int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double vtkNotUsed(tol),
-  double& t, double x[3], double pcoords[3], int& subId)
+int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double tol, double& t,
+  double x[3], double pcoords[3], int& subId)
 {
   double minPt[3], maxPt[3];
   double bounds[6];
@@ -578,7 +609,7 @@ int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double v
     bounds[2 * i + 1] = maxPt[i];
   }
 
-  if (!vtkBox::IntersectBox(bounds, p1, p21, x, t))
+  if (!vtkBox::IntersectBox(bounds, p1, p21, x, t, tol))
   {
     return 0;
   }
@@ -594,7 +625,7 @@ int vtkVoxel::IntersectWithLine(const double p1[3], const double p2[3], double v
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkVoxel::Triangulate(int index, vtkIdList* ptIds, vtkPoints* pts)
 {
   int p[4], i;
@@ -603,7 +634,7 @@ int vtkVoxel::Triangulate(int index, vtkIdList* ptIds, vtkPoints* pts)
   pts->Reset();
   //
   // Create five tetrahedron. Triangulation varies depending upon index. This
-  // is necessary to insure compatible voxel triangulations.
+  // is necessary to ensure compatible voxel triangulations.
   //
   if ((index % 2))
   {
@@ -713,7 +744,7 @@ int vtkVoxel::Triangulate(int index, vtkIdList* ptIds, vtkPoints* pts)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkVoxel::Derivatives(
   int vtkNotUsed(subId), const double pcoords[3], const double* values, int dim, double* derivs)
 {
@@ -749,7 +780,7 @@ void vtkVoxel::Derivatives(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkVoxel::GetPointToOneRingPoints(vtkIdType pointId, const vtkIdType*& pts)
 {
   assert(pointId < vtkVoxel::NumberOfPoints && "pointId too large");
@@ -757,7 +788,7 @@ vtkIdType vtkVoxel::GetPointToOneRingPoints(vtkIdType pointId, const vtkIdType*&
   return vtkVoxel::MaximumValence;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkVoxel::GetPointToIncidentFaces(vtkIdType pointId, const vtkIdType*& faceIds)
 {
   assert(pointId < vtkVoxel::NumberOfPoints && "pointId too large");
@@ -765,7 +796,7 @@ vtkIdType vtkVoxel::GetPointToIncidentFaces(vtkIdType pointId, const vtkIdType*&
   return vtkVoxel::MaximumValence;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkVoxel::GetPointToIncidentEdges(vtkIdType pointId, const vtkIdType*& edgeIds)
 {
   assert(pointId < vtkVoxel::NumberOfPoints && "pointId too large");
@@ -773,7 +804,7 @@ vtkIdType vtkVoxel::GetPointToIncidentEdges(vtkIdType pointId, const vtkIdType*&
   return vtkVoxel::MaximumValence;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkVoxel::GetFaceToAdjacentFaces(vtkIdType faceId, const vtkIdType*& faceIds)
 {
   assert(faceId < vtkVoxel::NumberOfFaces && "faceId too large");
@@ -781,76 +812,56 @@ vtkIdType vtkVoxel::GetFaceToAdjacentFaces(vtkIdType faceId, const vtkIdType*& f
   return vtkVoxel::MaximumFaceSize;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkVoxel::GetEdgeToAdjacentFaces(vtkIdType edgeId, const vtkIdType*& pts)
 {
   assert(edgeId < vtkVoxel::NumberOfEdges && "edgeId too large");
   pts = edgeToAdjacentFaces[edgeId];
 }
 
-#ifndef VTK_LEGACY_REMOVE
-//----------------------------------------------------------------------------
-void vtkVoxel::GetEdgePoints(int edgeId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkVoxel::GetEdgePoints(int, int*&), "VTK 9.0",
-    vtkVoxel::GetEdgePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[edgeId]), std::end(faces[edgeId]));
-  pts = tmp.data();
-}
-
-//----------------------------------------------------------------------------
-void vtkVoxel::GetFacePoints(int faceId, int*& pts)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkVoxel::GetFacePoints(int, int*&), "VTK 9.0",
-    vtkVoxel::GetFacePoints(vtkIdType, const vtkIdType*&));
-  static std::vector<int> tmp(std::begin(faces[faceId]), std::end(faces[faceId]));
-  pts = tmp.data();
-}
-#endif
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetEdgeToAdjacentFacesArray(vtkIdType edgeId)
 {
   assert(edgeId < vtkVoxel::NumberOfEdges && "edgeId too large");
   return edgeToAdjacentFaces[edgeId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetFaceToAdjacentFacesArray(vtkIdType faceId)
 {
   assert(faceId < vtkVoxel::NumberOfFaces && "faceId too large");
   return faceToAdjacentFaces[faceId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetPointToIncidentEdgesArray(vtkIdType pointId)
 {
   assert(pointId < vtkVoxel::NumberOfPoints && "pointId too large");
   return pointToIncidentEdges[pointId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetPointToIncidentFacesArray(vtkIdType pointId)
 {
   assert(pointId < vtkVoxel::NumberOfPoints && "pointId too large");
   return pointToIncidentFaces[pointId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkVoxel::GetPointToOneRingPointsArray(vtkIdType pointId)
 {
   assert(pointId < vtkVoxel::NumberOfPoints && "pointId too large");
   return pointToOneRingPoints[pointId];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkVoxel::GetEdgePoints(vtkIdType edgeId, const vtkIdType*& pts)
 {
   assert(edgeId < vtkVoxel::NumberOfEdges && "edgeId too large");
   pts = this->GetEdgeArray(edgeId);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkVoxel::GetFacePoints(vtkIdType faceId, const vtkIdType*& pts)
 {
   assert(faceId < vtkVoxel::NumberOfFaces && "faceId too large");
@@ -861,13 +872,13 @@ vtkIdType vtkVoxel::GetFacePoints(vtkIdType faceId, const vtkIdType*& pts)
 static double vtkVoxelCellPCoords[24] = { 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 1.0, 0.0, 1.0, 1.0,
   0.0, 0.0, 0.0, 1.0, 1.0, 0.0, 1.0, 0.0, 1.0, 1.0, 1.0, 1.0, 1.0 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double* vtkVoxel::GetParametricCoords()
 {
   return vtkVoxelCellPCoords;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkVoxel::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -891,3 +902,4 @@ void vtkVoxel::PrintSelf(ostream& os, vtkIndent indent)
     os << "None\n";
   }
 }
+VTK_ABI_NAMESPACE_END
