@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAlgorithmOutput.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkAlgorithmOutput
  * @brief   Proxy object to connect input/output ports.
@@ -23,7 +11,7 @@
  * an output and input port.  The connection is not stored in the
  * proxy object: it is simply a convenience for creating or removing
  * connections.
-*/
+ */
 
 #ifndef vtkAlgorithmOutput_h
 #define vtkAlgorithmOutput_h
@@ -31,31 +19,33 @@
 #include "vtkCommonExecutionModelModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkAlgorithm;
 
 class VTKCOMMONEXECUTIONMODEL_EXPORT vtkAlgorithmOutput : public vtkObject
 {
 public:
-  static vtkAlgorithmOutput *New();
-  vtkTypeMacro(vtkAlgorithmOutput,vtkObject);
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
+  static vtkAlgorithmOutput* New();
+  vtkTypeMacro(vtkAlgorithmOutput, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
   void SetIndex(int index);
-  int GetIndex();
+  int GetIndex() const;
 
-  vtkAlgorithm* GetProducer();
+  vtkAlgorithm* GetProducer() const;
   void SetProducer(vtkAlgorithm* producer);
 
 protected:
   vtkAlgorithmOutput();
-  ~vtkAlgorithmOutput() VTK_OVERRIDE;
+  ~vtkAlgorithmOutput() override;
 
   int Index;
   vtkAlgorithm* Producer;
 
 private:
-  vtkAlgorithmOutput(const vtkAlgorithmOutput&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkAlgorithmOutput&) VTK_DELETE_FUNCTION;
+  vtkAlgorithmOutput(const vtkAlgorithmOutput&) = delete;
+  void operator=(const vtkAlgorithmOutput&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
