@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkStreamingDemandDrivenPipeline.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkStreamingDemandDrivenPipeline.h"
 
 #include "vtkAlgorithm.h"
@@ -39,6 +27,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkSmartPointer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkStreamingDemandDrivenPipeline);
 
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, CONTINUE_EXECUTING, Integer);
@@ -65,7 +54,7 @@ vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, TIME_RANGE, DoubleVecto
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, BOUNDS, DoubleVector);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, TIME_DEPENDENT_INFORMATION, Integer);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 class vtkStreamingDemandDrivenPipelineToDataObjectFriendship
 {
 public:
@@ -89,7 +78,7 @@ void vtkSDDPSetUpdateExtentToWholeExtent(vtkInformation* info)
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStreamingDemandDrivenPipeline::vtkStreamingDemandDrivenPipeline()
 {
   this->ContinueExecuting = 0;
@@ -101,7 +90,7 @@ vtkStreamingDemandDrivenPipeline::vtkStreamingDemandDrivenPipeline()
   this->LastPropogateUpdateExtentShortCircuited = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStreamingDemandDrivenPipeline::~vtkStreamingDemandDrivenPipeline()
 {
   if (this->UpdateExtentRequest)
@@ -119,13 +108,13 @@ vtkStreamingDemandDrivenPipeline::~vtkStreamingDemandDrivenPipeline()
   this->InformationIterator->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkStreamingDemandDrivenPipeline ::ProcessRequest(
   vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -368,19 +357,19 @@ vtkTypeBool vtkStreamingDemandDrivenPipeline ::ProcessRequest(
   return this->Superclass::ProcessRequest(request, inInfoVec, outInfoVec);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkStreamingDemandDrivenPipeline::Update()
 {
   return this->Superclass::Update();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkStreamingDemandDrivenPipeline::Update(int port)
 {
   return this->Update(port, nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkStreamingDemandDrivenPipeline::Update(int port, vtkInformationVector* requests)
 {
   if (!this->UpdateInformation())
@@ -425,7 +414,7 @@ vtkTypeBool vtkStreamingDemandDrivenPipeline::Update(int port, vtkInformationVec
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkStreamingDemandDrivenPipeline::UpdateWholeExtent()
 {
   this->UpdateInformation();
@@ -453,7 +442,7 @@ vtkTypeBool vtkStreamingDemandDrivenPipeline::UpdateWholeExtent()
   return this->Update();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::ExecuteInformation(
   vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -491,7 +480,7 @@ int vtkStreamingDemandDrivenPipeline ::ExecuteInformation(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::CopyDefaultInformation(vtkInformation* request,
   int direction, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -514,6 +503,7 @@ void vtkStreamingDemandDrivenPipeline ::CopyDefaultInformation(vtkInformation* r
           outInfo->CopyEntry(inInfo, TIME_STEPS());
           outInfo->CopyEntry(inInfo, TIME_RANGE());
           outInfo->CopyEntry(inInfo, vtkDataObject::ORIGIN());
+          outInfo->CopyEntry(inInfo, vtkDataObject::DIRECTION());
           outInfo->CopyEntry(inInfo, vtkDataObject::SPACING());
           outInfo->CopyEntry(inInfo, TIME_DEPENDENT_INFORMATION());
           if (scalarInfo)
@@ -632,8 +622,8 @@ void vtkStreamingDemandDrivenPipeline ::CopyDefaultInformation(vtkInformation* r
           if (!inData)
           {
             vtkErrorMacro("Cannot copy default update request from output port "
-              << outputPort << " on algorithm " << this->Algorithm->GetClassName() << "("
-              << this->Algorithm << ") to input connection " << j << " on input port " << i
+              << outputPort << " on algorithm " << this->Algorithm->GetObjectDescription()
+              << " to input connection " << j << " on input port " << i
               << " because there is no data object.");
             continue;
           }
@@ -654,7 +644,7 @@ void vtkStreamingDemandDrivenPipeline ::CopyDefaultInformation(vtkInformation* r
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::ResetPipelineInformation(int port, vtkInformation* info)
 {
   this->Superclass::ResetPipelineInformation(port, info);
@@ -673,7 +663,7 @@ void vtkStreamingDemandDrivenPipeline ::ResetPipelineInformation(int port, vtkIn
   info->Remove(vtkAlgorithm::CAN_PRODUCE_SUB_EXTENT());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::PropagateUpdateExtent(int outputPort)
 {
   // The algorithm should not invoke anything on the executive.
@@ -710,7 +700,7 @@ int vtkStreamingDemandDrivenPipeline::PropagateUpdateExtent(int outputPort)
     this->UpdateExtentRequest, this->GetInputInformation(), this->GetOutputInformation());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::PropagateTime(int outputPort)
 {
   // The algorithm should not invoke anything on the executive.
@@ -746,7 +736,7 @@ int vtkStreamingDemandDrivenPipeline::PropagateTime(int outputPort)
     this->UpdateTimeRequest, this->GetInputInformation(), this->GetOutputInformation());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::UpdateTimeDependentInformation(int port)
 {
   // The algorithm should not invoke anything on the executive.
@@ -774,7 +764,7 @@ int vtkStreamingDemandDrivenPipeline::UpdateTimeDependentInformation(int port)
     this->GetOutputInformation());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::VerifyOutputInformation(
   int outputPort, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -816,16 +806,14 @@ int vtkStreamingDemandDrivenPipeline ::VerifyOutputInformation(
     {
       vtkErrorMacro("No update piece number has been set in the "
                     "information for output port "
-        << outputPort << " on algorithm " << this->Algorithm->GetClassName() << "("
-        << this->Algorithm << ").");
+        << outputPort << " on algorithm " << this->Algorithm->GetObjectDescription() << ".");
       return 0;
     }
     if (!outInfo->Has(UPDATE_NUMBER_OF_PIECES()))
     {
       vtkErrorMacro("No update number of pieces has been set in the "
                     "information for output port "
-        << outputPort << " on algorithm " << this->Algorithm->GetClassName() << "("
-        << this->Algorithm << ").");
+        << outputPort << " on algorithm " << this->Algorithm->GetObjectDescription() << ".");
       return 0;
     }
     if (!outInfo->Has(UPDATE_NUMBER_OF_GHOST_LEVELS()))
@@ -842,16 +830,14 @@ int vtkStreamingDemandDrivenPipeline ::VerifyOutputInformation(
     {
       vtkErrorMacro("No whole extent has been set in the "
                     "information for output port "
-        << outputPort << " on algorithm " << this->Algorithm->GetClassName() << "("
-        << this->Algorithm << ").");
+        << outputPort << " on algorithm " << this->Algorithm->GetObjectDescription() << ".");
       return 0;
     }
     if (!outInfo->Has(UPDATE_EXTENT()))
     {
       vtkErrorMacro("No update extent has been set in the "
                     "information for output port "
-        << outputPort << " on algorithm " << this->Algorithm->GetClassName() << "("
-        << this->Algorithm << ").");
+        << outputPort << " on algorithm " << this->Algorithm->GetObjectDescription() << ".");
       return 0;
     }
     // Make sure the update request is inside the whole extent.
@@ -870,12 +856,12 @@ int vtkStreamingDemandDrivenPipeline ::VerifyOutputInformation(
         // Update extent is outside the whole extent and is not empty.
         vtkErrorMacro("The update extent specified in the "
                       "information for output port "
-          << outputPort << " on algorithm " << this->Algorithm->GetClassName() << "("
-          << this->Algorithm << ") is " << updateExtent[0] << " " << updateExtent[1] << " "
-          << updateExtent[2] << " " << updateExtent[3] << " " << updateExtent[4] << " "
-          << updateExtent[5] << ", which is outside the whole extent " << wholeExtent[0] << " "
-          << wholeExtent[1] << " " << wholeExtent[2] << " " << wholeExtent[3] << " "
-          << wholeExtent[4] << " " << wholeExtent[5] << ".");
+          << outputPort << " on algorithm " << this->Algorithm->GetObjectDescription() << " is "
+          << updateExtent[0] << " " << updateExtent[1] << " " << updateExtent[2] << " "
+          << updateExtent[3] << " " << updateExtent[4] << " " << updateExtent[5]
+          << ", which is outside the whole extent " << wholeExtent[0] << " " << wholeExtent[1]
+          << " " << wholeExtent[2] << " " << wholeExtent[3] << " " << wholeExtent[4] << " "
+          << wholeExtent[5] << ".");
         return 0;
       }
     }
@@ -884,7 +870,7 @@ int vtkStreamingDemandDrivenPipeline ::VerifyOutputInformation(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::ExecuteDataStart(
   vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -944,7 +930,7 @@ void vtkStreamingDemandDrivenPipeline ::ExecuteDataStart(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::ExecuteDataEnd(
   vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -1024,7 +1010,7 @@ void vtkStreamingDemandDrivenPipeline ::ExecuteDataEnd(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::MarkOutputsGenerated(
   vtkInformation* request, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -1154,7 +1140,7 @@ void vtkStreamingDemandDrivenPipeline ::MarkOutputsGenerated(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::NeedToExecuteData(
   int outputPort, vtkInformationVector** inInfoVec, vtkInformationVector* outInfoVec)
 {
@@ -1288,7 +1274,7 @@ int vtkStreamingDemandDrivenPipeline ::NeedToExecuteData(
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::NeedToExecuteBasedOnTime(
   vtkInformation* outInfo, vtkDataObject* dataObject)
 {
@@ -1351,7 +1337,7 @@ int vtkStreamingDemandDrivenPipeline::NeedToExecuteBasedOnTime(
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::SetWholeExtent(vtkInformation* info, int extent[6])
 {
   if (!info)
@@ -1371,7 +1357,7 @@ int vtkStreamingDemandDrivenPipeline ::SetWholeExtent(vtkInformation* info, int
   return modified;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::GetWholeExtent(vtkInformation* info, int extent[6])
 {
   static int emptyExtent[6] = { 0, -1, 0, -1, 0, -1 };
@@ -1387,7 +1373,7 @@ void vtkStreamingDemandDrivenPipeline ::GetWholeExtent(vtkInformation* info, int
   info->Get(WHOLE_EXTENT(), extent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkStreamingDemandDrivenPipeline::GetWholeExtent(vtkInformation* info)
 {
   static int emptyExtent[6] = { 0, -1, 0, -1, 0, -1 };
@@ -1412,7 +1398,7 @@ int* vtkStreamingDemandDrivenPipeline::GetWholeExtent(vtkInformation* info)
 #pragma warning(disable : 4996)
 #endif
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline ::GetUpdateExtent(vtkInformation* info, int extent[6])
 {
   static int emptyExtent[6] = { 0, -1, 0, -1, 0, -1 };
@@ -1429,7 +1415,7 @@ void vtkStreamingDemandDrivenPipeline ::GetUpdateExtent(vtkInformation* info, in
   info->Get(UPDATE_EXTENT(), extent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkStreamingDemandDrivenPipeline ::GetUpdateExtent(vtkInformation* info)
 {
   static int emptyExtent[6] = { 0, -1, 0, -1, 0, -1 };
@@ -1445,7 +1431,7 @@ int* vtkStreamingDemandDrivenPipeline ::GetUpdateExtent(vtkInformation* info)
   return info->Get(UPDATE_EXTENT());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::GetUpdatePiece(vtkInformation* info)
 {
   if (!info)
@@ -1460,7 +1446,7 @@ int vtkStreamingDemandDrivenPipeline ::GetUpdatePiece(vtkInformation* info)
   return info->Get(UPDATE_PIECE_NUMBER());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::GetUpdateNumberOfPieces(vtkInformation* info)
 {
   if (!info)
@@ -1475,7 +1461,7 @@ int vtkStreamingDemandDrivenPipeline ::GetUpdateNumberOfPieces(vtkInformation* i
   return info->Get(UPDATE_NUMBER_OF_PIECES());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline ::GetUpdateGhostLevel(vtkInformation* info)
 {
   if (!info)
@@ -1490,7 +1476,7 @@ int vtkStreamingDemandDrivenPipeline ::GetUpdateGhostLevel(vtkInformation* info)
   return info->Get(UPDATE_NUMBER_OF_GHOST_LEVELS());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::SetRequestExactExtent(int port, int flag)
 {
   if (!this->OutputPortIndexInRange(port, "set request exact extent flag on"))
@@ -1506,7 +1492,7 @@ int vtkStreamingDemandDrivenPipeline::SetRequestExactExtent(int port, int flag)
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::GetRequestExactExtent(int port)
 {
   if (!this->OutputPortIndexInRange(port, "get request exact extent flag from"))
@@ -1520,3 +1506,4 @@ int vtkStreamingDemandDrivenPipeline::GetRequestExactExtent(int port)
   }
   return info->Get(EXACT_EXTENT());
 }
+VTK_ABI_NAMESPACE_END
