@@ -1,27 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPolynomialSolversUnivariate.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================
-  Copyright 2007 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
-  license for use of this work by or on behalf of the
-  U.S. Government. Redistribution and use in source and binary forms, with
-  or without modification, are permitted provided that this Notice and any
-  statement of authorship are reproduced on all copies.
-
-  Contact: pppebay@sandia.gov,dcthomp@sandia.gov
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2007 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 #include "vtkPolynomialSolversUnivariate.h"
 #include "vtkDataArray.h"
 #include "vtkMath.h"
@@ -31,6 +10,7 @@
 
 #define VTK_SIGN(x) (((x) < 0) ? (-1) : (1))
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPolynomialSolversUnivariate);
 
 static const double sqrt3 = sqrt(static_cast<double>(3.));
@@ -39,14 +19,15 @@ static const double absolute0 = 10. * VTK_DBL_MIN;
 
 double vtkPolynomialSolversUnivariate::DivisionTolerance = 1e-8; // sqrt( VTK_DBL_EPSILON );
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolynomialSolversUnivariate::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "(s) DivisionTolerance: " << this->GetDivisionTolerance() << "\n";
+  os << indent
+     << "(s) DivisionTolerance: " << vtkPolynomialSolversUnivariate::GetDivisionTolerance() << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Print the polynomial for debuggery
 ostream& vtkPolynomialSolversUnivariate::PrintPolynomial(ostream& os, double* P, int degP)
 {
@@ -111,14 +92,14 @@ ostream& vtkPolynomialSolversUnivariate::PrintPolynomial(ostream& os, double* P,
   return os;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Double precision comparison with 0
 inline bool IsZero(double x)
 {
-  return (fabs(x) < absolute0) ? true : false;
+  return fabs(x) < absolute0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Double precision comparison
 inline bool AreEqual(double x, double y, double rTol)
 {
@@ -136,15 +117,15 @@ inline bool AreEqual(double x, double y, double rTol)
   double absy = fabs(y);
   if (absx > absy)
   {
-    return delta > rTol * absx ? false : true;
+    return delta <= rTol * absx;
   }
   else
   {
-    return delta > rTol * absy ? false : true;
+    return delta <= rTol * absy;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Polynomial Euclidean division of A (deg m) by B (deg n).
 static int polynomialEucliDiv(double* A, int m, double* B, int n, double* Q, double* R, double rtol)
 {
@@ -222,7 +203,7 @@ static int polynomialEucliDiv(double* A, int m, double* B, int n, double* Q, dou
   return r;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Polynomial Euclidean division of A (deg m) by B (deg n).
 // Does not store Q and stores -R instead of R
 static int polynomialEucliDivOppositeR(double* A, int m, double* B, int n, double* mR, double rtol)
@@ -296,7 +277,7 @@ static int polynomialEucliDivOppositeR(double* A, int m, double* B, int n, doubl
   return r;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 inline double vtkNormalizePolyCoeff(double d, double* div = nullptr)
 {
   static const double high = 18446744073709551616.; // 2^64
@@ -330,7 +311,7 @@ inline double vtkNormalizePolyCoeff(double d, double* div = nullptr)
   return d;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Polynomial Euclidean division of A (deg m) by B (deg n).
 // Does not store Q and stores -R instead of R. This premultiplies Ai by mul and
 // then divides mR by div. mR MUST have at least the size of m+1, because it is
@@ -428,7 +409,7 @@ static int polynomialEucliDivOppositeR(
   return r;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Evaluate the value of the degree d univariate polynomial P at x
 // using Horner's algorithm.
 inline double evaluateHorner(double* P, int d, double x)
@@ -659,7 +640,15 @@ extern "C"
   {
     double aa = *static_cast<const double*>(a);
     double bb = *static_cast<const double*>(b);
-    return (aa < bb) ? -1 : 1;
+    if (aa < bb)
+    {
+      return -1;
+    }
+    if (aa > bb)
+    {
+      return 1;
+    }
+    return 0;
   }
 
 } // extern "C"
@@ -1178,7 +1167,7 @@ static int vtkHabichtOrSturmBisectionSolve(double* P, int d, double* a, double*
       } // While ub[nloc] - lb[nloc] > tol
 
       bisection[nloc] = false;
-      if (bisect == false)
+      if (!bisect)
       {
         // Move on to next interval.
         continue;
@@ -1268,7 +1257,7 @@ static int vtkHabichtOrSturmBisectionSolve(double* P, int d, double* a, double*
   return nIntervals;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Find all real roots in ] a[0] ; a[1] [ of a real
 // d-th degree polynomial using the Habicht sequence.
 // intervalType specifies as follows (in binary)
@@ -1295,7 +1284,7 @@ int vtkPolynomialSolversUnivariate::HabichtBisectionSolve(
     P, d, a, upperBnds, tol, intervalType, divideGCD ? 1 : 0, 1);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Find all real roots in ] a[0] ; a[1] [ of a real
 // d-th degree polynomial using the Sturm sequence.
 // intervalType specifies as follows (in binary)
@@ -1447,7 +1436,7 @@ int vtkPolynomialSolversUnivariate::FilterRoots(
   return rootcount;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Solves a d-th degree polynomial equation using Lin-Bairstow's method.
 //
 int vtkPolynomialSolversUnivariate::LinBairstowSolve(double* c, int d, double* r, double& tolerance)
@@ -1571,7 +1560,7 @@ int vtkPolynomialSolversUnivariate::LinBairstowSolve(double* c, int d, double* r
   return nr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Algebraically extracts REAL roots of the quartic polynomial with
 // REAL coefficients X^4 + c[0] X^3 + c[1] X^2 + c[2] X + c[3]
 // and stores them (when they exist) and their respective multiplicities
@@ -1758,7 +1747,7 @@ int vtkPolynomialSolversUnivariate::FerrariSolve(double* c, double* r, int* m, d
   return nr1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Algebraically extracts REAL roots of the cubic polynomial with
 // REAL coefficients X^3 + c[0] X^2 + c[1] X + c[2]
 // and stores them (when they exist) and their respective multiplicities.
@@ -1897,7 +1886,7 @@ int vtkPolynomialSolversUnivariate::TartagliaCardanSolve(double* c, double* r, i
   return 3;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Solves a cubic equation c0*t^3  + c1*t^2  + c2*t + c3 = 0 when
 // c0, c1, c2, and c3 are REAL.
 // Solution is motivated by Numerical Recipes In C 2nd Ed.
@@ -1918,7 +1907,7 @@ double* vtkPolynomialSolversUnivariate::SolveCubic(double c0, double c1, double
   return roots;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Solves a cubic equation when c0, c1, c2, And c3 Are REAL.  Solution
 // is motivated by Numerical Recipes In C 2nd Ed.  Roots and number of
 // real roots are stored in user provided variables r1, r2, r3, and
@@ -2032,7 +2021,7 @@ int vtkPolynomialSolversUnivariate::SolveCubic(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Solves a quadratic equation c0*t^2 + c1*t + c2 = 0 when c0, c1, and
 // c2 are REAL.  Solution is motivated by Numerical Recipes In C 2nd
 // Ed.  Return array contains number of (real) roots (counting
@@ -2053,7 +2042,7 @@ double* vtkPolynomialSolversUnivariate::SolveQuadratic(double c0, double c1, dou
   return roots;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Solves A Quadratic Equation c0*t^2  + c1*t  + c2 = 0 when
 // c0, c1, and c2 are REAL.
 // Solution is motivated by Numerical Recipes In C 2nd Ed.
@@ -2110,7 +2099,7 @@ int vtkPolynomialSolversUnivariate::SolveQuadratic(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Algebraically extracts REAL roots of the quadratic polynomial with
 // REAL coefficients c[0] X^2 + c[1] X + c[2]
 // and stores them (when they exist) and their respective multiplicities.
@@ -2165,39 +2154,39 @@ int vtkPolynomialSolversUnivariate::SolveQuadratic(double* c, double* r, int* m)
   }
 }
 
-//----------------------------------------------------------------------------
-// Solves a linear equation c2*t  + c3 = 0 when c2 and c3 are REAL.
+//------------------------------------------------------------------------------
+// Solves a linear equation c0*t  + c1 = 0 when c0 and c1 are REAL.
 // Solution is motivated by Numerical Recipes In C 2nd Ed.
 // Return array contains number of roots followed by roots themselves.
-double* vtkPolynomialSolversUnivariate::SolveLinear(double c2, double c3)
+double* vtkPolynomialSolversUnivariate::SolveLinear(double c0, double c1)
 {
   static double roots[3];
   int num_roots;
   roots[1] = 0.0;
-  roots[2] = vtkPolynomialSolversUnivariate::SolveLinear(c2, c3, &roots[1], &num_roots);
+  roots[2] = vtkPolynomialSolversUnivariate::SolveLinear(c0, c1, &roots[1], &num_roots);
   roots[0] = num_roots;
   return roots;
 }
 
-//----------------------------------------------------------------------------
-// Solves a linear equation c2*t + c3 = 0 when c2 and c3 are REAL.
+//------------------------------------------------------------------------------
+// Solves a linear equation c0*t + c1 = 0 when c0 and c1 are REAL.
 // Solution is motivated by Numerical Recipes In C 2nd Ed.
 // Root and number of (real) roots are stored in user provided variables
 // r2 and num_roots.
-int vtkPolynomialSolversUnivariate::SolveLinear(double c2, double c3, double* r1, int* num_roots)
+int vtkPolynomialSolversUnivariate::SolveLinear(double c0, double c1, double* r1, int* num_roots)
 {
-  // Linear equation: c2*t + c3 = 0
+  // Linear equation: c0*t + c1 = 0
   // Now this had better be linear
-  if (c2 != 0.0)
+  if (c0 != 0.0)
   {
-    *r1 = -c3 / c2;
+    *r1 = -c1 / c0;
     *num_roots = 1;
     return *num_roots;
   }
   else
   {
     *num_roots = 0;
-    if (c3 == 0.0)
+    if (c1 == 0.0)
     {
       return (-1);
     }
@@ -2206,14 +2195,15 @@ int vtkPolynomialSolversUnivariate::SolveLinear(double c2, double c3, double* r1
   return *num_roots;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPolynomialSolversUnivariate::SetDivisionTolerance(double tol)
 {
   vtkPolynomialSolversUnivariate::DivisionTolerance = tol;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkPolynomialSolversUnivariate::GetDivisionTolerance()
 {
   return vtkPolynomialSolversUnivariate::DivisionTolerance;
 }
+VTK_ABI_NAMESPACE_END
