@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkQuaternionInterpolator.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkQuaternionInterpolator
  * @brief   interpolate a quaternion
@@ -58,6 +46,7 @@
 #include "vtkCommonMathModule.h" // For export macro
 #include "vtkObject.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkQuaterniond;
 class vtkQuaternionList;
 
@@ -72,13 +61,20 @@ public:
    */
   static vtkQuaternionInterpolator* New();
 
+  enum vtkQuaternionInterpolationSearchMethod
+  {
+    BinarySearch = 0,
+    LinearSearch = 1,
+    MaxEnum
+  };
+
   /**
    * Return the number of quaternions in the list of quaternions to be
    * interpolated.
    */
   int GetNumberOfQuaternions();
 
-  //@{
+  ///@{
   /**
    * Obtain some information about the interpolation range. The numbers
    * returned (corresponding to parameter t, usually thought of as time)
@@ -87,7 +83,7 @@ public:
    */
   double GetMinimumT();
   double GetMaximumT();
-  //@}
+  ///@}
 
   /**
    * Reset the class so that it contains no data; i.e., the array of (t,q[4])
@@ -95,7 +91,7 @@ public:
    */
   void Initialize();
 
-  //@{
+  ///@{
   /**
    * Add another quaternion to the list of quaternions to be interpolated.
    * Note that using the same time t value more than once replaces the
@@ -104,7 +100,7 @@ public:
    */
   void AddQuaternion(double t, const vtkQuaterniond& q);
   void AddQuaternion(double t, double q[4]);
-  //@}
+  ///@}
 
   /**
    * Delete the quaternion at a particular parameter t. If there is no
@@ -112,7 +108,7 @@ public:
    */
   void RemoveQuaternion(double t);
 
-  //@{
+  ///@{
   /**
    * Interpolate the list of quaternions and determine a new quaternion
    * (i.e., fill in the quaternion provided). If t is outside the range of
@@ -120,7 +116,17 @@ public:
    */
   void InterpolateQuaternion(double t, vtkQuaterniond& q);
   void InterpolateQuaternion(double t, double q[4]);
-  //@}
+  ///@}
+
+  ///@{
+  /**
+   * Set / Get the search type method. 0 is a binary search method O(log(N))
+   * 1 is a linear search method O(N). Linear search method is kept because
+   * it can be faster than the dichotomous search method in specific cases
+   */
+  int GetSearchMethod();
+  void SetSearchMethod(int type);
+  ///@}
 
   /**
    * Enums to control the type of interpolation to use.
@@ -131,19 +137,20 @@ public:
     INTERPOLATION_TYPE_SPLINE
   };
 
-  //@{
+  ///@{
   /**
    * Specify which type of function to use for interpolation. By default
    * (SetInterpolationFunctionToSpline()), cubic spline interpolation using a
    * modified Kochanek basis is employed. Otherwise, if
-   * SetInterpolationFunctionToLinear() is invoked, linear spherical interpolation
+   * SetInterpolationFunctionToLinear() is invoked, linear spherical
+   * interpolation
    * is used between each pair of quaternions.
    */
   vtkSetClampMacro(InterpolationType, int, INTERPOLATION_TYPE_LINEAR, INTERPOLATION_TYPE_SPLINE);
   vtkGetMacro(InterpolationType, int);
   void SetInterpolationTypeToLinear() { this->SetInterpolationType(INTERPOLATION_TYPE_LINEAR); }
   void SetInterpolationTypeToSpline() { this->SetInterpolationType(INTERPOLATION_TYPE_SPLINE); }
-  //@}
+  ///@}
 
 protected:
   vtkQuaternionInterpolator();
@@ -151,6 +158,7 @@ protected:
 
   // Specify the type of interpolation to use
   int InterpolationType;
+  int SearchMethod;
 
   // Internal variables for interpolation functions
   vtkQuaternionList* QuaternionList; // used for linear quaternion interpolation
@@ -160,4 +168,5 @@ private:
   void operator=(const vtkQuaternionInterpolator&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
