@@ -1,26 +1,15 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkSphericalTransform.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSphericalTransform.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include <cmath>
 #include <cstdlib>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSphericalTransform);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSphericalTransform::vtkSphericalTransform() = default;
 
 vtkSphericalTransform::~vtkSphericalTransform() = default;
@@ -157,3 +146,4 @@ void vtkSphericalTransform::InverseTransformDerivative(
   vtkRectangularToSpherical(inPoint, outPoint);
   vtkSphericalToRectangular(outPoint, tmp, derivative);
 }
+VTK_ABI_NAMESPACE_END
