@@ -1,23 +1,11 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #import "MyGLKViewController.h"
 #import "vtkIOSRenderWindow.h"
 #import "vtkIOSRenderWindowInteractor.h"
 #include "vtkRenderingOpenGL2ObjectFactory.h"
 
-#include "vtkParametricTorus.h"
 #include "vtkParametricBoy.h"
 #include "vtkParametricConicSpiral.h"
 #include "vtkParametricCrossCap.h"
@@ -50,38 +38,35 @@ PURPOSE.  See the above copyright notice for more information.
 
 #include <deque>
 
-/* 2 or 3 -- needs to match VTK version */
-#define GL_ES_VERSION 2
-
-
-@interface MyGLKViewController () {
-  std::deque<vtkSmartPointer<vtkParametricFunction> > parametricObjects;
+@interface MyGLKViewController ()
+{
+  std::deque<vtkSmartPointer<vtkParametricFunction>> parametricObjects;
 }
 
-@property (strong, nonatomic) EAGLContext *context;
+@property (strong, nonatomic) EAGLContext* context;
 - (void)tearDownGL;
 @end
 
 @implementation MyGLKViewController
 
 //----------------------------------------------------------------------------
-- (vtkIOSRenderWindow *)getVTKRenderWindow
+- (vtkIOSRenderWindow*)getVTKRenderWindow
 {
   return _myVTKRenderWindow;
 }
 
 //----------------------------------------------------------------------------
-- (void)setVTKRenderWindow:(vtkIOSRenderWindow *)theVTKRenderWindow
+- (void)setVTKRenderWindow:(vtkIOSRenderWindow*)theVTKRenderWindow
 {
   _myVTKRenderWindow = theVTKRenderWindow;
 }
 
 //----------------------------------------------------------------------------
-- (vtkIOSRenderWindowInteractor *)getInteractor
+- (vtkIOSRenderWindowInteractor*)getInteractor
 {
   if (_myVTKRenderWindow)
   {
-    return (vtkIOSRenderWindowInteractor *)_myVTKRenderWindow->GetInteractor();
+    return (vtkIOSRenderWindowInteractor*)_myVTKRenderWindow->GetInteractor();
   }
   else
   {
@@ -130,10 +115,8 @@ PURPOSE.  See the above copyright notice for more information.
   parametricObjects.push_back(vtkSmartPointer<vtkParametricTorus>::New());
 
   // The spline needs points
-  vtkSmartPointer<vtkParametricSpline> spline =
-    vtkSmartPointer<vtkParametricSpline>::New();
-  vtkSmartPointer<vtkPoints> inputPoints =
-    vtkSmartPointer<vtkPoints>::New();
+  vtkSmartPointer<vtkParametricSpline> spline = vtkSmartPointer<vtkParametricSpline>::New();
+  vtkSmartPointer<vtkPoints> inputPoints = vtkSmartPointer<vtkPoints>::New();
   vtkMath::RandomSeed(8775070);
   for (int p = 0; p < 10; p++)
   {
@@ -156,10 +139,10 @@ PURPOSE.  See the above copyright notice for more information.
   //
   [self initializeParametricObjects];
 
-  std::vector<vtkSmartPointer<vtkParametricFunctionSource> > parametricFunctionSources;
-  std::vector<vtkSmartPointer<vtkRenderer> > renderers;
-  std::vector<vtkSmartPointer<vtkPolyDataMapper> > mappers;
-  std::vector<vtkSmartPointer<vtkActor> > actors;
+  std::vector<vtkSmartPointer<vtkParametricFunctionSource>> parametricFunctionSources;
+  std::vector<vtkSmartPointer<vtkRenderer>> renderers;
+  std::vector<vtkSmartPointer<vtkPolyDataMapper>> mappers;
+  std::vector<vtkSmartPointer<vtkActor>> actors;
 
   // No text mappers/actors in VTK GL2 yet
 #if 0
@@ -175,7 +158,7 @@ PURPOSE.  See the above copyright notice for more information.
 
   // Create a parametric function source, renderer, mapper, and actor
   // for each object
-  for(unsigned int i = 0; i < parametricObjects.size(); i++)
+  for (unsigned int i = 0; i < parametricObjects.size(); i++)
   {
     parametricFunctionSources.push_back(vtkSmartPointer<vtkParametricFunctionSource>::New());
     parametricFunctionSources[i]->SetParametricFunction(parametricObjects[i]);
@@ -204,41 +187,41 @@ PURPOSE.  See the above copyright notice for more information.
   unsigned int gridDimensions = 4;
 
   // Need a renderer even if there is no actor
-  for(size_t i = parametricObjects.size();
-      i < gridDimensions * gridDimensions;
-      i++)
+  for (size_t i = parametricObjects.size(); i < gridDimensions * gridDimensions; i++)
   {
     renderers.push_back(vtkSmartPointer<vtkRenderer>::New());
   }
 
-  vtkIOSRenderWindow *renWin = vtkIOSRenderWindow::New();
-  //renWin->DebugOn();
+  vtkIOSRenderWindow* renWin = vtkIOSRenderWindow::New();
+  // renWin->DebugOn();
   [self setVTKRenderWindow:renWin];
 
   int rendererSize = 200;
-  renWin->SetSize(rendererSize*gridDimensions, rendererSize*gridDimensions);
+  renWin->SetSize(rendererSize * gridDimensions, rendererSize * gridDimensions);
 
-  for(int row = 0; row < static_cast<int>(gridDimensions); row++)
+  for (int row = 0; row < static_cast<int>(gridDimensions); row++)
   {
-    for(int col = 0; col < static_cast<int>(gridDimensions); col++)
+    for (int col = 0; col < static_cast<int>(gridDimensions); col++)
     {
-      int index = row*gridDimensions + col;
+      int index = row * gridDimensions + col;
 
       // (xmin, ymin, xmax, ymax)
-      double viewport[4] =
-      {static_cast<double>(col) * rendererSize / (gridDimensions * rendererSize),
-        static_cast<double>(gridDimensions - (row+1)) * rendererSize / (gridDimensions * rendererSize),
-        static_cast<double>(col+1)*rendererSize / (gridDimensions * rendererSize),
-        static_cast<double>(gridDimensions - row) * rendererSize / (gridDimensions * rendererSize)};
+      double viewport[4] = {
+        static_cast<double>(col) * rendererSize / (gridDimensions * rendererSize),
+        static_cast<double>(gridDimensions - (row + 1)) * rendererSize /
+          (gridDimensions * rendererSize),
+        static_cast<double>(col + 1) * rendererSize / (gridDimensions * rendererSize),
+        static_cast<double>(gridDimensions - row) * rendererSize / (gridDimensions * rendererSize)
+      };
 
       renWin->AddRenderer(renderers[index]);
       renderers[index]->SetViewport(viewport);
-      if(index > static_cast<int>(parametricObjects.size() - 1))
+      if (index > static_cast<int>(parametricObjects.size() - 1))
       {
         continue;
       }
       renderers[index]->AddActor(actors[index]);
-      //renderers[index]->AddActor(textactors[index]);
+      // renderers[index]->AddActor(textactors[index]);
       renderers[index]->SetBackground(.2, .3, .4);
       renderers[index]->ResetCamera();
       renderers[index]->GetActiveCamera()->Azimuth(30);
@@ -250,50 +233,46 @@ PURPOSE.  See the above copyright notice for more information.
 
   // this example uses VTK's built in interaction but you could choose
   // to use your own instead.
-  vtkRenderWindowInteractor *iren = vtkRenderWindowInteractor::New();
+  vtkRenderWindowInteractor* iren = vtkRenderWindowInteractor::New();
   iren->SetRenderWindow(renWin);
 
-  vtkInteractorStyleMultiTouchCamera *ismt = vtkInteractorStyleMultiTouchCamera::New();
+  vtkInteractorStyleMultiTouchCamera* ismt = vtkInteractorStyleMultiTouchCamera::New();
   iren->SetInteractorStyle(ismt);
   ismt->Delete();
   iren->Start();
 }
 
-
 - (void)viewDidLoad
 {
   [super viewDidLoad];
 
-#if GL_ES_VERSION == 2
-  self.context = [[EAGLContext alloc] initWithAPI:kEAGLRenderingAPIOpenGLES2];
-#else
   self.context = [[EAGLContext alloc] initWithAPI:kEAGLRenderingAPIOpenGLES3];
-#endif
 
-  if (!self.context) {
-      NSLog(@"Failed to create ES context");
+  if (!self.context)
+  {
+    NSLog(@"Failed to create ES context");
   }
 
-  GLKView *view = (GLKView *)self.view;
+  GLKView* view = (GLKView*)self.view;
   view.context = self.context;
   view.drawableDepthFormat = GLKViewDrawableDepthFormat24;
-  //view.drawableMultisample = GLKViewDrawableMultisample4X;
+  // view.drawableMultisample = GLKViewDrawableMultisample4X;
 
   // setup the vis pipeline
   [self setupPipeline];
 
   [EAGLContext setCurrentContext:self.context];
   [self resizeView];
-  [self getVTKRenderWindow]->Render();
+  [self getVTKRenderWindow] -> Render();
 }
 
-
 - (void)dealloc
 {
   [self tearDownGL];
 
-  if ([EAGLContext currentContext] == self.context) {
-      [EAGLContext setCurrentContext:nil];
+  if ([EAGLContext currentContext] == self.context)
+  {
+    [EAGLContext setCurrentContext:nil];
   }
 }
 
@@ -301,13 +280,15 @@ PURPOSE.  See the above copyright notice for more information.
 {
   [super didReceiveMemoryWarning];
 
-  if ([self isViewLoaded] && ([[self view] window] == nil)) {
+  if ([self isViewLoaded] && ([[self view] window] == nil))
+  {
     self.view = nil;
 
     [self tearDownGL];
 
-    if ([EAGLContext currentContext] == self.context) {
-        [EAGLContext setCurrentContext:nil];
+    if ([EAGLContext currentContext] == self.context)
+    {
+      [EAGLContext setCurrentContext:nil];
     }
     self.context = nil;
   }
@@ -323,12 +304,12 @@ PURPOSE.  See the above copyright notice for more information.
   // ...
 }
 
--(void) resizeView
+- (void)resizeView
 {
   double scale = self.view.contentScaleFactor;
   double newWidth = scale * self.view.bounds.size.width;
   double newHeight = scale * self.view.bounds.size.height;
-  [self getVTKRenderWindow]->SetSize(newWidth, newHeight);
+  [self getVTKRenderWindow] -> SetSize(newWidth, newHeight);
 }
 
 - (void)viewWillLayoutSubviews
@@ -336,29 +317,27 @@ PURPOSE.  See the above copyright notice for more information.
   [self resizeView];
 }
 
-- (void)glkView:(GLKView *)view drawInRect:(CGRect)rect
+- (void)glkView:(GLKView*)view drawInRect:(CGRect)rect
 {
-  //std::cout << [self getVTKRenderWindow]->ReportCapabilities() << std::endl;
-  [self getVTKRenderWindow]->Render();
+  // std::cout << [self getVTKRenderWindow]->ReportCapabilities() << std::endl;
+  [self getVTKRenderWindow] -> Render();
 }
 
-
-
 //=================================================================
 // this example uses VTK's built in interaction but you could choose
 // to use your own instead. The remaining methods forward touch events
 // to VTKs interactor.
 
 // Handles the start of a touch
-- (void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event
+- (void)touchesBegan:(NSSet*)touches withEvent:(UIEvent*)event
 {
-  vtkIOSRenderWindowInteractor *interactor = [self getInteractor];
+  vtkIOSRenderWindowInteractor* interactor = [self getInteractor];
   if (!interactor)
   {
     return;
   }
 
-  vtkIOSRenderWindow *renWin = [self getVTKRenderWindow];
+  vtkIOSRenderWindow* renWin = [self getVTKRenderWindow];
   if (!renWin)
   {
     return;
@@ -368,8 +347,8 @@ PURPOSE.  See the above copyright notice for more information.
   double scale = self.view.contentScaleFactor;
 
   // set the position for all contacts
-  NSSet *myTouches = [event touchesForView:self.view];
-  for (UITouch *touch in myTouches)
+  NSSet* myTouches = [event touchesForView:self.view];
+  for (UITouch* touch in myTouches)
   {
     // Convert touch point from UIView referential to OpenGL one (upside-down flip)
     CGPoint location = [touch locationInView:self.view];
@@ -379,39 +358,37 @@ PURPOSE.  See the above copyright notice for more information.
     location.x *= scale;
     location.y *= scale;
 
-    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void *)touch);
+    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void*)touch);
     if (index < VTKI_MAX_POINTERS)
     {
-      interactor->SetEventInformation((int)round(location.x),
-                                      (int)round(location.y),
-                                      0, 0,
-                                      0, 0, 0, index);
+      interactor->SetEventInformation(
+        (int)round(location.x), (int)round(location.y), 0, 0, 0, 0, 0, index);
     }
   }
 
   // handle begin events
-  for (UITouch *touch in touches)
+  for (UITouch* touch in touches)
   {
-    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void *)touch);
+    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void*)touch);
     interactor->SetPointerIndex(index);
-    interactor->InvokeEvent(vtkCommand::LeftButtonPressEvent,NULL);
-    //NSLog(@"Starting left mouse");
+    interactor->InvokeEvent(vtkCommand::LeftButtonPressEvent, NULL);
+    // NSLog(@"Starting left mouse");
   }
 
   // Display the buffer
-  [(GLKView *)self.view display];
+  [(GLKView*)self.view display];
 }
 
 // Handles the continuation of a touch.
-- (void)touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event
+- (void)touchesMoved:(NSSet*)touches withEvent:(UIEvent*)event
 {
-  vtkIOSRenderWindowInteractor *interactor = [self getInteractor];
+  vtkIOSRenderWindowInteractor* interactor = [self getInteractor];
   if (!interactor)
   {
     return;
   }
 
-  vtkIOSRenderWindow *renWin = [self getVTKRenderWindow];
+  vtkIOSRenderWindow* renWin = [self getVTKRenderWindow];
   if (!renWin)
   {
     return;
@@ -422,8 +399,8 @@ PURPOSE.  See the above copyright notice for more information.
 
   // set the position for all contacts
   int index;
-  NSSet *myTouches = [event touchesForView:self.view];
-  for (UITouch *touch in myTouches)
+  NSSet* myTouches = [event touchesForView:self.view];
+  for (UITouch* touch in myTouches)
   {
     // Convert touch point from UIView referential to OpenGL one (upside-down flip)
     CGPoint location = [touch locationInView:self.view];
@@ -433,35 +410,33 @@ PURPOSE.  See the above copyright notice for more information.
     location.x *= scale;
     location.y *= scale;
 
-    index = interactor->GetPointerIndexForContact((size_t)(__bridge void *)touch);
+    index = interactor->GetPointerIndexForContact((size_t)(__bridge void*)touch);
     if (index < VTKI_MAX_POINTERS)
     {
-      interactor->SetEventInformation((int)round(location.x),
-                                      (int)round(location.y),
-                                      0, 0,
-                                      0, 0, 0, index);
+      interactor->SetEventInformation(
+        (int)round(location.x), (int)round(location.y), 0, 0, 0, 0, 0, index);
     }
   }
 
   // fire move event on last index
   interactor->SetPointerIndex(index);
-  interactor->InvokeEvent(vtkCommand::MouseMoveEvent,NULL);
+  interactor->InvokeEvent(vtkCommand::MouseMoveEvent, NULL);
   //  NSLog(@"Moved left mouse");
 
   // Display the buffer
-  [(GLKView *)self.view display];
+  [(GLKView*)self.view display];
 }
 
 // Handles the end of a touch event when the touch is a tap.
-- (void)touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event
+- (void)touchesEnded:(NSSet*)touches withEvent:(UIEvent*)event
 {
-  vtkIOSRenderWindowInteractor *interactor = [self getInteractor];
+  vtkIOSRenderWindowInteractor* interactor = [self getInteractor];
   if (!interactor)
   {
     return;
   }
 
-  vtkIOSRenderWindow *renWin = [self getVTKRenderWindow];
+  vtkIOSRenderWindow* renWin = [self getVTKRenderWindow];
   if (!renWin)
   {
     return;
@@ -471,8 +446,8 @@ PURPOSE.  See the above copyright notice for more information.
   double scale = self.view.contentScaleFactor;
 
   // set the position for all contacts
-  NSSet *myTouches = [event touchesForView:self.view];
-  for (UITouch *touch in myTouches)
+  NSSet* myTouches = [event touchesForView:self.view];
+  for (UITouch* touch in myTouches)
   {
     // Convert touch point from UIView referential to OpenGL one (upside-down flip)
     CGPoint location = [touch locationInView:self.view];
@@ -482,40 +457,38 @@ PURPOSE.  See the above copyright notice for more information.
     location.x *= scale;
     location.y *= scale;
 
-    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void *)touch);
+    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void*)touch);
     if (index < VTKI_MAX_POINTERS)
     {
-      interactor->SetEventInformation((int)round(location.x),
-                                  (int)round(location.y),
-                                  0, 0,
-                                  0, 0, 0, index);
+      interactor->SetEventInformation(
+        (int)round(location.x), (int)round(location.y), 0, 0, 0, 0, 0, index);
     }
   }
 
   // handle begin events
-  for (UITouch *touch in touches)
+  for (UITouch* touch in touches)
   {
-    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void *)touch);
+    int index = interactor->GetPointerIndexForContact((size_t)(__bridge void*)touch);
     interactor->SetPointerIndex(index);
-    interactor->InvokeEvent(vtkCommand::LeftButtonReleaseEvent,NULL);
-    interactor->ClearContact((size_t)(__bridge void *)touch);
-      //NSLog(@"lifting left mouse");
+    interactor->InvokeEvent(vtkCommand::LeftButtonReleaseEvent, NULL);
+    interactor->ClearContact((size_t)(__bridge void*)touch);
+    // NSLog(@"lifting left mouse");
   }
 
   // Display the buffer
-  [(GLKView *)self.view display];
+  [(GLKView*)self.view display];
 }
 
 // Handles the end of a touch event.
-- (void)touchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event
+- (void)touchesCancelled:(NSSet*)touches withEvent:(UIEvent*)event
 {
-  vtkIOSRenderWindowInteractor *interactor = [self getInteractor];
+  vtkIOSRenderWindowInteractor* interactor = [self getInteractor];
   if (!interactor)
   {
     return;
   }
 
-  vtkIOSRenderWindow *renWin = [self getVTKRenderWindow];
+  vtkIOSRenderWindow* renWin = [self getVTKRenderWindow];
   if (!renWin)
   {
     return;
@@ -533,16 +506,12 @@ PURPOSE.  See the above copyright notice for more information.
   location.x *= scale;
   location.y *= scale;
 
-  interactor->SetEventInformation((int)round(location.x),
-                                  (int)round(location.y),
-                                  0, 0,
-                                  0, 0);
+  interactor->SetEventInformation((int)round(location.x), (int)round(location.y), 0, 0, 0, 0);
   interactor->InvokeEvent(vtkCommand::LeftButtonReleaseEvent, NULL);
   // NSLog(@"Ended left mouse");
 
   // Display the buffer
-  [(GLKView *)self.view display];
+  [(GLKView*)self.view display];
 }
 
-
 @end
