@@ -1,16 +1,5 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #import "MyGLKViewController.h"
 #include "vtk/vtkIOSRenderWindow.h"
@@ -135,7 +124,8 @@ PURPOSE.  See the above copyright notice for more information.
   mi->Update();
 
   double range[2];
-  mi->GetOutput()->GetPointData()->GetScalars()->GetRange(range);
+  vtkPointData* pd = mi->GetOutput()->GetPointData();
+  pd->GetRange(pd->GetScalars()->GetName(), range);
 
   volumeMapper->SetInputConnection(mi->GetOutputPort());
 #endif
