@@ -1,24 +1,12 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAppendFilter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkAppendFilter.h"
 
 #include "vtkBoundingBox.h"
 #include "vtkCell.h"
 #include "vtkCellData.h"
 #include "vtkDataSetCollection.h"
-#include "vtkExecutive.h"
+#include "vtkIdTypeArray.h"
 #include "vtkIncrementalOctreePointLocator.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -30,10 +18,12 @@
 #include "vtkUnstructuredGrid.h"
 
 #include <string>
+#include <unordered_map>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAppendFilter);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAppendFilter::vtkAppendFilter()
 {
   this->InputList = nullptr;
@@ -43,7 +33,7 @@ vtkAppendFilter::vtkAppendFilter()
   this->ToleranceIsAbsolute = true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAppendFilter::~vtkAppendFilter()
 {
   if (this->InputList != nullptr)
@@ -53,7 +43,7 @@ vtkAppendFilter::~vtkAppendFilter()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataSet* vtkAppendFilter::GetInput(int idx)
 {
   if (idx >= this->GetNumberOfInputConnections(0) || idx < 0)
@@ -64,7 +54,7 @@ vtkDataSet* vtkAppendFilter::GetInput(int idx)
   return vtkDataSet::SafeDownCast(this->GetExecutive()->GetInputData(0, idx));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove a dataset from the list of data to append.
 void vtkAppendFilter::RemoveInputData(vtkDataSet* ds)
 {
@@ -82,7 +72,7 @@ void vtkAppendFilter::RemoveInputData(vtkDataSet* ds)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataSetCollection* vtkAppendFilter::GetInputList()
 {
   if (this->InputList)
@@ -102,31 +92,11 @@ vtkDataSetCollection* vtkAppendFilter::GetInputList()
   return this->InputList;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Append data sets into single unstructured grid
 int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
-  bool reallyMergePoints = false;
-  if (this->MergePoints == 1 && inputVector[0]->GetNumberOfInformationObjects() > 0)
-  {
-    reallyMergePoints = true;
-
-    // ensure that none of the inputs has ghost-cells.
-    // (originally the code was checking for ghost cells only on 1st input,
-    // that's not sufficient).
-    for (int cc = 0; cc < inputVector[0]->GetNumberOfInformationObjects(); cc++)
-    {
-      vtkDataSet* tempData = vtkDataSet::GetData(inputVector[0], cc);
-      if (tempData->HasAnyGhostCells())
-      {
-        vtkDebugMacro(<< "Ghost cells present, so points will not be merged");
-        reallyMergePoints = false;
-        break;
-      }
-    }
-  }
-
   // get the output info object
   vtkInformation* outInfo = outputVector->GetInformationObject(0);
 
@@ -211,6 +181,39 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
     newPts->SetDataType(VTK_DOUBLE);
   }
 
+  // We look if we really can merge points.
+  // Additionally to having this->MergePoints set to true,
+  // points can be merge if there are not input cells cells OR if global point ids are
+  // available in the inputs.
+  inputs->InitTraversal(iter);
+  dataSet = inputs->GetNextDataSet(iter);
+  vtkIdTypeArray* globalIdsArray =
+    vtkIdTypeArray::SafeDownCast(dataSet->GetPointData()->GetGlobalIds());
+
+  bool reallyMergePoints = false;
+  if (this->MergePoints == 1 && inputVector[0]->GetNumberOfInformationObjects() > 0)
+  {
+    reallyMergePoints = true;
+
+    // If global point ids are present, we merge points sharing same global id
+    if (!globalIdsArray)
+    {
+      // ensure that none of the inputs has ghost-cells.
+      // (originally the code was checking for ghost cells only on 1st input,
+      // that's not sufficient).
+      for (int cc = 0; cc < inputVector[0]->GetNumberOfInformationObjects(); cc++)
+      {
+        vtkDataSet* tempData = vtkDataSet::GetData(inputVector[0], cc);
+        if (tempData->HasAnyGhostCells())
+        {
+          vtkDebugMacro(<< "Ghost cells present, so points will not be merged");
+          reallyMergePoints = false;
+          break;
+        }
+      }
+    }
+  }
+
   // If we aren't merging points, we need to allocate the points here.
   if (!reallyMergePoints)
   {
@@ -226,15 +229,14 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
 
   // For optionally merging duplicate points
   vtkIdType* globalIndices = new vtkIdType[totalNumPts];
+
   vtkSmartPointer<vtkIncrementalOctreePointLocator> ptInserter;
   if (reallyMergePoints)
   {
     vtkBoundingBox outputBB;
-
     inputs->InitTraversal(iter);
     while ((dataSet = inputs->GetNextDataSet(iter)))
     {
-
       // Union of bounding boxes
       double localBox[6];
       dataSet->GetBounds(localBox);
@@ -258,30 +260,56 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
   }
 
   // append the blocks / pieces in terms of the geometry and topology
+  std::unordered_map<vtkIdType, vtkIdType> addedPointsMap;
   vtkIdType count = 0;
   vtkIdType ptOffset = 0;
   float decimal = 0.0;
   inputs->InitTraversal(iter);
-  int abort = 0;
+  bool abort = false;
+  double p[3];
   while (!abort && (dataSet = inputs->GetNextDataSet(iter)))
   {
     vtkIdType dataSetNumPts = dataSet->GetNumberOfPoints();
     vtkIdType dataSetNumCells = dataSet->GetNumberOfCells();
+    vtkIdTypeArray* dataSetGlobalIdsArray = globalIdsArray
+      ? vtkIdTypeArray::SafeDownCast(dataSet->GetPointData()->GetGlobalIds())
+      : nullptr;
 
     // copy points
     for (vtkIdType ptId = 0; ptId < dataSetNumPts && !abort; ++ptId)
     {
       if (reallyMergePoints)
       {
-        vtkIdType globalPtId = 0;
-        ptInserter->InsertUniquePoint(dataSet->GetPoint(ptId), globalPtId);
-        globalIndices[ptId + ptOffset] = globalPtId;
-        // The point inserter puts the point into newPts, so we don't have to do that here.
+        if (dataSetGlobalIdsArray)
+        {
+          vtkIdType globalId = dataSetGlobalIdsArray->GetValue(ptId);
+          auto it = addedPointsMap.find(globalId);
+          if (it == addedPointsMap.end())
+          {
+            globalIndices[ptId + ptOffset] = newPts->GetNumberOfPoints();
+            dataSet->GetPoint(ptId, p);
+            vtkIdType newPtId = newPts->InsertNextPoint(p);
+            addedPointsMap.emplace(globalId, newPtId);
+          }
+          else
+          {
+            globalIndices[ptId + ptOffset] = it->second;
+          }
+        }
+        else
+        {
+          vtkIdType globalPtId = 0;
+          dataSet->GetPoint(ptId, p);
+          ptInserter->InsertUniquePoint(p, globalPtId);
+          globalIndices[ptId + ptOffset] = globalPtId;
+          // The point inserter puts the point into newPts, so we don't have to do that here.
+        }
       }
       else
       {
         globalIndices[ptId + ptOffset] = ptId + ptOffset;
-        newPts->SetPoint(ptId + ptOffset, dataSet->GetPoint(ptId));
+        dataSet->GetPoint(ptId, p);
+        newPts->SetPoint(ptId + ptOffset, p);
       }
 
       // Update progress
@@ -290,7 +318,7 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
       {
         decimal += 0.05;
         this->UpdateProgress(decimal);
-        abort = this->GetAbortExecute();
+        abort = this->CheckAbort();
       }
     }
 
@@ -332,7 +360,7 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
       {
         decimal += 0.05;
         this->UpdateProgress(decimal);
-        abort = this->GetAbortExecute();
+        abort = this->CheckAbort();
       }
     }
     ptOffset += dataSetNumPts;
@@ -341,7 +369,9 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
   // this filter can copy global ids except for global point ids when merging
   // points (see paraview/paraview#18666).
   // Note, not copying global ids is the default behavior.
-  if (reallyMergePoints == false)
+  // Since paraview/paraview#19961, global point ids can be used for the merging
+  // decision. In this case, they can be merged.
+  if (!reallyMergePoints || (reallyMergePoints && globalIdsArray))
   {
     output->GetPointData()->CopyAllOn(vtkDataSetAttributes::COPYTUPLE);
   }
@@ -363,7 +393,7 @@ int vtkAppendFilter::RequestData(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataSetCollection* vtkAppendFilter::GetNonEmptyInputs(vtkInformationVector** inputVector)
 {
   vtkDataSetCollection* collection = vtkDataSetCollection::New();
@@ -389,7 +419,7 @@ vtkDataSetCollection* vtkAppendFilter::GetNonEmptyInputs(vtkInformationVector**
   return collection;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAppendFilter::AppendArrays(int attributesType, vtkInformationVector** inputVector,
   vtkIdType* globalIds, vtkUnstructuredGrid* output, vtkIdType totalNumberOfElements)
 {
@@ -442,7 +472,7 @@ void vtkAppendFilter::AppendArrays(int attributesType, vtkInformationVector** in
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAppendFilter::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector))
 {
@@ -464,7 +494,7 @@ int vtkAppendFilter::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkAppendFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet");
@@ -472,7 +502,7 @@ int vtkAppendFilter::FillInputPortInformation(int, vtkInformation* info)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkAppendFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -480,3 +510,4 @@ void vtkAppendFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "OutputPointsPrecision: " << this->OutputPointsPrecision << "\n";
   os << indent << "Tolerance: " << this->Tolerance << "\n";
 }
+VTK_ABI_NAMESPACE_END
