@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkFeatureEdges.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkFeatureEdges
  * @brief   extract interior, boundary, non-manifold, and/or
@@ -42,18 +30,19 @@
 #include "vtkFiltersCoreModule.h" // For export macro
 #include "vtkPolyDataAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIncrementalPointLocator;
 
 class VTKFILTERSCORE_EXPORT vtkFeatureEdges : public vtkPolyDataAlgorithm
 {
 public:
-  //@{
+  ///@{
   /**
    * Standard methods for type information and printing.
    */
   vtkTypeMacro(vtkFeatureEdges, vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Construct an instance with feature angle = 30; all types of edges
@@ -61,51 +50,51 @@ public:
    */
   static vtkFeatureEdges* New();
 
-  //@{
+  ///@{
   /**
    * Methods for turning the extraction of all types of edges on;
    * and turning the extraction of all types of edges off.
    */
   void ExtractAllEdgeTypesOn();
   void ExtractAllEdgeTypesOff();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the extraction of boundary edges.
    */
   vtkSetMacro(BoundaryEdges, bool);
   vtkGetMacro(BoundaryEdges, bool);
   vtkBooleanMacro(BoundaryEdges, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the extraction of feature edges.
    */
   vtkSetMacro(FeatureEdges, bool);
   vtkGetMacro(FeatureEdges, bool);
   vtkBooleanMacro(FeatureEdges, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the feature angle for extracting feature edges.
    */
   vtkSetClampMacro(FeatureAngle, double, 0.0, 180.0);
   vtkGetMacro(FeatureAngle, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the extraction of non-manifold edges.
    */
   vtkSetMacro(NonManifoldEdges, bool);
   vtkGetMacro(NonManifoldEdges, bool);
   vtkBooleanMacro(NonManifoldEdges, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the extraction of manifold edges. This typically
    * correspond to interior edges.
@@ -113,25 +102,53 @@ public:
   vtkSetMacro(ManifoldEdges, bool);
   vtkGetMacro(ManifoldEdges, bool);
   vtkBooleanMacro(ManifoldEdges, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Turn on/off passing input lines. If this flag is on, then all cells living inside the `Lines`
+   * cell array of the input are copied into the output.
+   *
+   * @note Input poly lines are split into separate lines in the output.
+   */
+  vtkSetMacro(PassLines, bool);
+  vtkGetMacro(PassLines, bool);
+  vtkBooleanMacro(PassLines, bool);
+  ///@}
+
+  ///@{
   /**
    * Turn on/off the coloring of edges by type.
    */
   vtkSetMacro(Coloring, bool);
   vtkGetMacro(Coloring, bool);
   vtkBooleanMacro(Coloring, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Turn on/off creating edges at ghost interfaces. An edge is at a ghost interface
+   * if it belongs to at least one ghost cell. This is turned on by default.
+   * When turned off, only edges that solely belong to ghost cells are discarded from the output.
+   * When turned on, edges are discarded if the belong to at least one ghost cell.
+   *
+   * @note In order for the interfaces between ranks to be removed, ghost cells must be first
+   * generated.
+   * @sa vtkGhostCellsGenerator
+   */
+  vtkSetMacro(RemoveGhostInterfaces, bool);
+  vtkGetMacro(RemoveGhostInterfaces, bool);
+  vtkBooleanMacro(RemoveGhostInterfaces, bool);
+  ///@}
+
+  ///@{
   /**
    * Set / get a spatial locator for merging points. By
    * default an instance of vtkMergePoints is used.
    */
   void SetLocator(vtkIncrementalPointLocator* locator);
   vtkGetObjectMacro(Locator, vtkIncrementalPointLocator);
-  //@}
+  ///@}
 
   /**
    * Create default locator. Used to create one when none is specified.
@@ -143,7 +160,7 @@ public:
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output point type. See the documentation
    * for the vtkAlgorithm::DesiredOutputPrecision enum for an explanation of
@@ -151,7 +168,7 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
 protected:
   vtkFeatureEdges();
@@ -166,7 +183,10 @@ protected:
   bool FeatureEdges;
   bool NonManifoldEdges;
   bool ManifoldEdges;
+  bool PassLines;
   bool Coloring;
+  bool PassGlobalIds;
+  bool RemoveGhostInterfaces;
   int OutputPointsPrecision;
   vtkIncrementalPointLocator* Locator;
 
@@ -175,4 +195,5 @@ private:
   void operator=(const vtkFeatureEdges&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
