@@ -1,21 +1,10 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkFlyingEdges3D.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkFlyingEdges3D.h"
 
 #include "vtkArrayListTemplate.h" // For processing attribute data
 #include "vtkCellArray.h"
+#include "vtkCellData.h"
 #include "vtkDataArrayRange.h"
 #include "vtkFloatArray.h"
 #include "vtkImageData.h"
@@ -33,9 +22,10 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkFlyingEdges3D);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
 // This templated class implements the heart of the algorithm.
@@ -56,6 +46,9 @@ public:
   };
 
   // Dealing with boundary situations when processing volumes.
+  // The voxel cells on the +x,+y,+z boundaries reference cell
+  // axes triads which are not fully formed. These are treated
+  // specially during certain operations (e.g., point generation).
   enum CellClass
   {
     Interior = 0,
@@ -132,9 +125,12 @@ public:
   vtkFlyingEdges3DAlgorithm();
 
   // The three main passes of the algorithm.
-  void ProcessXEdge(double value, T const* const inPtr, vtkIdType row, vtkIdType slice); // PASS 1
-  void ProcessYZEdges(vtkIdType row, vtkIdType slice);                                   // PASS 2
-  void GenerateOutput(double value, T* inPtr, vtkIdType row, vtkIdType slice);           // PASS 4
+  void ProcessXEdge(double value, T const* inPtr, vtkIdType row, vtkIdType slice); // PASS 1
+  void ProcessYZEdges(vtkIdType row, vtkIdType slice);                             // PASS 2
+  void GenerateOutput(double value, T* inPtr, vtkIdType row, vtkIdType slice);     // PASS 4
+
+  // Optional copying of cell data
+  void InterpolateCellData(ArrayList* cellArrays, vtkIdType row, vtkIdType slice);
 
   // Place holder for now in case fancy bit fiddling is needed later.
   void SetXEdge(unsigned char* ePtr, unsigned char edgeCase) { *ePtr = edgeCase; }
@@ -181,9 +177,20 @@ public:
         *connIter++ = eIds[*edges++];
         *connIter++ = eIds[*edges++];
       }
-
-      // Write the last offset:
-      *offsetIter = static_cast<ValueType>(3 * triId);
+    }
+  };
+  // Finalize the triangle cell array: after all the tris are inserted,
+  // the last offset has to be added to complete the offsets array.
+  struct FinalizeTrisImpl
+  {
+    template <typename CellStateT>
+    void operator()(CellStateT& state, vtkIdType numTris)
+    {
+      using ValueType = typename CellStateT::ValueType;
+      auto* offsets = state.GetOffsets();
+      auto offsetRange = vtk::DataArrayValueRange<1>(offsets);
+      auto offsetIter = offsetRange.begin() + numTris;
+      *offsetIter = static_cast<ValueType>(3 * numTris);
     }
   };
   void GenerateTris(unsigned char eCase, unsigned char numTris, vtkIdType* eIds, vtkIdType& triId)
@@ -254,19 +261,18 @@ public:
   }
 
   // Compute the gradient on a point which may be on the boundary of the volume.
-  void ComputeBoundaryGradient(vtkIdType ijk[3], T const* const s0_start, T const* const s0_end,
-    T const* const s1_start, T const* const s1_end, T const* const s2_start, T const* const s2_end,
-    float g[3]);
+  void ComputeBoundaryGradient(vtkIdType ijk[3], T const* s0_start, T const* s0_end,
+    T const* s1_start, T const* s1_end, T const* s2_start, T const* s2_end, float g[3]);
 
   // Interpolate along an arbitrary edge, typically one that may be on the
   // volume boundary. This means careful computation of stuff requiring
   // neighborhood information (e.g., gradients).
-  void InterpolateEdge(double value, vtkIdType ijk[3], T const* const s, const int incs[3],
-    unsigned char edgeNum, unsigned char const* const edgeUses, vtkIdType* eIds);
+  void InterpolateEdge(double value, vtkIdType ijk[3], T const* s, const int incs[3],
+    unsigned char edgeNum, unsigned char const* edgeUses, vtkIdType* eIds);
 
   // Produce the output points on the voxel axes for this voxel cell.
-  void GeneratePoints(double value, unsigned char loc, vtkIdType ijk[3], T const* const sPtr,
-    const int incs[3], unsigned char const* const edgeUses, vtkIdType* eIds);
+  void GeneratePoints(double value, unsigned char loc, vtkIdType ijk[3], T const* sPtr,
+    const int incs[3], unsigned char const* edgeUses, vtkIdType* eIds);
 
   // Helper function to set up the point ids on voxel edges.
   unsigned char InitVoxelIds(unsigned char* ePtr[4], vtkIdType* eMD[4], vtkIdType* eIds)
@@ -311,7 +317,9 @@ public:
   public:
     vtkFlyingEdges3DAlgorithm<TT>* Algo;
     double Value;
-    Pass1(vtkFlyingEdges3DAlgorithm<TT>* algo, double value)
+    vtkFlyingEdges3D* Filter;
+    Pass1(vtkFlyingEdges3DAlgorithm<TT>* algo, double value, vtkFlyingEdges3D* filter)
+      : Filter(filter)
     {
       this->Algo = algo;
       this->Value = value;
@@ -320,8 +328,22 @@ public:
     {
       vtkIdType row;
       TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
+      bool isFirst = vtkSMPTools::GetSingleThread();
+      vtkIdType checkAbortInterval = std::min((end - slice) / 10 + 1, (vtkIdType)1000);
       for (; slice < end; ++slice)
       {
+        if (slice % checkAbortInterval == 0)
+        {
+          if (isFirst)
+          {
+            this->Filter->CheckAbort();
+          }
+          if (this->Filter->GetAbortOutput())
+          {
+            break;
+          }
+        }
+
         for (row = 0, rowPtr = slicePtr; row < this->Algo->Dims[1]; ++row)
         {
           this->Algo->ProcessXEdge(this->Value, rowPtr, row, slice);
@@ -335,12 +357,30 @@ public:
   class Pass2
   {
   public:
-    Pass2(vtkFlyingEdges3DAlgorithm<TT>* algo) { this->Algo = algo; }
+    Pass2(vtkFlyingEdges3DAlgorithm<TT>* algo, vtkFlyingEdges3D* filter)
+      : Filter(filter)
+    {
+      this->Algo = algo;
+    }
     vtkFlyingEdges3DAlgorithm<TT>* Algo;
+    vtkFlyingEdges3D* Filter;
     void operator()(vtkIdType slice, vtkIdType end)
     {
+      bool isFirst = vtkSMPTools::GetSingleThread();
+      vtkIdType checkAbortInterval = std::min((end - slice) / 10 + 1, (vtkIdType)1000);
       for (; slice < end; ++slice)
       {
+        if (slice % checkAbortInterval == 0)
+        {
+          if (isFirst)
+          {
+            this->Filter->CheckAbort();
+          }
+          if (this->Filter->GetAbortOutput())
+          {
+            break;
+          }
+        }
         for (vtkIdType row = 0; row < (this->Algo->Dims[1] - 1); ++row)
         {
           this->Algo->ProcessYZEdges(row, slice);
@@ -352,12 +392,14 @@ public:
   class Pass4
   {
   public:
-    Pass4(vtkFlyingEdges3DAlgorithm<TT>* algo, double value)
+    Pass4(vtkFlyingEdges3DAlgorithm<TT>* algo, double value, vtkFlyingEdges3D* filter)
+      : Filter(filter)
     {
       this->Algo = algo;
       this->Value = value;
     }
     vtkFlyingEdges3DAlgorithm<TT>* Algo;
+    vtkFlyingEdges3D* Filter;
     double Value;
     void operator()(vtkIdType slice, vtkIdType end)
     {
@@ -365,8 +407,21 @@ public:
       vtkIdType* eMD0 = this->Algo->EdgeMetaData + slice * 6 * this->Algo->Dims[1];
       vtkIdType* eMD1 = eMD0 + 6 * this->Algo->Dims[1];
       TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
+      bool isFirst = vtkSMPTools::GetSingleThread();
+      vtkIdType checkAbortInterval = std::min((end - slice) / 10 + 1, (vtkIdType)1000);
       for (; slice < end; ++slice)
       {
+        if (slice % checkAbortInterval == 0)
+        {
+          if (isFirst)
+          {
+            this->Filter->CheckAbort();
+          }
+          if (this->Filter->GetAbortOutput())
+          {
+            break;
+          }
+        }
         // It's possible to skip entire slices if there is nothing to generate
         if (eMD1[3] > eMD0[3]) // there are triangle primitives!
         {
@@ -383,6 +438,42 @@ public:
     }
   };
 
+  template <class TT>
+  struct ProcessCD
+  {
+    ArrayList CellArrays;
+    ProcessCD(vtkFlyingEdges3DAlgorithm<TT>* algo, vtkIdType numCells, vtkCellData* inCD,
+      vtkCellData* outCD)
+    {
+      this->Algo = algo;
+      outCD->CopyAllocate(inCD, numCells);
+      this->CellArrays.AddArrays(numCells, inCD, outCD);
+    }
+    vtkFlyingEdges3DAlgorithm<TT>* Algo;
+    void operator()(vtkIdType slice, vtkIdType end)
+    {
+      vtkIdType row;
+      vtkIdType* eMD0 = this->Algo->EdgeMetaData + slice * 6 * this->Algo->Dims[1];
+      vtkIdType* eMD1 = eMD0 + 6 * this->Algo->Dims[1];
+      TT *rowPtr, *slicePtr = this->Algo->Scalars + slice * this->Algo->Inc2;
+      for (; slice < end; ++slice)
+      {
+        // It's possible to skip entire slices if there is no data to copy
+        if (eMD1[3] > eMD0[3]) // there are triangle primitives!
+        {
+          for (row = 0, rowPtr = slicePtr; row < this->Algo->Dims[1] - 1; ++row)
+          {
+            this->Algo->InterpolateCellData(&this->CellArrays, row, slice);
+            rowPtr += this->Algo->Inc1;
+          } // for all rows in this slice
+        }   // if there are triangles (i.e., output cells)
+        slicePtr += this->Algo->Inc2;
+        eMD0 = eMD1;
+        eMD1 = eMD0 + 6 * this->Algo->Dims[1];
+      } // for all slices in this batch
+    }
+  };
+
   // Interface between VTK and templated functions
   static void Contour(vtkFlyingEdges3D* self, vtkImageData* input, vtkDataArray* inScalars,
     int extent[6], vtkIdType* incs, T* scalars, vtkPolyData* output, vtkPoints* newPts,
@@ -390,13 +481,13 @@ public:
     vtkFloatArray* newGradients);
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Map MC edges numbering to use the saner FlyingEdges edge numbering scheme.
 template <class T>
 const unsigned char vtkFlyingEdges3DAlgorithm<T>::EdgeMap[12] = { 0, 5, 1, 4, 2, 7, 3, 6, 8, 9, 10,
   11 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Map MC edges numbering to use the saner FlyingEdges edge numbering scheme.
 template <class T>
 const unsigned char vtkFlyingEdges3DAlgorithm<T>::VertMap[12][2] = {
@@ -414,7 +505,7 @@ const unsigned char vtkFlyingEdges3DAlgorithm<T>::VertMap[12][2] = {
   { 3, 7 },
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The offsets of each vertex (in index space) from the voxel axes origin.
 template <class T>
 const unsigned char vtkFlyingEdges3DAlgorithm<T>::VertOffsets[8][3] = {
@@ -428,7 +519,7 @@ const unsigned char vtkFlyingEdges3DAlgorithm<T>::VertOffsets[8][3] = {
   { 1, 1, 1 },
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Instantiate and initialize key data members. Mostly we build the
 // edge-based case table, and associated acceleration structures, from the
 // marching cubes case table. Some of this code is borrowed shamelessly from
@@ -446,7 +537,7 @@ vtkFlyingEdges3DAlgorithm<T>::vtkFlyingEdges3DAlgorithm()
   int i, j, k, l, ii, eCase, index, numTris;
   static const int vertMap[8] = { 0, 1, 3, 2, 4, 5, 7, 6 };
   static const int CASE_MASK[8] = { 1, 2, 4, 8, 16, 32, 64, 128 };
-  EDGE_LIST* edge;
+  int* edge;
   vtkMarchingCubesTriangleCases* triCase;
   unsigned char* edgeCase;
 
@@ -532,7 +623,7 @@ vtkFlyingEdges3DAlgorithm<T>::vtkFlyingEdges3DAlgorithm()
   } // for all cases
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Count intersections along voxel axes. When traversing the volume across
 // x-edges, the voxel axes on the boundary may be undefined near boundaries
 // (because there are no fully-formed cells). Thus the voxel axes on the
@@ -582,7 +673,7 @@ void vtkFlyingEdges3DAlgorithm<T>::CountBoundaryYZInts(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Compute the gradient when the point may be near the boundary of the
 // volume.
 template <class T>
@@ -632,7 +723,7 @@ void vtkFlyingEdges3DAlgorithm<T>::ComputeBoundaryGradient(vtkIdType ijk[3],
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Interpolate a new point along a boundary edge. Make sure to consider
 // proximity to the boundary when computing gradients, etc.
 template <class T>
@@ -707,7 +798,7 @@ void vtkFlyingEdges3DAlgorithm<T>::InterpolateEdge(double value, vtkIdType ijk[3
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Generate the output points and optionally normals, gradients and
 // interpolate attributes.
 template <class T>
@@ -722,7 +813,8 @@ void vtkFlyingEdges3DAlgorithm<T>::GeneratePoints(double value, unsigned char lo
       sPtr + incs[2], sPtr - incs[2], g0);
   }
 
-  // Interpolate the cell axes edges
+  // Interpolate the cell axes edges. Recall this is the triad of edges
+  // located at the origin of the voxel.
   for (int i = 0; i < 3; ++i)
   {
     if (edgeUses[i * 4])
@@ -739,62 +831,123 @@ void vtkFlyingEdges3DAlgorithm<T>::GeneratePoints(double value, unsigned char lo
     }
   }
 
-  // On the boundary cells special work has to be done to cover the partial
-  // cell axes. These are boundary situations where the voxel axes is not
-  // fully formed. These situations occur on the +x,+y,+z volume
-  // boundaries. (The other cases fall through the default: case which is
-  // expected.)
+  // Interior voxels are completed at this point, avoid the switch statement.
+  if (loc == Interior)
+  {
+    return;
+  }
+
+  // On the boundary voxels special work has to be done to process the
+  // partial cell axes located on the + boundary faces of the volume. These
+  // are boundary situations where the voxel axes is not fully formed.  (The
+  // other cases fall through the default: case which is expected.)
   //
-  // Note that loc is one of 27 regions in the volume, with (0,1,2)
-  // indicating (interior, min, max) along coordinate axes.
+  // Note that loc describes one of 64 (2^6) voxel configurations in the
+  // volume, with (0,1,2) in each of the +x, +y, +z directions indicating
+  // (interior, min, max) along the coordinate axes. Note that processing
+  // boundary voxels really only requires seven possibilities corresponding
+  // to various combinations of +x,+y,+z (an eighth combination loc==0 is
+  // interior).  However, for historical reasons, and to signal to
+  // the gradient computation that a boundary voxel is involved, the more
+  // complex switch statement below is used.
   switch (loc)
   {
+    //+x
     case 2:
+    case 3:
     case 6:
+    case 7:
     case 18:
-    case 22: //+x
+    case 19:
+    case 22:
+    case 23:
       this->InterpolateEdge(value, ijk, sPtr, incs, 5, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 9, edgeUses, eIds);
       break;
+
+    //+y
     case 8:
     case 9:
+    case 12:
+    case 13:
     case 24:
-    case 25: //+y
+    case 25:
+    case 28:
+    case 29:
       this->InterpolateEdge(value, ijk, sPtr, incs, 1, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 10, edgeUses, eIds);
       break;
+
+    //+x +y
+    case 10:
+    case 11:
+    case 14:
+    case 15:
+    case 26:
+    case 27:
+    case 30:
+    case 31:
+      this->InterpolateEdge(value, ijk, sPtr, incs, 1, edgeUses, eIds);
+      this->InterpolateEdge(value, ijk, sPtr, incs, 5, edgeUses, eIds);
+      this->InterpolateEdge(value, ijk, sPtr, incs, 9, edgeUses, eIds);
+      this->InterpolateEdge(value, ijk, sPtr, incs, 10, edgeUses, eIds);
+      this->InterpolateEdge(value, ijk, sPtr, incs, 11, edgeUses, eIds);
+      break;
+
+    //+z
     case 32:
     case 33:
     case 36:
-    case 37: //+z
+    case 37:
+    case 48:
+    case 49:
+    case 52:
+    case 53:
       this->InterpolateEdge(value, ijk, sPtr, incs, 2, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 6, edgeUses, eIds);
       break;
-    case 10:
-    case 26: //+x +y
-      this->InterpolateEdge(value, ijk, sPtr, incs, 1, edgeUses, eIds);
-      this->InterpolateEdge(value, ijk, sPtr, incs, 5, edgeUses, eIds);
-      this->InterpolateEdge(value, ijk, sPtr, incs, 9, edgeUses, eIds);
-      this->InterpolateEdge(value, ijk, sPtr, incs, 10, edgeUses, eIds);
-      this->InterpolateEdge(value, ijk, sPtr, incs, 11, edgeUses, eIds);
-      break;
+
+    //+x +z
     case 34:
-    case 38: //+x +z
+    case 35:
+    case 38:
+    case 39:
+    case 50:
+    case 51:
+    case 54:
+    case 55:
       this->InterpolateEdge(value, ijk, sPtr, incs, 2, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 5, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 9, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 6, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 7, edgeUses, eIds);
       break;
+
+    //+y +z
     case 40:
-    case 41: //+y +z
+    case 41:
+    case 44:
+    case 45:
+    case 56:
+    case 57:
+    case 60:
+    case 61:
       this->InterpolateEdge(value, ijk, sPtr, incs, 1, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 2, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 3, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 6, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 10, edgeUses, eIds);
       break;
-    case 42: //+x +y +z happens no more than once per volume
+
+    //+x +y +z
+    case 42:
+    case 43:
+    case 46:
+    case 47:
+    case 58:
+    case 59:
+    case 62:
+    case 63:
       this->InterpolateEdge(value, ijk, sPtr, incs, 1, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 2, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 3, edgeUses, eIds);
@@ -805,12 +958,13 @@ void vtkFlyingEdges3DAlgorithm<T>::GeneratePoints(double value, unsigned char lo
       this->InterpolateEdge(value, ijk, sPtr, incs, 6, edgeUses, eIds);
       this->InterpolateEdge(value, ijk, sPtr, incs, 7, edgeUses, eIds);
       break;
-    default: // interior, or -x,-y,-z boundaries
+
+    default: // voxels with only -x,-y,-z boundaries
       return;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // PASS 1: Process a single volume x-row (and all of the voxel edges that
 // compose the row). Determine the x-edges case classification, count the
 // number of x-edge intersections, and figure out where intersections along
@@ -875,7 +1029,7 @@ void vtkFlyingEdges3DAlgorithm<T>::ProcessXEdge(
   edgeMetaData[5] = maxInt; // where intersections end along x edge
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // PASS 2: Process a single x-row of voxels. Count the number of y- and
 // z-intersections by topological reasoning from x-edge cases. Determine the
 // number of primitives (i.e., triangles) generated from this row. Use
@@ -1004,7 +1158,7 @@ void vtkFlyingEdges3DAlgorithm<T>::ProcessYZEdges(vtkIdType row, vtkIdType slice
   } // for all voxels along this x-edge
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // PASS 4: Process the x-row cells to generate output primitives, including
 // point coordinates and triangles. This is the fourth and final pass of the
 // algorithm.
@@ -1051,10 +1205,23 @@ void vtkFlyingEdges3DAlgorithm<T>::GenerateOutput(
   unsigned char eCase = this->InitVoxelIds(ePtr, eMD, eIds);
 
   // Determine the proximity to the boundary of volume. This information is
-  // used to generate edge intersections.
+  // used to generate edge intersections. It also controls calculations (like
+  // gradient computation) when proximity to the boundary is important. Currently,
+  // the loc variable can take on values [0,63] representing all combinations
+  // of +/- x,y,z boundaries and interior(==0).
   unsigned char loc, yLoc, zLoc, yzLoc;
-  yLoc = (row < 1 ? MinBoundary : (row >= (this->Dims[1] - 2) ? MaxBoundary : Interior));
-  zLoc = (slice < 1 ? MinBoundary : (slice >= (this->Dims[2] - 2) ? MaxBoundary : Interior));
+  yLoc = Interior;
+  if (row < 1)
+    yLoc |= MinBoundary;
+  if (row >= (this->Dims[1] - 2))
+    yLoc |= MaxBoundary;
+
+  zLoc = Interior;
+  if (slice < 1)
+    zLoc |= MinBoundary;
+  if (slice >= (this->Dims[2] - 2))
+    zLoc |= MaxBoundary;
+
   yzLoc = (yLoc << 2) | (zLoc << 4);
 
   // compute the ijk for this section
@@ -1074,9 +1241,14 @@ void vtkFlyingEdges3DAlgorithm<T>::GenerateOutput(
       // Start by generating triangles for this case
       this->GenerateTris(eCase, numTris, eIds, triId);
 
-      // Now generate point(s) along voxel axes if needed. Remember to take
-      // boundary into account.
-      loc = yzLoc | (i < 1 ? MinBoundary : (i >= dim0Wall ? MaxBoundary : Interior));
+      // Now generate point(s) along voxel cell triad axes if
+      // needed. Remember to take the volume boundary into account.
+      loc = yzLoc;
+      if (i < 1)
+        loc |= MinBoundary;
+      if (i >= dim0Wall)
+        loc |= MaxBoundary;
+
       if (this->CaseIncludesAxes(eCase) || loc != Interior)
       {
         unsigned char const* const edgeUses = this->GetEdgeUses(eCase);
@@ -1100,7 +1272,77 @@ void vtkFlyingEdges3DAlgorithm<T>::GenerateOutput(
   }   // for all non-trimmed cells along this x-edge
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+// Copy cell data from input to output
+template <class T>
+void vtkFlyingEdges3DAlgorithm<T>::InterpolateCellData(
+  ArrayList* arrays, vtkIdType row, vtkIdType slice)
+{
+  // Grab the edge meta data surrounding the voxel row.
+  vtkIdType* eMD[4];
+  eMD[0] = this->EdgeMetaData + (slice * this->Dims[1] + row) * 6; // this x-edge
+  eMD[1] = eMD[0] + 6;                                             // x-edge in +y direction
+  eMD[2] = eMD[0] + this->Dims[1] * 6;                             // x-edge in +z direction
+  eMD[3] = eMD[2] + 6;                                             // x-edge in +y+z direction
+
+  // Return if there is nothing to do (i.e., no triangles to generate)
+  if (eMD[0][3] == eMD[1][3])
+  {
+    return;
+  }
+
+  // Get the voxel row trim edges and prepare to generate. Find the voxel row
+  // trim edges, need to check all four x-edges to compute row trim edges.
+  vtkIdType xL = eMD[0][4], xR = eMD[0][5];
+  vtkIdType i;
+  for (i = 1; i < 4; ++i)
+  {
+    xL = (eMD[i][4] < xL ? eMD[i][4] : xL);
+    xR = (eMD[i][5] > xR ? eMD[i][5] : xR);
+  }
+
+  // Grab the four edge cases bounding this voxel x-row. Begin at left trim edge.
+  unsigned char* ePtr[4];
+  ePtr[0] = this->XCases + slice * this->SliceOffset + row * (this->Dims[0] - 1) + xL;
+  ePtr[1] = ePtr[0] + this->Dims[0] - 1;
+  ePtr[2] = ePtr[0] + this->SliceOffset;
+  ePtr[3] = ePtr[2] + this->Dims[0] - 1;
+
+  // Traverse all voxels in this row, those containing the contour are
+  // further identified for copying cell data. Begin by getting the
+  // starting voxel case and cell id.
+  unsigned char eCase = this->GetEdgeCase(ePtr);
+
+  // Determine the input and output cell ids.
+  vtkIdType inCellId =
+    xL + row * (this->Dims[0] - 1) + slice * (this->Dims[0] - 1) * (this->Dims[1] - 1);
+  vtkIdType outCellId = eMD[0][3];
+
+  for (i = xL; i < xR; ++i)
+  {
+    const unsigned char numTris = this->GetNumberOfPrimitives(eCase);
+    if (numTris > 0)
+    {
+      for (auto j = 0; j < numTris; ++j)
+      {
+        arrays->Copy(inCellId, outCellId++);
+      }
+    }
+
+    // advance along voxel row
+    inCellId++;
+    if (i != xR - 1)
+    {
+      ePtr[0]++;
+      ePtr[1]++;
+      ePtr[2]++;
+      ePtr[3]++;
+      eCase = this->GetEdgeCase(ePtr);
+    }
+  } // for voxel cells along row
+}
+
+//------------------------------------------------------------------------------
 // Contouring filter specialized for 3D volumes. This templated function
 // interfaces the vtkFlyingEdges3D class with the templated algorithm
 // class. It also invokes the three passes of the Flying Edges algorithm.
@@ -1152,25 +1394,29 @@ void vtkFlyingEdges3DAlgorithm<T>::Contour(vtkFlyingEdges3D* self, vtkImageData*
   // exist and the user requests it.
   algo.NeedGradients = (newGradients || newNormals);
   algo.InterpolateAttributes =
-    (self->GetInterpolateAttributes() && input->GetPointData()->GetNumberOfArrays() > 1) ? true
-                                                                                         : false;
+    self->GetInterpolateAttributes() && input->GetPointData()->GetNumberOfArrays() > 1;
 
+  vtkIdType checkAbortInterval = std::min(numContours / 10 + 1, (vtkIdType)1000);
   // Loop across each contour value. This encompasses all three passes.
   for (vidx = 0; vidx < numContours; vidx++)
   {
+    if (vidx % checkAbortInterval == 0 && self->CheckAbort())
+    {
+      break;
+    }
     value = values[vidx];
 
     // PASS 1: Traverse all x-rows building edge cases and counting number of
     // intersections (i.e., accumulate information necessary for later output
     // memory allocation, e.g., the number of output points along the x-rows
     // are counted).
-    Pass1<T> pass1(&algo, value);
+    Pass1<T> pass1(&algo, value, self);
     vtkSMPTools::For(0, algo.Dims[2], pass1);
 
     // PASS 2: Traverse all voxel x-rows and process voxel y&z edges.  The
     // result is a count of the number of y- and z-intersections, as well as
     // the number of triangles generated along these voxel rows.
-    Pass2<T> pass2(&algo);
+    Pass2<T> pass2(&algo, self);
     vtkSMPTools::For(0, algo.Dims[2] - 1, pass2);
 
     // PASS 3: Now allocate and generate output. First we have to update the
@@ -1216,6 +1462,7 @@ void vtkFlyingEdges3DAlgorithm<T>::Contour(vtkFlyingEdges3D* self, vtkImageData*
       newPts->GetData()->WriteVoidPointer(0, 3 * totalPts);
       algo.NewPoints = static_cast<float*>(newPts->GetVoidPointer(0));
       newTris->ResizeExact(numOutTris, 3 * numOutTris);
+      newTris->Visit(FinalizeTrisImpl{}, numOutTris);
       algo.NewTris = newTris;
       if (newScalars)
       {
@@ -1243,9 +1490,9 @@ void vtkFlyingEdges3DAlgorithm<T>::Contour(vtkFlyingEdges3D* self, vtkImageData*
           // Make sure we don't interpolate the input scalars twice; or generate scalars
           // when ComputeScalars is off.
           output->GetPointData()->InterpolateAllocate(input->GetPointData(), totalPts);
-          output->GetPointData()->RemoveArray(inScalars->GetName());
           algo.Arrays.ExcludeArray(inScalars);
           algo.Arrays.AddArrays(totalPts, input->GetPointData(), output->GetPointData());
+          output->GetPointData()->RemoveArray(inScalars->GetName());
         }
         else
         {
@@ -1257,7 +1504,7 @@ void vtkFlyingEdges3DAlgorithm<T>::Contour(vtkFlyingEdges3D* self, vtkImageData*
       // Note that we are simultaneously generating triangles and interpolating
       // points. These could be split into separate, parallel operations for
       // maximum performance.
-      Pass4<T> pass4(&algo, value);
+      Pass4<T> pass4(&algo, value, self);
       vtkSMPTools::For(0, algo.Dims[2] - 1, pass4);
     } // if anything generated
 
@@ -1266,6 +1513,15 @@ void vtkFlyingEdges3DAlgorithm<T>::Contour(vtkFlyingEdges3D* self, vtkImageData*
     startYPts = numOutYPts;
     startZPts = numOutZPts;
     startTris = numOutTris;
+
+    // Process Cell Data: Some applications require the production of cell
+    // data. Since this slows the filter, we only perform this operation if
+    // cell data is present, and attribute interpolation is enabled.
+    if (self->GetInterpolateAttributes() && input->GetCellData()->GetNumberOfArrays() > 0)
+    {
+      ProcessCD<T> processCD(&algo, numOutTris, input->GetCellData(), output->GetCellData());
+      vtkSMPTools::For(0, algo.Dims[2] - 1, processCD);
+    }
   } // for all contour values
 
   // Clean up and return
@@ -1275,7 +1531,7 @@ void vtkFlyingEdges3DAlgorithm<T>::Contour(vtkFlyingEdges3D* self, vtkImageData*
 
 } // anonymous namespace
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Here is the VTK class proper.
 // Construct object with a single contour value of 0.0.
 vtkFlyingEdges3D::vtkFlyingEdges3D()
@@ -1292,13 +1548,13 @@ vtkFlyingEdges3D::vtkFlyingEdges3D()
     0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, vtkDataSetAttributes::SCALARS);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkFlyingEdges3D::~vtkFlyingEdges3D()
 {
   this->ContourValues->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Overload standard modified time function. If contour values are modified,
 // then this object is modified as well.
 vtkMTimeType vtkFlyingEdges3D::GetMTime()
@@ -1308,7 +1564,7 @@ vtkMTimeType vtkFlyingEdges3D::GetMTime()
   return (mTime2 > mTime ? mTime2 : mTime);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkFlyingEdges3D::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -1326,7 +1582,7 @@ int vtkFlyingEdges3D::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkFlyingEdges3D::RequestData(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -1385,28 +1641,28 @@ int vtkFlyingEdges3D::RequestData(
 
   // Create necessary objects to hold output. We will defer the
   // actual allocation to a later point.
-  vtkCellArray* newTris = vtkCellArray::New();
-  vtkPoints* newPts = vtkPoints::New();
+  vtkNew<vtkCellArray> newTris;
+  vtkNew<vtkPoints> newPts;
   newPts->SetDataTypeToFloat();
-  vtkDataArray* newScalars = nullptr;
-  vtkFloatArray* newNormals = nullptr;
-  vtkFloatArray* newGradients = nullptr;
+  vtkSmartPointer<vtkDataArray> newScalars;
+  vtkSmartPointer<vtkFloatArray> newNormals;
+  vtkSmartPointer<vtkFloatArray> newGradients;
 
   if (this->ComputeScalars)
   {
-    newScalars = inScalars->NewInstance();
+    newScalars.TakeReference(inScalars->NewInstance());
     newScalars->SetNumberOfComponents(1);
     newScalars->SetName(inScalars->GetName());
   }
   if (this->ComputeNormals)
   {
-    newNormals = vtkFloatArray::New();
+    newNormals = vtkSmartPointer<vtkFloatArray>::New();
     newNormals->SetNumberOfComponents(3);
     newNormals->SetName("Normals");
   }
   if (this->ComputeGradients)
   {
-    newGradients = vtkFloatArray::New();
+    newGradients = vtkSmartPointer<vtkFloatArray>::New();
     newGradients->SetNumberOfComponents(3);
     newGradients->SetName("Gradients");
   }
@@ -1426,30 +1682,24 @@ int vtkFlyingEdges3D::RequestData(
   // Update ourselves.  Because we don't know up front how many lines
   // we've created, take care to reclaim memory.
   output->SetPoints(newPts);
-  newPts->Delete();
-
   output->SetPolys(newTris);
-  newTris->Delete();
 
   if (newScalars)
   {
     int idx = output->GetPointData()->AddArray(newScalars);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::SCALARS);
-    newScalars->Delete();
   }
 
   if (newNormals)
   {
     int idx = output->GetPointData()->AddArray(newNormals);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::NORMALS);
-    newNormals->Delete();
   }
 
   if (newGradients)
   {
     int idx = output->GetPointData()->AddArray(newGradients);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::VECTORS);
-    newGradients->Delete();
   }
 
   // Transform output if image orientation is not axis aligned
@@ -1458,14 +1708,14 @@ int vtkFlyingEdges3D::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkFlyingEdges3D::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkImageData");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlyingEdges3D::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -1478,3 +1728,4 @@ void vtkFlyingEdges3D::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Interpolate Attributes: " << (this->InterpolateAttributes ? "On\n" : "Off\n");
   os << indent << "ArrayComponent: " << this->ArrayComponent << endl;
 }
+VTK_ABI_NAMESPACE_END
