@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkGlyph3D.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkGlyph3D
  * @brief   copy oriented and scaled glyph geometry to every input point
@@ -95,11 +83,13 @@
 #define VTK_USE_VECTOR 0
 #define VTK_USE_NORMAL 1
 #define VTK_VECTOR_ROTATION_OFF 2
+#define VTK_FOLLOW_CAMERA_DIRECTION 3
 
 #define VTK_INDEXING_OFF 0
 #define VTK_INDEXING_BY_SCALAR 1
 #define VTK_INDEXING_BY_VECTOR 2
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkTransform;
 
 class VTKFILTERSCORE_EXPORT vtkGlyph3D : public vtkPolyDataAlgorithm
@@ -132,7 +122,7 @@ public:
    */
   void SetSourceData(int id, vtkPolyData* pd);
 
-  //@{
+  ///@{
   /**
    * Specify a source object at a specified table location. New style.
    * Source connection is stored in port 1. This method is equivalent
@@ -143,23 +133,23 @@ public:
   {
     this->SetSourceConnection(0, algOutput);
   }
-  //@}
+  ///@}
 
   /**
    * Get a pointer to a source object at a specified table location.
    */
   vtkPolyData* GetSource(int id = 0);
 
-  //@{
+  ///@{
   /**
    * Turn on/off scaling of source geometry.
    */
   vtkSetMacro(Scaling, vtkTypeBool);
   vtkBooleanMacro(Scaling, vtkTypeBool);
   vtkGetMacro(Scaling, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Either scale by scalar or by vector/normal magnitude.
    */
@@ -173,9 +163,9 @@ public:
   }
   void SetScaleModeToDataScalingOff() { this->SetScaleMode(VTK_DATA_SCALING_OFF); }
   const char* GetScaleModeAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Either color by scale, scalar or by vector/normal magnitude.
    */
@@ -185,34 +175,34 @@ public:
   void SetColorModeToColorByScalar() { this->SetColorMode(VTK_COLOR_BY_SCALAR); }
   void SetColorModeToColorByVector() { this->SetColorMode(VTK_COLOR_BY_VECTOR); }
   const char* GetColorModeAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify scale factor to scale object by.
    */
   vtkSetMacro(ScaleFactor, double);
   vtkGetMacro(ScaleFactor, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify range to map scalar values into.
    */
   vtkSetVector2Macro(Range, double);
   vtkGetVectorMacro(Range, double, 2);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off orienting of input geometry along vector/normal.
    */
   vtkSetMacro(Orient, vtkTypeBool);
   vtkBooleanMacro(Orient, vtkTypeBool);
   vtkGetMacro(Orient, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off clamping of "scalar" values to range. (Scalar value may be
    * vector magnitude if ScaleByVector() is enabled.)
@@ -220,9 +210,9 @@ public:
   vtkSetMacro(Clamping, vtkTypeBool);
   vtkBooleanMacro(Clamping, vtkTypeBool);
   vtkGetMacro(Clamping, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify whether to use vector or normal to perform vector operations.
    */
@@ -231,10 +221,28 @@ public:
   void SetVectorModeToUseVector() { this->SetVectorMode(VTK_USE_VECTOR); }
   void SetVectorModeToUseNormal() { this->SetVectorMode(VTK_USE_NORMAL); }
   void SetVectorModeToVectorRotationOff() { this->SetVectorMode(VTK_VECTOR_ROTATION_OFF); }
+  void SetVectorModeToFollowCameraDirection() { this->SetVectorMode(VTK_FOLLOW_CAMERA_DIRECTION); };
   const char* GetVectorModeAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Set/Get point position glyphs will face towards. Used if vector mode is
+   * VTK_FOLLOW_CAMERA_DIRECTION.
+   */
+  vtkSetVectorMacro(FollowedCameraPosition, double, 3);
+  vtkGetVectorMacro(FollowedCameraPosition, double, 3);
+  ///@}
+
+  ///@{
+  /**
+   * Set/Get glyphs up direction. Used if vector mode is VTK_FOLLOW_CAMERA_DIRECTION.
+   */
+  vtkSetVectorMacro(FollowedCameraViewUp, double, 3);
+  vtkGetVectorMacro(FollowedCameraViewUp, double, 3);
+  ///@}
+
+  ///@{
   /**
    * Index into table of sources by scalar, by vector/normal magnitude, or
    * no indexing. If indexing is turned off, then the first source glyph in
@@ -248,9 +256,9 @@ public:
   void SetIndexModeToVector() { this->SetIndexMode(VTK_INDEXING_BY_VECTOR); }
   void SetIndexModeToOff() { this->SetIndexMode(VTK_INDEXING_OFF); }
   const char* GetIndexModeAsString();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable the generation of point ids as part of the output. The
    * point ids are the id of the input generating point. The point ids are
@@ -260,18 +268,18 @@ public:
   vtkSetMacro(GeneratePointIds, vtkTypeBool);
   vtkGetMacro(GeneratePointIds, vtkTypeBool);
   vtkBooleanMacro(GeneratePointIds, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the name of the PointIds array if generated. By default the Ids
    * are named "InputPointIds", but this can be changed with this function.
    */
   vtkSetStringMacro(PointIdsName);
   vtkGetStringMacro(PointIdsName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Enable/disable the generation of cell data as part of the output.
    * The cell data at each cell will match the point data of the input
@@ -280,7 +288,7 @@ public:
   vtkSetMacro(FillCellData, vtkTypeBool);
   vtkGetMacro(FillCellData, vtkTypeBool);
   vtkBooleanMacro(FillCellData, vtkTypeBool);
-  //@}
+  ///@}
 
   /**
    * This can be overwritten by subclass to return 0 when a point is
@@ -288,7 +296,7 @@ public:
    */
   virtual int IsPointVisible(vtkDataSet*, vtkIdType) { return 1; }
 
-  //@{
+  ///@{
   /**
    * When set, this is use to transform the source polydata before using it to
    * generate the glyph. This is useful if one wanted to reorient the source,
@@ -296,14 +304,14 @@ public:
    */
   void SetSourceTransform(vtkTransform*);
   vtkGetObjectMacro(SourceTransform, vtkTransform);
-  //@}
+  ///@}
 
   /**
    * Overridden to include SourceTransform's MTime.
    */
   vtkMTimeType GetMTime() override;
 
-  //@{
+  ///@{
   /**
    * Set/get the desired precision for the output types. See the documentation
    * for the vtkAlgorithm::DesiredOutputPrecision enum for an explanation of
@@ -311,7 +319,7 @@ public:
    */
   vtkSetMacro(OutputPointsPrecision, int);
   vtkGetMacro(OutputPointsPrecision, int);
-  //@}
+  ///@}
 
 protected:
   vtkGlyph3D();
@@ -323,7 +331,7 @@ protected:
 
   vtkPolyData* GetSource(int idx, vtkInformationVector* sourceInfo);
 
-  //@{
+  ///@{
   /**
    * Method called in RequestData() to do the actual data processing. This will
    * glyph the \c input, filling up the \c output based on the filter
@@ -332,20 +340,23 @@ protected:
   virtual bool Execute(vtkDataSet* input, vtkInformationVector* sourceVector, vtkPolyData* output);
   virtual bool Execute(vtkDataSet* input, vtkInformationVector* sourceVector, vtkPolyData* output,
     vtkDataArray* inSScalars, vtkDataArray* inVectors);
-  //@}
+  ///@}
 
-  vtkPolyData** Source;         // Geometry to copy to each point
-  vtkTypeBool Scaling;          // Determine whether scaling of geometry is performed
-  int ScaleMode;                // Scale by scalar value or vector magnitude
-  int ColorMode;                // new scalars based on scale, scalar or vector
-  double ScaleFactor;           // Scale factor to use to scale geometry
-  double Range[2];              // Range to use to perform scalar scaling
-  int Orient;                   // boolean controls whether to "orient" data
-  int VectorMode;               // Orient/scale via normal or via vector data
-  vtkTypeBool Clamping;         // whether to clamp scale factor
-  int IndexMode;                // what to use to index into glyph table
-  vtkTypeBool GeneratePointIds; // produce input points ids for each output point
-  vtkTypeBool FillCellData;     // whether to fill output cell data
+  vtkPolyData** Source; // Geometry to copy to each point
+  vtkTypeBool Scaling;  // Determine whether scaling of geometry is performed
+  int ScaleMode;        // Scale by scalar value or vector magnitude
+  int ColorMode;        // new scalars based on scale, scalar or vector
+  double ScaleFactor;   // Scale factor to use to scale geometry
+  double Range[2];      // Range to use to perform scalar scaling
+  int Orient;           // boolean controls whether to "orient" data
+  int VectorMode;       // Orient/scale via normal or via vector data
+  double
+    FollowedCameraPosition[3]; // glyphs face towards this point in VTK_FOLLOW_CAMERA_DIRECTION mode
+  double FollowedCameraViewUp[3]; // glyph up direction in VTK_FOLLOW_CAMERA_DIRECTION mode
+  vtkTypeBool Clamping;           // whether to clamp scale factor
+  int IndexMode;                  // what to use to index into glyph table
+  vtkTypeBool GeneratePointIds;   // produce input points ids for each output point
+  vtkTypeBool FillCellData;       // whether to fill output cell data
   char* PointIdsName;
   vtkTransform* SourceTransform;
   int OutputPointsPrecision;
@@ -355,11 +366,10 @@ private:
   void operator=(const vtkGlyph3D&) = delete;
 };
 
-//@{
 /**
  * Return the method of scaling as a descriptive character string.
  */
-inline const char* vtkGlyph3D::GetScaleModeAsString(void)
+inline const char* vtkGlyph3D::GetScaleModeAsString()
 {
   if (this->ScaleMode == VTK_SCALE_BY_SCALAR)
   {
@@ -374,13 +384,11 @@ inline const char* vtkGlyph3D::GetScaleModeAsString(void)
     return "DataScalingOff";
   }
 }
-//@}
 
-//@{
 /**
  * Return the method of coloring as a descriptive character string.
  */
-inline const char* vtkGlyph3D::GetColorModeAsString(void)
+inline const char* vtkGlyph3D::GetColorModeAsString()
 {
   if (this->ColorMode == VTK_COLOR_BY_SCALAR)
   {
@@ -395,13 +403,11 @@ inline const char* vtkGlyph3D::GetColorModeAsString(void)
     return "ColorByScale";
   }
 }
-//@}
 
-//@{
 /**
  * Return the vector mode as a character string.
  */
-inline const char* vtkGlyph3D::GetVectorModeAsString(void)
+inline const char* vtkGlyph3D::GetVectorModeAsString()
 {
   if (this->VectorMode == VTK_USE_VECTOR)
   {
@@ -411,18 +417,20 @@ inline const char* vtkGlyph3D::GetVectorModeAsString(void)
   {
     return "UseNormal";
   }
+  else if (this->VectorMode == VTK_FOLLOW_CAMERA_DIRECTION)
+  {
+    return "FollowCameraDirection";
+  }
   else
   {
     return "VectorRotationOff";
   }
 }
-//@}
 
-//@{
 /**
  * Return the index mode as a character string.
  */
-inline const char* vtkGlyph3D::GetIndexModeAsString(void)
+inline const char* vtkGlyph3D::GetIndexModeAsString()
 {
   if (this->IndexMode == VTK_INDEXING_OFF)
   {
@@ -437,6 +445,6 @@ inline const char* vtkGlyph3D::GetIndexModeAsString(void)
     return "IndexingByVector";
   }
 }
-//@}
 
+VTK_ABI_NAMESPACE_END
 #endif
