@@ -1,22 +1,9 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImplicitPolyDataDistance.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkImplicitPolyDataDistance.h"
 
 #include "vtkCellData.h"
 #include "vtkCellLocator.h"
-#include "vtkGenericCell.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 #include "vtkPolyData.h"
@@ -24,9 +11,10 @@
 #include "vtkSmartPointer.h"
 #include "vtkTriangleFilter.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImplicitPolyDataDistance);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImplicitPolyDataDistance::vtkImplicitPolyDataDistance()
 {
   this->NoClosestPoint[0] = 0.0;
@@ -44,7 +32,7 @@ vtkImplicitPolyDataDistance::vtkImplicitPolyDataDistance()
   this->Tolerance = 1e-12;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitPolyDataDistance::SetInput(vtkPolyData* input)
 {
   if (this->Input != input)
@@ -52,7 +40,7 @@ void vtkImplicitPolyDataDistance::SetInput(vtkPolyData* input)
     // Use a vtkTriangleFilter on the polydata input.
     // This is done to filter out lines and vertices to leave only
     // polygons which are required by this algorithm for cell normals.
-    vtkSmartPointer<vtkTriangleFilter> triangleFilter = vtkSmartPointer<vtkTriangleFilter>::New();
+    vtkNew<vtkTriangleFilter> triangleFilter;
     triangleFilter->PassVertsOff();
     triangleFilter->PassLinesOff();
 
@@ -74,7 +62,7 @@ void vtkImplicitPolyDataDistance::SetInput(vtkPolyData* input)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMTimeType vtkImplicitPolyDataDistance::GetMTime()
 {
   vtkMTimeType mTime = this->vtkImplicitFunction::GetMTime();
@@ -89,7 +77,7 @@ vtkMTimeType vtkImplicitPolyDataDistance::GetMTime()
   return mTime;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImplicitPolyDataDistance::~vtkImplicitPolyDataDistance()
 {
   if (this->Locator)
@@ -99,7 +87,7 @@ vtkImplicitPolyDataDistance::~vtkImplicitPolyDataDistance()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitPolyDataDistance::CreateDefaultLocator()
 {
   if (this->Locator == nullptr)
@@ -108,7 +96,7 @@ void vtkImplicitPolyDataDistance::CreateDefaultLocator()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkImplicitPolyDataDistance::EvaluateFunction(double x[3])
 {
   double g[3];
@@ -117,7 +105,7 @@ double vtkImplicitPolyDataDistance::EvaluateFunction(double x[3])
     x, g, p); // get distance value returned, normal and closest point not used
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkImplicitPolyDataDistance::EvaluateFunctionAndGetClosestPoint(
   double x[3], double closestPoint[3])
 {
@@ -126,7 +114,7 @@ double vtkImplicitPolyDataDistance::EvaluateFunctionAndGetClosestPoint(
                                                    // vtkPolyData stored in p (normal not used).
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitPolyDataDistance::EvaluateGradient(double x[3], double g[3])
 {
   double p[3];
@@ -134,7 +122,7 @@ void vtkImplicitPolyDataDistance::EvaluateGradient(double x[3], double g[3])
     x, g, p); // get normal, returned distance value not used and closest point not used
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], double closestPoint[3])
 {
   // Set defaults
@@ -169,13 +157,13 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
   }
 
   // Get point id of closest point in data set.
-  vtkSmartPointer<vtkGenericCell> cell = vtkSmartPointer<vtkGenericCell>::New();
+  auto cell = this->TLCell.Local();
   this->Locator->FindClosestPoint(x, p, cell, cellId, subId, vlen2);
 
   if (cellId != -1) // point located
   {
     // dist = | point - x |
-    ret = sqrt(vlen2);
+    ret = std::sqrt(vlen2);
     // grad = (point - x) / dist
     for (int i = 0; i < 3; i++)
     {
@@ -185,11 +173,11 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
     double dist2, weights[3], pcoords[3], awnorm[3] = { 0, 0, 0 };
     cell->EvaluatePosition(p, closestPoint, subId, pcoords, dist2, weights);
 
-    vtkIdList* idList = vtkIdList::New();
+    auto idList = this->TLCellIds.Local();
     int count = 0;
     for (int i = 0; i < 3; i++)
     {
-      count += (fabs(weights[i]) < this->Tolerance ? 1 : 0);
+      count += (std::abs(weights[i]) < this->Tolerance ? 1 : 0);
     }
     // Face case - weights contains no 0s
     if (count == 0)
@@ -211,7 +199,7 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
       int a = -1, b = -1;
       for (int edge = 0; edge < 3; edge++)
       {
-        if (fabs(weights[edge]) < this->Tolerance)
+        if (std::abs(weights[edge]) < this->Tolerance)
         {
           a = cell->PointIds->GetId((edge + 1) % 3);
           b = cell->PointIds->GetId((edge + 2) % 3);
@@ -238,7 +226,8 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
         }
         else
         {
-          vtkPolygon::ComputeNormal(this->Input->GetCell(idList->GetId(i))->GetPoints(), norm);
+          this->Input->GetCell(idList->GetId(i), cell);
+          vtkPolygon::ComputeNormal(cell->GetPoints(), norm);
         }
         awnorm[0] += norm[0];
         awnorm[1] += norm[1];
@@ -256,7 +245,7 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
       int a = -1;
       for (int i = 0; i < 3; i++)
       {
-        if (fabs(weights[i]) > this->Tolerance)
+        if (std::abs(weights[i]) > this->Tolerance)
         {
           a = cell->PointIds->GetId(i);
         }
@@ -273,25 +262,26 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
       for (int i = 0; i < idList->GetNumberOfIds(); i++)
       {
         double norm[3];
+        this->Input->GetCell(idList->GetId(i), cell);
         if (cnorms)
         {
           cnorms->GetTuple(idList->GetId(i), norm);
         }
         else
         {
-          vtkPolygon::ComputeNormal(this->Input->GetCell(idList->GetId(i))->GetPoints(), norm);
+          vtkPolygon::ComputeNormal(cell->GetPoints(), norm);
         }
 
         // Compute angle at point a
-        int b = this->Input->GetCell(idList->GetId(i))->GetPointId(0);
-        int c = this->Input->GetCell(idList->GetId(i))->GetPointId(1);
+        int b = cell->GetPointId(0);
+        int c = cell->GetPointId(1);
         if (a == b)
         {
-          b = this->Input->GetCell(idList->GetId(i))->GetPointId(2);
+          b = cell->GetPointId(2);
         }
         else if (a == c)
         {
-          c = this->Input->GetCell(idList->GetId(i))->GetPointId(2);
+          c = cell->GetPointId(2);
         }
         double pa[3], pb[3], pc[3];
         this->Input->GetPoint(a, pa);
@@ -304,14 +294,13 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
         }
         vtkMath::Normalize(pb);
         vtkMath::Normalize(pc);
-        double alpha = acos(vtkMath::Dot(pb, pc));
+        double alpha = std::acos(vtkMath::Dot(pb, pc));
         awnorm[0] += alpha * norm[0];
         awnorm[1] += alpha * norm[1];
         awnorm[2] += alpha * norm[2];
       }
       vtkMath::Normalize(awnorm);
     }
-    idList->Delete();
 
     // sign(dist) = dot(grad, cell normal)
     if (ret == 0)
@@ -335,7 +324,7 @@ double vtkImplicitPolyDataDistance::SharedEvaluate(double x[3], double g[3], dou
   return ret;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitPolyDataDistance::PrintSelf(ostream& os, vtkIndent indent)
 {
   vtkImplicitFunction::PrintSelf(os, indent);
@@ -354,3 +343,4 @@ void vtkImplicitPolyDataDistance::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Input : (none)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
