@@ -1,19 +1,9 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkQuadricClustering.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkQuadricClustering.h"
 
+#include <cstdint>
+
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkExecutive.h"
@@ -29,21 +19,21 @@
 
 #include <unordered_set> // keep track of inserted triangles
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkQuadricClustering);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // PIMPLd STL set for keeping track of inserted cells
-struct vtkQuadricClusteringIdTypeHash
+struct vtkQuadricClusteringIdxHash
 {
-  size_t operator()(vtkIdType val) const { return static_cast<size_t>(val); }
+  size_t operator()(int64_t val) const { return static_cast<size_t>(val); }
 };
-class vtkQuadricClusteringCellSet
-  : public std::unordered_set<vtkIdType, vtkQuadricClusteringIdTypeHash>
+class vtkQuadricClusteringCellSet : public std::unordered_set<int64_t, vtkQuadricClusteringIdxHash>
 {
 };
 typedef vtkQuadricClusteringCellSet::iterator vtkQuadricClusteringCellSetIterator;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct with default NumberOfDivisions to 50, DivisionSpacing to 1
 // in all (x,y,z) directions. AutoAdjustNumberOfDivisions is set to ON.
 // ComputeNumberOfDivisions to OFF. UseFeatureEdges and UseFeaturePoints
@@ -88,13 +78,14 @@ vtkQuadricClustering::vtkQuadricClustering()
   this->FeatureEdges = vtkFeatureEdges::New();
   this->FeatureEdges->FeatureEdgesOff();
   this->FeatureEdges->BoundaryEdgesOn();
+  this->FeatureEdges->SetContainerAlgorithm(this);
   this->FeaturePoints = vtkPoints::New();
 
   this->InCellCount = this->OutCellCount = 0;
   this->CopyCellData = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkQuadricClustering::~vtkQuadricClustering()
 {
   this->FeatureEdges->Delete();
@@ -117,7 +108,7 @@ vtkQuadricClustering::~vtkQuadricClustering()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkQuadricClustering::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -158,7 +149,7 @@ int vtkQuadricClustering::RequestData(vtkInformation* vtkNotUsed(request),
   // (To minimize chance of overflow, force math in vtkIdType type,
   // which is sometimes bigger than int, and never smaller.)
   vtkIdType target = input->GetNumberOfPoints();
-  vtkIdType numDiv = static_cast<vtkIdType>(this->NumberOfXDivisions) * this->NumberOfYDivisions *
+  int64_t numDiv = static_cast<int64_t>(this->NumberOfXDivisions) * this->NumberOfYDivisions *
     this->NumberOfZDivisions / 2;
   if (this->AutoAdjustNumberOfDivisions && numDiv > target)
   {
@@ -212,7 +203,7 @@ int vtkQuadricClustering::RequestData(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::StartAppend(double* bounds)
 {
   // If there are duplicate triangles. remove them
@@ -312,7 +303,7 @@ void vtkQuadricClustering::StartAppend(double* bounds)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::Append(vtkPolyData* pd)
 {
   vtkCellArray *inputPolys, *inputStrips, *inputLines, *inputVerts;
@@ -356,7 +347,7 @@ void vtkQuadricClustering::Append(vtkPolyData* pd)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::AddPolygons(
   vtkCellArray* polys, vtkPoints* points, int geometryFlag, vtkPolyData* input, vtkPolyData* output)
 {
@@ -389,6 +380,10 @@ void vtkQuadricClustering::AddPolygons(
     ++this->InCellCount;
     if (curr > cstep)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       this->UpdateProgress(.6 + .2 * curr / total);
       cstep += step;
     }
@@ -396,7 +391,7 @@ void vtkQuadricClustering::AddPolygons(
   } // for all polygons
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::AddStrips(vtkCellArray* strips, vtkPoints* points, int geometryFlag,
   vtkPolyData* input, vtkPolyData* output)
 {
@@ -405,9 +400,14 @@ void vtkQuadricClustering::AddStrips(vtkCellArray* strips, vtkPoints* points, in
   double pts[3][3];
   vtkIdType binIds[3];
   int odd; // Used to flip order of every other triangle in a strip.
+  vtkIdType checkAbortInterval = std::min(strips->GetNumberOfCells() / 10 + 1, (vtkIdType)1000);
 
   for (strips->InitTraversal(); strips->GetNextCell(numPts, ptIds);)
   {
+    if (this->InCellCount % checkAbortInterval == 0 && this->CheckAbort())
+    {
+      break;
+    }
     points->GetPoint(ptIds[0], pts[0]);
     binIds[0] = this->HashPoint(pts[0]);
     points->GetPoint(ptIds[1], pts[1]);
@@ -430,8 +430,8 @@ void vtkQuadricClustering::AddStrips(vtkCellArray* strips, vtkPoints* points, in
   }
 }
 
-//----------------------------------------------------------------------------
-inline void vtkQuadricClustering::InitializeQuadric(double quadric[9])
+//------------------------------------------------------------------------------
+void vtkQuadricClustering::InitializeQuadric(double quadric[9])
 {
   quadric[0] = 0.0;
   quadric[1] = 0.0;
@@ -444,7 +444,7 @@ inline void vtkQuadricClustering::InitializeQuadric(double quadric[9])
   quadric[8] = 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The error function is the volume (squared) of the tetrahedron formed by the
 // triangle and the point.  We ignore constant factors across all coefficients,
 // and the constant coefficient.
@@ -554,9 +554,11 @@ void vtkQuadricClustering::AddTriangle(vtkIdType* binIds, double* pt0, double* p
             }
             break;
         }
-        // TODO: this arithmetic overflows with the TestQuadricLODActor test.
-        vtkIdType idx = binIds[minIdx] + this->NumberOfBins * binIds[midIdx] +
-          this->NumberOfBins * this->NumberOfBins * binIds[maxIdx];
+        int64_t upsizedBinMin = static_cast<int64_t>(binIds[minIdx]);
+        int64_t upsizedBinMid = static_cast<int64_t>(binIds[midIdx]);
+        int64_t upsizedBinMax = static_cast<int64_t>(binIds[maxIdx]);
+        int64_t idx = upsizedBinMin + this->NumberOfBins * upsizedBinMid +
+          this->NumberOfBins * this->NumberOfBins * upsizedBinMax;
         if (this->CellSet->find(idx) == this->CellSet->end())
         {
           this->CellSet->insert(idx);
@@ -581,7 +583,7 @@ void vtkQuadricClustering::AddTriangle(vtkIdType* binIds, double* pt0, double* p
   }       // if this should be inserted
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::AddEdges(
   vtkCellArray* edges, vtkPoints* points, int geometryFlag, vtkPolyData* input, vtkPolyData* output)
 {
@@ -594,8 +596,13 @@ void vtkQuadricClustering::AddEdges(
   // Add the edges to the error function.
   numCells = edges->GetNumberOfCells();
   edges->InitTraversal();
+  vtkIdType checkAbortInterval = std::min(numCells / 10 + 1, (vtkIdType)1000);
   for (vtkIdType i = 0; i < numCells; ++i)
   {
+    if (i % checkAbortInterval == 0 && this->CheckAbort())
+    {
+      break;
+    }
     edges->GetNextCell(numPts, ptIds);
     if (numPts != 0)
     {
@@ -616,7 +623,7 @@ void vtkQuadricClustering::AddEdges(
     ++this->InCellCount;
   }
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The error function is the square of the area of the triangle formed by the
 // edge and the point.  We ignore constants across all terms.
 // If geometryFlag is 1 then the edge is added to the output.  Otherwise,
@@ -660,7 +667,7 @@ void vtkQuadricClustering::AddEdge(vtkIdType* binIds, double* pt0, double* pt1,
   // Compute dot(m, d);
   md = m[0] * d[0] + m[1] * d[1] + m[2] * d[2];
 
-  // We save nine coefficients of the error function cooresponding to:
+  // We save nine coefficients of the error function corresponding to:
   // 0: Px^2
   // 1: PxPy
   // 2: PxPz
@@ -722,7 +729,7 @@ void vtkQuadricClustering::AddEdge(vtkIdType* binIds, double* pt0, double* pt1,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::AddVertices(
   vtkCellArray* verts, vtkPoints* points, int geometryFlag, vtkPolyData* input, vtkPolyData* output)
 {
@@ -742,8 +749,13 @@ void vtkQuadricClustering::AddVertices(
   double curr = 0;
 
   verts->InitTraversal();
+  vtkIdType checkAbortInterval = std::min(numCells / 10 + 1, (vtkIdType)1000);
   for (vtkIdType i = 0; i < numCells; ++i)
   {
+    if (i % checkAbortInterval == 0 && this->CheckAbort())
+    {
+      break;
+    }
     verts->GetNextCell(numPts, ptIds);
     // Can there be poly vertices?
     for (vtkIdType j = 0; j < numPts; ++j)
@@ -763,7 +775,7 @@ void vtkQuadricClustering::AddVertices(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The error function is the length (point to vert) squared.
 // We ignore constants across all terms.
 // If geomertyFlag is 1 then the vert is added to the output.  Otherwise,
@@ -775,7 +787,7 @@ void vtkQuadricClustering::AddVertex(
 
   // Compute quadric for the vertex.
 
-  // We save nine coefficients of the error function cooresponding to:
+  // We save nine coefficients of the error function corresponding to:
   // 0: Px^2
   // 1: PxPy
   // 2: PxPz
@@ -827,7 +839,7 @@ void vtkQuadricClustering::AddVertex(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::AddQuadric(vtkIdType binId, double quadric[9])
 {
   double* q = this->QuadricArray[binId].Quadric;
@@ -838,7 +850,7 @@ void vtkQuadricClustering::AddQuadric(vtkIdType binId, double quadric[9])
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkQuadricClustering::HashPoint(double point[3])
 {
   vtkIdType xBinCoord = static_cast<vtkIdType>((point[0] - this->Bounds[0]) * this->XBinStep);
@@ -878,7 +890,7 @@ vtkIdType vtkQuadricClustering::HashPoint(double point[3])
   return binId;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::EndAppend()
 {
   vtkInformation* inInfo = this->GetExecutive()->GetInputInformation(0, 0);
@@ -891,7 +903,7 @@ void vtkQuadricClustering::EndAppend()
   vtkPolyData* output = vtkPolyData::SafeDownCast(outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   vtkIdType numBuckets;
-  int abortExecute = 0;
+  bool abortExecute = false;
   vtkPoints* outputPoints;
   double newPt[3];
   numBuckets = this->NumberOfDivisions[0] * this->NumberOfDivisions[1] * this->NumberOfDivisions[2];
@@ -925,7 +937,7 @@ void vtkQuadricClustering::EndAppend()
       cstep = 0;
       vtkDebugMacro(<< "Finding point in bin #" << i);
       this->UpdateProgress(0.8 + 0.2 * i / numBuckets);
-      abortExecute = this->GetAbortExecute();
+      abortExecute = this->CheckAbort();
     }
     ++cstep;
 
@@ -965,7 +977,7 @@ void vtkQuadricClustering::EndAppend()
   this->QuadricArray = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::ComputeRepresentativePoint(
   double quadric[9], vtkIdType binId, double point[3])
 {
@@ -1076,7 +1088,7 @@ void vtkQuadricClustering::ComputeRepresentativePoint(
   point[2] = cellCenter[2] + tempVector[2];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::SetNumberOfDivisions(int div0, int div1, int div2)
 {
   this->SetNumberOfXDivisions(div0);
@@ -1084,7 +1096,7 @@ void vtkQuadricClustering::SetNumberOfDivisions(int div0, int div1, int div2)
   this->SetNumberOfZDivisions(div2);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::SetNumberOfXDivisions(int num)
 {
   if (this->NumberOfXDivisions == num && this->ComputeNumberOfDivisions == 0)
@@ -1101,7 +1113,7 @@ void vtkQuadricClustering::SetNumberOfXDivisions(int num)
   this->ComputeNumberOfDivisions = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::SetNumberOfYDivisions(int num)
 {
   if (this->NumberOfYDivisions == num && this->ComputeNumberOfDivisions == 0)
@@ -1118,7 +1130,7 @@ void vtkQuadricClustering::SetNumberOfYDivisions(int num)
   this->ComputeNumberOfDivisions = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::SetNumberOfZDivisions(int num)
 {
   if (this->NumberOfZDivisions == num && this->ComputeNumberOfDivisions == 0)
@@ -1135,7 +1147,7 @@ void vtkQuadricClustering::SetNumberOfZDivisions(int num)
   this->ComputeNumberOfDivisions = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int* vtkQuadricClustering::GetNumberOfDivisions()
 {
   static int divs[3];
@@ -1143,7 +1155,7 @@ int* vtkQuadricClustering::GetNumberOfDivisions()
   return divs;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::GetNumberOfDivisions(int divs[3])
 {
   divs[0] = this->NumberOfXDivisions;
@@ -1151,7 +1163,7 @@ void vtkQuadricClustering::GetNumberOfDivisions(int divs[3])
   divs[2] = this->NumberOfZDivisions;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::SetDivisionOrigin(double x, double y, double z)
 {
   if (this->ComputeNumberOfDivisions && this->DivisionOrigin[0] == x &&
@@ -1166,7 +1178,7 @@ void vtkQuadricClustering::SetDivisionOrigin(double x, double y, double z)
   this->ComputeNumberOfDivisions = 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::SetDivisionSpacing(double x, double y, double z)
 {
   if (this->ComputeNumberOfDivisions && this->DivisionSpacing[0] == x &&
@@ -1196,7 +1208,7 @@ void vtkQuadricClustering::SetDivisionSpacing(double x, double y, double z)
   this->ComputeNumberOfDivisions = 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::EndAppendUsingPoints(vtkPolyData* input, vtkPolyData* output)
 {
   vtkIdType outPtId;
@@ -1294,7 +1306,7 @@ void vtkQuadricClustering::EndAppendUsingPoints(vtkPolyData* input, vtkPolyData*
   delete[] minError;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This is not a perfect implementation, because it does not determine
 // which vertex cell is the best for a bin.  The first detected is used.
 void vtkQuadricClustering::EndAppendVertexGeometry(vtkPolyData* input, vtkPolyData* output)
@@ -1328,7 +1340,7 @@ void vtkQuadricClustering::EndAppendVertexGeometry(vtkPolyData* input, vtkPolyDa
       outPtId = this->QuadricArray[binId].VertexId;
       if (outPtId >= 0)
       {
-        // Do not use this point.  Destroy infomration in Quadric array.
+        // Do not use this point.  Destroy information in Quadric array.
         this->QuadricArray[binId].VertexId = -1;
         tmp[tmpIdx] = outPtId;
         ++tmpIdx;
@@ -1351,7 +1363,7 @@ void vtkQuadricClustering::EndAppendVertexGeometry(vtkPolyData* input, vtkPolyDa
   outVerts->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method is called after the execution, but before the vertex array
 // is deleted. It changes some points to be based on the boundary edges.
 void vtkQuadricClustering::AppendFeatureQuadrics(vtkPolyData* pd, vtkPolyData* output)
@@ -1481,7 +1493,7 @@ void vtkQuadricClustering::FindFeaturePoints(
   delete[] pointTable;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkQuadricClustering::FillInputPortInformation(int port, vtkInformation* info)
 {
   int retval = this->Superclass::FillInputPortInformation(port, info);
@@ -1489,7 +1501,7 @@ int vtkQuadricClustering::FillInputPortInformation(int port, vtkInformation* inf
   return retval;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkQuadricClustering::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -1529,3 +1541,4 @@ void vtkQuadricClustering::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Prevent Duplicate Cells : " << (this->PreventDuplicateCells ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
