@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkSmoothPolyDataFilter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSmoothPolyDataFilter.h"
 
 #include "vtkCellArray.h"
@@ -29,12 +17,14 @@
 #include "vtkTriangleFilter.h"
 
 #include <limits>
+#include <memory>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSmoothPolyDataFilter);
 
 // The following code defines a helper class for performing mesh smoothing
 // across the surface of another mesh.
-typedef struct _vtkSmoothPoint
+typedef struct
 {
   vtkIdType cellId; // cell
   int subId;        // cell sub id
@@ -69,6 +59,7 @@ public:
   vtkIdType Extend;      // grow array by this amount
 };
 
+//------------------------------------------------------------------------------
 vtkSmoothPoints::vtkSmoothPoints()
 {
   this->MaxId = -1;
@@ -77,6 +68,7 @@ vtkSmoothPoints::vtkSmoothPoints()
   this->Extend = 5000;
 }
 
+//------------------------------------------------------------------------------
 vtkSmoothPoint* vtkSmoothPoints::Resize(vtkIdType sz)
 {
   vtkSmoothPoint* newArray;
@@ -110,6 +102,7 @@ vtkSmoothPoint* vtkSmoothPoints::Resize(vtkIdType sz)
 // angle 45 degrees; edge angle 15 degrees; and boundary smoothing turned
 // on. Error scalars and vectors are not generated (by default). The
 // convergence criterion is 0.0 of the bounding box diagonal.
+//------------------------------------------------------------------------------
 vtkSmoothPolyDataFilter::vtkSmoothPolyDataFilter()
 {
   this->Convergence = 0.0; // goes to number of specified iterations
@@ -133,11 +126,16 @@ vtkSmoothPolyDataFilter::vtkSmoothPolyDataFilter()
   this->SetNumberOfInputPorts(2);
 }
 
+//------------------------------------------------------------------------------
+vtkSmoothPolyDataFilter::~vtkSmoothPolyDataFilter() = default;
+
+//------------------------------------------------------------------------------
 void vtkSmoothPolyDataFilter::SetSourceData(vtkPolyData* source)
 {
   this->SetInputData(1, source);
 }
 
+//------------------------------------------------------------------------------
 vtkPolyData* vtkSmoothPolyDataFilter::GetSource()
 {
   if (this->GetNumberOfInputConnections(1) < 1)
@@ -193,7 +191,7 @@ void vtkSPDF_MovePoints(vtkSPDF_InternalParams<T>& params)
     if (iterationNumber && !(iterationNumber % 5))
     {
       params.spdf->UpdateProgress(0.5 + 0.5 * iterationNumber / params.numberOfIterations);
-      if (params.spdf->GetAbortExecute())
+      if (params.spdf->CheckAbort())
       {
         break;
       }
@@ -211,7 +209,7 @@ void vtkSPDF_MovePoints(vtkSPDF_InternalParams<T>& params)
     // position of its connected neighbors using the relaxation factor.
     for (vtkIdType i = 0; i < params.numPts; ++i)
     {
-      if (vertsPtr->type != VTK_FIXED_VERTEX && vertsPtr->edges != nullptr &&
+      if (vertsPtr->type != VTK_FIXED_VERTEX && vertsPtr->edges &&
         (npts = vertsPtr->edges->GetNumberOfIds()) > 0)
       {
         deltaX[0] = deltaX[1] = deltaX[2] = 0.0;
@@ -278,6 +276,7 @@ void vtkSPDF_MovePoints(vtkSPDF_InternalParams<T>& params)
 
 } // namespace
 
+//------------------------------------------------------------------------------
 int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -304,15 +303,11 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   double x1[3], x2[3], x3[3], l1[3], l2[3];
   double CosFeatureAngle; // Cosine of angle between adjacent polys
   double CosEdgeAngle;    // Cosine of angle between adjacent edges
-  double closestPt[3], dist2, *w = nullptr;
+  double closestPt[3], dist2;
   vtkIdType numSimple = 0, numBEdges = 0, numFixed = 0, numFEdges = 0;
-  vtkPolyData *inMesh, *Mesh;
+  vtkPolyData* Mesh;
   vtkPoints* inPts;
-  vtkTriangleFilter* toTris = nullptr;
   vtkCellArray *inVerts, *inLines, *inPolys, *inStrips;
-  vtkPoints* newPts;
-  vtkMeshVertexPtr Verts;
-  vtkCellLocator* cellLocator = nullptr;
 
   // Check input
   //
@@ -353,7 +348,10 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   // using a subset of the attached vertices.
   //
   vtkDebugMacro(<< "Analyzing topology...");
-  Verts = new vtkMeshVertex[numPts];
+
+  // Smart pointer to storage; use a raw pointer for operator[] array access.
+  std::unique_ptr<vtkMeshVertex> uVerts = std::unique_ptr<vtkMeshVertex>(new vtkMeshVertex[numPts]);
+  vtkMeshVertex* Verts = uVerts.get();
 
   inPts = input->GetPoints();
   conv = this->Convergence * input->GetLength();
@@ -367,10 +365,17 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
     }
   }
   this->UpdateProgress(0.10);
+  vtkIdType checkAbortInterval = std::min(input->GetNumberOfLines() / 10 + 1, (vtkIdType)1000);
+  vtkIdType progressCounter = 0;
 
   // now check lines. Only manifold lines can be smoothed------------
   for (inLines = input->GetLines(), inLines->InitTraversal(); inLines->GetNextCell(npts, pts);)
   {
+    if (progressCounter % checkAbortInterval == 0 && this->CheckAbort())
+    {
+      break;
+    }
+    progressCounter++;
     for (j = 0; j < npts; j++)
     {
       if (Verts[pts[j]].type == VTK_SIMPLE_VERTEX)
@@ -420,20 +425,20 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
     vtkIdType numNeiPts;
     const vtkIdType* neiPts;
     double normal[3], neiNormal[3];
-    vtkIdList* neighbors;
 
-    neighbors = vtkIdList::New();
+    vtkNew<vtkIdList> neighbors;
     neighbors->Allocate(VTK_CELL_SIZE);
 
-    inMesh = vtkPolyData::New();
+    vtkNew<vtkPolyData> inMesh;
     inMesh->SetPoints(inPts);
     inMesh->SetPolys(inPolys);
     Mesh = inMesh;
 
+    vtkSmartPointer<vtkTriangleFilter> toTris;
     if ((numStrips = inStrips->GetNumberOfCells()) > 0)
     { // convert data to triangles
       inMesh->SetStrips(inStrips);
-      toTris = vtkTriangleFilter::New();
+      toTris.TakeReference(vtkTriangleFilter::New());
       toTris->SetInputData(inMesh);
       toTris->Update();
       Mesh = toTris->GetOutput();
@@ -443,8 +448,14 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
     polys = Mesh->GetPolys();
     this->UpdateProgress(0.375);
 
+    checkAbortInterval = std::min(polys->GetNumberOfCells() / 10 + 1, (vtkIdType)1000);
+
     for (cellId = 0, polys->InitTraversal(); polys->GetNextCell(npts, pts); cellId++)
     {
+      if (cellId % checkAbortInterval == 0 && this->CheckAbort())
+      {
+        break;
+      }
       for (i = 0; i < npts; i++)
       {
         p1 = pts[i];
@@ -540,21 +551,19 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
         }
       }
     }
-
-    inMesh->Delete();
-    if (toTris)
-    {
-      toTris->Delete();
-    }
-
-    neighbors->Delete();
   } // if strips or polys
 
   this->UpdateProgress(0.50);
 
+  checkAbortInterval = std::min(numPts / 10 + 1, (vtkIdType)1000);
+
   // post-process edge vertices to make sure we can smooth them
   for (i = 0; i < numPts; i++)
   {
+    if (i % checkAbortInterval == 0 && this->CheckAbort())
+    {
+      break;
+    }
     if (Verts[i].type == VTK_SIMPLE_VERTEX)
     {
       numSimple++;
@@ -615,12 +624,16 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkDebugMacro(<< "Found\n\t" << numSimple << " simple vertices\n\t" << numFEdges
                 << " feature edge vertices\n\t" << numBEdges << " boundary edge vertices\n\t"
                 << numFixed << " fixed vertices\n\t");
+  (void)numSimple;
+  (void)numBEdges;
+  (void)numFixed;
+  (void)numFEdges;
 
   vtkDebugMacro(<< "Beginning smoothing iterations...");
 
   // We've setup the topology...now perform Laplacian smoothing
   //
-  newPts = vtkPoints::New();
+  vtkNew<vtkPoints> newPts;
 
   // Set the desired precision for the points in the output.
   if (this->OutputPointsPrecision == vtkAlgorithm::DEFAULT_PRECISION)
@@ -638,15 +651,17 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
 
   newPts->SetNumberOfPoints(numPts);
 
-  // If Source defined, we do constrained smoothing (that is, points are
+  // If a Source is defined, we do constrained smoothing (that is, points are
   // constrained to the surface of the mesh object).
+  std::unique_ptr<double[]> w;
+  vtkSmartPointer<vtkCellLocator> cellLocator;
   if (source)
   {
-    this->SmoothPoints = new vtkSmoothPoints;
+    this->SmoothPoints = std::unique_ptr<vtkSmoothPoints>(new vtkSmoothPoints);
     vtkSmoothPoint* sPtr;
-    cellLocator = vtkCellLocator::New();
-    w = new double[source->GetMaxCellSize()];
-
+    cellLocator.TakeReference(vtkCellLocator::New());
+    auto maxCellSize = source->GetMaxCellSize();
+    w.reset(new double[maxCellSize]);
     cellLocator->SetDataSet(source);
     cellLocator->BuildLocator();
 
@@ -669,7 +684,8 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   if (newPts->GetDataType() == VTK_DOUBLE)
   {
     vtkSPDF_InternalParams<double> params = { this, this->NumberOfIterations, newPts,
-      this->RelaxationFactor, conv, numPts, Verts, source, this->SmoothPoints, w, cellLocator };
+      this->RelaxationFactor, conv, numPts, Verts, source, this->SmoothPoints.get(), w.get(),
+      cellLocator };
 
     vtkSPDF_MovePoints(params);
   }
@@ -677,17 +693,13 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   {
     vtkSPDF_InternalParams<float> params = { this, this->NumberOfIterations, newPts,
       static_cast<float>(this->RelaxationFactor), static_cast<float>(conv), numPts, Verts, source,
-      this->SmoothPoints, w, cellLocator };
+      this->SmoothPoints.get(), w.get(), cellLocator };
 
     vtkSPDF_MovePoints(params);
   }
 
-  if (source)
-  {
-    cellLocator->Delete();
-    delete this->SmoothPoints;
-    delete[] w;
-  }
+  // Release memory if it's been allocated
+  this->SmoothPoints.reset(nullptr);
 
   // Update output. Only point coordinates have changed.
   //
@@ -696,7 +708,7 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
 
   if (this->GenerateErrorScalars)
   {
-    vtkFloatArray* newScalars = vtkFloatArray::New();
+    vtkNew<vtkFloatArray> newScalars;
     newScalars->SetNumberOfTuples(numPts);
     for (i = 0; i < numPts; i++)
     {
@@ -706,12 +718,11 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
     }
     int idx = output->GetPointData()->AddArray(newScalars);
     output->GetPointData()->SetActiveAttribute(idx, vtkDataSetAttributes::SCALARS);
-    newScalars->Delete();
   }
 
   if (this->GenerateErrorVectors)
   {
-    vtkFloatArray* newVectors = vtkFloatArray::New();
+    vtkNew<vtkFloatArray> newVectors;
     newVectors->SetNumberOfComponents(3);
     newVectors->SetNumberOfTuples(numPts);
     for (i = 0; i < numPts; i++)
@@ -725,11 +736,9 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
       newVectors->SetTuple(i, x3);
     }
     output->GetPointData()->SetVectors(newVectors);
-    newVectors->Delete();
   }
 
   output->SetPoints(newPts);
-  newPts->Delete();
 
   output->SetVerts(input->GetVerts());
   output->SetLines(input->GetLines());
@@ -739,17 +748,17 @@ int vtkSmoothPolyDataFilter::RequestData(vtkInformation* vtkNotUsed(request),
   // free up connectivity storage
   for (i = 0; i < numPts; i++)
   {
-    if (Verts[i].edges != nullptr)
+    if (Verts[i].edges)
     {
       Verts[i].edges->Delete();
       Verts[i].edges = nullptr;
     }
   }
-  delete[] Verts;
 
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkSmoothPolyDataFilter::FillInputPortInformation(int port, vtkInformation* info)
 {
   if (!this->Superclass::FillInputPortInformation(port, info))
@@ -764,6 +773,7 @@ int vtkSmoothPolyDataFilter::FillInputPortInformation(int port, vtkInformation*
   return 1;
 }
 
+//------------------------------------------------------------------------------
 void vtkSmoothPolyDataFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -788,3 +798,4 @@ void vtkSmoothPolyDataFilter::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Output Points Precision: " << this->OutputPointsPrecision << "\n";
 }
+VTK_ABI_NAMESPACE_END
