@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkSynchronizedTemplates3D.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSynchronizedTemplates3D.h"
 
 #include "vtkCellArray.h"
@@ -41,9 +29,10 @@
 
 #include <cmath>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkSynchronizedTemplates3D);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Construct object with initial scalar range (0,1) and single contour value
 // of 0.0. The ImageRange are set to extract the first k-plane.
@@ -62,13 +51,13 @@ vtkSynchronizedTemplates3D::vtkSynchronizedTemplates3D()
     0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, vtkDataSetAttributes::SCALARS);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSynchronizedTemplates3D::~vtkSynchronizedTemplates3D()
 {
   this->ContourValues->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Overload standard modified time function. If contour values are modified,
 // then this object is modified as well.
 vtkMTimeType vtkSynchronizedTemplates3D::GetMTime()
@@ -80,7 +69,7 @@ vtkMTimeType vtkSynchronizedTemplates3D::GetMTime()
   return mTime;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static void vtkSynchronizedTemplates3DInitializeOutput(int* ext, vtkImageData* input,
   vtkPolyData* o, vtkFloatArray* scalars, vtkFloatArray* normals, vtkFloatArray* gradients,
   vtkDataArray* inScalars)
@@ -141,7 +130,7 @@ static void vtkSynchronizedTemplates3DInitializeOutput(int* ext, vtkImageData* i
   newPolys->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Calculate the gradient using central difference.
 template <class T>
 void vtkSTComputePointGradient(int i, int j, int k, T* s, int* inExt, vtkIdType xInc,
@@ -210,39 +199,42 @@ void vtkSTComputePointGradient(int i, int j, int k, T* s, int* inExt, vtkIdType
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 #define VTK_CSP3PA(i2, j2, k2, s)                                                                  \
-  if (NeedGradients)                                                                               \
+  do                                                                                               \
   {                                                                                                \
-    if (!g0)                                                                                       \
+    if (NeedGradients)                                                                             \
     {                                                                                              \
-      vtkSTComputePointGradient(i, j, k, s0, inExt, xInc, yInc, zInc, spacing, n0);                \
-      g0 = 1;                                                                                      \
+      if (!g0)                                                                                     \
+      {                                                                                            \
+        vtkSTComputePointGradient(i, j, k, s0, inExt, xInc, yInc, zInc, spacing, n0);              \
+        g0 = 1;                                                                                    \
+      }                                                                                            \
+      vtkSTComputePointGradient(i2, j2, k2, s, inExt, xInc, yInc, zInc, spacing, n1);              \
+      for (jj = 0; jj < 3; jj++)                                                                   \
+      {                                                                                            \
+        n[jj] = n0[jj] + t * (n1[jj] - n0[jj]);                                                    \
+      }                                                                                            \
+      if (ComputeGradients)                                                                        \
+      {                                                                                            \
+        newGradients->InsertNextTuple(n);                                                          \
+      }                                                                                            \
+      if (ComputeNormals)                                                                          \
+      {                                                                                            \
+        vtkMath::Normalize(n);                                                                     \
+        n[0] = -n[0];                                                                              \
+        n[1] = -n[1];                                                                              \
+        n[2] = -n[2];                                                                              \
+        newNormals->InsertNextTuple(n);                                                            \
+      }                                                                                            \
     }                                                                                              \
-    vtkSTComputePointGradient(i2, j2, k2, s, inExt, xInc, yInc, zInc, spacing, n1);                \
-    for (jj = 0; jj < 3; jj++)                                                                     \
+    if (ComputeScalars)                                                                            \
     {                                                                                              \
-      n[jj] = n0[jj] + t * (n1[jj] - n0[jj]);                                                      \
+      newScalars->InsertNextTuple(&value);                                                         \
     }                                                                                              \
-    if (ComputeGradients)                                                                          \
-    {                                                                                              \
-      newGradients->InsertNextTuple(n);                                                            \
-    }                                                                                              \
-    if (ComputeNormals)                                                                            \
-    {                                                                                              \
-      vtkMath::Normalize(n);                                                                       \
-      n[0] = -n[0];                                                                                \
-      n[1] = -n[1];                                                                                \
-      n[2] = -n[2];                                                                                \
-      newNormals->InsertNextTuple(n);                                                              \
-    }                                                                                              \
-  }                                                                                                \
-  if (ComputeScalars)                                                                              \
-  {                                                                                                \
-    newScalars->InsertNextTuple(&value);                                                           \
-  }
+  } while (false)
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 //
 // Contouring filter specialized for images
 //
@@ -266,10 +258,10 @@ void ContourImage(vtkSynchronizedTemplates3D* self, int* exExt, vtkImageData* da
   int i, j, k;
   vtkIdType zstep, yisectstep;
   vtkIdType offsets[12];
-  int ComputeNormals = self->GetComputeNormals();
-  int ComputeGradients = self->GetComputeGradients();
-  int ComputeScalars = self->GetComputeScalars();
-  int NeedGradients = ComputeGradients || ComputeNormals;
+  vtkTypeBool ComputeNormals = self->GetComputeNormals();
+  vtkTypeBool ComputeGradients = self->GetComputeGradients();
+  vtkTypeBool ComputeScalars = self->GetComputeScalars();
+  bool NeedGradients = ComputeGradients || ComputeNormals;
   double n[3], n0[3], n1[3];
   vtkIdType jj, g0;
   int* tablePtr;
@@ -294,6 +286,7 @@ void ContourImage(vtkSynchronizedTemplates3D* self, int* exExt, vtkImageData* da
   ptr += self->GetArrayComponent();
   vtkPolygonBuilder polyBuilder;
   vtkSmartPointer<vtkIdListCollection> polys = vtkSmartPointer<vtkIdListCollection>::New();
+  bool abort = false;
 
   if (ComputeScalars)
   {
@@ -357,8 +350,10 @@ void ContourImage(vtkSynchronizedTemplates3D* self, int* exExt, vtkImageData* da
     isect1[((ydim - 1) * xdim + i) * 3 * 2 + 1] = -1;
   }
 
+  int checkAbortInterval = std::min((zMax - zMin) / 10 + 1, 1000);
+
   // for each contour
-  for (vidx = 0; vidx < numContours; vidx++)
+  for (vidx = 0; vidx < numContours && !abort; vidx++)
   {
     value = values[vidx];
     inPtrZ = ptr;
@@ -368,6 +363,11 @@ void ContourImage(vtkSynchronizedTemplates3D* self, int* exExt, vtkImageData* da
     {
       self->UpdateProgress(
         (double)vidx / numContours + (k - zMin) / ((zMax - zMin + 1.0) * numContours));
+      if (k % checkAbortInterval == 0 && self->CheckAbort())
+      {
+        abort = true;
+        break;
+      }
       z = origin[2] + spacing[2] * k;
       x[2] = z;
 
@@ -650,7 +650,7 @@ void ContourImage(vtkSynchronizedTemplates3D* self, int* exExt, vtkImageData* da
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedTemplates3D::SetInputMemoryLimit(unsigned long vtkNotUsed(limit))
 {
   vtkErrorMacro(<< "This filter no longer supports a memory limit.");
@@ -659,7 +659,7 @@ void vtkSynchronizedTemplates3D::SetInputMemoryLimit(unsigned long vtkNotUsed(li
     << "Please use a vtkPolyDataStreamer after this filter to achieve similar functionality.");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned long vtkSynchronizedTemplates3D::GetInputMemoryLimit()
 {
   vtkErrorMacro(<< "This filter no longer supports a memory limit.");
@@ -670,7 +670,7 @@ unsigned long vtkSynchronizedTemplates3D::GetInputMemoryLimit()
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 //
 // Contouring filter specialized for images (or slices from images)
 //
@@ -732,7 +732,7 @@ void vtkSynchronizedTemplates3D::ThreadedExecute(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSynchronizedTemplates3D::RequestData(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -757,7 +757,7 @@ int vtkSynchronizedTemplates3D::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSynchronizedTemplates3D::RequestUpdateExtent(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -775,14 +775,14 @@ int vtkSynchronizedTemplates3D::RequestUpdateExtent(vtkInformation* vtkNotUsed(r
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkSynchronizedTemplates3D::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkImageData");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkSynchronizedTemplates3D::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -1849,3 +1849,4 @@ int VTK_SYNCHRONIZED_TEMPLATES_3D_TABLE_2[] = {
   3, 2, 1, 4, 2, 3, -1, 0, 3, 4, -1, 0,      //
   2, 1, -1                                   //
 };
+VTK_ABI_NAMESPACE_END
