@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkExtractUnstructuredGrid.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkExtractUnstructuredGrid
  * @brief   extract subset of unstructured grid geometry
@@ -42,6 +30,7 @@
 #include "vtkFiltersExtractionModule.h" // For export macro
 #include "vtkUnstructuredGridAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIncrementalPointLocator;
 
 class VTKFILTERSEXTRACTION_EXPORT vtkExtractUnstructuredGrid : public vtkUnstructuredGridAlgorithm
@@ -55,79 +44,79 @@ public:
    */
   static vtkExtractUnstructuredGrid* New();
 
-  //@{
+  ///@{
   /**
    * Turn on/off selection of geometry by point id.
    */
   vtkSetMacro(PointClipping, vtkTypeBool);
   vtkGetMacro(PointClipping, vtkTypeBool);
   vtkBooleanMacro(PointClipping, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off selection of geometry by cell id.
    */
   vtkSetMacro(CellClipping, vtkTypeBool);
   vtkGetMacro(CellClipping, vtkTypeBool);
   vtkBooleanMacro(CellClipping, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off selection of geometry via bounding box.
    */
   vtkSetMacro(ExtentClipping, vtkTypeBool);
   vtkGetMacro(ExtentClipping, vtkTypeBool);
   vtkBooleanMacro(ExtentClipping, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the minimum point id for point id selection.
    */
   vtkSetClampMacro(PointMinimum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(PointMinimum, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the maximum point id for point id selection.
    */
   vtkSetClampMacro(PointMaximum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(PointMaximum, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the minimum cell id for point id selection.
    */
   vtkSetClampMacro(CellMinimum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(CellMinimum, vtkIdType);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Specify the maximum cell id for point id selection.
    */
   vtkSetClampMacro(CellMaximum, vtkIdType, 0, VTK_ID_MAX);
   vtkGetMacro(CellMaximum, vtkIdType);
-  //@}
+  ///@}
 
   /**
    * Specify a (xmin,xmax, ymin,ymax, zmin,zmax) bounding box to clip data.
    */
   void SetExtent(double xMin, double xMax, double yMin, double yMax, double zMin, double zMax);
 
-  //@{
+  ///@{
   /**
    * Set / get a (xmin,xmax, ymin,ymax, zmin,zmax) bounding box to clip data.
    */
   void SetExtent(double extent[6]);
   double* GetExtent() VTK_SIZEHINT(6) { return this->Extent; }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off merging of coincident points. Note that is merging is
    * on, points with different point attributes (e.g., normals) are merged,
@@ -136,16 +125,16 @@ public:
   vtkSetMacro(Merging, vtkTypeBool);
   vtkGetMacro(Merging, vtkTypeBool);
   vtkBooleanMacro(Merging, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / get a spatial locator for merging points. By
    * default an instance of vtkMergePoints is used.
    */
   void SetLocator(vtkIncrementalPointLocator* locator);
   vtkGetObjectMacro(Locator, vtkIncrementalPointLocator);
-  //@}
+  ///@}
 
   /**
    * Create default locator. Used to create one when none is specified.
@@ -159,7 +148,7 @@ public:
 
 protected:
   vtkExtractUnstructuredGrid();
-  ~vtkExtractUnstructuredGrid() override {}
+  ~vtkExtractUnstructuredGrid() override = default;
 
   int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
@@ -180,4 +169,5 @@ private:
   void operator=(const vtkExtractUnstructuredGrid&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
