@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestLagrangianIntegrationModel.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-    This software is distributed WITHOUT ANY WARRANTY; without even
-    the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-    PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkLagrangianMatidaIntegrationModel.h"
 
 #include "vtkActor.h"
@@ -172,11 +160,9 @@ int TestLagrangianIntegrationModel(int, char*[])
   }
   odeWavelet->SetUseInitialIntegrationTime(false);
 
-  std::unique_ptr<vtkLagrangianThreadedData> data(new vtkLagrangianThreadedData);
-  vtkLagrangianParticle part(nvar, seedIdx, seedIdx, 0, 0, pd, odeWavelet->GetWeightsSize(), 3);
-  std::unique_ptr<vtkBilinearQuadIntersection> bqi(new vtkBilinearQuadIntersection);
-  data->BilinearQuadIntersection = bqi.get();
-  part.SetThreadedData(data.get());
+  vtkLagrangianThreadedData* data = odeWavelet->InitializeThreadedData();
+  vtkLagrangianParticle part(nvar, seedIdx, seedIdx, 0, 0, pd, 3);
+  part.SetThreadedData(data);
 
   odeWavelet->InitializeParticleData(pd);
   odeWavelet->InsertParticleData(&part, pd, 0);
@@ -197,7 +183,8 @@ int TestLagrangianIntegrationModel(int, char*[])
 
   if (odeWavelet->GetWeightsSize() != 8)
   {
-    std::cerr << "Incorrect Weights Size" << std::endl;
+    std::cerr << "Incorrect Weights Size: " << odeWavelet->GetWeightsSize() << ". Expecting 8"
+              << std::endl;
     return EXIT_FAILURE;
   }
 
@@ -663,5 +650,7 @@ int TestLagrangianIntegrationModel(int, char*[])
               << std::endl;
     return EXIT_FAILURE;
   }
+
+  odeWavelet->FinalizeThreadedData(data);
   return EXIT_SUCCESS;
 }
