@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkLagrangianBasicIntegrationModel.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-    This software is distributed WITHOUT ANY WARRANTY; without even
-    the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-    PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkLagrangianBasicIntegrationModel.h"
 
 #include "vtkBilinearQuadIntersection.h"
@@ -47,18 +35,19 @@
 
 #define USER_SURFACE_TYPE 100 // Minimal value for user defined surface type
 
-//----------------------------------------------------------------------------
-typedef std::vector<vtkSmartPointer<vtkAbstractCellLocator> > LocatorsTypeBase;
+//------------------------------------------------------------------------------
+typedef std::vector<vtkSmartPointer<vtkAbstractCellLocator>> LocatorsTypeBase;
+VTK_ABI_NAMESPACE_BEGIN
 class vtkLocatorsType : public LocatorsTypeBase
 {
 };
 
-typedef std::vector<vtkSmartPointer<vtkDataSet> > DataSetsTypeBase;
+typedef std::vector<vtkSmartPointer<vtkDataSet>> DataSetsTypeBase;
 class vtkDataSetsType : public DataSetsTypeBase
 {
 };
 
-typedef std::pair<unsigned int, vtkSmartPointer<vtkDataSet> > SurfaceItem;
+typedef std::pair<unsigned int, vtkSmartPointer<vtkDataSet>> SurfaceItem;
 typedef std::vector<SurfaceItem> SurfaceTypeBase;
 class vtkSurfaceType : public SurfaceTypeBase
 {
@@ -67,7 +56,7 @@ class vtkSurfaceType : public SurfaceTypeBase
 typedef std::pair<unsigned int, double> PassThroughItem;
 typedef std::set<PassThroughItem> PassThroughSetType;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLagrangianBasicIntegrationModel::vtkLagrangianBasicIntegrationModel()
   : Locator(nullptr)
   , Tolerance(1.0e-8)
@@ -78,11 +67,11 @@ vtkLagrangianBasicIntegrationModel::vtkLagrangianBasicIntegrationModel()
   SurfaceArrayDescription surfaceTypeDescription;
   surfaceTypeDescription.nComp = 1;
   surfaceTypeDescription.type = VTK_INT;
-  surfaceTypeDescription.enumValues.push_back(std::make_pair(SURFACE_TYPE_MODEL, "ModelDefined"));
-  surfaceTypeDescription.enumValues.push_back(std::make_pair(SURFACE_TYPE_TERM, "Terminate"));
-  surfaceTypeDescription.enumValues.push_back(std::make_pair(SURFACE_TYPE_BOUNCE, "Bounce"));
-  surfaceTypeDescription.enumValues.push_back(std::make_pair(SURFACE_TYPE_BREAK, "BreakUp"));
-  surfaceTypeDescription.enumValues.push_back(std::make_pair(SURFACE_TYPE_PASS, "PassThrough"));
+  surfaceTypeDescription.enumValues.emplace_back(SURFACE_TYPE_MODEL, "ModelDefined");
+  surfaceTypeDescription.enumValues.emplace_back(SURFACE_TYPE_TERM, "Terminate");
+  surfaceTypeDescription.enumValues.emplace_back(SURFACE_TYPE_BOUNCE, "Bounce");
+  surfaceTypeDescription.enumValues.emplace_back(SURFACE_TYPE_BREAK, "BreakUp");
+  surfaceTypeDescription.enumValues.emplace_back(SURFACE_TYPE_PASS, "PassThrough");
   this->SurfaceArrayDescriptions["SurfaceType"] = surfaceTypeDescription;
 
   this->SeedArrayNames->InsertNextValue("ParticleInitialVelocity");
@@ -103,7 +92,7 @@ vtkLagrangianBasicIntegrationModel::vtkLagrangianBasicIntegrationModel()
   this->LocatorsBuilt = false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLagrangianBasicIntegrationModel::~vtkLagrangianBasicIntegrationModel()
 {
   this->ClearDataSets();
@@ -115,7 +104,7 @@ vtkLagrangianBasicIntegrationModel::~vtkLagrangianBasicIntegrationModel()
   delete this->SurfaceLocators;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -128,16 +117,17 @@ void vtkLagrangianBasicIntegrationModel::PrintSelf(ostream& os, vtkIndent indent
   {
     os << indent << "Locator: " << this->Locator << endl;
   }
+  os << indent << "WeightsSize: " << this->WeightsSize << endl;
   os << indent << "Tolerance: " << this->Tolerance << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::SetTracker(vtkLagrangianParticleTracker* tracker)
 {
   this->Tracker = tracker;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::AddDataSet(
   vtkDataSet* dataset, bool surface, unsigned int surfaceFlatIndex)
 {
@@ -185,7 +175,7 @@ void vtkLagrangianBasicIntegrationModel::AddDataSet(
     {
       locator.TakeReference(this->Locator->NewInstance());
     }
-
+    locator->SetTolerance(this->LocatorTolerance);
     locator->SetDataSet(datasetCpy);
     locator->CacheCellBoundsOn();
     locator->AutomaticOn();
@@ -216,16 +206,11 @@ void vtkLagrangianBasicIntegrationModel::AddDataSet(
   else
   {
     this->Locators->push_back(locator);
-
-    int size = dataset->GetMaxCellSize();
-    if (size > static_cast<int>(this->SharedWeights.size()))
-    {
-      this->SharedWeights.resize(size);
-    }
+    this->WeightsSize = std::max(this->WeightsSize, dataset->GetMaxCellSize());
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::ClearDataSets(bool surface)
 {
   if (surface)
@@ -237,11 +222,11 @@ void vtkLagrangianBasicIntegrationModel::ClearDataSets(bool surface)
   {
     this->DataSets->clear();
     this->Locators->clear();
-    this->SharedWeights.clear();
+    this->WeightsSize = 0;
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkLagrangianBasicIntegrationModel::FunctionValues(double* x, double* f, void* userData)
 {
   // Sanity check
@@ -259,7 +244,7 @@ int vtkLagrangianBasicIntegrationModel::FunctionValues(double* x, double* f, voi
   vtkAbstractCellLocator* loc;
   vtkDataSet* ds;
   vtkIdType cellId;
-  double* weights = particle->GetLastWeights();
+  double* weights;
   if (this->FindInLocators(x, particle, ds, cellId, loc, weights))
   {
     // Evaluate integration model velocity field with the found cell
@@ -270,7 +255,7 @@ int vtkLagrangianBasicIntegrationModel::FunctionValues(double* x, double* f, voi
   return 0;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::SetLocator(vtkAbstractCellLocator* locator)
 {
   if (this->Locator != locator)
@@ -290,7 +275,7 @@ void vtkLagrangianBasicIntegrationModel::SetLocator(vtkAbstractCellLocator* loca
   }
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLagrangianParticle* vtkLagrangianBasicIntegrationModel::ComputeSurfaceInteraction(
   vtkLagrangianParticle* particle, std::queue<vtkLagrangianParticle*>& particles,
   unsigned int& surfaceFlatIndex, PassThroughParticlesType& passThroughParticles)
@@ -401,7 +386,7 @@ vtkLagrangianParticle* vtkLagrangianBasicIntegrationModel::ComputeSurfaceInterac
       vtkLagrangianParticle* clone = particle->CloneParticle();
       clone->SetInteraction(vtkLagrangianParticle::SURFACE_INTERACTION_PASS);
       this->InterpolateNextParticleVariables(clone, item.second);
-      passThroughParticles.push(std::make_pair(item.first, clone));
+      passThroughParticles.emplace(item.first, clone);
     }
   }
 
@@ -452,7 +437,7 @@ vtkLagrangianParticle* vtkLagrangianBasicIntegrationModel::ComputeSurfaceInterac
   return interactionParticle;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::TerminateParticle(vtkLagrangianParticle* particle)
 {
   particle->SetTermination(vtkLagrangianParticle::PARTICLE_TERMINATION_SURF_TERMINATED);
@@ -460,7 +445,7 @@ bool vtkLagrangianBasicIntegrationModel::TerminateParticle(vtkLagrangianParticle
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::BounceParticle(
   vtkLagrangianParticle* particle, vtkDataSet* surface, vtkIdType cellId)
 {
@@ -482,7 +467,7 @@ bool vtkLagrangianBasicIntegrationModel::BounceParticle(
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::BreakParticle(vtkLagrangianParticle* particle,
   vtkDataSet* surface, vtkIdType cellId, std::queue<vtkLagrangianParticle*>& particles)
 {
@@ -536,7 +521,7 @@ bool vtkLagrangianBasicIntegrationModel::BreakParticle(vtkLagrangianParticle* pa
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::InteractWithSurface(int vtkNotUsed(surfaceType),
   vtkLagrangianParticle* particle, vtkDataSet* vtkNotUsed(surface), vtkIdType vtkNotUsed(cellId),
   std::queue<vtkLagrangianParticle*>& vtkNotUsed(particles))
@@ -544,7 +529,7 @@ bool vtkLagrangianBasicIntegrationModel::InteractWithSurface(int vtkNotUsed(surf
   return this->TerminateParticle(particle);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::IntersectWithLine(vtkLagrangianParticle* particle,
   vtkCell* cell, double p1[3], double p2[3], double tol, double& t, double x[3])
 {
@@ -608,17 +593,10 @@ bool vtkLagrangianBasicIntegrationModel::IntersectWithLine(vtkLagrangianParticle
   double pcoords[3];
   int subId;
   int ret = cell->IntersectWithLine(p1, p2, tol, t, x, pcoords, subId);
-  if (ret != 0)
-  {
-    return true;
-  }
-  else
-  {
-    return false;
-  }
+  return ret != 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InterpolateNextParticleVariables(
   vtkLagrangianParticle* particle, double interpolationFactor, bool forceInside)
 {
@@ -639,7 +617,7 @@ void vtkLagrangianBasicIntegrationModel::InterpolateNextParticleVariables(
   stepTime *= interpolationFactor;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::CheckSurfacePerforation(
   vtkLagrangianParticle* particle, vtkDataSet* surface, vtkIdType cellId)
 {
@@ -678,7 +656,7 @@ bool vtkLagrangianBasicIntegrationModel::CheckSurfacePerforation(
   return false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::SetInputArrayToProcess(
   int idx, int port, int connection, int fieldAssociation, const char* name)
 {
@@ -692,24 +670,26 @@ void vtkLagrangianBasicIntegrationModel::SetInputArrayToProcess(
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::FindInLocators(double* x, vtkLagrangianParticle* particle)
 {
   vtkIdType cellId;
   vtkDataSet* dataset;
-  return this->FindInLocators(x, particle, dataset, cellId);
+  vtkAbstractCellLocator* loc;
+  double* weights;
+  return this->FindInLocators(x, particle, dataset, cellId, loc, weights);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::FindInLocators(
   double* x, vtkLagrangianParticle* particle, vtkDataSet*& dataset, vtkIdType& cellId)
 {
   vtkAbstractCellLocator* loc;
-  double* weights = this->SharedWeights.data();
+  double* weights;
   return this->FindInLocators(x, particle, dataset, cellId, loc, weights);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::FindInLocators(double* x, vtkLagrangianParticle* particle,
   vtkDataSet*& dataset, vtkIdType& cellId, vtkAbstractCellLocator*& loc, double*& weights)
 {
@@ -719,15 +699,19 @@ bool vtkLagrangianBasicIntegrationModel::FindInLocators(double* x, vtkLagrangian
     return false;
   }
 
-  vtkGenericCell* cell = particle->GetThreadedData()->GenericCell;
+  vtkLagrangianThreadedData* data = particle->GetThreadedData();
+  vtkGenericCell* cell = data->GenericCell;
 
-  // Try the provided cache
-  dataset = particle->GetLastDataSet();
-  loc = particle->GetLastLocator();
-  cellId = particle->GetLastCellId();
-  double* lastPosition = particle->GetLastCellPosition();
-  if (dataset)
+  cellId = data->LastCellId;
+  double* lastPosition = data->LastCellPosition;
+
+  weights = data->LastWeights.data();
+
+  if (data->LastDataSetIndex != -1)
   {
+    loc = (*this->Locators)[data->LastDataSetIndex];
+    dataset = (*this->DataSets)[data->LastDataSetIndex];
+
     // Check the last cell
     if (cellId != -1)
     {
@@ -744,6 +728,7 @@ bool vtkLagrangianBasicIntegrationModel::FindInLocators(double* x, vtkLagrangian
       dataset->GetCell(cellId, cell);
       if (cell->EvaluatePosition(x, nullptr, subId, pcoords, dist2, weights) == 1)
       {
+        std::copy(x, x + 3, data->LastCellPosition);
         return true;
       }
     }
@@ -752,34 +737,42 @@ bool vtkLagrangianBasicIntegrationModel::FindInLocators(double* x, vtkLagrangian
     cellId = this->FindInLocator(dataset, loc, x, cell, weights);
     if (cellId != -1)
     {
-      particle->SetLastCell(loc, dataset, cellId, x);
+      data->LastCellId = cellId;
+      std::copy(x, x + 3, data->LastCellPosition);
       return true;
     }
   }
 
   // No cache or Cache miss, try other datasets
-  vtkDataSet* lastDataSet = dataset;
   for (size_t iDs = 0; iDs < this->DataSets->size(); iDs++)
   {
     loc = (*this->Locators)[iDs];
     dataset = (*this->DataSets)[iDs];
-    if (dataset != lastDataSet)
+
+    if (static_cast<int>(iDs) != data->LastDataSetIndex)
     {
       cellId = this->FindInLocator(dataset, loc, x, cell, weights);
       if (cellId != -1)
       {
         // Store the found cell for caching purpose
-        particle->SetLastCell(loc, dataset, cellId, x);
+        data->LastDataSetIndex = static_cast<int>(iDs);
+        data->LastCellId = cellId;
+        std::copy(x, x + 3, data->LastCellPosition);
         return true;
       }
     }
   }
+
+  data->LastCellId = -1;
+  loc = nullptr;
+  dataset = nullptr;
+
   return false;
 }
 
-//----------------------------------------------------------------------------
-vtkIdType vtkLagrangianBasicIntegrationModel::FindInLocator(
-  vtkDataSet* ds, vtkAbstractCellLocator* loc, double* x, vtkGenericCell* cell, double* weights)
+//------------------------------------------------------------------------------
+vtkIdType vtkLagrangianBasicIntegrationModel::FindInLocator(vtkDataSet* dataSet,
+  vtkAbstractCellLocator* loc, double* x, vtkGenericCell* cell, double* weights)
 {
   double pcoords[3];
   vtkIdType cellId;
@@ -790,29 +783,29 @@ vtkIdType vtkLagrangianBasicIntegrationModel::FindInLocator(
   }
   else
   {
-    // No locator, ds is vtkImageData or vtkRectilinearGrid,
+    // No locator, dataSet is vtkImageData or vtkRectilinearGrid,
     // which does not require any cellToUse when calling FindCell.
     int subId;
-    cellId = ds->FindCell(x, nullptr, cell, 0, this->Tolerance, subId, pcoords, weights);
+    cellId = dataSet->FindCell(x, nullptr, cell, 0, this->Tolerance, subId, pcoords, weights);
   }
 
   // Ignore Ghost cells
-  if (cellId != -1 && ds->GetCellGhostArray() &&
-    ds->GetCellGhostArray()->GetValue(cellId) & vtkDataSetAttributes::DUPLICATECELL)
+  if (cellId != -1 && dataSet->GetCellGhostArray() &&
+    dataSet->GetCellGhostArray()->GetValue(cellId) & vtkDataSetAttributes::DUPLICATECELL)
   {
     return -1;
   }
   return cellId;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractArray* vtkLagrangianBasicIntegrationModel::GetSeedArray(
   int idx, vtkLagrangianParticle* particle)
 {
   return this->GetSeedArray(idx, particle->GetSeedData());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractArray* vtkLagrangianBasicIntegrationModel::GetSeedArray(int idx, vtkPointData* pointData)
 {
   // Check the provided index
@@ -859,7 +852,7 @@ vtkAbstractArray* vtkLagrangianBasicIntegrationModel::GetSeedArray(int idx, vtkP
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkLagrangianBasicIntegrationModel::GetFlowOrSurfaceDataNumberOfComponents(
   int idx, vtkDataSet* dataSet)
 {
@@ -939,7 +932,7 @@ int vtkLagrangianBasicIntegrationModel::GetFlowOrSurfaceDataNumberOfComponents(
   return -1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::GetFlowOrSurfaceData(vtkLagrangianParticle* particle,
   int idx, vtkDataSet* dataSet, vtkIdType tupleId, double* weights, double* data)
 {
@@ -1053,7 +1046,7 @@ bool vtkLagrangianBasicIntegrationModel::GetFlowOrSurfaceData(vtkLagrangianParti
   return false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkLagrangianBasicIntegrationModel::GetFlowOrSurfaceDataFieldAssociation(int idx)
 {
   // Check index
@@ -1083,25 +1076,25 @@ int vtkLagrangianBasicIntegrationModel::GetFlowOrSurfaceDataFieldAssociation(int
   return arrayIndexes.first.val[2];
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStringArray* vtkLagrangianBasicIntegrationModel::GetSeedArrayNames()
 {
   return this->SeedArrayNames;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIntArray* vtkLagrangianBasicIntegrationModel::GetSeedArrayComps()
 {
   return this->SeedArrayComps;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIntArray* vtkLagrangianBasicIntegrationModel::GetSeedArrayTypes()
 {
   return this->SeedArrayTypes;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStringArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayNames()
 {
   this->SurfaceArrayNames->SetNumberOfValues(0);
@@ -1113,7 +1106,7 @@ vtkStringArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayNames()
   return this->SurfaceArrayNames;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIntArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayComps()
 {
   this->SurfaceArrayComps->SetNumberOfValues(0);
@@ -1126,13 +1119,13 @@ vtkIntArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayComps()
   return this->SurfaceArrayComps;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkLagrangianBasicIntegrationModel::GetWeightsSize()
 {
-  return static_cast<int>(this->SharedWeights.size());
+  return this->WeightsSize;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStringArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayEnumValues()
 {
   this->SurfaceArrayEnumValues->SetNumberOfValues(0);
@@ -1152,7 +1145,7 @@ vtkStringArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayEnumValues()
   return this->SurfaceArrayEnumValues;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDoubleArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayDefaultValues()
 {
   this->SurfaceArrayDefaultValues->SetNumberOfValues(0);
@@ -1171,7 +1164,7 @@ vtkDoubleArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayDefaultValues
   return this->SurfaceArrayDefaultValues;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIntArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayTypes()
 {
   this->SurfaceArrayTypes->SetNumberOfValues(0);
@@ -1184,7 +1177,7 @@ vtkIntArray* vtkLagrangianBasicIntegrationModel::GetSurfaceArrayTypes()
   return this->SurfaceArrayTypes;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkLagrangianBasicIntegrationModel::ManualIntegration(
   vtkInitialValueProblemSolver* vtkNotUsed(integrator), double* vtkNotUsed(xcur),
   double* vtkNotUsed(xnext), double vtkNotUsed(t), double& vtkNotUsed(delT),
@@ -1195,7 +1188,7 @@ bool vtkLagrangianBasicIntegrationModel::ManualIntegration(
   return false;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::ComputeSurfaceDefaultValues(
   const char* arrayName, vtkDataSet* vtkNotUsed(dataset), int nComponents, double* defaultValues)
 {
@@ -1204,7 +1197,22 @@ void vtkLagrangianBasicIntegrationModel::ComputeSurfaceDefaultValues(
   std::fill(defaultValues, defaultValues + nComponents, defVal);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+vtkLagrangianThreadedData* vtkLagrangianBasicIntegrationModel::InitializeThreadedData()
+{
+  vtkLagrangianThreadedData* data = new vtkLagrangianThreadedData();
+  data->LastWeights.resize(this->GetWeightsSize());
+  return data;
+}
+
+//------------------------------------------------------------------------------
+void vtkLagrangianBasicIntegrationModel::FinalizeThreadedData(vtkLagrangianThreadedData*& data)
+{
+  delete data;
+  data = nullptr;
+}
+
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InitializeParticleData(
   vtkFieldData* particleData, int maxTuple)
 {
@@ -1227,7 +1235,7 @@ void vtkLagrangianBasicIntegrationModel::InitializeParticleData(
   particleData->AddArray(particleIntegrationTimeArray);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InitializePathData(vtkFieldData* data)
 {
   vtkNew<vtkLongLongArray> particleIdArray;
@@ -1251,7 +1259,7 @@ void vtkLagrangianBasicIntegrationModel::InitializePathData(vtkFieldData* data)
   data->AddArray(particleTerminationArray);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InitializeInteractionData(vtkFieldData* data)
 {
   vtkNew<vtkIntArray> interactionArray;
@@ -1260,7 +1268,7 @@ void vtkLagrangianBasicIntegrationModel::InitializeInteractionData(vtkFieldData*
   data->AddArray(interactionArray);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InsertParticleSeedData(
   vtkLagrangianParticle* particle, vtkFieldData* data)
 {
@@ -1285,7 +1293,7 @@ void vtkLagrangianBasicIntegrationModel::InsertParticleSeedData(
   }
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InsertPathData(
   vtkLagrangianParticle* particle, vtkFieldData* data)
 {
@@ -1297,7 +1305,7 @@ void vtkLagrangianBasicIntegrationModel::InsertPathData(
     ->InsertNextValue(particle->GetTermination());
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InsertInteractionData(
   vtkLagrangianParticle* particle, vtkFieldData* data)
 {
@@ -1305,7 +1313,7 @@ void vtkLagrangianBasicIntegrationModel::InsertInteractionData(
     ->InsertNextValue(particle->GetInteraction());
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLagrangianBasicIntegrationModel::InsertParticleData(
   vtkLagrangianParticle* particle, vtkFieldData* data, int stepEnum)
 {
@@ -1334,3 +1342,4 @@ void vtkLagrangianBasicIntegrationModel::InsertParticleData(
       break;
   }
 }
+VTK_ABI_NAMESPACE_END
