@@ -1,23 +1,9 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestGradientAndVorticity.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*----------------------------------------------------------------------------
- Copyright (c) Sandia Corporation
- See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-----------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Sandia Corporation
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkCell.h"
+#include "vtkCellCenters.h"
 #include "vtkCellData.h"
 #include "vtkCellType.h"
 #include "vtkCellTypeSource.h"
@@ -29,16 +15,24 @@
 #include "vtkHigherOrderHexahedron.h"
 #include "vtkHigherOrderQuadrilateral.h"
 #include "vtkHigherOrderWedge.h"
+#include "vtkIOSSReader.h"
+#include "vtkImageData.h"
 #include "vtkNew.h"
+#include "vtkPartitionedDataSet.h"
+#include "vtkPartitionedDataSetCollection.h"
 #include "vtkPointData.h"
+#include "vtkPointDataToCellData.h"
+#include "vtkResampleToImage.h"
 #include "vtkSmartPointer.h"
-#include "vtkStdString.h"
+#include "vtkStructuredData.h"
 #include "vtkStructuredGrid.h"
 #include "vtkStructuredGridReader.h"
+#include "vtkThreshold.h"
 #include "vtkTransformFilter.h"
 #include "vtkUnstructuredGrid.h"
 #include "vtkUnstructuredGridReader.h"
 
+#include <limits>
 #include <vector>
 
 #define VTK_CREATE(type, var) vtkSmartPointer<type> var = vtkSmartPointer<type>::New()
@@ -76,7 +70,7 @@ bool ArePointsWithinTolerance(double v1, double v2)
   return false;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void CreateCellData(vtkDataSet* grid, int numberOfComponents, int offset, const char* arrayName)
 {
   vtkIdType numberOfCells = grid->GetNumberOfCells();
@@ -95,13 +89,13 @@ void CreateCellData(vtkDataSet* grid, int numberOfComponents, int offset, const
     { // +offset makes the curl/vorticity nonzero
       tupleValues[j] = point[(j + offset) % 3];
     }
-    array->SetTypedTuple(i, &tupleValues[0]);
+    array->SetTypedTuple(i, tupleValues.data());
   }
   array->SetName(arrayName);
   grid->GetCellData()->AddArray(array);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void CreatePointData(vtkDataSet* grid, int numberOfComponents, int offset, const char* arrayName)
 {
   vtkIdType numberOfPoints = grid->GetNumberOfPoints();
@@ -117,13 +111,13 @@ void CreatePointData(vtkDataSet* grid, int numberOfComponents, int offset, const
     { // +offset makes the curl/vorticity nonzero
       tupleValues[j] = point[(j + offset) % 3];
     }
-    array->SetTypedTuple(i, &tupleValues[0]);
+    array->SetTypedTuple(i, tupleValues.data());
   }
   array->SetName(arrayName);
   grid->GetPointData()->AddArray(array);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int IsGradientCorrect(vtkDoubleArray* gradients, int offset)
 {
   int numberOfComponents = gradients->GetNumberOfComponents();
@@ -155,7 +149,7 @@ int IsGradientCorrect(vtkDoubleArray* gradients, int offset)
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // we assume that the gradients are correct and so we can compute the "real"
 // vorticity from it
 int IsVorticityCorrect(vtkDoubleArray* gradients, vtkDoubleArray* vorticity)
@@ -192,7 +186,7 @@ int IsVorticityCorrect(vtkDoubleArray* gradients, vtkDoubleArray* vorticity)
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // we assume that the gradients are correct and so we can compute the "real"
 // Q criterion from it
 int IsQCriterionCorrect(vtkDoubleArray* gradients, vtkDoubleArray* qCriterion)
@@ -227,7 +221,7 @@ int IsQCriterionCorrect(vtkDoubleArray* gradients, vtkDoubleArray* qCriterion)
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // we assume that the gradients are correct and so we can compute the "real"
 // divergence from it
 int IsDivergenceCorrect(vtkDoubleArray* gradients, vtkDoubleArray* divergence)
@@ -254,7 +248,7 @@ int IsDivergenceCorrect(vtkDoubleArray* gradients, vtkDoubleArray* divergence)
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int PerformTest(vtkDataSet* grid)
 {
   // Cleaning out the existing field data so that I can replace it with
@@ -367,9 +361,126 @@ int PerformTest(vtkDataSet* grid)
 
   return EXIT_SUCCESS;
 }
+
+//------------------------------------------------------------------------------
+int TestGradient(int* cellTypes, vtkGeneralTransform* transform)
+{
+  vtkNew<vtkCellTypeSource> cellTypeSource;
+  cellTypeSource->SetBlocksDimensions(3, 3, 3); // make sure we have an interior cell
+  cellTypeSource->SetCellOrder(3);
+
+  vtkNew<vtkTransformFilter> transformFilter;
+  transformFilter->SetInputConnection(cellTypeSource->GetOutputPort());
+  transformFilter->SetTransform(transform);
+
+  vtkNew<vtkElevationFilter> elevationFilter;
+  elevationFilter->SetLowPoint(0, 0, 0);
+  elevationFilter->SetHighPoint(1, 0, 0);
+  elevationFilter->SetScalarRange(0, 1);
+  elevationFilter->SetInputConnection(transformFilter->GetOutputPort());
+
+  vtkNew<vtkGradientFilter> gradientFilter;
+  gradientFilter->SetInputConnection(elevationFilter->GetOutputPort());
+  gradientFilter->SetInputScalars(vtkDataObject::FIELD_ASSOCIATION_POINTS, "Elevation");
+
+  transformFilter->Update();
+  vtkDataSet* output = transformFilter->GetOutput();
+  double bounds[6];
+  output->GetBounds(bounds);
+  elevationFilter->SetLowPoint(bounds[0], 0, 0);
+  elevationFilter->SetHighPoint(bounds[1], 0, 0);
+  elevationFilter->SetScalarRange(bounds[0], bounds[1]);
+
+  for (auto i = 0; cellTypes[i] != -1; i++)
+  {
+    cellTypeSource->SetCellType(cellTypes[i]);
+    gradientFilter->Update();
+    // Arrays generated by vtkm filters are of type `vtkAOSDataArrayTemplate`
+    auto* result = vtkFloatArray::Superclass::SafeDownCast(
+      gradientFilter->GetOutput()->GetPointData()->GetArray("Gradients"));
+    double range[2];
+    result->GetRange(range, 0);
+    if (range[0] < .99 || range[1] > 1.01)
+    {
+      vtkGenericWarningMacro("Incorrect gradient for cell type " << cellTypes[i]);
+      return EXIT_FAILURE;
+    }
+    for (auto j = 1; j < 3; j++)
+    {
+      result->GetRange(range, j);
+      if (range[0] < -.01 || range[1] > .01)
+      {
+        vtkGenericWarningMacro("Incorrect gradient for cell type " << cellTypes[i]);
+        return EXIT_FAILURE;
+      }
+    }
+  }
+
+  return EXIT_SUCCESS;
+}
+
+//------------------------------------------------------------------------------
+int TestPoints(vtkImageData* grid, vtkUnstructuredGrid* ref)
+{
+  auto gridArray = vtkArrayDownCast<vtkDoubleArray>(grid->GetPointData()->GetAbstractArray("Pres"));
+  auto refArray = vtkArrayDownCast<vtkDoubleArray>(ref->GetPointData()->GetAbstractArray("Pres"));
+  double refPoint[3];
+  double bounds[6];
+  int extent[6];
+  grid->GetBounds(bounds);
+  grid->GetExtent(extent);
+  int width[3];
+  vtkStructuredData::GetDimensionsFromExtent(extent, width);
+  int ijk[3];
+  for (vtkIdType pointId = 0; pointId < ref->GetNumberOfPoints(); ++pointId)
+  {
+    ref->GetPoint(pointId, refPoint);
+    ijk[0] = (refPoint[0] - bounds[0]) / (bounds[1] - bounds[0]) * width[0];
+    ijk[1] = (refPoint[1] - bounds[2]) / (bounds[3] - bounds[2]) * width[1];
+    ijk[2] = (refPoint[2] - bounds[4]) / (bounds[5] - bounds[4]) * width[2];
+    vtkIdType gridPointId = vtkStructuredData::ComputePointId(width, ijk);
+
+    if (std::abs(gridArray->GetValue(gridPointId) - refArray->GetValue(pointId)) > 1e-6)
+    {
+      vtkGenericWarningMacro("Computing gradient on a grid with hidden points failed");
+      return EXIT_FAILURE;
+    }
+  }
+  return EXIT_SUCCESS;
+}
+
+//------------------------------------------------------------------------------
+int TestCells(vtkImageData* grid, vtkPointSet* ref)
+{
+  auto gridArray = vtkArrayDownCast<vtkDoubleArray>(grid->GetCellData()->GetAbstractArray("Pres"));
+  auto refArray = vtkArrayDownCast<vtkDoubleArray>(ref->GetPointData()->GetAbstractArray("Pres"));
+  double refPoint[3];
+  double bounds[6];
+  int extent[6];
+  grid->GetBounds(bounds);
+  grid->GetExtent(extent);
+  int width[3];
+  vtkStructuredData::GetDimensionsFromExtent(extent, width);
+  int ijk[3];
+  for (vtkIdType pointId = 0; pointId < ref->GetNumberOfPoints(); ++pointId)
+  {
+    ref->GetPoint(pointId, refPoint);
+    ijk[0] = (refPoint[0] - bounds[0]) / (bounds[1] - bounds[0]) * (width[0] - 1);
+    ijk[1] = (refPoint[1] - bounds[2]) / (bounds[3] - bounds[2]) * (width[1] - 1);
+    ijk[2] = (refPoint[2] - bounds[4]) / (bounds[5] - bounds[4]) * (width[2] - 1);
+    vtkIdType gridPointId = vtkStructuredData::ComputeCellId(width, ijk);
+
+    if (std::abs(gridArray->GetValue(gridPointId) - refArray->GetValue(pointId)) > 1e-6)
+    {
+      vtkGenericWarningMacro("Computing gradient on a grid with hidden cells failed");
+      return EXIT_FAILURE;
+    }
+  }
+  return EXIT_SUCCESS;
+}
 } // end local namespace
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int TestGradientAndVorticity(int argc, char* argv[])
 {
   int i;
@@ -389,7 +500,7 @@ int TestGradientAndVorticity(int argc, char* argv[])
     return EXIT_FAILURE;
   }
 
-  vtkStdString filename;
+  std::string filename;
   filename = data_root;
   filename += "/Data/SampleStructGrid.vtk";
   VTK_CREATE(vtkStructuredGridReader, structuredGridReader);
@@ -417,98 +528,38 @@ int TestGradientAndVorticity(int argc, char* argv[])
     return EXIT_FAILURE;
   }
 
-  // now test gradient of a variety of cell types using the cell type source. we scale
-  // and rotate the grid to make sure that we don't have the cells conveniently
-  // set up to their parametric coordinate system and then compare to an analytic
-  // function (f=x) such that the gradient is (1, 0, 0).
-  vtkNew<vtkCellTypeSource> cellTypeSource;
-  cellTypeSource->SetBlocksDimensions(3, 3, 3); // make sure we have an interior cell
-  cellTypeSource->SetCellOrder(3);
-  vtkNew<vtkTransformFilter> transformFilter;
-  transformFilter->SetInputConnection(cellTypeSource->GetOutputPort());
-  vtkNew<vtkGeneralTransform> generalTransform;
-  generalTransform->Scale(2, 3, 4);
-  transformFilter->SetTransform(generalTransform);
-  vtkNew<vtkElevationFilter> elevationFilter;
-  elevationFilter->SetLowPoint(0, 0, 0);
-  elevationFilter->SetHighPoint(1, 0, 0);
-  elevationFilter->SetScalarRange(0, 1);
-  elevationFilter->SetInputConnection(transformFilter->GetOutputPort());
-  vtkNew<vtkGradientFilter> gradientFilter;
-  gradientFilter->SetInputConnection(elevationFilter->GetOutputPort());
-  gradientFilter->SetInputScalars(vtkDataObject::FIELD_ASSOCIATION_POINTS, "Elevation");
+  // Now test the gradient of a variety of cell types using the cell type
+  // source. We scale and rotate the grid to make sure that we don't have the
+  // cells conveniently set up to their parametric coordinate system and then
+  // compare to an analytic function (f=x) such that the gradient is
+  // (1, 0, 0).
+  vtkNew<vtkGeneralTransform> transform;
+  transform->Scale(2, 3, 4);
   int oneDCells[] = {
     VTK_LINE,
-    // VTK_QUADRATIC_EDGE, Derivatives() not implemented
-    VTK_CUBIC_LINE, VTK_LAGRANGE_CURVE,
+    // VTK_QUADRATIC_EDGE, //Derivatives() not implemented
+    VTK_CUBIC_LINE,
+    // VTK_LAGRANGE_CURVE, //Derivatives() not implemented
     -1 // mark as end
   };
-  transformFilter->Update();
-  vtkDataSet* output = transformFilter->GetOutput();
-  double bounds[6];
-  output->GetBounds(bounds);
-  elevationFilter->SetLowPoint(bounds[0], 0, 0);
-  elevationFilter->SetHighPoint(bounds[1], 0, 0);
-  elevationFilter->SetScalarRange(bounds[0], bounds[1]);
-  for (i = 0; oneDCells[i + 1] != -1; i++)
+  if (TestGradient(oneDCells, transform))
   {
-    cellTypeSource->SetCellType(oneDCells[i]);
-    gradientFilter->Update();
-    vtkFloatArray* result = vtkFloatArray::SafeDownCast(
-      gradientFilter->GetOutput()->GetPointData()->GetArray("Gradients"));
-    double range[2];
-    result->GetRange(range, 0);
-    if (range[0] < .99 || range[1] > 1.01)
-    {
-      vtkGenericWarningMacro("Incorrect gradient for cell type " << oneDCells[i]);
-      return EXIT_FAILURE;
-    }
-    for (int j = 1; j < 3; j++)
-    {
-      result->GetRange(range, j);
-      if (range[0] < -.01 || range[1] > .01)
-      {
-        vtkGenericWarningMacro("Incorrect gradient for cell type " << oneDCells[i]);
-        return EXIT_FAILURE;
-      }
-    }
+    return EXIT_FAILURE;
   }
+
+  transform->RotateZ(30);
   int twoDCells[] = {
     VTK_TRIANGLE, VTK_QUAD, VTK_QUADRATIC_TRIANGLE, VTK_QUADRATIC_QUAD, VTK_LAGRANGE_TRIANGLE,
     VTK_LAGRANGE_QUADRILATERAL,
     -1 // mark as end
   };
-  cellTypeSource->SetCellType(twoDCells[0]);
-  generalTransform->RotateZ(30);
-  transformFilter->Update();
-  output = transformFilter->GetOutput();
-  output->GetBounds(bounds);
-  elevationFilter->SetLowPoint(bounds[0], 0, 0);
-  elevationFilter->SetHighPoint(bounds[1], 0, 0);
-  elevationFilter->SetScalarRange(bounds[0], bounds[1]);
-  for (i = 0; twoDCells[i + 1] != -1; i++)
+  if (TestGradient(twoDCells, transform))
   {
-    cellTypeSource->SetCellType(twoDCells[i]);
-    gradientFilter->Update();
-    vtkFloatArray* result = vtkFloatArray::SafeDownCast(
-      gradientFilter->GetOutput()->GetPointData()->GetArray("Gradients"));
-    double range[2];
-    result->GetRange(range, 0);
-    if (range[0] < .99 || range[1] > 1.01)
-    {
-      vtkGenericWarningMacro("Incorrect gradient for cell type " << twoDCells[i]);
-      return EXIT_FAILURE;
-    }
-    for (int j = 1; j < 3; j++)
-    {
-      result->GetRange(range, j);
-      if (range[0] < -.01 || range[1] > .01)
-      {
-        vtkGenericWarningMacro("Incorrect gradient for cell type " << twoDCells[i]);
-        return EXIT_FAILURE;
-      }
-    }
+    return EXIT_FAILURE;
   }
+
+  transform->RotateX(20);
+  transform->RotateY(40);
   int threeDCells[] = {
     VTK_TETRA, VTK_HEXAHEDRON, VTK_WEDGE, VTK_PYRAMID, VTK_QUADRATIC_TETRA,
     VTK_QUADRATIC_HEXAHEDRON, VTK_QUADRATIC_WEDGE,
@@ -516,37 +567,80 @@ int TestGradientAndVorticity(int argc, char* argv[])
     VTK_LAGRANGE_TETRAHEDRON, VTK_LAGRANGE_HEXAHEDRON, VTK_LAGRANGE_WEDGE,
     -1 // mark as end
   };
-  cellTypeSource->SetCellType(threeDCells[0]);
-  generalTransform->RotateX(20);
-  generalTransform->RotateY(40);
-  transformFilter->Update();
-  output = transformFilter->GetOutput();
-  output->GetBounds(bounds);
-  elevationFilter->SetLowPoint(bounds[0], 0, 0);
-  elevationFilter->SetHighPoint(bounds[1], 0, 0);
-  elevationFilter->SetScalarRange(bounds[0], bounds[1]);
-  for (i = 0; threeDCells[i] != -1; i++)
+  if (TestGradient(threeDCells, transform))
   {
-    cellTypeSource->SetCellType(threeDCells[i]);
-    gradientFilter->Update();
-    vtkFloatArray* result = vtkFloatArray::SafeDownCast(
-      gradientFilter->GetOutput()->GetPointData()->GetArray("Gradients"));
-    double range[2];
-    result->GetRange(range, 0);
-    if (range[0] < .99 || range[1] > 1.01)
-    {
-      vtkGenericWarningMacro("Incorrect gradient for cell type " << threeDCells[i]);
-      return EXIT_FAILURE;
-    }
-    for (int j = 1; j < 3; j++)
-    {
-      result->GetRange(range, j);
-      if (range[0] < -.01 || range[1] > .01)
-      {
-        vtkGenericWarningMacro("Incorrect gradient for cell type " << threeDCells[i]);
-        return EXIT_FAILURE;
-      }
-    }
+    return EXIT_FAILURE;
+  }
+
+  // Testing handling of hidden cells and points
+  std::string disk_out_ref = data_root;
+  disk_out_ref += "/Data/disk_out_ref.ex2";
+  vtkNew<vtkIOSSReader> iossReader;
+  iossReader->SetFileName(disk_out_ref.c_str());
+  iossReader->Update();
+  vtkUnstructuredGrid* disk = vtkUnstructuredGrid::SafeDownCast(vtkPartitionedDataSet::SafeDownCast(
+    vtkPartitionedDataSetCollection::SafeDownCast(iossReader->GetOutputDataObject(0))
+      ->GetPartitionedDataSet(0))
+                                                                  ->GetPartition(0));
+
+  vtkNew<vtkResampleToImage> resampler;
+  resampler->SetInputDataObject(disk);
+  resampler->SetSamplingDimensions(50, 50, 50);
+  resampler->SetUseInputBounds(true);
+
+  vtkNew<vtkGradientFilter> pointGradient;
+  pointGradient->SetInputArrayToProcess(0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, "Pres");
+  pointGradient->SetInputConnection(resampler->GetOutputPort());
+
+  vtkNew<vtkThreshold> ugPointConverter;
+  ugPointConverter->SetInputConnection(resampler->GetOutputPort());
+  ugPointConverter->SetInputArrayToProcess(
+    0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, "Pres");
+  ugPointConverter->SetLowerThreshold(-std::numeric_limits<double>::infinity());
+  ugPointConverter->SetUpperThreshold(std::numeric_limits<double>::infinity());
+
+  vtkNew<vtkGradientFilter> pointRefGradient;
+  pointRefGradient->SetInputArrayToProcess(
+    0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, "Pres");
+  pointRefGradient->SetInputConnection(ugPointConverter->GetOutputPort());
+
+  pointRefGradient->Update();
+  pointGradient->Update();
+
+  if (TestPoints(vtkImageData::SafeDownCast(pointGradient->GetOutput()),
+        vtkUnstructuredGrid::SafeDownCast(pointRefGradient->GetOutput())))
+  {
+    return EXIT_FAILURE;
+  }
+
+  vtkNew<vtkPointDataToCellData> point2cell;
+  point2cell->SetInputConnection(resampler->GetOutputPort());
+
+  vtkNew<vtkGradientFilter> cellGradient;
+  cellGradient->SetInputArrayToProcess(0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_CELLS, "Pres");
+  cellGradient->SetInputConnection(point2cell->GetOutputPort());
+
+  vtkNew<vtkThreshold> ugCellConverter;
+  ugCellConverter->SetInputConnection(cellGradient->GetOutputPort());
+  ugCellConverter->SetInputArrayToProcess(0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_CELLS, "Pres");
+  ugCellConverter->SetLowerThreshold(-std::numeric_limits<double>::infinity());
+  ugCellConverter->SetUpperThreshold(std::numeric_limits<double>::infinity());
+
+  vtkNew<vtkGradientFilter> cellRefGradient;
+  cellRefGradient->SetInputArrayToProcess(0, 0, 0, vtkDataObject::FIELD_ASSOCIATION_CELLS, "Pres");
+  cellRefGradient->SetInputConnection(ugCellConverter->GetOutputPort());
+
+  vtkNew<vtkCellCenters> cellCenterRefGradient;
+  cellCenterRefGradient->CopyArraysOn();
+  cellCenterRefGradient->SetInputConnection(cellRefGradient->GetOutputPort());
+
+  cellCenterRefGradient->Update();
+  cellGradient->Update();
+
+  if (TestCells(vtkImageData::SafeDownCast(cellGradient->GetOutput()),
+        vtkPointSet::SafeDownCast(cellCenterRefGradient->GetOutput())))
+  {
+    return EXIT_FAILURE;
   }
 
   return EXIT_SUCCESS;
