@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include <vtkDataSetAttributes.h>
 #include <vtkFloatArray.h>
 #include <vtkMutableUndirectedGraph.h>
@@ -7,7 +9,7 @@
 #include "vtkGraphWeightEuclideanDistanceFilter.h"
 
 template <typename T>
-static bool FuzzyCompare(const T a, const T b);
+static bool FuzzyCompare(T a, T b);
 
 int TestGraphWeightEuclideanDistanceFilter(int, char*[])
 {
@@ -63,11 +65,7 @@ int TestGraphWeightEuclideanDistanceFilter(int, char*[])
 }
 
 template <typename T>
-static bool FuzzyCompare(const T a, const T b)
+static bool FuzzyCompare(T a, T b)
 {
-  if (fabs(static_cast<float>(a) - static_cast<float>(b)) < 1e-4)
-  {
-    return true;
-  }
-  return false;
+  return fabs(static_cast<float>(a) - static_cast<float>(b)) < 1e-4;
 }
