@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestQuadraturePoints.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 // This example demonstrates the capabilities of vtkQuadraturePointInterpolator
 // vtkQuadraturePointsGenerator and the class required to support their
 // addition.
@@ -72,7 +60,7 @@ int TestQuadraturePoints(int argc, char* argv[])
   std::string tempFile = tempDir + "/tmp.vtu";
   std::string tempBaseline = tempDir + "/TestQuadraturePoints.png";
 
-  // Raed, xml or legacy file.
+  // Read, xml or legacy file.
   vtkUnstructuredGrid* input = nullptr;
   vtkSmartPointer<vtkXMLUnstructuredGridReader> xusgr =
     vtkSmartPointer<vtkXMLUnstructuredGridReader>::New();
@@ -161,7 +149,9 @@ int TestQuadraturePoints(int argc, char* argv[])
   // Demonstrate threshold functionality.
   vtkSmartPointer<vtkThreshold> thresholder = vtkSmartPointer<vtkThreshold>::New();
   thresholder->SetInputConnection(clip->GetOutputPort());
-  thresholder->ThresholdBetween(0.0, 3.0);
+  thresholder->SetThresholdFunction(vtkThreshold::THRESHOLD_BETWEEN);
+  thresholder->SetLowerThreshold(0.0);
+  thresholder->SetUpperThreshold(3.0);
 
   // Generate the quadrature point set using a specific array as point data.
   vtkSmartPointer<vtkQuadraturePointsGenerator> pointGen =
@@ -266,7 +256,7 @@ int TestQuadraturePoints(int argc, char* argv[])
   return EXIT_SUCCESS;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int GenerateWarpVector(vtkUnstructuredGrid* usg)
 {
   vtkDoubleArray* pts = vtkArrayDownCast<vtkDoubleArray>(usg->GetPoints()->GetData());
@@ -306,7 +296,7 @@ int GenerateWarpVector(vtkUnstructuredGrid* usg)
   }
   return idx;
 }
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int GenerateThresholdScalar(vtkUnstructuredGrid* usg)
 {
   vtkDoubleArray* pts = vtkArrayDownCast<vtkDoubleArray>(usg->GetPoints()->GetData());
