@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkCellValidator.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkCellValidator.h"
 
 #include "vtkCell.h"
@@ -69,6 +58,7 @@
 #include "vtkQuadraticWedge.h"
 #include "vtkTetra.h"
 #include "vtkTriQuadraticHexahedron.h"
+#include "vtkTriQuadraticPyramid.h"
 #include "vtkTriangle.h"
 #include "vtkTriangleStrip.h"
 #include "vtkVertex.h"
@@ -84,16 +74,17 @@
 #include <map>
 #include <sstream>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCellValidator);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::vtkCellValidator()
 {
   this->Tolerance = FLT_EPSILON;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
 bool PointsAreCoincident(double p[3], double q[3], double tolerance)
@@ -105,8 +96,7 @@ bool PointsAreCoincident(double p[3], double q[3], double tolerance)
 bool LineSegmentsIntersect(double p1[3], double p2[3], double q1[3], double q2[3], double tolerance)
 {
   double u, v;
-  static const int VTK_YES_INTERSECTION = 2;
-  if (vtkLine::Intersection3D(p1, p2, q1, q2, u, v) == VTK_YES_INTERSECTION)
+  if (vtkLine::Intersection(p1, p2, q1, q2, u, v) == vtkLine::Intersect)
   {
     if ((std::abs(u) > tolerance && std::abs(u - 1.) > tolerance) ||
       (std::abs(v) > tolerance && std::abs(v - 1.) > tolerance))
@@ -118,7 +108,7 @@ bool LineSegmentsIntersect(double p1[3], double p2[3], double q1[3], double q2[3
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkCellValidator::NoIntersectingEdges(vtkCell* cell, double tolerance)
 {
   // Ensures no cell edges intersect.
@@ -160,7 +150,7 @@ bool vtkCellValidator::NoIntersectingEdges(vtkCell* cell, double tolerance)
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
 bool TrianglesIntersect(double p1[3], double p2[3], double p3[3], double q1[3], double q2[3],
@@ -190,7 +180,7 @@ bool TrianglesIntersect(double p1[3], double p2[3], double p3[3], double q1[3],
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkCellValidator::NoIntersectingFaces(vtkCell* cell, double tolerance)
 {
   // Ensures no cell faces intersect.
@@ -231,7 +221,7 @@ bool vtkCellValidator::NoIntersectingFaces(vtkCell* cell, double tolerance)
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkCellValidator::ContiguousEdges(vtkCell* twoDimensionalCell, double tolerance)
 {
   // Ensures that a two-dimensional cell's edges are contiguous.
@@ -257,12 +247,8 @@ bool vtkCellValidator::ContiguousEdges(vtkCell* twoDimensionalCell, double toler
     edge->GetPoints()->GetPoint(0, x[0]);
     edge->GetPoints()->GetPoint(1, x[1]);
 
-    static const int VTK_NO_INTERSECTION = 0;
-    if (vtkLine::Intersection3D(p[0], p[1], x[0], x[1], u, v) == VTK_NO_INTERSECTION)
-    {
-      return false;
-    }
-    else if ((std::abs(u) > tolerance && std::abs(1. - u) > tolerance) ||
+    vtkLine::Intersection(p[0], p[1], x[0], x[1], u, v, vtkMath::Inf());
+    if ((std::abs(u) > tolerance && std::abs(1. - u) > tolerance) ||
       (std::abs(v) > tolerance && std::abs(1. - v) > tolerance))
     {
       return false;
@@ -273,17 +259,21 @@ bool vtkCellValidator::ContiguousEdges(vtkCell* twoDimensionalCell, double toler
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
 void Centroid(vtkCell* cell, double* centroid)
 {
   // Return the centroid of a cell in world coordinates.
-  static double weights[512];
+  static std::vector<double> weights;
+  if (weights.size() < static_cast<size_t>(cell->GetNumberOfPoints()))
+  {
+    weights.resize(cell->GetNumberOfPoints());
+  }
   double pCenter[3];
   int subId = -1;
   cell->GetParametricCenter(pCenter);
-  cell->EvaluateLocation(subId, pCenter, centroid, weights);
+  cell->EvaluateLocation(subId, pCenter, centroid, weights.data());
 }
 
 void Normal(vtkCell* twoDimensionalCell, double* normal)
@@ -296,7 +286,7 @@ void Normal(vtkCell* twoDimensionalCell, double* normal)
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkCellValidator::Convex(vtkCell* cell, double vtkNotUsed(tolerance))
 {
   // Determine whether or not a cell is convex. vtkPolygon and vtkPolyhedron can
@@ -350,7 +340,7 @@ bool vtkCellValidator::Convex(vtkCell* cell, double vtkNotUsed(tolerance))
         polyhedron_pointIds[i] = i;
       }
 
-      // udpate the face ids
+      // update the face ids
       vtkIdType cpt = 0;
       for (vtkIdType i = 0; i < faces_n; i++)
       {
@@ -376,7 +366,7 @@ bool vtkCellValidator::Convex(vtkCell* cell, double vtkNotUsed(tolerance))
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 namespace
 {
 // The convention for three-dimensional cells is that the normal of each face
@@ -384,17 +374,12 @@ namespace
 // inconsistent to maintain backwards compatibility.
 bool outwardOrientation(int cellType)
 {
-  if (cellType == VTK_QUADRATIC_LINEAR_WEDGE || cellType == VTK_BIQUADRATIC_QUADRATIC_WEDGE ||
-    cellType == VTK_QUADRATIC_WEDGE)
-  {
-    return false;
-  }
-
-  return true;
+  return cellType != VTK_QUADRATIC_LINEAR_WEDGE && cellType != VTK_BIQUADRATIC_QUADRATIC_WEDGE &&
+    cellType != VTK_QUADRATIC_WEDGE;
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkCellValidator::FacesAreOrientedCorrectly(vtkCell* threeDimensionalCell, double tolerance)
 {
   // Ensure that a 3-dimensional cell's faces are oriented away from the
@@ -433,7 +418,7 @@ bool vtkCellValidator::FacesAreOrientedCorrectly(vtkCell* threeDimensionalCell,
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkCell* cell, double tolerance)
 {
   // Ensure the number of points is at least as great as the number of point ids
@@ -475,6 +460,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkCell* cell, double tolerance)
     CheckCase(VTK_QUADRATIC_PYRAMID, vtkQuadraticPyramid);
     CheckCase(VTK_BIQUADRATIC_QUAD, vtkBiQuadraticQuad);
     CheckCase(VTK_TRIQUADRATIC_HEXAHEDRON, vtkTriQuadraticHexahedron);
+    CheckCase(VTK_TRIQUADRATIC_PYRAMID, vtkTriQuadraticPyramid);
     CheckCase(VTK_QUADRATIC_LINEAR_QUAD, vtkQuadraticLinearQuad);
     CheckCase(VTK_QUADRATIC_LINEAR_WEDGE, vtkQuadraticLinearWedge);
     CheckCase(VTK_BIQUADRATIC_QUADRATIC_WEDGE, vtkBiQuadraticQuadraticWedge);
@@ -502,19 +488,19 @@ vtkCellValidator::State vtkCellValidator::Check(vtkCell* cell, double tolerance)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkGenericCell* cell, double tolerance)
 {
   return vtkCellValidator::Check(cell->GetRepresentativeCell(), tolerance);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkEmptyCell*, double)
 {
   return State::Valid;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkVertex* vertex, double vtkNotUsed(tolerance))
 {
   State state = State::Valid;
@@ -528,7 +514,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkVertex* vertex, double vtkNot
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(
   vtkPolyVertex* polyVertex, double vtkNotUsed(tolerance))
 {
@@ -543,7 +529,7 @@ vtkCellValidator::State vtkCellValidator::Check(
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkLine* line, double vtkNotUsed(tolerance))
 {
   State state = State::Valid;
@@ -557,7 +543,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkLine* line, double vtkNotUsed
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkPolyLine* polyLine, double vtkNotUsed(tolerance))
 {
   State state = State::Valid;
@@ -571,7 +557,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkPolyLine* polyLine, double vt
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkTriangle* triangle, double tolerance)
 {
   State state = State::Valid;
@@ -592,7 +578,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkTriangle* triangle, double to
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkTriangleStrip* triangleStrip, double tolerance)
 {
   State state = State::Valid;
@@ -613,7 +599,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkTriangleStrip* triangleStrip,
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkPolygon* polygon, double tolerance)
 {
   State state = State::Valid;
@@ -646,7 +632,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkPolygon* polygon, double tole
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkPixel* pixel, double tolerance)
 {
   State state = State::Valid;
@@ -682,7 +668,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkPixel* pixel, double toleranc
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuad* quad, double tolerance)
 {
   State state = State::Valid;
@@ -715,7 +701,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuad* quad, double tolerance)
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkTetra* tetra, double tolerance)
 {
   State state = State::Valid;
@@ -742,7 +728,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkTetra* tetra, double toleranc
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkVoxel* voxel, double tolerance)
 {
   State state = State::Valid;
@@ -791,7 +777,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkVoxel* voxel, double toleranc
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkHexahedron* hex, double tolerance)
 {
   State state = State::Valid;
@@ -830,7 +816,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkHexahedron* hex, double toler
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkWedge* wedge, double tolerance)
 {
   State state = State::Valid;
@@ -869,7 +855,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkWedge* wedge, double toleranc
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkPyramid* pyramid, double tolerance)
 {
   State state = State::Valid;
@@ -908,7 +894,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkPyramid* pyramid, double tole
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(
   vtkPentagonalPrism* pentagonalPrism, double tolerance)
 {
@@ -948,7 +934,7 @@ vtkCellValidator::State vtkCellValidator::Check(
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkHexagonalPrism* hexagonalPrism, double tolerance)
 {
   State state = State::Valid;
@@ -987,7 +973,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkHexagonalPrism* hexagonalPris
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticEdge* edge, double tolerance)
 {
   State state = State::Valid;
@@ -1008,7 +994,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticEdge* edge, double t
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticTriangle* triangle, double tolerance)
 {
   State state = State::Valid;
@@ -1035,7 +1021,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticTriangle* triangle,
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticQuad* quad, double tolerance)
 {
   State state = State::Valid;
@@ -1062,7 +1048,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticQuad* quad, double t
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticPolygon* polygon, double tolerance)
 {
   State state = State::Valid;
@@ -1089,7 +1075,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticPolygon* polygon, do
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticTetra* tetra, double tolerance)
 {
   State state = State::Valid;
@@ -1122,7 +1108,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticTetra* tetra, double
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticHexahedron* hex, double tolerance)
 {
   State state = State::Valid;
@@ -1155,7 +1141,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticHexahedron* hex, dou
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticWedge* wedge, double tolerance)
 {
   State state = State::Valid;
@@ -1188,7 +1174,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticWedge* wedge, double
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticPyramid* pyramid, double tolerance)
 {
   State state = State::Valid;
@@ -1221,7 +1207,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticPyramid* pyramid, do
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBiQuadraticQuad* quad, double tolerance)
 {
   State state = State::Valid;
@@ -1248,7 +1234,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBiQuadraticQuad* quad, double
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkTriQuadraticHexahedron* hex, double tolerance)
 {
   State state = State::Valid;
@@ -1281,7 +1267,40 @@ vtkCellValidator::State vtkCellValidator::Check(vtkTriQuadraticHexahedron* hex,
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+vtkCellValidator::State vtkCellValidator::Check(vtkTriQuadraticPyramid* pyramid, double tolerance)
+{
+  State state = State::Valid;
+
+  // Ensure there are thirteen underlying point ids for the pyramid
+  if (pyramid->GetNumberOfPoints() != 19)
+  {
+    state |= State::WrongNumberOfPoints;
+    return state;
+  }
+
+  // Ensure that no edges intersect
+  if (!NoIntersectingEdges(pyramid, tolerance))
+  {
+    state |= State::IntersectingEdges;
+  }
+
+  // Ensure that no faces intersect
+  if (!NoIntersectingFaces(pyramid, tolerance))
+  {
+    state |= State::IntersectingEdges;
+  }
+
+  // Ensure the wedge's faces are oriented correctly
+  if (!FacesAreOrientedCorrectly(pyramid, tolerance))
+  {
+    state |= State::FacesAreOrientedIncorrectly;
+  }
+
+  return state;
+}
+
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticLinearQuad* quad, double tolerance)
 {
   State state = State::Valid;
@@ -1308,7 +1327,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticLinearQuad* quad, do
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticLinearWedge* wedge, double tolerance)
 {
   State state = State::Valid;
@@ -1341,7 +1360,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkQuadraticLinearWedge* wedge,
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(
   vtkBiQuadraticQuadraticWedge* wedge, double tolerance)
 {
@@ -1375,7 +1394,7 @@ vtkCellValidator::State vtkCellValidator::Check(
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(
   vtkBiQuadraticQuadraticHexahedron* hex, double tolerance)
 {
@@ -1409,7 +1428,7 @@ vtkCellValidator::State vtkCellValidator::Check(
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBiQuadraticTriangle* triangle, double tolerance)
 {
   State state = State::Valid;
@@ -1436,7 +1455,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBiQuadraticTriangle* triangle
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkCubicLine* line, double vtkNotUsed(tolerance))
 {
   State state = State::Valid;
@@ -1451,7 +1470,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkCubicLine* line, double vtkNo
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkConvexPointSet* pointSet, double tolerance)
 {
   State state = State::Valid;
@@ -1472,7 +1491,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkConvexPointSet* pointSet, dou
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkPolyhedron* polyhedron, double tolerance)
 {
   State state = State::Valid;
@@ -1511,7 +1530,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkPolyhedron* polyhedron, doubl
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeCurve* curve, double tolerance)
 {
   State state = State::Valid;
@@ -1532,7 +1551,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeCurve* curve, double
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeTriangle* triangle, double tolerance)
 {
   State state = State::Valid;
@@ -1559,7 +1578,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeTriangle* triangle, d
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(
   vtkLagrangeQuadrilateral* quadrilateral, double tolerance)
 {
@@ -1587,7 +1606,7 @@ vtkCellValidator::State vtkCellValidator::Check(
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeTetra* tetrahedron, double tolerance)
 {
   State state = State::Valid;
@@ -1620,7 +1639,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeTetra* tetrahedron, d
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeHexahedron* hexahedron, double tolerance)
 {
   State state = State::Valid;
@@ -1653,7 +1672,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeHexahedron* hexahedro
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeWedge* wedge, double tolerance)
 {
   State state = State::Valid;
@@ -1686,7 +1705,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkLagrangeWedge* wedge, double
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBezierCurve* curve, double tolerance)
 {
   State state = State::Valid;
@@ -1707,7 +1726,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBezierCurve* curve, double to
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBezierTriangle* triangle, double tolerance)
 {
   State state = State::Valid;
@@ -1734,7 +1753,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBezierTriangle* triangle, dou
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(
   vtkBezierQuadrilateral* quadrilateral, double tolerance)
 {
@@ -1762,7 +1781,7 @@ vtkCellValidator::State vtkCellValidator::Check(
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBezierTetra* tetrahedron, double tolerance)
 {
   State state = State::Valid;
@@ -1795,7 +1814,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBezierTetra* tetrahedron, dou
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBezierHexahedron* hexahedron, double tolerance)
 {
   State state = State::Valid;
@@ -1828,7 +1847,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBezierHexahedron* hexahedron,
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCellValidator::State vtkCellValidator::Check(vtkBezierWedge* wedge, double tolerance)
 {
   State state = State::Valid;
@@ -1861,7 +1880,7 @@ vtkCellValidator::State vtkCellValidator::Check(vtkBezierWedge* wedge, double to
   return state;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkCellValidator::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -1889,6 +1908,10 @@ int vtkCellValidator::RequestData(vtkInformation* vtkNotUsed(request),
   State state;
   for (it->InitTraversal(); !it->IsDoneWithTraversal(); it->GoToNextCell())
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     it->GetCell(cell);
     state = Check(cell, this->Tolerance);
     stateArray->SetValue(counter, static_cast<short>(state));
@@ -1896,7 +1919,7 @@ int vtkCellValidator::RequestData(vtkInformation* vtkNotUsed(request),
     {
       std::stringstream s;
       cell->Print(s);
-      this->PrintState(state, s, vtkIndent(0));
+      vtkCellValidator::PrintState(state, s, vtkIndent(0));
       vtkOutputWindowDisplayText(s.str().c_str());
     }
     ++counter;
@@ -1909,13 +1932,13 @@ int vtkCellValidator::RequestData(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkCellValidator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkCellValidator::PrintState(vtkCellValidator::State state, ostream& os, vtkIndent indent)
 {
   if (state == State::Valid)
@@ -1952,3 +1975,4 @@ void vtkCellValidator::PrintState(vtkCellValidator::State state, ostream& os, vt
     }
   }
 }
+VTK_ABI_NAMESPACE_END
