@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkClipClosedSurface.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkClipClosedSurface.h"
 
 #include "vtkCellArray.h"
@@ -20,6 +8,7 @@
 #include "vtkContourTriangulator.h"
 #include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
+#include "vtkExecutive.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
@@ -43,11 +32,12 @@
 #include <utility>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkClipClosedSurface);
 
 vtkCxxSetObjectMacro(vtkClipClosedSurface, ClippingPlanes, vtkPlaneCollection);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkClipClosedSurface::vtkClipClosedSurface()
 {
   this->ClippingPlanes = nullptr;
@@ -75,9 +65,12 @@ vtkClipClosedSurface::vtkClipClosedSurface()
 
   // A whole bunch of objects needed during execution
   this->IdList = nullptr;
+
+  // Initialize two output ports
+  this->SetNumberOfOutputPorts(2);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkClipClosedSurface::~vtkClipClosedSurface()
 {
   if (this->ClippingPlanes)
@@ -91,7 +84,7 @@ vtkClipClosedSurface::~vtkClipClosedSurface()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkClipClosedSurface::GetScalarModeAsString()
 {
   switch (this->ScalarMode)
@@ -106,7 +99,7 @@ const char* vtkClipClosedSurface::GetScalarModeAsString()
   return "";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -146,7 +139,7 @@ void vtkClipClosedSurface::PrintSelf(ostream& os, vtkIndent indent)
      << "TriangulationErrorDisplay: " << (this->TriangulationErrorDisplay ? "On\n" : "Off\n");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkClipClosedSurface::ComputePipelineMTime(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* vtkNotUsed(outputVector),
   int vtkNotUsed(requestFromOutputPort), vtkMTimeType* mtime)
@@ -181,7 +174,7 @@ int vtkClipClosedSurface::ComputePipelineMTime(vtkInformation* vtkNotUsed(reques
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // A helper class to quickly locate an edge, given the endpoint ids.
 // It uses an stl map rather than a table partitioning scheme, since
 // we have no idea how many entries there will be when we start.  So
@@ -286,10 +279,8 @@ vtkIdType* vtkCCSEdgeLocator::InsertUniqueEdge(vtkIdType i0, vtkIdType i1, vtkId
     return nullptr;
   }
 
-  int i = 1;
   while (node->next != nullptr)
   {
-    i++;
     node = node->next;
 
     if (node->ptId0 == i0 && node->ptId1 == i1)
@@ -308,7 +299,7 @@ vtkIdType* vtkCCSEdgeLocator::InsertUniqueEdge(vtkIdType i0, vtkIdType i1, vtkId
   return &node->edgeId;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -362,6 +353,12 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
     }
   }
 
+  vtkCellArray* clipFacePolys = nullptr;
+  if (this->GenerateClipFaceOutput)
+  {
+    clipFacePolys = vtkCellArray::New();
+  }
+
   // An edge locator to avoid point duplication while clipping
   vtkCCSEdgeLocator* edgeLocator = vtkCCSEdgeLocator::New();
 
@@ -385,7 +382,8 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   if (this->ScalarMode == VTK_CCS_SCALAR_MODE_COLORS)
   {
     numberOfScalarComponents = 3;
-    this->CreateColorValues(this->BaseColor, this->ClipColor, this->ActivePlaneColor, colors);
+    vtkClipClosedSurface::CreateColorValues(
+      this->BaseColor, this->ClipColor, this->ActivePlaneColor, colors);
   }
   else if (this->ScalarMode == VTK_CCS_SCALAR_MODE_LABELS)
   {
@@ -436,7 +434,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   vtkCellArray* lines = vtkCellArray::New();
   if (input->GetLines() && input->GetLines()->GetNumberOfCells() > 0)
   {
-    this->BreakPolylines(
+    vtkClipClosedSurface::BreakPolylines(
       input->GetLines(), lines, inputScalars, firstLineScalar, lineScalars, colors[0]);
   }
 
@@ -454,9 +452,9 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
     }
 
     polys = vtkCellArray::New();
-    this->CopyPolygons(
+    vtkClipClosedSurface::CopyPolygons(
       input->GetPolys(), polys, inputScalars, firstPolyScalar, polyScalars, colors[0]);
-    this->BreakTriangleStrips(
+    vtkClipClosedSurface::BreakTriangleStrips(
       input->GetStrips(), polys, inputScalars, firstStripScalar, polyScalars, colors[0]);
 
     // Check if the input has polys and quads or just triangles
@@ -527,7 +525,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   for (int planeId = 0; planes && (plane = planes->GetNextPlane(iter)); planeId++)
   {
     this->UpdateProgress((planeId + 1.0) / (numPlanes + 1.0));
-    if (this->GetAbortExecute())
+    if (this->CheckAbort())
     {
       break;
     }
@@ -545,6 +543,13 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
     // Convert the plane into an easy-to-evaluate function
     double pc[4];
     plane->GetNormal(pc);
+    if (this->InsideOut)
+    {
+      for (int i = 0; i < 3; ++i)
+      {
+        pc[i] *= -1.0;
+      }
+    }
     pc[3] = -vtkMath::Dot(pc, plane->GetOrigin());
 
     // Create the clip scalars by evaluating the plane at each point
@@ -578,6 +583,16 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
       // Cut the polys to generate more lines
       this->ClipAndContourPolys(points, pointScalars, pointData, edgeLocator, triangulate, polys,
         newPolys, newLines, inPolyData, outPolyData, outLineData);
+      if (this->GenerateClipFaceOutput)
+      {
+        vtkCellArray* tmpPolys = vtkCellArray::New();
+        vtkCellArray* tmpLines = vtkCellArray::New();
+        this->ClipAndContourPolys(points, pointScalars, pointData, edgeLocator, triangulate,
+          clipFacePolys, tmpPolys, tmpLines, inPolyData, outPolyData, outLineData);
+        clipFacePolys->DeepCopy(tmpPolys);
+        tmpPolys->Delete();
+        tmpLines->Delete();
+      }
 
       // Add scalars for the newly-created contour lines
       vtkUnsignedCharArray* scalars =
@@ -611,8 +626,24 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
       tmpContourData->SetLines(newLines);
       tmpContourData->BuildCells();
 
-      this->TriangulateContours(
-        tmpContourData, numClipLines, numClipAndContourLines - numClipLines, newPolys, pc);
+      if (this->GenerateClipFaceOutput)
+      {
+        vtkCellArray* tmpPolys = vtkCellArray::New();
+        this->TriangulateContours(
+          tmpContourData, numClipLines, numClipAndContourLines - numClipLines, tmpPolys, pc);
+        tmpContourData->SetPolys(tmpPolys);
+        newPolys->Append(tmpPolys);
+        if (this->GenerateClipFaceOutput)
+        {
+          clipFacePolys->Append(tmpPolys);
+        }
+        tmpPolys->Delete();
+      }
+      else
+      {
+        this->TriangulateContours(
+          tmpContourData, numClipLines, numClipAndContourLines - numClipLines, newPolys, pc);
+      }
 
       // Add scalars for the newly-created polys
       scalars = vtkArrayDownCast<vtkUnsignedCharArray>(outPolyData->GetScalars());
@@ -683,6 +714,26 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   edgeLocator->Delete();
 
   // Delete the contour data container
+  if (this->GenerateClipFaceOutput)
+  {
+    if (!this->GenerateOutline)
+    {
+      // Remove lines from the clip face output if not required
+      tmpContourData->SetLines(nullptr);
+    }
+    if (this->GenerateFaces)
+    {
+      tmpContourData->SetPolys(clipFacePolys);
+    }
+    else
+    {
+      // Remove faces from the clip face output if not required
+      tmpContourData->SetPolys(nullptr);
+    }
+    // Finally, set the clip face output
+    this->GetClipFaceOutput()->DeepCopy(tmpContourData);
+    clipFacePolys->Delete();
+  }
   tmpContourData->Delete();
 
   // Delete the clip scalars
@@ -769,7 +820,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   outPolyData->Delete();
 
   // Finally, store the points in the output
-  this->SqueezeOutputPoints(output, points, pointData, inputPointsType);
+  vtkClipClosedSurface::SqueezeOutputPoints(output, points, pointData, inputPointsType);
   output->Squeeze();
 
   points->Delete();
@@ -778,7 +829,7 @@ int vtkClipClosedSurface::RequestData(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::SqueezeOutputPoints(
   vtkPolyData* output, vtkPoints* points, vtkPointData* pointData, int outputPointDataType)
 {
@@ -871,7 +922,7 @@ void vtkClipClosedSurface::SqueezeOutputPoints(
   delete[] pointMap;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::CreateColorValues(const double color1[3], const double color2[3],
   const double color3[3], unsigned char colors[3][3])
 {
@@ -900,7 +951,7 @@ void vtkClipClosedSurface::CreateColorValues(const double color1[3], const doubl
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Point interpolation for clipping and contouring, given the scalar
 // values (v0, v1) for the two endpoints (p0, p1).  The use of this
 // function guarantees perfect consistency in the results.
@@ -969,7 +1020,7 @@ int vtkClipClosedSurface::InterpolateEdge(vtkPoints* points, vtkPointData* point
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::ClipLines(vtkPoints* points, vtkDoubleArray* pointScalars,
   vtkPointData* pointData, vtkCCSEdgeLocator* edgeLocator, vtkCellArray* inputCells,
   vtkCellArray* outputLines, vtkCellData* inCellData, vtkCellData* outLineData)
@@ -1022,7 +1073,7 @@ void vtkClipClosedSurface::ClipLines(vtkPoints* points, vtkDoubleArray* pointSca
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::ClipAndContourPolys(vtkPoints* points, vtkDoubleArray* pointScalars,
   vtkPointData* pointData, vtkCCSEdgeLocator* edgeLocator, int triangulate,
   vtkCellArray* inputCells, vtkCellArray* outputPolys, vtkCellArray* outputLines,
@@ -1158,7 +1209,7 @@ void vtkClipClosedSurface::ClipAndContourPolys(vtkPoints* points, vtkDoubleArray
   idList->Initialize();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::BreakPolylines(vtkCellArray* inputLines, vtkCellArray* lines,
   vtkUnsignedCharArray* inputScalars, vtkIdType firstLineScalar, vtkUnsignedCharArray* scalars,
   const unsigned char color[3])
@@ -1195,7 +1246,7 @@ void vtkClipClosedSurface::BreakPolylines(vtkCellArray* inputLines, vtkCellArray
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::CopyPolygons(vtkCellArray* inputPolys, vtkCellArray* polys,
   vtkUnsignedCharArray* inputScalars, vtkIdType firstPolyScalar, vtkUnsignedCharArray* polyScalars,
   const unsigned char color[3])
@@ -1235,7 +1286,7 @@ void vtkClipClosedSurface::CopyPolygons(vtkCellArray* inputPolys, vtkCellArray*
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::BreakTriangleStrips(vtkCellArray* inputStrips, vtkCellArray* polys,
   vtkUnsignedCharArray* inputScalars, vtkIdType firstStripScalar, vtkUnsignedCharArray* polyScalars,
   const unsigned char color[3])
@@ -1283,7 +1334,7 @@ void vtkClipClosedSurface::BreakTriangleStrips(vtkCellArray* inputStrips, vtkCel
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipClosedSurface::TriangulateContours(vtkPolyData* data, vtkIdType firstLine,
   vtkIdType numLines, vtkCellArray* outputPolys, const double normal[3])
 {
@@ -1294,8 +1345,8 @@ void vtkClipClosedSurface::TriangulateContours(vtkPolyData* data, vtkIdType firs
   }
 
   double nnormal[3] = { -normal[0], -normal[1], -normal[2] };
-  int rval =
-    vtkContourTriangulator::TriangulateContours(data, firstLine, numLines, outputPolys, nnormal);
+  int rval = vtkContourTriangulator::TriangulateContours(
+    data, firstLine, numLines, outputPolys, nnormal, this);
 
   if (rval == 0 && this->TriangulationErrorDisplay)
   {
@@ -1303,9 +1354,16 @@ void vtkClipClosedSurface::TriangulateContours(vtkPolyData* data, vtkIdType firs
   }
 }
 
-// ---------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkClipClosedSurface::TriangulatePolygon(
   vtkIdList* polygon, vtkPoints* points, vtkCellArray* triangles)
 {
   return vtkContourTriangulator::TriangulatePolygon(polygon, points, triangles);
 }
+
+//------------------------------------------------------------------------------
+vtkPolyData* vtkClipClosedSurface::GetClipFaceOutput()
+{
+  return vtkPolyData::SafeDownCast(this->GetExecutive()->GetOutputData(1));
+}
+VTK_ABI_NAMESPACE_END
