@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkClipVolume.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkClipVolume.h"
 
 #include "vtkCellArray.h"
@@ -35,6 +24,7 @@
 #include "vtkUnstructuredGrid.h"
 #include "vtkVoxel.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkClipVolume);
 vtkCxxSetObjectMacro(vtkClipVolume, ClipFunction, vtkImplicitFunction);
 
@@ -215,10 +205,11 @@ int vtkClipVolume::RequestData(vtkInformation* vtkNotUsed(request),
     {
       inPD->SetScalars(tmpScalars);
     }
+    double pt[3];
     for (i = 0; i < numPts; i++)
     {
-      s = this->ClipFunction->FunctionValue(input->GetPoint(i));
-      tmpScalars->InsertTuple(i, &s);
+      input->GetPoint(i, pt);
+      tmpScalars->InsertValue(i, this->ClipFunction->FunctionValue(pt));
     }
     clipScalars = tmpScalars;
   }
@@ -272,17 +263,17 @@ int vtkClipVolume::RequestData(vtkInformation* vtkNotUsed(request),
 
   // Interior voxels (i.e., inside the clip region) are tetrahedralized using
   // 5 tetrahedra. This requires swapping the face diagonals on alternating
-  // voxels to insure compatibility. Loop over i-j-k directions so that we
+  // voxels to ensure compatibility. Loop over i-j-k directions so that we
   // can control the direction of face diagonals on voxels (i.e., the flip
   // variable). The flip variable also controls the generation of tetrahedra
   // in boundary voxels in ClipTets() and the ordered Delaunay triangulation
   // used in ClipVoxel().
-  int abort = 0;
+  bool abort = false;
   for (k = 0; k < numKCells && !abort; k++)
   {
     // Check for progress and abort on every z-slice
     this->UpdateProgress(static_cast<double>(k) / numKCells);
-    abort = this->GetAbortExecute();
+    abort = this->CheckAbort();
     for (j = 0; j < numJCells; j++)
     {
       for (i = 0; i < numICells; i++)
@@ -683,7 +674,7 @@ void vtkClipVolume::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Mixed 3D Cell Type: " << (this->Mixed3DCellGeneration ? "On\n" : "Off\n");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkClipVolume::ReportReferences(vtkGarbageCollector* collector)
 {
   this->Superclass::ReportReferences(collector);
@@ -691,3 +682,4 @@ void vtkClipVolume::ReportReferences(vtkGarbageCollector* collector)
   // reference loop.
   vtkGarbageCollectorReport(collector, this->ClipFunction, "ClipFunction");
 }
+VTK_ABI_NAMESPACE_END
