@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkRandomAttributeGenerator.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkRandomAttributeGenerator.h"
 
 #include "vtkBitArray.h"
@@ -41,9 +29,10 @@
 #include "vtkUnsignedLongLongArray.h"
 #include "vtkUnsignedShortArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkRandomAttributeGenerator);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkRandomAttributeGenerator::vtkRandomAttributeGenerator()
 {
   this->DataType = VTK_FLOAT;
@@ -70,7 +59,10 @@ vtkRandomAttributeGenerator::vtkRandomAttributeGenerator()
   this->AttributesConstantPerBlock = false;
 }
 
-// ----------------------------------------------------------------------------
+namespace
+{
+
+//------------------------------------------------------------------------------
 template <class T>
 void GenerateRandomTuple(
   T* data, vtkIdType i, int numComp, int minComp, int maxComp, double min, double max)
@@ -82,7 +74,7 @@ void GenerateRandomTuple(
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void GenerateRandomTupleBit(vtkDataArray* data, vtkIdType i, int minComp, int maxComp)
 {
   for (int comp = minComp; comp <= maxComp; comp++)
@@ -92,13 +84,13 @@ void GenerateRandomTupleBit(vtkDataArray* data, vtkIdType i, int minComp, int ma
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void CopyTupleFrom0(T* data, vtkIdType i, int numComp, int minComp, int maxComp)
 {
   memcpy(data + i * numComp + minComp, data + minComp, (maxComp - minComp + 1) * sizeof(T));
 }
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void CopyTupleFrom0Bit(vtkDataArray* data, vtkIdType i, int minComp, int maxComp)
 {
   for (int comp = minComp; comp <= maxComp; comp++)
@@ -107,7 +99,9 @@ void CopyTupleFrom0Bit(vtkDataArray* data, vtkIdType i, int minComp, int maxComp
   }
 }
 
-// ----------------------------------------------------------------------------
+}
+
+//------------------------------------------------------------------------------
 // This function template creates random attributes within a given range. It is
 // assumed that the input data array may have a variable number of components.
 template <class T>
@@ -125,7 +119,7 @@ void vtkRandomAttributeGenerator::GenerateRandomTuples(
     if (!(i % tenth))
     {
       this->UpdateProgress(static_cast<double>(i) / total);
-      if (this->GetAbortExecute())
+      if (this->CheckAbort())
       {
         break;
       }
@@ -141,7 +135,7 @@ void vtkRandomAttributeGenerator::GenerateRandomTuples(
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method does the data type allocation and switching for various types.
 vtkDataArray* vtkRandomAttributeGenerator::GenerateData(
   int dataType, vtkIdType numTuples, int numComp, int minComp, int maxComp, double min, double max)
@@ -283,7 +277,7 @@ vtkDataArray* vtkRandomAttributeGenerator::GenerateData(
         if (!(i % tenth))
         {
           this->UpdateProgress(static_cast<double>(i) / total);
-          if (this->GetAbortExecute())
+          if (this->CheckAbort())
           {
             break;
           }
@@ -307,7 +301,7 @@ vtkDataArray* vtkRandomAttributeGenerator::GenerateData(
   return dataArray;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkRandomAttributeGenerator::RequestData(
   vtkCompositeDataSet* input, vtkCompositeDataSet* output)
 {
@@ -321,6 +315,10 @@ int vtkRandomAttributeGenerator::RequestData(
   it.TakeReference(input->NewIterator());
   for (it->InitTraversal(); !it->IsDoneWithTraversal(); it->GoToNextItem())
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     vtkDataSet* inputDS = vtkDataSet::SafeDownCast(it->GetCurrentDataObject());
     vtkSmartPointer<vtkDataSet> outputDS;
     outputDS.TakeReference(inputDS->NewInstance());
@@ -330,7 +328,7 @@ int vtkRandomAttributeGenerator::RequestData(
   return 1;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkRandomAttributeGenerator::RequestData(vtkDataSet* input, vtkDataSet* output)
 {
   vtkDebugMacro(<< "Producing random attributes");
@@ -504,7 +502,7 @@ int vtkRandomAttributeGenerator::RequestData(vtkDataSet* input, vtkDataSet* outp
   return 1;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkRandomAttributeGenerator::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -527,7 +525,7 @@ int vtkRandomAttributeGenerator::RequestData(vtkInformation* vtkNotUsed(request)
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRandomAttributeGenerator::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -562,3 +560,4 @@ int vtkRandomAttributeGenerator::FillInputPortInformation(
   info->Append(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkCompositeDataSet");
   return 1;
 }
+VTK_ABI_NAMESPACE_END
