@@ -1,17 +1,6 @@
-/*=========================================================================
-
-  Project:   vtkCSCS
-  Module:    vtkTemporalPathLineFilter.cxx
-
-  Copyright (c) CSCS - Swiss National Supercomputing Centre.
-  You may use modify and and distribute this code freely providing this
-  copyright notice appears on all copies of source code and an
-  acknowledgment appears with any substantial usage of the code.
-
-  This software is distributed WITHOUT ANY WARRANTY; without even the
-  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) CSCS - Swiss National Supercomputing Centre
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkTemporalPathLineFilter.h"
 #include "vtkCellArray.h"
 #include "vtkFloatArray.h"
@@ -24,6 +13,8 @@
 #include "vtkPointSet.h"
 #include "vtkPolyData.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
+#include "vtkUnsignedIntArray.h"
+
 //
 #include <cmath>
 #include <list>
@@ -31,17 +22,20 @@
 #include <stdexcept>
 #include <string>
 #include <vector>
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkTemporalPathLineFilter);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 //
-typedef struct
+struct Position_t
 {
   double x[3];
-} Position;
+};
+using Position = struct Position_t;
+
 typedef std::vector<Position> CoordList;
 typedef std::vector<vtkIdType> IdList;
-typedef std::vector<vtkSmartPointer<vtkAbstractArray> > FieldList;
+typedef std::vector<vtkSmartPointer<vtkAbstractArray>> FieldList;
 
 class ParticleTrail : public vtkObject
 {
@@ -90,7 +84,7 @@ public:
   //
   // This specifies the order of the arrays in the trails fields.  These are
   // valid in between calls to RequestData.
-  std::vector<vtkStdString> TrailFieldNames;
+  std::vector<std::string> TrailFieldNames;
   // Input arrays corresponding to the entries in TrailFieldNames.  nullptr arrays
   // indicate missing arrays.  This field is only valid during a call to
   // RequestData.
@@ -99,39 +93,29 @@ public:
 vtkStandardNewMacro(vtkTemporalPathLineFilterInternals);
 
 typedef std::map<int, double>::iterator TimeStepIterator;
-//----------------------------------------------------------------------------
+static constexpr double LATEST_TIME_MAX = VTK_DOUBLE_MAX;
+//------------------------------------------------------------------------------
 vtkTemporalPathLineFilter::vtkTemporalPathLineFilter()
 {
-  this->NumberOfTimeSteps = 0;
-  this->MaskPoints = 200;
-  this->MaxTrackLength = 10;
-  this->LastTrackLength = 10;
-  this->FirstTime = 1;
-  this->IdChannelArray = nullptr;
-  this->LatestTime = 01E10;
-  this->MaxStepDistance[0] = 0.0001;
-  this->MaxStepDistance[1] = 0.0001;
-  this->MaxStepDistance[2] = 0.0001;
-  this->MaxStepDistance[0] = 1;
-  this->MaxStepDistance[1] = 1;
-  this->MaxStepDistance[2] = 1;
-  this->KeepDeadTrails = 0;
-  this->Vertices = vtkSmartPointer<vtkCellArray>::New();
+  this->LatestTime = LATEST_TIME_MAX;
+
   this->PolyLines = vtkSmartPointer<vtkCellArray>::New();
+  this->Vertices = vtkSmartPointer<vtkCellArray>::New();
   this->LineCoordinates = vtkSmartPointer<vtkPoints>::New();
   this->VertexCoordinates = vtkSmartPointer<vtkPoints>::New();
   this->TrailId = vtkSmartPointer<vtkFloatArray>::New();
   this->Internals = vtkSmartPointer<vtkTemporalPathLineFilterInternals>::New();
+
   this->SetNumberOfInputPorts(2);
   this->SetNumberOfOutputPorts(2); // Lines and points
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTemporalPathLineFilter::~vtkTemporalPathLineFilter()
 {
   delete[] this->IdChannelArray;
   this->IdChannelArray = nullptr;
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTemporalPathLineFilter::FillInputPortInformation(int port, vtkInformation* info)
 {
   if (port == 0)
@@ -145,7 +129,7 @@ int vtkTemporalPathLineFilter::FillInputPortInformation(int port, vtkInformation
   }
   return 1;
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTemporalPathLineFilter::FillOutputPortInformation(int port, vtkInformation* info)
 {
   // Lines on 0, First point as Vertex Cell on 1
@@ -159,17 +143,29 @@ int vtkTemporalPathLineFilter::FillOutputPortInformation(int port, vtkInformatio
   }
   return 1;
 }
-//----------------------------------------------------------------------------
+
+//------------------------------------------------------------------------------
+void vtkTemporalPathLineFilter::SetBackwardTime(bool backward)
+{
+  if (this->BackwardTime != backward)
+  {
+    this->LatestTime = backward ? 0 : LATEST_TIME_MAX;
+    this->BackwardTime = backward;
+    this->Modified();
+  }
+}
+
+//------------------------------------------------------------------------------
 void vtkTemporalPathLineFilter::SetSelectionConnection(vtkAlgorithmOutput* algOutput)
 {
   this->SetInputConnection(1, algOutput);
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTemporalPathLineFilter::SetSelectionData(vtkDataSet* input)
 {
   this->SetInputData(1, input);
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTemporalPathLineFilter::RequestInformation(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* vtkNotUsed(outputVector))
 {
@@ -180,7 +176,7 @@ int vtkTemporalPathLineFilter::RequestInformation(vtkInformation* vtkNotUsed(req
   }
   return 1;
 }
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 TrailPointer vtkTemporalPathLineFilter::GetTrail(vtkIdType i)
 {
   TrailPointer trail;
@@ -200,8 +196,8 @@ TrailPointer vtkTemporalPathLineFilter::GetTrail(vtkIdType i)
     trail->lastpoint = 0;
     trail->firstpoint = 0;
     trail->length = 0;
-    trail->alive = 1;
-    trail->updated = 0;
+    trail->alive = true;
+    trail->updated = false;
     trail->TrailId = i;
 
     trail->Fields.assign(this->Internals->InputFieldArrays.size(), nullptr);
@@ -222,7 +218,7 @@ TrailPointer vtkTemporalPathLineFilter::GetTrail(vtkIdType i)
   }
   return trail;
 }
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTemporalPathLineFilter::IncrementTrail(TrailPointer trail, vtkDataSet* input, vtkIdType id)
 {
   //
@@ -231,8 +227,8 @@ void vtkTemporalPathLineFilter::IncrementTrail(TrailPointer trail, vtkDataSet* i
   //
   if (id >= input->GetNumberOfPoints())
   {
-    trail->alive = 0;
-    trail->updated = 1;
+    trail->alive = false;
+    trail->updated = true;
     return;
   }
   // if for some reason, two particles have the same ID, only update once
@@ -285,8 +281,8 @@ void vtkTemporalPathLineFilter::IncrementTrail(TrailPointer trail, vtkDataSet* i
     if (distx > this->MaxStepDistance[0] || disty > this->MaxStepDistance[1] ||
       distz > this->MaxStepDistance[2])
     {
-      trail->alive = 0;
-      trail->updated = 1;
+      trail->alive = false;
+      trail->updated = true;
       return;
     }
   }
@@ -303,12 +299,12 @@ void vtkTemporalPathLineFilter::IncrementTrail(TrailPointer trail, vtkDataSet* i
       trail->firstpoint = trail->lastpoint;
       trail->length = this->MaxTrackLength;
     }
-    trail->updated = 1;
+    trail->updated = true;
   }
   trail->FrontPointId = id;
-  trail->alive = 1;
+  trail->alive = true;
 }
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(information),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -389,10 +385,15 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
   //
   // Check time and Track length
   //
-  if (CurrentTimeStep < this->LatestTime)
+  if ((!this->BackwardTime && (CurrentTimeStep < this->LatestTime)) ||
+    (this->BackwardTime && (CurrentTimeStep > this->LatestTime)))
+  {
     this->FirstTime = 1;
+  }
   if (this->LastTrackLength != this->MaxTrackLength)
+  {
     this->FirstTime = 1;
+  }
 
   //
   // Reset everything if we are starting afresh
@@ -425,8 +426,8 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
   for (size_t i = 0; i < this->Internals->TrailFieldNames.size(); i++)
   {
     this->Internals->InputFieldArrays[i] =
-      inPD->GetAbstractArray(this->Internals->TrailFieldNames[i]);
-    outputFieldArrays[i] = outPD->GetAbstractArray(this->Internals->TrailFieldNames[i]);
+      inPD->GetAbstractArray(this->Internals->TrailFieldNames[i].c_str());
+    outputFieldArrays[i] = outPD->GetAbstractArray(this->Internals->TrailFieldNames[i].c_str());
   }
 
   //
@@ -437,17 +438,17 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
   for (vtkTemporalPathLineFilterInternals::TrailIterator t = this->Internals->Trails.begin();
        t != this->Internals->Trails.end(); ++t)
   {
-    t->second->alive = 0;
-    t->second->updated = 0;
+    t->second->alive = false;
+    t->second->updated = false;
   }
 
   //
   // If a selection input was provided, Build a list of selected Ids
   //
-  this->UsingSelection = 0;
+  this->UsingSelection = false;
   if (selection && Ids)
   {
-    this->UsingSelection = 1;
+    this->UsingSelection = true;
     this->SelectionIds.clear();
     vtkDataArray* selectionIds;
     if (this->IdChannelArray)
@@ -547,6 +548,10 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
   this->PolyLines->AllocateEstimate(static_cast<vtkIdType>(2 * size * this->MaxTrackLength), 1);
   this->TrailId->Allocate(static_cast<vtkIdType>(size * this->MaxTrackLength));
   this->TrailId->SetName("TrailId");
+
+  vtkNew<vtkUnsignedIntArray> trackLength;
+  trackLength->Allocate(static_cast<vtkIdType>(size * this->MaxTrackLength));
+  trackLength->SetName("TrackLength");
   //
   std::vector<vtkIdType> TempIds(this->MaxTrackLength);
   vtkIdType VertexId = 0;
@@ -554,6 +559,10 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
   for (vtkTemporalPathLineFilterInternals::TrailIterator t = this->Internals->Trails.begin();
        t != this->Internals->Trails.end(); ++t)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     TrailPointer tp = t->second;
     if (tp->length > 0)
     {
@@ -568,6 +577,7 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
           outputFieldArrays[fieldId]->InsertNextTuple(index, tp->Fields[fieldId]);
         }
         this->TrailId->InsertNextTuple1(static_cast<double>(tp->TrailId));
+        trackLength->InsertNextValue(tp->length - p);
 
         // export the front end of the line as a vertex on Output1
         if (p == (tp->length - 1))
@@ -579,7 +589,7 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
       }
       if (tp->length > 1)
       {
-        this->PolyLines->InsertNextCell(tp->length, &TempIds[0]);
+        this->PolyLines->InsertNextCell(tp->length, TempIds.data());
       }
       this->Vertices->InsertNextCell(1, &VertexId);
     }
@@ -588,6 +598,7 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
   output0->SetPoints(this->LineCoordinates);
   output0->SetLines(this->PolyLines);
   outPD->AddArray(this->TrailId);
+  outPD->AddArray(trackLength);
   outPD->SetActiveScalars(this->TrailId->GetName());
   this->Internals->InputFieldArrays.resize(0);
 
@@ -597,7 +608,7 @@ int vtkTemporalPathLineFilter::RequestData(vtkInformation* vtkNotUsed(informatio
 
   return 1;
 }
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTemporalPathLineFilter::Flush()
 {
   this->LineCoordinates->Initialize();
@@ -610,7 +621,7 @@ void vtkTemporalPathLineFilter::Flush()
   this->FirstTime = 1;
   ParticleTrail::UniqueId = 0;
 }
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTemporalPathLineFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -623,3 +634,4 @@ void vtkTemporalPathLineFilter::PrintSelf(ostream& os, vtkIndent indent)
      << this->MaxStepDistance[1] << "," << this->MaxStepDistance[2] << "}\n";
   os << indent << "KeepDeadTrails: " << this->KeepDeadTrails << "\n";
 }
+VTK_ABI_NAMESPACE_END
