@@ -1,24 +1,12 @@
-/*=========================================================================
-
- Program:   Visualization Toolkit
- Module:    vtkRectilinearGridPartitioner.h
-
- Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
- All rights reserved.
- See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
- This software is distributed WITHOUT ANY WARRANTY; without even
- the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- PURPOSE.  See the above copyright notice for more information.
-
- =========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkRectilinearGridPartitioner
  *
  *
  *  A concrete implementation of vtkMultiBlockDataSetAlgorithm that provides
  *  functionality for partitioning a VTK rectilinear dataset. The partitioning
- *  methd used is Recursive Coordinate Bisection (RCB) where each time the
+ *  method used is Recursive Coordinate Bisection (RCB) where each time the
  *  longest dimension is split.
  *
  * @sa
@@ -31,6 +19,7 @@
 #include "vtkFiltersGeometryModule.h" // For export macro
 #include "vtkMultiBlockDataSetAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkInformation;
 class vtkInformationVector;
 class vtkIndent;
@@ -44,27 +33,27 @@ public:
   vtkTypeMacro(vtkRectilinearGridPartitioner, vtkMultiBlockDataSetAlgorithm);
   void PrintSelf(ostream& oss, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Set/Get macro for the number of subdivisions.
    */
   vtkGetMacro(NumberOfPartitions, int);
   vtkSetMacro(NumberOfPartitions, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get macro for the number of ghost layers.
    */
   vtkGetMacro(NumberOfGhostLayers, int);
   vtkSetMacro(NumberOfGhostLayers, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   vtkGetMacro(DuplicateNodes, vtkTypeBool);
   vtkSetMacro(DuplicateNodes, vtkTypeBool);
   vtkBooleanMacro(DuplicateNodes, vtkTypeBool);
-  //@}
+  ///@}
 
 protected:
   vtkRectilinearGridPartitioner();
@@ -90,4 +79,5 @@ private:
   void operator=(const vtkRectilinearGridPartitioner&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif /* vtkRectilinearGridPartitioner_h */
