@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkHyperTreeGridGeometry.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkHyperTreeGridGeometry.h"
 
 #include "vtkBitArray.h"
@@ -43,6 +31,24 @@
 #include <set>
 #include <vector>
 
+namespace
+{
+
+bool PassCellId(vtkDataArray* cellIds, vtkIdType inId, vtkIdType outId)
+{
+  auto typedCellIds = vtkIdTypeArray::SafeDownCast(cellIds);
+  if (!typedCellIds)
+  {
+    vtkErrorWithObjectMacro(nullptr, "Pass cell ids array has wrong type.");
+    return false;
+  }
+  typedCellIds->InsertValue(outId, inId);
+  return true;
+}
+
+}
+
+VTK_ABI_NAMESPACE_BEGIN
 static constexpr unsigned int VonNeumannCursors3D[] = { 0, 1, 2, 4, 5, 6 };
 static constexpr unsigned int VonNeumannOrientations3D[] = { 2, 1, 0, 0, 1, 2 };
 static constexpr unsigned int VonNeumannOffsets3D[] = { 0, 0, 0, 1, 1, 1 };
@@ -54,7 +60,7 @@ constexpr unsigned char FULL_WORK_FACES = std::numeric_limits<unsigned char>::ma
 
 vtkStandardNewMacro(vtkHyperTreeGridGeometry);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHyperTreeGridGeometry::vtkHyperTreeGridGeometry()
 {
   // Create storage for corners of leaf cells
@@ -95,7 +101,7 @@ vtkHyperTreeGridGeometry::vtkHyperTreeGridGeometry()
   this->EdgeFlags = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHyperTreeGridGeometry::~vtkHyperTreeGridGeometry()
 {
   if (this->Points)
@@ -147,7 +153,7 @@ vtkHyperTreeGridGeometry::~vtkHyperTreeGridGeometry()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridGeometry::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -262,14 +268,14 @@ void vtkHyperTreeGridGeometry::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridGeometry::FillOutputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkPolyData");
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridGeometry::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObject* outputDO)
 {
   // Downcast output data object to polygonal data set
@@ -287,10 +293,18 @@ int vtkHyperTreeGridGeometry::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObjec
   this->BranchFactor = static_cast<int>(input->GetBranchFactor());
 
   // Initialize output cell data
-  this->InData = input->GetPointData();
+  this->InData = input->GetCellData();
   this->OutData = output->GetCellData();
   this->OutData->CopyAllocate(this->InData);
 
+  if (this->PassThroughCellIds)
+  {
+    vtkNew<vtkIdTypeArray> originalCellIds;
+    originalCellIds->SetName(this->OriginalCellIdArrayName.c_str());
+    originalCellIds->SetNumberOfComponents(1);
+    this->OutData->AddArray(originalCellIds);
+  }
+
   // Retrieve material mask
   this->Mask = input->HasMask() ? input->GetMask() : nullptr;
 
@@ -350,6 +364,10 @@ int vtkHyperTreeGridGeometry::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObjec
     vtkNew<vtkHyperTreeGridNonOrientedVonNeumannSuperCursor> cursor;
     while (it.GetNextTree(index))
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       // Initialize new cursor at root of current tree
       // In 3 dimensions, von Neumann neighborhood information is needed
       input->InitializeNonOrientedVonNeumannSuperCursor(cursor, index);
@@ -362,6 +380,10 @@ int vtkHyperTreeGridGeometry::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObjec
     vtkNew<vtkHyperTreeGridNonOrientedGeometryCursor> cursor;
     while (it.GetNextTree(index))
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       // Initialize new cursor at root of current tree
       // Otherwise, geometric properties of the cells suffice
       input->InitializeNonOrientedGeometryCursor(cursor, index);
@@ -403,11 +425,10 @@ int vtkHyperTreeGridGeometry::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObjec
     this->Locator->Delete();
     this->Locator = nullptr;
   }
-
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridGeometry::RecursivelyProcessTreeNot3D(
   vtkHyperTreeGridNonOrientedGeometryCursor* cursor)
 {
@@ -438,6 +459,10 @@ void vtkHyperTreeGridGeometry::RecursivelyProcessTreeNot3D(
   unsigned int numChildren = cursor->GetNumberOfChildren();
   for (unsigned int ichild = 0; ichild < numChildren; ++ichild)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     cursor->ToChild(ichild);
     // Recurse
     this->RecursivelyProcessTreeNot3D(cursor);
@@ -445,7 +470,7 @@ void vtkHyperTreeGridGeometry::RecursivelyProcessTreeNot3D(
   } // ichild
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // JB Meme code que vtkAdaptativeDataSetSurfaceFiltre ??
 void vtkHyperTreeGridGeometry::ProcessLeaf1D(vtkHyperTreeGridNonOrientedGeometryCursor* cursor)
 {
@@ -483,9 +508,13 @@ void vtkHyperTreeGridGeometry::ProcessLeaf1D(vtkHyperTreeGridNonOrientedGeometry
 
   // Copy edge data from that of the cell from which it comes
   this->OutData->CopyData(this->InData, inId, outId);
+  if (this->PassThroughCellIds)
+  {
+    ::PassCellId(this->OutData->GetArray(this->OriginalCellIdArrayName.c_str()), inId, outId);
+  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // JB Meme code que vtkAdaptativeDataSetSurfaceFiltre ??
 void vtkHyperTreeGridGeometry::ProcessLeaf2D(vtkHyperTreeGridNonOrientedGeometryCursor* cursor)
 
@@ -509,7 +538,7 @@ void vtkHyperTreeGridGeometry::ProcessLeaf2D(vtkHyperTreeGridNonOrientedGeometry
   this->AddFace2(inId, inId, cursor->GetOrigin(), cursor->GetSize(), 0, this->Orientation);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridGeometry::RecursivelyProcessTree3D(
   vtkHyperTreeGridNonOrientedVonNeumannSuperCursor* cursor, unsigned char crtWorkFaces)
 {
@@ -584,6 +613,10 @@ void vtkHyperTreeGridGeometry::RecursivelyProcessTree3D(
     }   // f
     for (std::set<int>::iterator it = childList.begin(); it != childList.end(); ++it)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       cursor->ToChild(*it);
       this->RecursivelyProcessTree3D(cursor, workFaces[*it]);
       cursor->ToParent();
@@ -594,13 +627,17 @@ void vtkHyperTreeGridGeometry::RecursivelyProcessTree3D(
   unsigned int numChildren = cursor->GetNumberOfChildren();
   for (unsigned int ichild = 0; ichild < numChildren; ++ichild)
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     cursor->ToChild(ichild);
     this->RecursivelyProcessTree3D(cursor, FULL_WORK_FACES);
     cursor->ToParent();
   } // ichild
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // JB Meme code que vtkAdaptativeDataSetSurfaceFiltre ??
 void vtkHyperTreeGridGeometry::ProcessLeaf3D(
   vtkHyperTreeGridNonOrientedVonNeumannSuperCursor* superCursor)
@@ -777,6 +814,10 @@ void vtkHyperTreeGridGeometry::ProcessLeaf3D(
 
       // Copy face data from that of the cell from which it comes
       this->OutData->CopyData(this->InData, inId, outId);
+      if (this->PassThroughCellIds)
+      {
+        ::PassCellId(this->OutData->GetArray(this->OriginalCellIdArrayName.c_str()), inId, outId);
+      }
     } // if ( nA > 0 )
 
     // Create face B when its vertices are present
@@ -820,11 +861,15 @@ void vtkHyperTreeGridGeometry::ProcessLeaf3D(
 
       // Copy face data from that of the cell from which it comes
       this->OutData->CopyData(this->InData, inId, outId);
+      if (this->PassThroughCellIds)
+      {
+        ::PassCellId(this->OutData->GetArray(this->OriginalCellIdArrayName.c_str()), inId, outId);
+      }
     } // if ( nB > 0 )
   }   // if ( this->HasInterface )
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridGeometry::AddFace(vtkIdType useId, const double* origin, const double* size,
   unsigned int offset, unsigned int orientation, unsigned char hideEdge)
 {
@@ -922,8 +967,12 @@ void vtkHyperTreeGridGeometry::AddFace(vtkIdType useId, const double* origin, co
 
   // Copy face data from that of the cell from which it comes
   this->OutData->CopyData(this->InData, useId, outId);
+  if (this->PassThroughCellIds)
+  {
+    ::PassCellId(this->OutData->GetArray(this->OriginalCellIdArrayName.c_str()), useId, outId);
+  }
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const double* origin,
   const double* size, unsigned int offset, unsigned int orientation, bool create)
 {
@@ -937,8 +986,8 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
   }
 
   // Storage for face vertex IDs
-  vtkIdType ids[4];
-  unsigned int nPts = 4;
+  std::vector<vtkIdType> ids;
+  ids.reserve(6);
 
   // Keep track of face axes
   unsigned int axis1 = orientation ? 0 : 1;
@@ -988,7 +1037,6 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
       // Storage for points
       double coordsB[3];
       double coordsC[3];
-      nPts = 0;
 
       // Distinguish between relevant types
       if (type == 1)
@@ -1010,8 +1058,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
           // Add point when necessary
           if (create && A <= 0.)
           {
-            ids[nPts] = this->Points->InsertNextPoint(coordsA);
-            ++nPts;
+            ids.emplace_back(this->Points->InsertNextPoint(coordsA));
           }
           if (A * B < 0)
           {
@@ -1028,8 +1075,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             } // if ( this->EdgesB[i] == -1 )
 
             // Update points
-            ids[nPts] = this->EdgesB[i];
-            ++nPts;
+            ids.emplace_back(this->EdgesB[i]);
             if (indPair)
             {
               pair[1] = i;
@@ -1037,7 +1083,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             else
             {
               pair[0] = i;
-            };
+            }
             ++indPair;
           } // if ( A * B < 0 )
         }   // p
@@ -1074,8 +1120,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
           // Add point when necessary
           if (create && A1 >= 0. && A2 <= 0.)
           {
-            ids[nPts] = this->Points->InsertNextPoint(coordsA);
-            ++nPts;
+            ids.emplace_back(this->Points->InsertNextPoint(coordsA));
           }
           if (A1 < 0. && A1 * B1 < 0.)
           {
@@ -1092,8 +1137,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             } // if ( this->EdgesB[i] == -1 )
 
             // Update points
-            ids[nPts] = this->EdgesA[i];
-            ++nPts;
+            ids.emplace_back(this->EdgesA[i]);
             if (indPairA)
             {
               pairA[1] = i;
@@ -1101,7 +1145,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             else
             {
               pairA[0] = i;
-            };
+            }
             ++indPairA;
           } // if ( A1 < 0. && A1 * B1 < 0. )
           if (A2 * B2 < 0.)
@@ -1119,8 +1163,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             } // if ( this->EdgesA[i] == -1 )
 
             // Update points
-            ids[nPts] = this->EdgesB[i];
-            ++nPts;
+            ids.emplace_back(this->EdgesB[i]);
             if (indPairB)
             {
               pairB[1] = i;
@@ -1128,7 +1171,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             else
             {
               pairB[0] = i;
-            };
+            }
             ++indPairB;
           } // if ( A2 * B2 < 0. )
           if (A1 > 0. && A1 * B1 < 0.)
@@ -1146,8 +1189,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             } // if ( this->EdgesA[i] == -1 )
 
             // Update points
-            ids[nPts] = this->EdgesA[i];
-            ++nPts;
+            ids.emplace_back(this->EdgesA[i]);
             if (indPairA)
             {
               pairA[1] = i;
@@ -1155,7 +1197,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             else
             {
               pairA[0] = i;
-            };
+            }
             ++indPairA;
           } // if ( A1 > 0. && A1 * B1 < 0. )
         }   // p
@@ -1189,8 +1231,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
           // Add point when necessary
           if (create && A >= 0.)
           {
-            ids[nPts] = this->Points->InsertNextPoint(coordsA);
-            ++nPts;
+            ids.emplace_back(this->Points->InsertNextPoint(coordsA));
           }
           if (A * B < 0.)
           {
@@ -1207,8 +1248,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             } // if ( this->EdgesB[i] == -1 )
 
             // Update points
-            ids[nPts] = this->EdgesA[i];
-            ++nPts;
+            ids.emplace_back(this->EdgesA[i]);
             if (indPair)
             {
               pair[1] = i;
@@ -1216,7 +1256,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
             else
             {
               pair[0] = i;
-            };
+            }
             ++indPair;
           } // if ( A * B < 0. )
         }   // p
@@ -1230,6 +1270,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
     }   // if ( type < 2 )
     else
     {
+      ids.resize(4);
       // Create quadrangle vertices depending on orientation
       ids[0] = this->Points->InsertNextPoint(pt);
       pt[axis1] += size[axis1];
@@ -1242,6 +1283,7 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
   }   // if ( this->HasInterface )
   else
   {
+    ids.resize(4);
     // Create quadrangle vertices depending on orientation
     ids[0] = this->Points->InsertNextPoint(pt);
     pt[axis1] += size[axis1];
@@ -1253,12 +1295,17 @@ void vtkHyperTreeGridGeometry::AddFace2(vtkIdType inId, vtkIdType useId, const d
   } // else
 
   // Insert next face if needed
-  if (create)
+  if (create && !ids.empty())
   {
     // Create cell and corresponding ID
-    vtkIdType outId = this->Cells->InsertNextCell(nPts, ids);
+    vtkIdType outId = this->Cells->InsertNextCell(ids.size(), ids.data());
 
     // Copy face data from that of the cell from which it comes
     this->OutData->CopyData(this->InData, useId, outId);
+    if (this->PassThroughCellIds)
+    {
+      ::PassCellId(this->OutData->GetArray(this->OriginalCellIdArrayName.c_str()), inId, outId);
+    }
   } // if ( create )
 }
+VTK_ABI_NAMESPACE_END
