@@ -1,20 +1,9 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-Module:    vtkHyperTreeGridToDualGrid.cxx
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkHyperTreeGridToDualGrid.h"
 
 #include "vtkBitArray.h"
+#include "vtkCellData.h"
 #include "vtkCellType.h"
 #include "vtkHyperTree.h"
 #include "vtkHyperTreeGrid.h"
@@ -28,6 +17,7 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkPoints.h"
 #include "vtkUnstructuredGrid.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHyperTreeGridToDualGrid);
 
 static const unsigned int CornerNeighborCursorsTable3D0[8] = { 0, 1, 3, 4, 9, 10, 12, 13 };
@@ -49,7 +39,7 @@ static const unsigned int* CornerNeighborCursorsTable3D[8] = {
   CornerNeighborCursorsTable3D7,
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHyperTreeGridToDualGrid::vtkHyperTreeGridToDualGrid()
 {
   // Dual grid corners (primal grid leaf centers)
@@ -57,7 +47,7 @@ vtkHyperTreeGridToDualGrid::vtkHyperTreeGridToDualGrid()
   this->Connectivity = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHyperTreeGridToDualGrid::~vtkHyperTreeGridToDualGrid()
 {
   if (this->Points)
@@ -71,7 +61,7 @@ vtkHyperTreeGridToDualGrid::~vtkHyperTreeGridToDualGrid()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -79,14 +69,14 @@ void vtkHyperTreeGridToDualGrid::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Connectivity: " << this->Connectivity << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridToDualGrid::FillOutputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkUnstructuredGrid");
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObject* outputDO)
 {
   // Downcast output data object to hyper tree grid
@@ -117,7 +107,7 @@ int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObj
   // entre les noeuds de l'HTG et ces points du maillage dual.
   // En effet, si l'on definit un GlobalIndex ou un IndexStart specifique
   // cette ecriture simpliste ne fonctionnait plus... tableau trop petit
-  // car GetGlobalIndex retourne une valeur > this->GetNumberOfVertices().
+  // car GetGlobalIndex retourne une valeur > this->GetNumberOfCells().
   this->Points->SetNumberOfPoints(input->GetGlobalNodeIndexMax() + 1);
 
   // TODO: find out why we get some uninitialized point coords instead
@@ -148,7 +138,7 @@ int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObj
 
   // Compute and store reduction factors for speed
   double factor = 1.;
-  for (unsigned short p = 0; p < gridDepth; ++p)
+  for (unsigned int p = 0; p < gridDepth; ++p)
   {
     this->ReductionFactors[p] = .5 * factor;
     factor /= input->GetBranchFactor();
@@ -164,6 +154,10 @@ int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObj
   vtkNew<vtkHyperTreeGridNonOrientedMooreSuperCursor> cursor;
   while (it.GetNextTree(index))
   {
+    if (this->CheckAbort())
+    {
+      break;
+    }
     // Initialize new Moore cursor at root of current tree
     input->InitializeNonOrientedMooreSuperCursor(cursor, index);
     // Convert hyper tree into unstructured mesh recursively
@@ -186,12 +180,12 @@ int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObj
     {
       double pt[3];
 
-      assert(_it->first < input->GetNumberOfVertices());
+      assert(_it->first < input->GetNumberOfCells());
       this->Points->GetPoint(_it->first, pt);
 
       pt[d] += _it->second;
 
-      assert(_it->first < input->GetNumberOfVertices());
+      assert(_it->first < input->GetNumberOfCells());
       this->Points->SetPoint(_it->first, pt);
     } // it
     this->PointShifts[d].clear();
@@ -200,7 +194,7 @@ int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObj
 
   // now populate my output from the mesh internals made above
   output->SetPoints(this->Points);
-  output->GetPointData()->ShallowCopy(input->GetPointData());
+  output->GetPointData()->ShallowCopy(input->GetCellData());
 
   int numPts = 1 << input->GetDimension();
   int type = VTK_VOXEL;
@@ -223,7 +217,7 @@ int vtkHyperTreeGridToDualGrid::ProcessTrees(vtkHyperTreeGrid* input, vtkDataObj
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::TraverseDualRecursively(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkHyperTreeGrid* input)
 {
@@ -251,6 +245,10 @@ void vtkHyperTreeGridToDualGrid::TraverseDualRecursively(
     int numChildren = input->GetNumberOfChildren();
     for (int child = 0; child < numChildren; ++child)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       cursor->ToChild(child);
       // Recurse
       this->TraverseDualRecursively(cursor, input);
@@ -259,7 +257,7 @@ void vtkHyperTreeGridToDualGrid::TraverseDualRecursively(
   }   // else
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf1D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkHyperTreeGrid* input)
 {
@@ -283,13 +281,11 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf1D(
   {
     // Move to left corner
     pt[input->GetOrientation()] -= .5 * cursor->GetSize()[input->GetOrientation()];
-    ;
   }
   if (!cursorR->HasTree())
   {
     // Move to right corner
     pt[input->GetOrientation()] += .5 * cursor->GetSize()[input->GetOrientation()];
-    ;
   }
 
   // Retrieve global index of center cursor
@@ -319,7 +315,7 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf1D(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf2D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkHyperTreeGrid* input)
 {
@@ -443,7 +439,7 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf2D(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf3D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkHyperTreeGrid* vtkNotUsed(input))
 {
@@ -453,7 +449,7 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf3D(
   //   (d-2)-faces are corners, neighbor cursors are 0, 2, 6, 8, 18, 20, 24, 26
 
   // Retrieve cursors
-  std::vector<vtkSmartPointer<vtkHyperTreeGridOrientedGeometryCursor> > cursors;
+  std::vector<vtkSmartPointer<vtkHyperTreeGridOrientedGeometryCursor>> cursors;
   cursors.resize(27);
   for (unsigned int c = 0; c < 27; ++c)
   {
@@ -544,7 +540,7 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf3D(
   }   // c
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::TraverseDualRecursively(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkBitArray* mask, vtkHyperTreeGrid* input)
 {
@@ -588,6 +584,10 @@ void vtkHyperTreeGridToDualGrid::TraverseDualRecursively(
     int numChildren = input->GetNumberOfChildren();
     for (int child = 0; child < numChildren; ++child)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       cursor->ToChild(child);
       // Recurse
       this->TraverseDualRecursively(cursor, mask, input);
@@ -596,7 +596,7 @@ void vtkHyperTreeGridToDualGrid::TraverseDualRecursively(
   }   // else
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::ShiftDualCornerFromMaskedLeaf2D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkBitArray* mask, vtkHyperTreeGrid* input)
 {
@@ -747,7 +747,7 @@ void vtkHyperTreeGridToDualGrid::ShiftDualCornerFromMaskedLeaf2D(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::ShiftDualCornerFromMaskedLeaf3D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkBitArray* mask,
   vtkHyperTreeGrid* vtkNotUsed(input))
@@ -856,7 +856,7 @@ void vtkHyperTreeGridToDualGrid::ShiftDualCornerFromMaskedLeaf3D(
   }     // o3
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf2D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkBitArray* mask, vtkHyperTreeGrid* input)
 {
@@ -1003,7 +1003,7 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf2D(
   vtkIdType id = cursor->GetGlobalNodeIndex();
 
   // Insert dual point at center of leaf cell
-  assert(id < input->GetNumberOfVertices());
+  assert(id < input->GetNumberOfCells());
   this->Points->SetPoint(id, pt);
 
   // If cell is masked, terminate recursion, no dual cell will be generated
@@ -1090,7 +1090,7 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf2D(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf3D(
   vtkHyperTreeGridNonOrientedMooreSuperCursor* cursor, vtkBitArray* mask,
   vtkHyperTreeGrid* vtkNotUsed(input))
@@ -1309,3 +1309,4 @@ void vtkHyperTreeGridToDualGrid::GenerateDualCornerFromLeaf3D(
     } // if ( owner )
   }   // c
 }
+VTK_ABI_NAMESPACE_END
