@@ -1,47 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCollisionDetection.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-  Copyright (c) Goodwin Lawlor All rights reserved.
-  BSD 3-Clause License
-
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
-
-  Redistributions of source code must retain the above copyright notice,
-  this list of conditions and the following disclaimer.
-
-  Redistributions in binary form must reproduce the above copyright
-  notice, this list of conditions and the following disclaimer in the
-  documentation and/or other materials provided with the distribution.
-
-  Neither the name of the copyright holder nor the names of its
-  contributors may be used to endorse or promote products derived from
-  this software without specific prior written permission.
-
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  AS IS AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-=========================================================================*/
-
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Goodwin Lawlor All rights reserved
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkCollisionDetectionFilter.h"
 
 #include "vtkBox.h"
@@ -71,6 +30,7 @@
 #include "vtkTrivialProducer.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCollisionDetectionFilter);
 
 // Constructs with initial 0 values.
@@ -147,7 +107,7 @@ void vtkCollisionDetectionFilter::SetInputData(int idx, vtkPolyData* input)
   this->SetNthInputConnection(idx, 0, input ? inputProducer->GetOutputPort() : nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPolyData* vtkCollisionDetectionFilter::GetInputData(int idx)
 {
   if (2 <= idx || idx < 0)
@@ -168,9 +128,33 @@ vtkIdTypeArray* vtkCollisionDetectionFilter::GetContactCells(int i)
       << " is out of range in GetContactCells. There are only two contact cells arrays!");
     return nullptr;
   }
+  if (!this->GetOutput(i))
+  {
+    vtkErrorMacro(<< "Output " << i << " is null!");
+    return nullptr;
+  }
+  if (!this->GetOutput(i)->GetFieldData()->GetArray("ContactCells"))
+  {
+    vtkErrorMacro(<< "Output " << i << " has null contact cells array!");
+    return nullptr;
+  }
   return vtkIdTypeArray::SafeDownCast(this->GetOutput(i)->GetFieldData()->GetArray("ContactCells"));
 }
 
+int vtkCollisionDetectionFilter::GetNumberOfContacts()
+{
+  if (this->GetOutput(0) && this->GetOutput(0)->GetFieldData()->GetArray("ContactCells"))
+  {
+    return this->GetOutput(0)->GetFieldData()->GetArray("ContactCells")->GetNumberOfTuples();
+  }
+  else
+  {
+    vtkErrorMacro(
+      << "Number of contacts cannot be calculated, nullptr found! Call Update() before.");
+    return -1;
+  }
+}
+
 void vtkCollisionDetectionFilter::SetTransform(int i, vtkLinearTransform* transform)
 {
   if (i > 1 || i < 0)
@@ -374,8 +358,9 @@ static int ComputeCollisions(
           boundsB[5] = ptsB[v + 2];
       }
       // Test for intersection
-      if (self->IntersectPolygonWithPolygon(
-            3, ptsA, boundsA, 3, ptsB, boundsB, Tolerance, x1, x2, self->GetCollisionMode()))
+      if (contactcells1 && contactcells2 &&
+        self->IntersectPolygonWithPolygon(
+          3, ptsA, boundsA, 3, ptsB, boundsB, Tolerance, x1, x2, self->GetCollisionMode()))
       {
         contactcells1->InsertNextValue(cellIdA);
         contactcells2->InsertNextValue(cellIdB);
@@ -470,11 +455,17 @@ int vtkCollisionDetectionFilter::RequestData(vtkInformation* vtkNotUsed(request)
 
   // Allocate arrays for the contact cells lists
   vtkSmartPointer<vtkIdTypeArray> contactcells0 = vtkSmartPointer<vtkIdTypeArray>::New();
-  contactcells0->SetName("ContactCells");
+  if (contactcells0)
+  {
+    contactcells0->SetName("ContactCells");
+  }
   output[0]->GetFieldData()->AddArray(contactcells0);
 
   vtkSmartPointer<vtkIdTypeArray> contactcells1 = vtkSmartPointer<vtkIdTypeArray>::New();
-  contactcells1->SetName("ContactCells");
+  if (contactcells1)
+  {
+    contactcells1->SetName("ContactCells");
+  }
   output[1]->GetFieldData()->AddArray(contactcells1);
 
   // The transformations...
@@ -524,6 +515,10 @@ int vtkCollisionDetectionFilter::RequestData(vtkInformation* vtkNotUsed(request)
 
     for (int idx = 0; idx < 2; idx++)
     {
+      if (this->CheckAbort())
+      {
+        break;
+      }
       vtkUnsignedCharArray* scalars = vtkUnsignedCharArray::New();
       output[idx]->GetCellData()->SetScalars(scalars);
       vtkIdType numCells = input[idx]->GetNumberOfCells();
@@ -569,7 +564,7 @@ int vtkCollisionDetectionFilter::RequestData(vtkInformation* vtkNotUsed(request)
       double* RGBA;
       float RGB[4];
 
-      for (vtkIdType id, i = 0; i < numContacts; i++)
+      for (vtkIdType id, i = 0; i < numContacts && contactcells; i++)
       {
         id = contactcells->GetValue(i);
         RGBA = lut->GetTableValue(i);
@@ -586,6 +581,8 @@ int vtkCollisionDetectionFilter::RequestData(vtkInformation* vtkNotUsed(request)
   }
   this->InvokeEvent(vtkCommand::EndEvent, nullptr);
 
+  this->CheckAbort();
+
   return 1;
 }
 
@@ -772,3 +769,4 @@ void vtkCollisionDetectionFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Matrix 0: " << this->GetMatrix(0) << "\n";
   os << indent << "Matrix 1: " << this->GetMatrix(1) << "\n";
 }
+VTK_ABI_NAMESPACE_END
