@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkIntegrateAttributes.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkIntegrateAttributes.h"
 
 #include "vtkCellData.h"
@@ -35,8 +23,11 @@
 
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkIntegrateAttributes);
 
+vtkCxxSetObjectMacro(vtkIntegrateAttributes, Controller, vtkMultiProcessController);
+
 class vtkIntegrateAttributes::vtkFieldList : public vtkDataSetAttributes::FieldList
 {
   typedef vtkDataSetAttributes::FieldList Superclass;
@@ -63,7 +54,7 @@ protected:
   }
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIntegrateAttributes::vtkIntegrateAttributes()
 {
   this->IntegrationDimension = 0;
@@ -80,35 +71,19 @@ vtkIntegrateAttributes::vtkIntegrateAttributes()
   this->SetController(vtkMultiProcessController::GetGlobalController());
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIntegrateAttributes::~vtkIntegrateAttributes()
 {
   this->SetController(nullptr);
 }
 
-//----------------------------------------------------------------------------
-void vtkIntegrateAttributes::SetController(vtkMultiProcessController* controller)
-{
-  if (this->Controller)
-  {
-    this->Controller->UnRegister(this);
-  }
-
-  this->Controller = controller;
-
-  if (this->Controller)
-  {
-    this->Controller->Register(this);
-  }
-}
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkExecutive* vtkIntegrateAttributes::CreateDefaultExecutive()
 {
   return vtkCompositeDataPipeline::New();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkIntegrateAttributes::FillInputPortInformation(int port, vtkInformation* info)
 {
   if (!this->Superclass::FillInputPortInformation(port, info))
@@ -119,7 +94,7 @@ int vtkIntegrateAttributes::FillInputPortInformation(int port, vtkInformation* i
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkIntegrateAttributes::CompareIntegrationDimension(vtkDataSet* output, int dim)
 {
   // higher dimension prevails
@@ -136,7 +111,7 @@ int vtkIntegrateAttributes::CompareIntegrationDimension(vtkDataSet* output, int
   return (this->IntegrationDimension == dim);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::ExecuteBlock(vtkDataSet* input, vtkUnstructuredGrid* output,
   int fieldset_index, vtkIntegrateAttributes::vtkFieldList& pdList,
   vtkIntegrateAttributes::vtkFieldList& cdList)
@@ -316,7 +291,7 @@ void vtkIntegrateAttributes::ExecuteBlock(vtkDataSet* input, vtkUnstructuredGrid
   this->FieldListIndex = 0;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkIntegrateAttributes::RequestData(
   vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -578,7 +553,7 @@ void vtkIntegrateAttributes::ReceivePiece(vtkUnstructuredGrid* mergeTo, int from
   tmp = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::AllocateAttributes(
   vtkIntegrateAttributes::vtkFieldList& fieldList, vtkDataSetAttributes* outda)
 {
@@ -603,7 +578,7 @@ void vtkIntegrateAttributes::AllocateAttributes(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::ZeroAttributes(vtkDataSetAttributes* outda)
 {
   int numArrays, i, numComponents, j;
@@ -619,7 +594,7 @@ void vtkIntegrateAttributes::ZeroAttributes(vtkDataSetAttributes* outda)
     }
   }
 }
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateData1(vtkDataSetAttributes* inda, vtkDataSetAttributes* outda,
   vtkIdType pt1Id, double k, vtkIntegrateAttributes::vtkFieldList& fieldList, int index)
 {
@@ -643,7 +618,7 @@ void vtkIntegrateAttributes::IntegrateData1(vtkDataSetAttributes* inda, vtkDataS
   fieldList.TransformData(index, inda, outda, f);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateData2(vtkDataSetAttributes* inda, vtkDataSetAttributes* outda,
   vtkIdType pt1Id, vtkIdType pt2Id, double k, vtkIntegrateAttributes::vtkFieldList& fieldList,
   int index)
@@ -669,7 +644,7 @@ void vtkIntegrateAttributes::IntegrateData2(vtkDataSetAttributes* inda, vtkDataS
   fieldList.TransformData(index, inda, outda, f);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Is the extra performance worth duplicating this code with IntergrateData2.
 void vtkIntegrateAttributes::IntegrateData3(vtkDataSetAttributes* inda, vtkDataSetAttributes* outda,
   vtkIdType pt1Id, vtkIdType pt2Id, vtkIdType pt3Id, double k,
@@ -696,7 +671,7 @@ void vtkIntegrateAttributes::IntegrateData3(vtkDataSetAttributes* inda, vtkDataS
   fieldList.TransformData(index, inda, outda, f);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Is the extra performance worth duplicating this code with IntergrateData2.
 void vtkIntegrateAttributes::IntegrateData4(vtkDataSetAttributes* inda, vtkDataSetAttributes* outda,
   vtkIdType pt1Id, vtkIdType pt2Id, vtkIdType pt3Id, vtkIdType pt4Id, double k,
@@ -726,7 +701,7 @@ void vtkIntegrateAttributes::IntegrateData4(vtkDataSetAttributes* inda, vtkDataS
   fieldList.TransformData(index, inda, outda, f);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Used to sum arrays from all processes.
 void vtkIntegrateAttributes::IntegrateSatelliteData(
   vtkDataSetAttributes* sendingProcAttributes, vtkDataSetAttributes* proc0Attributes)
@@ -773,7 +748,7 @@ void vtkIntegrateAttributes::IntegrateSatelliteData(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegratePolyLine(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* ptIds)
 {
@@ -811,7 +786,7 @@ void vtkIntegrateAttributes::IntegratePolyLine(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateGeneral1DCell(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* ptIds)
 {
@@ -858,7 +833,7 @@ void vtkIntegrateAttributes::IntegrateGeneral1DCell(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateTriangleStrip(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* ptIds)
 {
@@ -875,7 +850,7 @@ void vtkIntegrateAttributes::IntegrateTriangleStrip(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Works for convex polygons, and interpoaltion is not correct.
 void vtkIntegrateAttributes::IntegratePolygon(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* ptIds)
@@ -893,7 +868,7 @@ void vtkIntegrateAttributes::IntegratePolygon(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For axis aligned rectangular cells
 void vtkIntegrateAttributes::IntegratePixel(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* cellPtIds)
@@ -935,7 +910,7 @@ void vtkIntegrateAttributes::IntegratePixel(
     this->FieldListIndex);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateTriangle(vtkDataSet* input, vtkUnstructuredGrid* output,
   vtkIdType cellId, vtkIdType pt1Id, vtkIdType pt2Id, vtkIdType pt3Id)
 {
@@ -982,7 +957,7 @@ void vtkIntegrateAttributes::IntegrateTriangle(vtkDataSet* input, vtkUnstructure
     this->FieldListIndex);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateGeneral2DCell(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* ptIds)
 {
@@ -1008,7 +983,7 @@ void vtkIntegrateAttributes::IntegrateGeneral2DCell(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For Tetrahedral cells
 void vtkIntegrateAttributes::IntegrateTetrahedron(vtkDataSet* input, vtkUnstructuredGrid* output,
   vtkIdType cellId, vtkIdType pt1Id, vtkIdType pt2Id, vtkIdType pt3Id, vtkIdType pt4Id)
@@ -1050,7 +1025,7 @@ void vtkIntegrateAttributes::IntegrateTetrahedron(vtkDataSet* input, vtkUnstruct
     *this->PointFieldList, this->FieldListIndex);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For axis aligned hexahedral cells
 void vtkIntegrateAttributes::IntegrateVoxel(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* cellPtIds)
@@ -1117,7 +1092,7 @@ void vtkIntegrateAttributes::IntegrateVoxel(
     v * 0.5, *this->PointFieldList, this->FieldListIndex);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::IntegrateGeneral3DCell(
   vtkDataSet* input, vtkUnstructuredGrid* output, vtkIdType cellId, vtkIdList* ptIds)
 {
@@ -1145,7 +1120,7 @@ void vtkIntegrateAttributes::IntegrateGeneral3DCell(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::DivideDataArraysByConstant(
   vtkDataSetAttributes* data, bool skipLastArray, double sum)
 {
@@ -1163,10 +1138,11 @@ void vtkIntegrateAttributes::DivideDataArraysByConstant(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkIntegrateAttributes::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
   os << indent << "IntegrationDimension: " << this->IntegrationDimension << endl;
 }
+VTK_ABI_NAMESPACE_END
