@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkGenerateGlobalIds.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkGenerateGlobalIds.h"
 
 #include "vtkBoundingBox.h"
@@ -57,9 +46,10 @@
 
 namespace impl
 {
+VTK_ABI_NAMESPACE_BEGIN
 
 static vtkBoundingBox AllReduceBounds(
-  diy::mpi::communicator& comm, std::vector<vtkSmartPointer<vtkPoints> > points)
+  diy::mpi::communicator& comm, std::vector<vtkSmartPointer<vtkPoints>> points)
 {
   vtkBoundingBox bbox;
   for (auto& pts : points)
@@ -75,45 +65,6 @@ static vtkBoundingBox AllReduceBounds(
   return bbox;
 }
 
-class ExplicitAssigner : public ::diy::StaticAssigner
-{
-  std::vector<int> GIDs;
-
-public:
-  ExplicitAssigner(const std::vector<int>& counts)
-    : diy::StaticAssigner(
-        static_cast<int>(counts.size()), std::accumulate(counts.begin(), counts.end(), 0))
-    , GIDs(counts)
-  {
-    for (size_t cc = 1; cc < this->GIDs.size(); ++cc)
-    {
-      this->GIDs[cc] += this->GIDs[cc - 1];
-    }
-  }
-
-  //! returns the process rank of the block with global id gid (need not be local)
-  int rank(int gid) const override
-  {
-    for (size_t cc = 0; cc < this->GIDs.size(); ++cc)
-    {
-      if (gid < this->GIDs[cc])
-      {
-        return static_cast<int>(cc);
-      }
-    }
-    abort();
-  }
-
-  //! gets the local gids for a given process rank
-  void local_gids(int rank, std::vector<int>& gids) const override
-  {
-    const auto min = rank == 0 ? 0 : this->GIDs[rank - 1];
-    const auto max = this->GIDs[rank];
-    gids.resize(max - min);
-    std::iota(gids.begin(), gids.end(), min);
-  }
-};
-
 /**
  * This is the main implementation of the global id generation algorithm.
  * The code is similar for both point and cell ids generation except small
@@ -133,17 +84,20 @@ public:
 template <typename ElementBlockT>
 static bool GenerateIds(vtkDataObject* dobj, vtkGenerateGlobalIds* self, bool cell_centers)
 {
+  const double tolerance = self->GetTolerance();
+
   self->UpdateProgress(0.0);
   diy::mpi::communicator comm = vtkDIYUtilities::GetCommunicator(self->GetController());
 
   vtkLogStartScope(TRACE, "extract points");
-  auto datasets = vtkDIYUtilities::GetDataSets(dobj);
+  auto datasets = vtkCompositeDataSet::GetDataSets(dobj);
   datasets.erase(std::remove_if(datasets.begin(), datasets.end(),
                    [&cell_centers](vtkDataSet* ds) {
                      return ds == nullptr || ds->GetNumberOfPoints() == 0 ||
                        (cell_centers && ds->GetNumberOfCells() == 0);
                    }),
     datasets.end());
+
   const auto points = vtkDIYUtilities::ExtractPoints(datasets, cell_centers);
   vtkLogEndScope("extract points");
 
@@ -167,7 +121,7 @@ static bool GenerateIds(vtkDataObject* dobj, vtkGenerateGlobalIds* self, bool ce
     if (lid < points.size() && points[lid] != nullptr)
     {
       assert(datasets[lid] != nullptr);
-      block->Initialize(gids[lid], points[lid], datasets[lid]);
+      block->Initialize(gids[lid], points[lid], datasets[lid], cell_centers);
     }
 
     auto link = new diy::RegularContinuousLink(3, gdomain, gdomain);
@@ -188,9 +142,9 @@ static bool GenerateIds(vtkDataObject* dobj, vtkGenerateGlobalIds* self, bool ce
 
   vtkLogStartScope(TRACE, "merge-points");
   // iterate over all local blocks to give them unique ids.
-  master.foreach ([](ElementBlockT* b,                         // local block
+  master.foreach ([&tolerance](ElementBlockT* b,               // local block
                     const diy::Master::ProxyWithLink&) -> void // communication proxy
-    { b->MergeElements(); });
+    { b->MergeElements(tolerance); });
   vtkLogEndScope("merge-points");
   self->UpdateProgress(0.75);
 
@@ -205,7 +159,7 @@ static bool GenerateIds(vtkDataObject* dobj, vtkGenerateGlobalIds* self, bool ce
     }
     else
     {
-      // now dequeue owership information and process locally to assign ids
+      // now dequeue ownership information and process locally to assign ids
       // to locally owned points and flag ghost points.
       b->DequeueOwnershipInformation(rp);
     }
@@ -266,11 +220,47 @@ static bool GenerateIds(vtkDataObject* dobj, vtkGenerateGlobalIds* self, bool ce
   self->UpdateProgress(1.0);
   return true;
 }
+VTK_ABI_NAMESPACE_END
 }
 
 namespace
 {
 
+struct CopyHiddenGhostPointsWorker
+{
+  CopyHiddenGhostPointsWorker(
+    vtkUnsignedCharArray* inputGhosts, vtkUnsignedCharArray* outputGhosts, bool cell_centers)
+    : InputGhosts(inputGhosts)
+    , OutputGhosts(outputGhosts)
+  {
+    if (cell_centers)
+    {
+      this->HiddenGhost = vtkDataSetAttributes::HIDDENCELL;
+    }
+    else
+    {
+      this->HiddenGhost = vtkDataSetAttributes::HIDDENPOINT;
+    }
+  }
+
+  void operator()(vtkIdType startId, vtkIdType endId)
+  {
+    auto inputGhostsRange = vtk::DataArrayValueRange<1>(this->InputGhosts);
+    auto outputGhostsRange = vtk::DataArrayValueRange<1>(this->OutputGhosts);
+    for (vtkIdType id = startId; id < endId; ++id)
+    {
+      if (inputGhostsRange[id] & this->HiddenGhost)
+      {
+        outputGhostsRange[id] = inputGhostsRange[id];
+      }
+    }
+  }
+
+  vtkUnsignedCharArray* InputGhosts;
+  vtkUnsignedCharArray* OutputGhosts;
+  unsigned char HiddenGhost;
+};
+
 /**
  * This is the point type that keeps the coordinates for each point in the
  * dataset as well as enough information to track where that point came from so
@@ -317,10 +307,11 @@ struct PointTT
     });
   }
 
-  static std::vector<vtkIdType> GenerateMergeMap(const std::vector<PointTT>& points)
+  static std::vector<vtkIdType> GenerateMergeMap(
+    const std::vector<PointTT>& points, double tolerance)
   {
     std::vector<vtkIdType> mergemap(points.size(), -1);
-    if (points.size() == 0)
+    if (points.empty())
     {
       return mergemap;
     }
@@ -341,8 +332,9 @@ struct PointTT
 
     vtkNew<vtkStaticPointLocator> locator;
     locator->SetDataSet(grid);
+    locator->SetTolerance(tolerance);
     locator->BuildLocator();
-    locator->MergePoints(0.0, &mergemap[0]);
+    locator->MergePoints(tolerance, mergemap.data());
     return mergemap;
   }
 };
@@ -407,10 +399,11 @@ struct CellTT
     });
   }
 
-  static std::vector<vtkIdType> GenerateMergeMap(const std::vector<CellTT>& cells)
+  static std::vector<vtkIdType> GenerateMergeMap(
+    const std::vector<CellTT>& cells, double vtkNotUsed(tolerance))
   {
     std::vector<vtkIdType> mergemap(cells.size(), -1);
-    if (cells.size() == 0)
+    if (cells.empty())
     {
       return mergemap;
     }
@@ -455,18 +448,23 @@ public:
   std::vector<ElementT> Elements;
   std::vector<vtkIdType> MergeMap;
   vtkIdType UniqueElementsCount{ 0 };
-  std::map<int, std::vector<MessageItemTT> > OutMessage;
+  std::map<int, std::vector<MessageItemTT>> OutMessage;
 
   vtkSmartPointer<vtkIdTypeArray> GlobalIds;
   vtkSmartPointer<vtkUnsignedCharArray> GhostArray;
 
-  void Initialize(int self_gid, vtkPoints* points, vtkDataSet* dataset)
+  void Initialize(int self_gid, vtkPoints* points, vtkDataSet* dataset, bool cell_centers)
   {
     this->Dataset = dataset;
     this->Elements = ElementT::GetElements(self_gid, points, dataset);
 
     if (dataset)
     {
+      unsigned char duplicateGhost = vtkDataSetAttributes::DUPLICATEPOINT;
+      if (cell_centers)
+      {
+        duplicateGhost = vtkDataSetAttributes::DUPLICATECELL;
+      }
       this->GlobalIds = vtkSmartPointer<vtkIdTypeArray>::New();
       this->GlobalIds->SetName(
         ElementT::attr_type == vtkDataObject::POINT ? "GlobalPointIds" : "GlobalCellIds");
@@ -477,7 +475,14 @@ public:
       this->GhostArray = vtkSmartPointer<vtkUnsignedCharArray>::New();
       this->GhostArray->SetName(vtkDataSetAttributes::GhostArrayName());
       this->GhostArray->SetNumberOfTuples(points->GetNumberOfPoints());
-      this->GhostArray->FillValue(vtkDataSetAttributes::DUPLICATEPOINT);
+      this->GhostArray->FillValue(duplicateGhost);
+
+      if (vtkUnsignedCharArray* inputGhostPoints =
+            dataset->GetAttributes(ElementT::attr_type)->GetGhostArray())
+      {
+        ::CopyHiddenGhostPointsWorker worker(inputGhostPoints, this->GhostArray, cell_centers);
+        vtkSMPTools::For(0, this->GhostArray->GetNumberOfValues(), worker);
+      }
 
       // we're only adding ghost points, not cells.
       if (ElementT::attr_type == vtkDataObject::POINT)
@@ -487,11 +492,11 @@ public:
     }
   }
 
-  void MergeElements()
+  void MergeElements(double tolerance)
   {
     // sort to make elements on lower gid's the primary elements
     ElementT::Sort(this->Elements);
-    this->MergeMap = ElementT::GenerateMergeMap(this->Elements);
+    this->MergeMap = ElementT::GenerateMergeMap(this->Elements, tolerance);
 
     std::vector<char> needs_replies(this->MergeMap.size());
     for (size_t cc = 0, max = this->MergeMap.size(); cc < max; ++cc)
@@ -520,7 +525,7 @@ public:
   void EnqueueOwnershipInformation(const diy::ReduceProxy& rp) { this->Enqueue(rp); }
   void DequeueOwnershipInformation(const diy::ReduceProxy& rp)
   {
-    std::map<int, std::vector<MessageItemTT> > inmessage;
+    std::map<int, std::vector<MessageItemTT>> inmessage;
     for (int i = 0; i < rp.in_link().size(); ++i)
     {
       const int in_gid = rp.in_link().target(i).gid;
@@ -538,11 +543,17 @@ public:
       return;
     }
 
+    // We will tag any ghost that is not a hidden point in the input ghost array
+    auto ghosts = vtk::DataArrayValueRange<1>(this->GhostArray);
+
     for (const auto& pair : inmessage)
     {
       for (const auto& data : pair.second)
       {
-        this->GhostArray->SetTypedComponent(data.elem_id, 0, 0);
+        if (!(ghosts[data.elem_id] & vtkDataSetAttributes::HIDDENPOINT))
+        {
+          ghosts[data.elem_id] = 0;
+        }
       }
     }
 
@@ -550,7 +561,7 @@ public:
     this->UniqueElementsCount = 0;
     for (vtkIdType cc = 0, max = this->GhostArray->GetNumberOfTuples(); cc < max; ++cc)
     {
-      if (this->GhostArray->GetTypedComponent(cc, 0) == 0)
+      if (ghosts[cc] == 0)
       {
         this->GlobalIds->SetTypedComponent(cc, 0, this->UniqueElementsCount);
         this->UniqueElementsCount++;
@@ -660,7 +671,7 @@ public:
 namespace diy
 {
 template <>
-struct Serialization< ::CellTT>
+struct Serialization<::CellTT>
 {
   static void save(BinaryBuffer& bb, const CellTT& c)
   {
@@ -681,24 +692,27 @@ struct Serialization< ::CellTT>
 };
 }
 
+VTK_ABI_NAMESPACE_BEGIN
+
 vtkStandardNewMacro(vtkGenerateGlobalIds);
 vtkCxxSetObjectMacro(vtkGenerateGlobalIds, Controller, vtkMultiProcessController);
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGenerateGlobalIds::vtkGenerateGlobalIds()
   : Controller(nullptr)
+  , Tolerance(0)
 {
   this->SetNumberOfInputPorts(1);
   this->SetNumberOfOutputPorts(1);
   this->SetController(vtkMultiProcessController::GetGlobalController());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGenerateGlobalIds::~vtkGenerateGlobalIds()
 {
   this->SetController(nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGenerateGlobalIds::RequestData(
   vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -710,7 +724,7 @@ int vtkGenerateGlobalIds::RequestData(
   {
     this->SetProgressShiftScale(0, 0.5);
     vtkLogScopeF(TRACE, "generate global point ids");
-    if (!impl::GenerateIds<BlockT<PointTT> >(outputDO, this, false))
+    if (!impl::GenerateIds<BlockT<PointTT>>(outputDO, this, false))
     {
       this->SetProgressShiftScale(0, 1.0);
       return 0;
@@ -721,7 +735,7 @@ int vtkGenerateGlobalIds::RequestData(
   {
     this->SetProgressShiftScale(0.5, 0.5);
     vtkLogScopeF(TRACE, "generate global cell ids");
-    if (!impl::GenerateIds<BlockT<CellTT> >(outputDO, this, true))
+    if (!impl::GenerateIds<BlockT<CellTT>>(outputDO, this, true))
     {
       this->SetProgressShiftScale(0, 1.0);
       return 0;
@@ -732,9 +746,11 @@ int vtkGenerateGlobalIds::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGenerateGlobalIds::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Controller: " << this->Controller << endl;
+  os << indent << "Tolerance: " << this->Tolerance << endl;
 }
+VTK_ABI_NAMESPACE_END
