@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkPResampleWithDataSet.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkPResampleWithDataSet.h"
 
 #include "vtkArrayDispatch.h"
@@ -20,10 +9,12 @@
 #include "vtkCompositeDataIterator.h"
 #include "vtkCompositeDataProbeFilter.h"
 #include "vtkCompositeDataSet.h"
+#include "vtkCompositeDataSetRange.h"
 #include "vtkDIYUtilities.h"
 #include "vtkDataArrayRange.h"
 #include "vtkDataObject.h"
 #include "vtkDataSet.h"
+#include "vtkHyperTreeGrid.h"
 #include "vtkIdTypeArray.h"
 #include "vtkImageData.h"
 #include "vtkInformation.h"
@@ -49,7 +40,7 @@
 #include <string>
 #include <vector>
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Algorithm of this filter:
 // 1) Compute the bounds of all the blocks of Source.
 // 2) Do an all_gather so that all the nodes know all the bounds.
@@ -66,13 +57,14 @@
 //    and since different Source blocks can have different arrays (Partial Arrays),
 //    it is possible that the points of an output block will have different arrays.
 //    Remove arrays from a block that are not valid for all its points.
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkPResampleWithDataSet);
 
 vtkCxxSetObjectMacro(vtkPResampleWithDataSet, Controller, vtkMultiProcessController);
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPResampleWithDataSet::vtkPResampleWithDataSet()
   : Controller(nullptr)
   , UseBalancedPartitionForPointsLookup(false)
@@ -80,13 +72,13 @@ vtkPResampleWithDataSet::vtkPResampleWithDataSet()
   this->SetController(vtkMultiProcessController::GetGlobalController());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPResampleWithDataSet::~vtkPResampleWithDataSet()
 {
   this->SetController(nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPResampleWithDataSet::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -98,7 +90,7 @@ void vtkPResampleWithDataSet::PrintSelf(ostream& os, vtkIndent indent)
      << (this->UseBalancedPartitionForPointsLookup ? "Balanced" : "Regular") << endl;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPResampleWithDataSet::RequestUpdateExtent(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -118,11 +110,12 @@ int vtkPResampleWithDataSet::RequestUpdateExtent(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
 
 namespace
 {
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 struct Point
 {
   double Position[3];
@@ -130,11 +123,11 @@ struct Point
   int BlockId;
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 class Partition
 {
 public:
-  virtual ~Partition() {}
+  virtual ~Partition() = default;
   virtual void CreatePartition(const std::vector<vtkDataSet*>& blocks) = 0;
   virtual void FindPointsInBounds(const double bounds[6], std::vector<Point>& points) const = 0;
 };
@@ -383,7 +376,7 @@ public:
     // approximate number of nodes in the tree
     vtkIdType splitsSize = totalNumberOfPoints / (NUM_POINTS_PER_BIN / 2);
     this->Splits.resize(splitsSize);
-    this->RecursiveSplit(&this->Nodes[0], &this->Nodes[totalNumberOfPoints], &this->Splits[0],
+    this->RecursiveSplit(this->Nodes.data(), &this->Nodes[totalNumberOfPoints], this->Splits.data(),
       &this->Splits[splitsSize], 0);
   }
 
@@ -402,7 +395,7 @@ public:
 
     vtkIdType numPoints = static_cast<vtkIdType>(this->Nodes.size());
     vtkIdType splitSize = static_cast<vtkIdType>(this->Splits.size());
-    this->RecursiveSearch(bounds, &this->Nodes[0], &this->Nodes[numPoints], &this->Splits[0],
+    this->RecursiveSearch(bounds, this->Nodes.data(), &this->Nodes[numPoints], this->Splits.data(),
       &this->Splits[splitSize], 0, tag, points);
   }
 
@@ -487,7 +480,7 @@ private:
   double Bounds[6];
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Iterate over each dataset in a composite dataset and execute func
 template <typename Functor>
 void ForEachDataSetBlock(vtkDataObject* data, const Functor& func)
@@ -509,6 +502,26 @@ void ForEachDataSetBlock(vtkDataObject* data, const Functor& func)
   }
 }
 
+//------------------------------------------------------------------------------
+// Iterate over each dataobject in a composite dataset and execute func
+template <typename Functor>
+void ForEachDataObjectBlock(vtkDataObject* data, const Functor& func)
+{
+  if (data->IsA("vtkDataSet") || data->IsA("vtkHyperTreeGrid"))
+  {
+    func(data);
+  }
+  else if (data->IsA("vtkCompositeDataSet"))
+  {
+    vtkCompositeDataSet* composite = static_cast<vtkCompositeDataSet*>(data);
+
+    for (auto block : vtk::Range(composite))
+    {
+      func(block);
+    }
+  }
+}
+
 // For each valid block add its bounds to boundsArray
 struct GetBlockBounds
 {
@@ -517,12 +530,18 @@ struct GetBlockBounds
   {
   }
 
-  void operator()(vtkDataSet* block) const
+  void operator()(vtkDataObject* block) const
   {
-    if (block)
+    if (vtkDataSet* dsBlock = vtkDataSet::SafeDownCast(block))
     {
       double bounds[6];
-      block->GetBounds(bounds);
+      dsBlock->GetBounds(bounds);
+      this->BoundsArray->insert(this->BoundsArray->end(), bounds, bounds + 6);
+    }
+    if (vtkHyperTreeGrid* htgBlock = vtkHyperTreeGrid::SafeDownCast(block))
+    {
+      double bounds[6];
+      htgBlock->GetBounds(bounds);
       this->BoundsArray->insert(this->BoundsArray->end(), bounds, bounds + 6);
     }
   }
@@ -542,7 +561,7 @@ struct FlattenCompositeDataset
   std::vector<vtkDataSet*>* Blocks;
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void CopyDataSetStructure(vtkDataObject* input, vtkDataObject* output)
 {
   if (input->IsA("vtkDataSet"))
@@ -574,7 +593,7 @@ void CopyDataSetStructure(vtkDataObject* input, vtkDataObject* output)
 // Find all the neighbors that this rank will need to send to and recv from.
 // Based on the intersection of this rank's input bounds with remote's source
 // bounds.
-void FindNeighbors(diy::mpi::communicator comm, std::vector<std::vector<double> >& sourceBounds,
+void FindNeighbors(diy::mpi::communicator comm, std::vector<std::vector<double>>& sourceBounds,
   std::vector<vtkDataSet*>& inputBlocks, std::vector<int>& neighbors)
 {
   for (int gid = 0; gid < comm.size(); ++gid)
@@ -595,7 +614,7 @@ void FindNeighbors(diy::mpi::communicator comm, std::vector<std::vector<double>
         if (ds)
         {
           const double* ibounds = ds->GetBounds();
-          if ((intersects = (vtkBoundingBox(sbounds).Intersects(ibounds) == 1)) == true)
+          if ((intersects = (vtkBoundingBox(sbounds).Intersects(ibounds) == 1)))
           {
             break;
           }
@@ -609,7 +628,7 @@ void FindNeighbors(diy::mpi::communicator comm, std::vector<std::vector<double>
     }
   }
 
-  std::vector<std::vector<int> > allNbrs;
+  std::vector<std::vector<int>> allNbrs;
   diy::mpi::all_gather(comm, neighbors, allNbrs);
   for (int gid = 0; gid < comm.size(); ++gid)
   {
@@ -627,10 +646,10 @@ void FindNeighbors(diy::mpi::communicator comm, std::vector<std::vector<double>
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 struct DiyBlock
 {
-  std::vector<std::vector<double> > SourceBlocksBounds;
+  std::vector<std::vector<double>> SourceBlocksBounds;
   std::vector<vtkDataSet*> InputBlocks;
   std::vector<vtkDataSet*> OutputBlocks;
   Partition* PointsLookup;
@@ -864,7 +883,7 @@ void PerformResampling(
         cp.enqueue(bid, blockId);
         cp.enqueue(bid, static_cast<vtkIdType>(pointIds.size())); // send valid points only
         cp.enqueue(bid, resPD->GetNumberOfArrays());
-        cp.enqueue(bid, &pointIds[0], pointIds.size());
+        cp.enqueue(bid, pointIds.data(), pointIds.size());
 
         enqueuer.SetMaskArray(masks);
         enqueuer.SetRange(blockBegin, blockEnd);
@@ -987,7 +1006,7 @@ void ReceiveResampledPoints(
   DiyBlock* block, const diy::Master::ProxyWithLink& cp, const char* maskArrayName)
 {
   int numBlocks = static_cast<int>(block->InputBlocks.size());
-  std::vector<std::map<std::string, int> > arrayReceiveCounts(numBlocks);
+  std::vector<std::map<std::string, int>> arrayReceiveCounts(numBlocks);
 
   diy::Master::IncomingQueues& in = *cp.incoming();
   for (diy::Master::IncomingQueues::iterator i = in.begin(); i != in.end(); ++i)
@@ -1012,7 +1031,7 @@ void ReceiveResampledPoints(
       vtkDataSet* ds = block->OutputBlocks[blockId];
 
       pointIds.resize(numberOfPoints);
-      cp.dequeue(i->first, &pointIds[0], numberOfPoints);
+      cp.dequeue(i->first, pointIds.data(), numberOfPoints);
 
       dequeuer.SetPointIds(pointIds);
       for (int j = 0; j < numberOfArrays; ++j)
@@ -1067,7 +1086,8 @@ void ReceiveResampledPoints(
 
 } // anonymous namespace
 
-//---------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
+//------------------------------------------------------------------------------
 int vtkPResampleWithDataSet::RequestData(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -1088,7 +1108,7 @@ int vtkPResampleWithDataSet::RequestData(
   // compute and communicate the bounds of all the source blocks in all the ranks
   vtkDataObject* source = sourceInfo->Get(vtkDataObject::DATA_OBJECT());
   std::vector<double> srcBounds;
-  ForEachDataSetBlock(source, GetBlockBounds(srcBounds));
+  ForEachDataObjectBlock(source, GetBlockBounds(srcBounds));
   diy::mpi::all_gather(comm, srcBounds, block.SourceBlocksBounds);
 
   // copy the input structure to output
@@ -1170,7 +1190,9 @@ int vtkPResampleWithDataSet::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_END
+
+//------------------------------------------------------------------------------
 namespace diy
 {
 
