@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPStreaklineFilter.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkPStreaklineFilter
  * @brief   A Parallel Particle tracer for unsteady vector fields
@@ -31,6 +19,7 @@
 #include "vtkSmartPointer.h"     // For protected ivars.
 #include "vtkStreaklineFilter.h" //for utility
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKFILTERSPARALLELFLOWPATHS_EXPORT vtkPStreaklineFilter : public vtkPParticleTracerBase
 {
 public:
@@ -41,13 +30,14 @@ public:
 
 protected:
   vtkPStreaklineFilter();
-  ~vtkPStreaklineFilter() {}
+  ~vtkPStreaklineFilter() override = default;
   vtkPStreaklineFilter(const vtkPStreaklineFilter&) = delete;
   void operator=(const vtkPStreaklineFilter&) = delete;
-  virtual int OutputParticles(vtkPolyData* poly) override;
-  virtual void Finalize() override;
+  int OutputParticles(vtkPolyData* poly) override;
+  void Finalize() override;
 
   StreaklineFilterInternal It;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
