@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkHierarchicalBinningFilter.cxx
-
-  Copyright (c) Kitware, Inc.
-  All rights reserved.
-  See LICENSE file for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-CLAUSE
 #include "vtkHierarchicalBinningFilter.h"
 
 #include "vtkDoubleArray.h"
@@ -27,14 +15,15 @@
 #include "vtkPoints.h"
 #include "vtkSMPTools.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHierarchicalBinningFilter);
 
 namespace
 {
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Number ^ index: power function for integers.
-static int power(int number, int level)
+int power(int number, int level)
 {
   if (level == 0)
   {
@@ -48,8 +37,8 @@ static int power(int number, int level)
   return number;
 }
 
-//----------------------------------------------------------------------------
-static int GetLevelOffset(int level, int divs[3])
+//------------------------------------------------------------------------------
+int GetLevelOffset(int level, int divs[3])
 {
   int block = divs[0] * divs[1] * divs[2];
   int offset = 0;
@@ -60,7 +49,7 @@ static int GetLevelOffset(int level, int divs[3])
   return offset;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The hierarchy of uniform subdivided binning grids.
 struct UniformBinning
 {
@@ -158,7 +147,7 @@ struct UniformBinning
 
 } // anonymous namespace
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This non-templated class provides virtual functions to simplify the access
 // to the templated subclass. Note this is not in anonymous namespace because the
 // VTK class refers to it in the header file (PIMPLd).
@@ -236,7 +225,6 @@ struct vtkBinTree
   {
     for (level = this->NumLevels - 1; globalBin < this->Tree[level]->LevelOffset; --level)
     {
-      ;
     }
     localBin = globalBin - this->Tree[level]->LevelOffset;
   }
@@ -280,12 +268,12 @@ struct vtkBinTree
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Helper classes to support efficient computing, and threaded execution.
 namespace
 {
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The following tuple is what is sorted in the map. Note that it is templated
 // because depending on the number of points / bins to process we may want
 // to use vtkIdType. Otherwise for performance reasons it's best to use an int
@@ -303,7 +291,7 @@ public:
   bool operator<(const BinTuple& tuple) const { return Bin < tuple.Bin; }
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This templated class manages the creation of the binning tree. It also
 // implements the operator() functors which are supplied to vtkSMPTools for
 // threaded processesing.
@@ -387,7 +375,6 @@ struct BinTree : public vtkBinTree
 
         for (level = numLevels - 1; idx < this->Thresh[level]; --level)
         {
-          ;
         }
         t->Bin = this->Tree->Tree[level]->GetBinIndex(p);
       } // for all points in this batch
@@ -450,7 +437,7 @@ struct BinTree : public vtkBinTree
       {
         for (; curPt->Bin == prevPt->Bin && curPt <= endBatchPt; ++curPt)
         {
-          ; // advance
+          // advance
         }
         // Fill in any gaps in the offset array
         std::fill_n(offsets + prevPt->Bin + 1, curPt->Bin - prevPt->Bin, curPt - this->Tree->Map);
@@ -600,7 +587,7 @@ struct BinTree : public vtkBinTree
     vtkPointData* outPD = output->GetPointData();
     outPD->CopyAllocate(inPD, this->NumPts);
 
-    char* name;
+    const char* name;
     vtkDataArray *iArray, *oArray;
     void *iD, *oD;
     int i, numComp, numArrays = inPD->GetNumberOfArrays();
@@ -688,7 +675,7 @@ struct BinTree : public vtkBinTree
 } // anonymous namespace
 
 //================= Begin VTK class proper =======================================
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHierarchicalBinningFilter::vtkHierarchicalBinningFilter()
 {
 
@@ -702,7 +689,7 @@ vtkHierarchicalBinningFilter::vtkHierarchicalBinningFilter()
   this->Tree = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHierarchicalBinningFilter::~vtkHierarchicalBinningFilter()
 {
   if (this->Tree)
@@ -712,7 +699,7 @@ vtkHierarchicalBinningFilter::~vtkHierarchicalBinningFilter()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Produce the output data
 int vtkHierarchicalBinningFilter::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -785,7 +772,7 @@ int vtkHierarchicalBinningFilter::RequestData(vtkInformation* vtkNotUsed(request
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHierarchicalBinningFilter::GetNumberOfGlobalBins()
 {
   if (this->Tree)
@@ -798,7 +785,7 @@ int vtkHierarchicalBinningFilter::GetNumberOfGlobalBins()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHierarchicalBinningFilter::GetNumberOfBins(int level)
 {
   if (this->Tree)
@@ -811,7 +798,7 @@ int vtkHierarchicalBinningFilter::GetNumberOfBins(int level)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkHierarchicalBinningFilter::GetLevelOffset(int level, vtkIdType& npts)
 {
   if (this->Tree)
@@ -824,7 +811,7 @@ vtkIdType vtkHierarchicalBinningFilter::GetLevelOffset(int level, vtkIdType& npt
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkHierarchicalBinningFilter::GetBinOffset(int globalBin, vtkIdType& npts)
 {
   if (this->Tree)
@@ -837,7 +824,7 @@ vtkIdType vtkHierarchicalBinningFilter::GetBinOffset(int globalBin, vtkIdType& n
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkHierarchicalBinningFilter::GetLocalBinOffset(int level, int localBin, vtkIdType& npts)
 {
   if (this->Tree)
@@ -850,7 +837,7 @@ vtkIdType vtkHierarchicalBinningFilter::GetLocalBinOffset(int level, int localBi
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHierarchicalBinningFilter::GetBinBounds(int globalBin, double bounds[6])
 {
   if (this->Tree)
@@ -863,7 +850,7 @@ void vtkHierarchicalBinningFilter::GetBinBounds(int globalBin, double bounds[6])
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHierarchicalBinningFilter::GetLocalBinBounds(int level, int localBin, double bounds[6])
 {
   if (this->Tree)
@@ -876,14 +863,14 @@ void vtkHierarchicalBinningFilter::GetLocalBinBounds(int level, int localBin, do
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHierarchicalBinningFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPointSet");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHierarchicalBinningFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -900,3 +887,4 @@ void vtkHierarchicalBinningFilter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Divisions: (" << this->Divisions[0] << "," << this->Divisions[1] << ","
      << this->Divisions[2] << ")\n";
 }
+VTK_ABI_NAMESPACE_END
