@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPointCloudFilter.cxx
-
-  Copyright (c) Kitware, Inc.
-  All rights reserved.
-  See LICENSE file for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-CLAUSE
 #include "vtkPointCloudFilter.h"
 
 #include "vtkAbstractPointLocator.h"
@@ -31,12 +19,13 @@
 #include "vtkStaticPointLocator.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Helper classes to support efficient computing, and threaded execution.
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Map input points to output. Basically the third pass of the algorithm.
 struct MapPoints
 {
@@ -64,7 +53,7 @@ struct MapPoints
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Map outlier points to second output. This is an optional pass of the
 // algorithm.
 struct MapOutliers
@@ -97,7 +86,7 @@ struct MapOutliers
 } // anonymous namespace
 
 //================= Begin class proper =======================================
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPointCloudFilter::vtkPointCloudFilter()
 {
   this->PointMap = nullptr;
@@ -109,25 +98,25 @@ vtkPointCloudFilter::vtkPointCloudFilter()
   this->SetNumberOfOutputPorts(2);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPointCloudFilter::~vtkPointCloudFilter()
 {
   delete[] this->PointMap;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const vtkIdType* vtkPointCloudFilter::GetPointMap()
 {
   return this->PointMap;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkPointCloudFilter::GetNumberOfPointsRemoved()
 {
   return this->NumberOfPointsRemoved;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // There are three high level passes. First we traverse all the input points
 // to see how many neighbors each point has within a specified radius, and a
 // map is created indicating whether an input point is to be copied to the
@@ -268,7 +257,7 @@ int vtkPointCloudFilter::RequestData(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPointCloudFilter::GenerateVerticesIfRequested(vtkPolyData* output)
 {
   vtkIdType numPts;
@@ -292,14 +281,14 @@ void vtkPointCloudFilter::GenerateVerticesIfRequested(vtkPolyData* output)
   verts->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPointCloudFilter::FillInputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkPointSet");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPointCloudFilter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -310,3 +299,4 @@ void vtkPointCloudFilter::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Generate Vertices: " << (this->GenerateVertices ? "On\n" : "Off\n");
 }
+VTK_ABI_NAMESPACE_END
