@@ -1,20 +1,9 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-Module:    vtkHyperTreeGridSource.cxx
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkHyperTreeGridSource.h"
 
 #include "vtkBitArray.h"
+#include "vtkCellData.h"
 #include "vtkDataArray.h"
 #include "vtkDoubleArray.h"
 #include "vtkHyperTree.h"
@@ -26,19 +15,19 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkMath.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
-#include "vtkPointData.h"
 #include "vtkQuadric.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
 #include <cassert>
 #include <sstream>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkHyperTreeGridSource);
 vtkCxxSetObjectMacro(vtkHyperTreeGridSource, DescriptorBits, vtkBitArray);
 vtkCxxSetObjectMacro(vtkHyperTreeGridSource, MaskBits, vtkBitArray);
 vtkCxxSetObjectMacro(vtkHyperTreeGridSource, Quadric, vtkQuadric);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHyperTreeGridSource::vtkHyperTreeGridSource()
 {
   // This a source: no input ports
@@ -104,7 +93,7 @@ vtkHyperTreeGridSource::vtkHyperTreeGridSource()
   this->Quadric->SetCoefficients(1., 1., 1., 0., 0., 0., 0., 0., 0., -1.);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkHyperTreeGridSource::~vtkHyperTreeGridSource()
 {
   if (this->XCoordinates)
@@ -158,7 +147,7 @@ vtkHyperTreeGridSource::~vtkHyperTreeGridSource()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -210,7 +199,7 @@ void vtkHyperTreeGridSource::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetDimensions(const unsigned int* dims)
 {
   this->Dimension = 0;
@@ -251,7 +240,7 @@ void vtkHyperTreeGridSource::SetDimensions(const unsigned int* dims)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetDimensions(unsigned int dimx, unsigned int dimy, unsigned int dimz)
 {
   unsigned int dims[3];
@@ -261,19 +250,19 @@ void vtkHyperTreeGridSource::SetDimensions(unsigned int dimx, unsigned int dimy,
   this->SetDimensions(dims);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetIndexingModeToKJI()
 {
   this->SetTransposedRootIndexing(false);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetIndexingModeToIJK()
 {
   this->SetTransposedRootIndexing(true);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetLevelZeroMaterialIndex(vtkIdTypeArray* indexArray)
 {
   if (this->LevelZeroMaterialIndex == indexArray)
@@ -300,32 +289,14 @@ void vtkHyperTreeGridSource::SetLevelZeroMaterialIndex(vtkIdTypeArray* indexArra
   this->Modified();
 }
 
-#ifndef VTK_LEGACY_REMOVE
-//----------------------------------------------------------------------------
-unsigned int vtkHyperTreeGridSource::GetMaximumLevel()
-{
-  VTK_LEGACY_REPLACED_BODY(
-    vtkHyperTreeGridSource::GetMaximumLevel, "VTK 9", vtkHyperTreeGridSource::GetMaxDepth);
-  return this->GetMaxDepth();
-}
-
-//----------------------------------------------------------------------------
-void vtkHyperTreeGridSource::SetMaximumLevel(unsigned int levels)
-{
-  VTK_LEGACY_REPLACED_BODY(
-    vtkHyperTreeGridSource::SetMaximumLevel, "VTK 9", vtkHyperTreeGridSource::SetMaxDepth);
-  this->SetMaxDepth(levels);
-}
-#endif
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkHyperTreeGridSource::GetMaxDepth()
 {
   assert("post: positive_result" && this->MaxDepth >= 1);
   return this->MaxDepth;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetMaxDepth(unsigned int levels)
 {
   if (levels < 1)
@@ -344,14 +315,14 @@ void vtkHyperTreeGridSource::SetMaxDepth(unsigned int levels)
   assert("post: is_set" && this->GetMaxDepth() == levels);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridSource::FillOutputPortInformation(int, vtkInformation* info)
 {
   info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkHyperTreeGrid");
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridSource::RequestInformation(
   vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector)
 {
@@ -382,7 +353,7 @@ int vtkHyperTreeGridSource::RequestInformation(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridSource::RequestData(
   vtkInformation*, vtkInformationVector**, vtkInformationVector* outputVector)
 {
@@ -396,8 +367,13 @@ int vtkHyperTreeGridSource::RequestData(
   }
 
   output->Initialize();
+  if (this->UseMask)
+  {
+    vtkNew<vtkBitArray> mask;
+    output->SetMask(mask);
+  }
 
-  vtkPointData* outData = output->GetPointData();
+  vtkCellData* outData = output->GetCellData();
 
   this->LevelBitsIndexCnt.clear();
   this->LevelBitsIndexCnt.push_back(0);
@@ -577,7 +553,7 @@ int vtkHyperTreeGridSource::RequestData(
   vtkNew<vtkDoubleArray> depthArray;
   depthArray->SetName("Depth");
   depthArray->SetNumberOfComponents(1);
-  outData->SetScalars(depthArray);
+  outData->AddArray(depthArray);
 
   if (this->GenerateInterfaceFields)
   {
@@ -620,7 +596,7 @@ int vtkHyperTreeGridSource::RequestData(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridSource::ProcessTrees(vtkHyperTreeGrid*, vtkDataObject* outputDO)
 {
   // Downcast output data object to hyper tree grid
@@ -684,7 +660,7 @@ int vtkHyperTreeGridSource::ProcessTrees(vtkHyperTreeGrid*, vtkDataObject* outpu
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::InitTreeFromDescriptor(
   vtkHyperTreeGrid* output, vtkHyperTreeGridNonOrientedCursor* cursor, int treeIdx, int idx[3])
 {
@@ -698,7 +674,7 @@ void vtkHyperTreeGridSource::InitTreeFromDescriptor(
     this->SubdivideFromBitsDescriptor(output, cursor, 0, treeIdx, 0, idx, 0);
   }
 }
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridSource::InitializeFromStringDescriptor()
 {
   size_t descLen = strlen(this->Descriptor);
@@ -781,9 +757,9 @@ int vtkHyperTreeGridSource::InitializeFromStringDescriptor()
           // Verify that level descriptor cardinality matches expected value
           if (descriptor.str().size() != nNextLevel)
           {
-            vtkErrorMacro(<< "String level descriptor " << descriptor.str().c_str()
-                          << " has cardinality " << descriptor.str().size()
-                          << " which is not expected value of " << nNextLevel);
+            vtkErrorMacro(<< "String level descriptor " << descriptor.str() << " has cardinality "
+                          << descriptor.str().size() << " which is not expected value of "
+                          << nNextLevel);
 
             return 0;
           }
@@ -842,7 +818,7 @@ int vtkHyperTreeGridSource::InitializeFromStringDescriptor()
   // Verify and append last level string
   if (descriptor.str().size() != nNextLevel)
   {
-    vtkErrorMacro(<< "String level descriptor " << descriptor.str().c_str() << " has cardinality "
+    vtkErrorMacro(<< "String level descriptor " << descriptor.str() << " has cardinality "
                   << descriptor.str().size() << " which is not expected value of " << nNextLevel);
 
     return 0;
@@ -863,7 +839,7 @@ int vtkHyperTreeGridSource::InitializeFromStringDescriptor()
     nNextLevel = nRefined * this->BlockSize;
     if (nRefined > 0)
     {
-      this->LevelDescriptors.emplace_back(std::string('.', nNextLevel));
+      this->LevelDescriptors.emplace_back(nNextLevel, '.');
     }
   }
 
@@ -885,13 +861,13 @@ int vtkHyperTreeGridSource::InitializeFromStringDescriptor()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SubdivideFromStringDescriptor(vtkHyperTreeGrid* output,
   vtkHyperTreeGridNonOrientedCursor* cursor, unsigned int level, int treeIdx, int childIdx,
   int idx[3], int parentPos)
 {
   // Get handle on point data
-  vtkPointData* outData = output->GetPointData();
+  vtkCellData* outData = output->GetCellData();
 
   // Calculate pointer into level descriptor string
   unsigned int pointer = level ? childIdx + parentPos * this->BlockSize : treeIdx;
@@ -1014,12 +990,12 @@ void vtkHyperTreeGridSource::SubdivideFromStringDescriptor(vtkHyperTreeGrid* out
   else if (this->UseMask)
   {
     // Blank leaf if needed
-    bool masked = this->LevelMasks.at(level).at(pointer) == '0' ? 1 : 0;
+    bool masked = this->LevelMasks.at(level).at(pointer) == '0';
     output->GetMask()->InsertTuple1(id, masked);
   } // else if
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkHyperTreeGridSource::InitializeFromBitsDescriptor()
 {
   // Verify that grid and material specifications are consistent
@@ -1054,7 +1030,6 @@ int vtkHyperTreeGridSource::InitializeFromBitsDescriptor()
   this->LevelBitsIndex.clear();
   this->LevelBitsIndex.push_back(0);
   vtkIdType nRefined = 0;
-  vtkIdType nLeaves = 0;
   vtkIdType nNextLevel = nTotal;
   vtkIdType nCurrentLevelCount = 0;
   vtkIdType descSize = this->DescriptorBits->GetNumberOfTuples();
@@ -1066,13 +1041,11 @@ int vtkHyperTreeGridSource::InitializeFromBitsDescriptor()
     {
       nNextLevel = nRefined * this->BlockSize;
       nRefined = 0;
-      nLeaves = 0;
       nCurrentLevelCount = 0;
       ++nCurrentLevel;
       this->LevelBitsIndex.push_back(i);
     }
     nRefined += this->DescriptorBits->GetValue(i);
-    nLeaves += this->DescriptorBits->GetValue(i) == 0 ? 1 : 0;
 
     ++nCurrentLevelCount;
   }
@@ -1101,13 +1074,13 @@ int vtkHyperTreeGridSource::InitializeFromBitsDescriptor()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SubdivideFromBitsDescriptor(vtkHyperTreeGrid* output,
   vtkHyperTreeGridNonOrientedCursor* cursor, unsigned int level, int treeIdx, int childIdx,
   int idx[3], int parentPos)
 {
   // Get handle on point data
-  vtkPointData* outData = output->GetPointData();
+  vtkCellData* outData = output->GetCellData();
 
   vtkIdType startIdx = this->LevelBitsIndex[level];
   int pointer = level ? childIdx + parentPos * this->BlockSize : treeIdx;
@@ -1262,13 +1235,13 @@ void vtkHyperTreeGridSource::SubdivideFromBitsDescriptor(vtkHyperTreeGrid* outpu
   } // else
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SubdivideFromQuadric(vtkHyperTreeGrid* output,
   vtkHyperTreeGridNonOrientedCursor* cursor, unsigned int level, int treeIdx, const int idx[3],
   double origin[3], double size[3])
 {
   // Get handle on point data
-  vtkPointData* outData = output->GetPointData();
+  vtkCellData* outData = output->GetCellData();
 
   // Calculate the node global index
   vtkIdType id = cursor->GetTree()->GetGlobalIndexFromLocal(cursor->GetVertexId());
@@ -1319,7 +1292,7 @@ void vtkHyperTreeGridSource::SubdivideFromQuadric(vtkHyperTreeGrid* output,
   } // v
 
   // Subdivide iff quadric changes sign within cell
-  bool subdivide = (nPos != nVert && nNeg != nVert) ? true : false;
+  bool subdivide = nPos != nVert && nNeg != nVert;
 
   // Assign cell value
   if (subdivide && level + 1 == this->MaxDepth)
@@ -1454,7 +1427,7 @@ void vtkHyperTreeGridSource::SubdivideFromQuadric(vtkHyperTreeGrid* output,
   {
     if (this->UseMask)
     {
-      cursor->SetMask((nPos > 0) ? 1 : 0);
+      cursor->SetMask(nPos > 0);
     }
 
     // Cell values
@@ -1470,7 +1443,7 @@ void vtkHyperTreeGridSource::SubdivideFromQuadric(vtkHyperTreeGrid* output,
   } // else
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::SetQuadricCoefficients(double q[10])
 {
   if (!this->Quadric)
@@ -1481,19 +1454,19 @@ void vtkHyperTreeGridSource::SetQuadricCoefficients(double q[10])
   this->Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkHyperTreeGridSource::GetQuadricCoefficients(double q[10])
 {
   this->Quadric->GetCoefficients(q);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double* vtkHyperTreeGridSource::GetQuadricCoefficients()
 {
   return this->Quadric->GetCoefficients();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMTimeType vtkHyperTreeGridSource::GetMTime()
 {
   vtkMTimeType mTime = this->Superclass::GetMTime();
@@ -1507,7 +1480,7 @@ vtkMTimeType vtkHyperTreeGridSource::GetMTime()
   return mTime;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkBitArray* vtkHyperTreeGridSource::ConvertDescriptorStringToBitArray(const std::string& str)
 {
   vtkBitArray* desc = vtkBitArray::New();
@@ -1546,8 +1519,9 @@ vtkBitArray* vtkHyperTreeGridSource::ConvertDescriptorStringToBitArray(const std
   return desc;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkBitArray* vtkHyperTreeGridSource::ConvertMaskStringToBitArray(const std::string& str)
 {
   return ConvertDescriptorStringToBitArray(str);
 }
+VTK_ABI_NAMESPACE_END
