@@ -1,24 +1,6 @@
-/*=========================================================================
-
-Program:   Visualization Toolkit
-Module:    vtkContingencyStatistics.cxx
-
-Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-All rights reserved.
-See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*-------------------------------------------------------------------------
-  Copyright 2011 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-  the U.S. Government retains certain rights in this software.
-  -------------------------------------------------------------------------*/
-
-#include "vtkToolkits.h"
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2011 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 
 #include "vtkContingencyStatistics.h"
 #include "vtkStatisticsAlgorithmPrivate.h"
@@ -31,7 +13,6 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkLongArray.h"
 #include "vtkMultiBlockDataSet.h"
 #include "vtkObjectFactory.h"
-#include "vtkStdString.h"
 #include "vtkStringArray.h"
 #include "vtkTable.h"
 #include "vtkVariantArray.h"
@@ -41,10 +22,11 @@ PURPOSE.  See the above copyright notice for more information.
 
 #include <sstream>
 
-typedef std::map<vtkStdString, vtkIdType> StringCounts;
+typedef std::map<std::string, vtkIdType> StringCounts;
 typedef std::map<vtkIdType, double> Entropies;
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 template <typename TypeSpec, typename vtkType>
 class BivariateContingenciesAndInformationFunctor : public vtkStatisticsAlgorithm::AssessFunctor
 {
@@ -137,7 +119,7 @@ public:
 
 // Count is separated from the class so that it can be properly specialized
 template <typename TypeSpec>
-void Count(std::map<std::vector<TypeSpec>, std::map<std::vector<TypeSpec>, vtkIdType> >& table,
+void Count(std::map<std::vector<TypeSpec>, std::map<std::vector<TypeSpec>, vtkIdType>>& table,
   vtkAbstractArray* valsX, vtkAbstractArray* valsY)
 {
   vtkDataArray* dataX = vtkArrayDownCast<vtkDataArray>(valsX);
@@ -163,7 +145,7 @@ void Count(std::map<std::vector<TypeSpec>, std::map<std::vector<TypeSpec>, vtkId
   }
 }
 
-void Count(std::map<vtkStdString, std::map<vtkStdString, vtkIdType> >& table,
+void Count(std::map<vtkStdString, std::map<vtkStdString, vtkIdType>>& table,
   vtkAbstractArray* valsX, vtkAbstractArray* valsY)
 {
   vtkIdType nRow = valsX->GetNumberOfTuples();
@@ -173,7 +155,7 @@ void Count(std::map<vtkStdString, std::map<vtkStdString, vtkIdType> >& table,
   }
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename TypeSpec, typename vtkType>
 class ContingencyImpl
 {
@@ -246,7 +228,7 @@ public:
 
     // Calculate marginal counts (marginal PDFs are calculated at storage time to avoid redundant
     // summations)
-    std::map<vtkStdString, std::pair<vtkStdString, vtkStdString> > marginalToPair;
+    std::map<vtkStdString, std::pair<vtkStdString, vtkStdString>> marginalToPair;
 
     marginalCounts.clear();
 
@@ -263,8 +245,8 @@ public:
         return;
       }
 
-      vtkStdString c1 = varX->GetValue(key);
-      vtkStdString c2 = varY->GetValue(key);
+      std::string c1 = varX->GetValue(key);
+      std::string c2 = varY->GetValue(key);
 
       if (marginalToPair.find(c1) == marginalToPair.end())
       {
@@ -346,7 +328,7 @@ public:
 
     marginalPDFs.clear();
 
-    for (typename std::map<vtkStdString, Counts>::iterator sit = marginalCounts.begin();
+    for (typename std::map<std::string, Counts>::iterator sit = marginalCounts.begin();
          sit != marginalCounts.end(); ++sit, ++nBlocks)
     {
       vtkTable* marginalTab = vtkTable::New();
@@ -424,8 +406,8 @@ public:
       vtkIdType key = keys->GetValue(r);
 
       // Get values
-      vtkStdString c1 = varX->GetValue(key);
-      vtkStdString c2 = varY->GetValue(key);
+      std::string c1 = varX->GetValue(key);
+      std::string c2 = varY->GetValue(key);
 
       // Get primary statistics for (c1,c2) pair
       Tuple x(dataX->GetNumberOfComponents());
@@ -558,8 +540,8 @@ public:
   }
 
 private:
-  std::map<vtkStdString, Counts> marginalCounts;
-  std::map<vtkStdString, PDF> marginalPDFs;
+  std::map<std::string, Counts> marginalCounts;
+  std::map<std::string, PDF> marginalPDFs;
 };
 
 template <>
@@ -625,7 +607,7 @@ public:
 
     // Calculate marginal counts (marginal PDFs are calculated at storage time to avoid redundant
     // summations)
-    std::map<vtkStdString, std::pair<vtkStdString, vtkStdString> > marginalToPair;
+    std::map<vtkStdString, std::pair<vtkStdString, vtkStdString>> marginalToPair;
 
     marginalCounts.clear();
 
@@ -642,8 +624,8 @@ public:
         return;
       }
 
-      vtkStdString c1 = varX->GetValue(key);
-      vtkStdString c2 = varY->GetValue(key);
+      std::string c1 = varX->GetValue(key);
+      std::string c2 = varY->GetValue(key);
 
       if (marginalToPair.find(c1) == marginalToPair.end())
       {
@@ -785,8 +767,8 @@ public:
       vtkIdType key = keys->GetValue(r);
 
       // Get values
-      vtkStdString c1 = varX->GetValue(key);
-      vtkStdString c2 = varY->GetValue(key);
+      std::string c1 = varX->GetValue(key);
+      std::string c2 = varY->GetValue(key);
 
       // Get primary statistics for (c1,c2) pair
       Tuple x = dataX->GetValue(r);
@@ -907,7 +889,7 @@ private:
 
 vtkObjectFactoryNewMacro(vtkContingencyStatistics);
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkContingencyStatistics::vtkContingencyStatistics()
 {
   // This engine has 2 primary tables: summary and contingency table
@@ -920,16 +902,16 @@ vtkContingencyStatistics::vtkContingencyStatistics()
   this->AssessNames->SetValue(3, "PMI");
 };
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkContingencyStatistics::~vtkContingencyStatistics() = default;
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::Learn(
   vtkTable* inData, vtkTable* vtkNotUsed(inParameters), vtkMultiBlockDataSet* outMeta)
 {
@@ -951,12 +933,12 @@ void vtkContingencyStatistics::Learn(
   } Specialization;
 
   Specialization specialization = Integer;
-  for (std::set<std::set<vtkStdString> >::const_iterator rit = this->Internals->Requests.begin();
+  for (std::set<std::set<vtkStdString>>::const_iterator rit = this->Internals->Requests.begin();
        rit != this->Internals->Requests.end(); ++rit)
   {
     std::set<vtkStdString>::const_iterator it = rit->begin();
-    vtkStdString colX = *it;
-    if (!inData->GetColumnByName(colX))
+    std::string colX = *it;
+    if (!inData->GetColumnByName(colX.c_str()))
     {
       vtkWarningMacro("InData table does not have a column " << colX << ". Ignoring this pair.");
       continue;
@@ -964,14 +946,14 @@ void vtkContingencyStatistics::Learn(
 
     ++it;
     vtkStdString colY = *it;
-    if (!inData->GetColumnByName(colY))
+    if (!inData->GetColumnByName(colY.c_str()))
     {
       vtkWarningMacro("InData table does not have a column " << colY << ". Ignoring this pair.");
       continue;
     }
 
-    vtkDataArray* dataX = vtkArrayDownCast<vtkDataArray>(inData->GetColumnByName(colX));
-    vtkDataArray* dataY = vtkArrayDownCast<vtkDataArray>(inData->GetColumnByName(colY));
+    vtkDataArray* dataX = vtkArrayDownCast<vtkDataArray>(inData->GetColumnByName(colX.c_str()));
+    vtkDataArray* dataY = vtkArrayDownCast<vtkDataArray>(inData->GetColumnByName(colY.c_str()));
 
     if (dataX == nullptr || dataY == nullptr)
     {
@@ -1052,7 +1034,7 @@ void vtkContingencyStatistics::Learn(
   // normalization: including the cardinality to the other counts can lead to inconsistency, in
   // particular when the input meta table is calculated by something else than the learn mode (e.g.,
   // is specified by the user).
-  vtkStdString zString = vtkStdString("");
+  vtkStdString zString;
   contingencyTab->InsertNextBlankRow();
   contingencyTab->SetValue(0, 0, -1);
   if (specialization == None)
@@ -1068,14 +1050,14 @@ void vtkContingencyStatistics::Learn(
   contingencyTab->SetValue(0, 3, -1);
 
   // Loop over requests
-  for (std::set<std::set<vtkStdString> >::const_iterator rit = this->Internals->Requests.begin();
+  for (std::set<std::set<vtkStdString>>::const_iterator rit = this->Internals->Requests.begin();
        rit != this->Internals->Requests.end(); ++rit)
   {
     // Each request contains only one pair of column of interest (if there are others, they are
     // ignored)
     std::set<vtkStdString>::const_iterator it = rit->begin();
     vtkStdString colX = *it;
-    if (!inData->GetColumnByName(colX))
+    if (!inData->GetColumnByName(colX.c_str()))
     {
       vtkWarningMacro("InData table does not have a column " << colX << ". Ignoring this pair.");
       continue;
@@ -1083,7 +1065,7 @@ void vtkContingencyStatistics::Learn(
 
     ++it;
     vtkStdString colY = *it;
-    if (!inData->GetColumnByName(colY))
+    if (!inData->GetColumnByName(colY.c_str()))
     {
       vtkWarningMacro("InData table does not have a column " << colY << ". Ignoring this pair.");
       continue;
@@ -1096,8 +1078,8 @@ void vtkContingencyStatistics::Learn(
     int summaryRow = summaryTab->GetNumberOfRows();
     summaryTab->InsertNextRow(row2);
 
-    vtkAbstractArray* valsX = inData->GetColumnByName(colX);
-    vtkAbstractArray* valsY = inData->GetColumnByName(colY);
+    vtkAbstractArray* valsX = inData->GetColumnByName(colX.c_str());
+    vtkAbstractArray* valsY = inData->GetColumnByName(colY.c_str());
 
     vtkDataArray* dataX = vtkArrayDownCast<vtkDataArray>(valsX);
     vtkDataArray* dataY = vtkArrayDownCast<vtkDataArray>(valsY);
@@ -1136,7 +1118,7 @@ void vtkContingencyStatistics::Learn(
   row2->Delete();
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::Derive(vtkMultiBlockDataSet* inMeta)
 {
   if (!inMeta || inMeta->GetNumberOfBlocks() < 2)
@@ -1157,17 +1139,17 @@ void vtkContingencyStatistics::Derive(vtkMultiBlockDataSet* inMeta)
   }
 
   int nEntropy = 3;
-  vtkStdString entropyNames[] = { "H(X,Y)", "H(Y|X)", "H(X|Y)" };
+  std::string entropyNames[] = { "H(X,Y)", "H(Y|X)", "H(X|Y)" };
 
   // Create table for derived meta statistics
   vtkIdType nRowSumm = summaryTab->GetNumberOfRows();
   vtkDoubleArray* doubleCol;
   for (int j = 0; j < nEntropy; ++j)
   {
-    if (!summaryTab->GetColumnByName(entropyNames[j]))
+    if (!summaryTab->GetColumnByName(entropyNames[j].c_str()))
     {
       doubleCol = vtkDoubleArray::New();
-      doubleCol->SetName(entropyNames[j]);
+      doubleCol->SetName(entropyNames[j].c_str());
       doubleCol->SetNumberOfTuples(nRowSumm);
       summaryTab->AddColumn(doubleCol);
       doubleCol->Delete();
@@ -1176,15 +1158,15 @@ void vtkContingencyStatistics::Derive(vtkMultiBlockDataSet* inMeta)
 
   // Create columns of derived statistics
   int nDerivedVals = 4;
-  vtkStdString derivedNames[] = { "P", "Py|x", "Px|y", "PMI" };
+  std::string derivedNames[] = { "P", "Py|x", "Px|y", "PMI" };
 
   vtkIdType nRowCont = contingencyTab->GetNumberOfRows();
   for (int j = 0; j < nDerivedVals; ++j)
   {
-    if (!contingencyTab->GetColumnByName(derivedNames[j]))
+    if (!contingencyTab->GetColumnByName(derivedNames[j].c_str()))
     {
       doubleCol = vtkDoubleArray::New();
-      doubleCol->SetName(derivedNames[j]);
+      doubleCol->SetName(derivedNames[j].c_str());
       doubleCol->SetNumberOfTuples(nRowCont);
       contingencyTab->AddColumn(doubleCol);
       doubleCol->Delete();
@@ -1210,7 +1192,7 @@ void vtkContingencyStatistics::Derive(vtkMultiBlockDataSet* inMeta)
   // Fill cardinality row (0) with invalid values for derived statistics
   for (int i = 0; i < nDerivedVals; ++i)
   {
-    contingencyTab->SetValueByName(0, derivedNames[i], -1.);
+    contingencyTab->SetValueByName(0, derivedNames[i].c_str(), -1.);
   }
 
   std::vector<vtkDoubleArray*> derivedCols(nDerivedVals);
@@ -1218,7 +1200,7 @@ void vtkContingencyStatistics::Derive(vtkMultiBlockDataSet* inMeta)
   for (int j = 0; j < nDerivedVals; ++j)
   {
     derivedCols[j] =
-      vtkArrayDownCast<vtkDoubleArray>(contingencyTab->GetColumnByName(derivedNames[j]));
+      vtkArrayDownCast<vtkDoubleArray>(contingencyTab->GetColumnByName(derivedNames[j].c_str()));
 
     if (!derivedCols[j])
     {
@@ -1258,13 +1240,15 @@ void vtkContingencyStatistics::Derive(vtkMultiBlockDataSet* inMeta)
   // Store information entropies
   for (Entropies::iterator eit = entropies[0].begin(); eit != entropies[0].end(); ++eit)
   {
-    summaryTab->SetValueByName(eit->first, entropyNames[0], eit->second);              // H(X,Y)
-    summaryTab->SetValueByName(eit->first, entropyNames[1], entropies[1][eit->first]); // H(Y|X)
-    summaryTab->SetValueByName(eit->first, entropyNames[2], entropies[2][eit->first]); // H(X|Y)
+    summaryTab->SetValueByName(eit->first, entropyNames[0].c_str(), eit->second); // H(X,Y)
+    summaryTab->SetValueByName(
+      eit->first, entropyNames[1].c_str(), entropies[1][eit->first]); // H(Y|X)
+    summaryTab->SetValueByName(
+      eit->first, entropyNames[2].c_str(), entropies[2][eit->first]); // H(X|Y)
   }
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::Assess(
   vtkTable* inData, vtkMultiBlockDataSet* inMeta, vtkTable* outData)
 {
@@ -1293,14 +1277,14 @@ void vtkContingencyStatistics::Assess(
   // Loop over requests
   vtkIdType nRowSumm = summaryTab->GetNumberOfRows();
   vtkIdType nRowData = inData->GetNumberOfRows();
-  for (std::set<std::set<vtkStdString> >::const_iterator rit = this->Internals->Requests.begin();
+  for (std::set<std::set<vtkStdString>>::const_iterator rit = this->Internals->Requests.begin();
        rit != this->Internals->Requests.end(); ++rit)
   {
     // Each request contains only one pair of column of interest (if there are others, they are
     // ignored)
     std::set<vtkStdString>::const_iterator it = rit->begin();
-    vtkStdString varNameX = *it;
-    if (!inData->GetColumnByName(varNameX))
+    std::string varNameX = *it;
+    if (!inData->GetColumnByName(varNameX.c_str()))
     {
       vtkWarningMacro(
         "InData table does not have a column " << varNameX << ". Ignoring this pair.");
@@ -1309,7 +1293,7 @@ void vtkContingencyStatistics::Assess(
 
     ++it;
     vtkStdString varNameY = *it;
-    if (!inData->GetColumnByName(varNameY))
+    if (!inData->GetColumnByName(varNameY.c_str()))
     {
       vtkWarningMacro(
         "InData table does not have a column " << varNameY << ". Ignoring this pair.");
@@ -1339,7 +1323,7 @@ void vtkContingencyStatistics::Assess(
 
     // Store names to be able to use SetValueByName which is faster than SetValue
     vtkIdType nv = this->AssessNames->GetNumberOfValues();
-    std::vector<vtkStdString> names(nv);
+    std::vector<std::string> names(nv);
     int columnOffset = outData->GetNumberOfColumns();
     for (vtkIdType v = 0; v < nv; ++v)
     {
@@ -1349,7 +1333,7 @@ void vtkContingencyStatistics::Assess(
       names[v] = assessColName.str();
 
       vtkDoubleArray* assessValues = vtkDoubleArray::New();
-      assessValues->SetName(names[v]);
+      assessValues->SetName(names[v].c_str());
       assessValues->SetNumberOfTuples(nRowData);
       outData->AddColumn(assessValues);
       assessValues->Delete();
@@ -1388,7 +1372,7 @@ void vtkContingencyStatistics::Assess(
   }                     // rit
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::CalculatePValues(vtkTable* testTab)
 {
   vtkIdTypeArray* dimCol = vtkArrayDownCast<vtkIdTypeArray>(testTab->GetColumn(0));
@@ -1419,7 +1403,7 @@ void vtkContingencyStatistics::CalculatePValues(vtkTable* testTab)
   testChi2yCol->Delete();
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::Test(
   vtkTable* inData, vtkMultiBlockDataSet* inMeta, vtkTable* outMeta)
 {
@@ -1484,14 +1468,14 @@ void vtkContingencyStatistics::Test(
   // Loop over requests
   vtkIdType nRowSumm = summaryTab->GetNumberOfRows();
   vtkIdType nRowCont = contingencyTab->GetNumberOfRows();
-  for (std::set<std::set<vtkStdString> >::const_iterator rit = this->Internals->Requests.begin();
+  for (std::set<std::set<vtkStdString>>::const_iterator rit = this->Internals->Requests.begin();
        rit != this->Internals->Requests.end(); ++rit)
   {
     // Each request contains only one pair of column of interest (if there are others, they are
     // ignored)
     std::set<vtkStdString>::const_iterator it = rit->begin();
-    vtkStdString varNameX = *it;
-    if (!inData->GetColumnByName(varNameX))
+    std::string varNameX = *it;
+    if (!inData->GetColumnByName(varNameX.c_str()))
     {
       vtkWarningMacro(
         "InData table does not have a column " << varNameX << ". Ignoring this pair.");
@@ -1500,7 +1484,7 @@ void vtkContingencyStatistics::Test(
 
     ++it;
     vtkStdString varNameY = *it;
-    if (!inData->GetColumnByName(varNameY))
+    if (!inData->GetColumnByName(varNameY.c_str()))
     {
       vtkWarningMacro(
         "InData table does not have a column " << varNameY << ". Ignoring this pair.");
@@ -1530,8 +1514,8 @@ void vtkContingencyStatistics::Test(
     vtkIdType sumij = 0;
 
     // Loop over parameters table until the requested variables are found
-    std::map<vtkStdString, StringCounts> oij;
-    vtkStdString x, y;
+    std::map<std::string, StringCounts> oij;
+    std::string x, y;
     vtkIdType key, c;
     for (int r = 1; r < nRowCont; ++r) // Skip first row which contains data set cardinality
     {
@@ -1568,13 +1552,13 @@ void vtkContingencyStatistics::Test(
     {
       const char* name = inMeta->GetMetaData(b)->Get(vtkCompositeDataSet::NAME());
       int foundIndex = -1;
-      if (!strcmp(name, varNameX))
+      if (name == varNameX)
       {
         // Found the marginal count of X
         foundIndex = 0;
         ++foundCount;
       }
-      else if (!strcmp(name, varNameY))
+      else if (name == varNameY)
       {
         // Found the marginal count of Y
         foundIndex = 1;
@@ -1670,7 +1654,7 @@ void vtkContingencyStatistics::Test(
   testTab->Delete();
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::SelectAssessFunctor(vtkTable* vtkNotUsed(outData),
   vtkDataObject* vtkNotUsed(inMetaDO), vtkStringArray* vtkNotUsed(rowNames),
   AssessFunctor*& vtkNotUsed(dfunc))
@@ -1679,7 +1663,7 @@ void vtkContingencyStatistics::SelectAssessFunctor(vtkTable* vtkNotUsed(outData)
   // for the passing of necessary parameters.
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContingencyStatistics::SelectAssessFunctor(vtkTable* outData, vtkMultiBlockDataSet* inMeta,
   vtkIdType pairKey, vtkStringArray* rowNames, AssessFunctor*& dfunc)
 {
@@ -1690,12 +1674,12 @@ void vtkContingencyStatistics::SelectAssessFunctor(vtkTable* outData, vtkMultiBl
     return;
   }
 
-  vtkStdString varNameX = rowNames->GetValue(0);
-  vtkStdString varNameY = rowNames->GetValue(1);
+  std::string varNameX = rowNames->GetValue(0);
+  std::string varNameY = rowNames->GetValue(1);
 
   // Grab the data for the requested variables
-  vtkAbstractArray* valsX = outData->GetColumnByName(varNameX);
-  vtkAbstractArray* valsY = outData->GetColumnByName(varNameY);
+  vtkAbstractArray* valsX = outData->GetColumnByName(varNameX.c_str());
+  vtkAbstractArray* valsY = outData->GetColumnByName(varNameY.c_str());
   if (!valsX || !valsY)
   {
     return;
@@ -1728,3 +1712,4 @@ void vtkContingencyStatistics::SelectAssessFunctor(vtkTable* outData, vtkMultiBl
       "Incorrect CDF for column pair:" << varNameX << "," << varNameY << "). Ignoring it.");
   }
 }
+VTK_ABI_NAMESPACE_END
