@@ -1,22 +1,11 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkFlashReaderInternal.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkAMRFlashReaderInternal.h"
 
 #include <vector>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 void vtkFlashReaderInternal::GetBlockAttribute(
   const char* attribute, int blockIdx, vtkDataSet* pDataSet)
 {
@@ -154,7 +143,7 @@ void vtkFlashReaderInternal::GetBlockAttribute(
   arrayPtr = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::Init()
 {
   this->FileName = nullptr;
@@ -189,7 +178,7 @@ void vtkFlashReaderInternal::Init()
   this->ParticleAttributeNamesToIds.clear();
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkFlashReaderInternal::GetCycle()
 {
   const bool bTmCycle = true;
@@ -207,7 +196,7 @@ int vtkFlashReaderInternal::GetCycle()
   return this->SimulationParameters.NumberOfTimeSteps;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkFlashReaderInternal::GetTime()
 {
   const bool bTmCycle = true;
@@ -225,7 +214,7 @@ double vtkFlashReaderInternal::GetTime()
   return this->SimulationParameters.Time;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadMetaData()
 {
   if (this->FileIndex >= 0)
@@ -275,7 +264,7 @@ void vtkFlashReaderInternal::ReadMetaData()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadProcessorIds()
 {
   hid_t rootIndx = H5Gopen(this->FileIndex, "/");
@@ -366,7 +355,7 @@ void vtkFlashReaderInternal::ReadProcessorIds()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadDoubleScalars(hid_t fileIndx)
 {
   // Should only be used for FLASH3 files
@@ -424,7 +413,7 @@ void vtkFlashReaderInternal::ReadDoubleScalars(hid_t fileIndx)
   H5Dclose(realScalarsId);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadIntegerScalars(hid_t fileIndx)
 {
   // Should only be used for FLASH3 files
@@ -496,7 +485,7 @@ void vtkFlashReaderInternal::ReadIntegerScalars(hid_t fileIndx)
   H5Dclose(intScalarsId);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadVersionInformation(hid_t fileIndx)
 {
   // temporarily disable error reporting
@@ -596,7 +585,7 @@ void vtkFlashReaderInternal::ReadVersionInformation(hid_t fileIndx)
   old_clientdata = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadSimulationParameters(hid_t fileIndx, bool bTmCycle)
 {
   if (this->FileFormatVersion < FLASH_READER_FLASH3_FFV8)
@@ -684,7 +673,7 @@ void vtkFlashReaderInternal::ReadSimulationParameters(hid_t fileIndx, bool bTmCy
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::GetBlockMinMaxGlobalDivisionIds()
 {
   double problemsize[3] = { this->MaxBounds[0] - this->MinBounds[0],
@@ -692,7 +681,7 @@ void vtkFlashReaderInternal::GetBlockMinMaxGlobalDivisionIds()
 
   for (int b = 0; b < this->NumberOfBlocks; b++)
   {
-    Block& B = this->Blocks[b];
+    FlashReaderBlock& B = this->Blocks[b];
 
     for (int d = 0; d < 3; d++)
     {
@@ -715,7 +704,7 @@ void vtkFlashReaderInternal::GetBlockMinMaxGlobalDivisionIds()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadBlockTypes()
 {
   // Read the node type description for the blocks
@@ -762,7 +751,7 @@ void vtkFlashReaderInternal::ReadBlockTypes()
   H5Dclose(nodetypeId);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadBlockBounds()
 {
   // Read the bounding box description for the blocks
@@ -918,7 +907,7 @@ void vtkFlashReaderInternal::ReadBlockBounds()
   H5Dclose(bboxId);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadBlockCenters()
 {
   // Read the coordinates description for the blocks
@@ -1004,7 +993,7 @@ void vtkFlashReaderInternal::ReadBlockCenters()
   H5Dclose(coordinatesId);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadBlockStructures()
 {
   // temporarily disable error reporting
@@ -1109,7 +1098,7 @@ void vtkFlashReaderInternal::ReadBlockStructures()
   H5Dclose(gidId);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadRefinementLevels()
 {
   // Read the bounding box description for the blocks
@@ -1155,7 +1144,7 @@ void vtkFlashReaderInternal::ReadRefinementLevels()
   H5Dclose(refinementId);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadDataAttributeNames()
 {
   hid_t unknownsId = H5Dopen(this->FileIndex, "unknown names");
@@ -1201,7 +1190,7 @@ void vtkFlashReaderInternal::ReadDataAttributeNames()
   H5Dclose(unknownsId);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadParticlesComponent(
   hid_t dataIndx, const char* compName, double* dataBuff)
 {
@@ -1226,7 +1215,7 @@ void vtkFlashReaderInternal::ReadParticlesComponent(
   H5Sclose(spaceMem);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadParticleAttributes()
 {
   // temporarily disable error reporting
@@ -1276,19 +1265,19 @@ void vtkFlashReaderInternal::ReadParticleAttributes()
     hid_t member_type = H5Tget_native_type(member_raw_type, H5T_DIR_ASCEND);
     int index = (int)(this->ParticleAttributeTypes.size());
 
-    if (strcmp(member_name, "particle_x") && strcmp(member_name, "particle_y") &&
-      strcmp(member_name, "particle_z"))
+    if (strcmp(member_name, "particle_x") != 0 && strcmp(member_name, "particle_y") != 0 &&
+      strcmp(member_name, "particle_z") != 0)
     {
       if (H5Tequal(member_type, H5T_NATIVE_DOUBLE) > 0)
       {
         this->ParticleAttributeTypes.push_back(H5T_NATIVE_DOUBLE);
-        this->ParticleAttributeNames.push_back(member_name);
+        this->ParticleAttributeNames.emplace_back(member_name);
         this->ParticleAttributeNamesToIds[nice_name] = index;
       }
       else if (H5Tequal(member_type, H5T_NATIVE_INT) > 0)
       {
         this->ParticleAttributeTypes.push_back(H5T_NATIVE_INT);
-        this->ParticleAttributeNames.push_back(member_name);
+        this->ParticleAttributeNames.emplace_back(member_name);
         this->ParticleAttributeNamesToIds[nice_name] = index;
       }
       else
@@ -1328,7 +1317,7 @@ void vtkFlashReaderInternal::ReadParticleAttributes()
   H5Dclose(pointId);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFlashReaderInternal::ReadParticleAttributesFLASH3()
 {
   // Should only be used for FLASH3 files
@@ -1469,3 +1458,4 @@ void vtkFlashReaderInternal::ReadParticleAttributesFLASH3()
   H5Sclose(pointSpaceId);
   H5Dclose(pointId);
 }
+VTK_ABI_NAMESPACE_END
