@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkEnSightReader.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkEnSightReader.h"
 
 #include "vtkDataArrayCollection.h"
@@ -34,13 +22,14 @@
 #include <string>
 #include <vector>
 
-//----------------------------------------------------------------------------
-typedef std::vector<vtkSmartPointer<vtkIdList> > vtkEnSightReaderCellIdsTypeBase;
+//------------------------------------------------------------------------------
+typedef std::vector<vtkSmartPointer<vtkIdList>> vtkEnSightReaderCellIdsTypeBase;
+VTK_ABI_NAMESPACE_BEGIN
 class vtkEnSightReaderCellIdsType : public vtkEnSightReaderCellIdsTypeBase
 {
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkEnSightReader::vtkEnSightReader()
 {
   this->MeasuredFileName = nullptr;
@@ -93,7 +82,7 @@ vtkEnSightReader::vtkEnSightReader()
   this->NumberOfNewOutputs = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkEnSightReader::~vtkEnSightReader()
 {
   int i;
@@ -160,14 +149,14 @@ vtkEnSightReader::~vtkEnSightReader()
   this->ActualTimeValue = 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::ClearForNewCaseFileName()
 {
   this->UnstructuredPartIds->Reset();
   vtkGenericEnSightReader::ClearForNewCaseFileName();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
@@ -251,7 +240,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             filenameNum = filenameNumbers->GetId(timeStep - 1);
             if (!this->UseFileSets)
             {
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -285,7 +274,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             {
               filenameNumbers = this->FileSetFileNameNumbers->GetItem(collectionNum);
               filenameNum = filenameNumbers->GetId(fileNum - 1);
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -334,7 +323,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             filenameNum = filenameNumbers->GetId(timeStep - 1);
             if (!this->UseFileSets)
             {
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -368,7 +357,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
             {
               filenameNumbers = this->FileSetFileNameNumbers->GetItem(fileSet);
               filenameNum = filenameNumbers->GetId(fileNum - 1);
-              this->ReplaceWildcards(fileName, filenameNum);
+              vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
             }
           }
         }
@@ -395,7 +384,7 @@ int vtkEnSightReader::RequestData(vtkInformation* vtkNotUsed(request),
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::RequestInformation(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
@@ -430,7 +419,7 @@ int vtkEnSightReader::RequestInformation(vtkInformation* vtkNotUsed(request),
     {
       vtkInformation* outInfo = outputVector->GetInformationObject(0);
       outInfo->Set(
-        vtkStreamingDemandDrivenPipeline::TIME_STEPS(), &uniqueTimeValues[0], numTimeValues);
+        vtkStreamingDemandDrivenPipeline::TIME_STEPS(), uniqueTimeValues.data(), numTimeValues);
       double timeRange[2];
       timeRange[0] = uniqueTimeValues[0];
       timeRange[1] = uniqueTimeValues[numTimeValues - 1];
@@ -440,7 +429,25 @@ int vtkEnSightReader::RequestInformation(vtkInformation* vtkNotUsed(request),
   return this->CaseFileRead;
 }
 
-//----------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
+int vtkEnSightReader::ReadCaseFileScripts(char* line)
+{
+  /* The scripts variable is a new area of the EnSight Gold Format which is used
+  to reference an eventual metadata xml file for handling units. The function
+  just skips it.*/
+  int lineRead = this->ReadNextDataLine(line);
+  while (lineRead)
+  {
+    if (strncmp(line, "metadata:", 9) == 0)
+    {
+      vtkDebugMacro("Skipping metadata");
+    }
+    lineRead = this->ReadNextDataLine(line);
+  }
+  return lineRead;
+}
+
+//------------------------------------------------------------------------------
 int vtkEnSightReader::ReadCaseFileGeometry(char* line)
 {
   char subLine[256];
@@ -455,20 +462,20 @@ int vtkEnSightReader::ReadCaseFileGeometry(char* line)
   {
     if (strncmp(line, "model:", 6) == 0)
     {
-      if (sscanf(line, " %*s %d%*[ \t]%d%*[ \t]%s", &timeSet, &fileSet, subLine) == 3)
+      if (sscanf(line, " %*s %d%*[ \t]%d%*[ \t]%[^\t\r\n]", &timeSet, &fileSet, subLine) == 3)
       {
         this->GeometryTimeSet = timeSet;
         this->GeometryFileSet = fileSet;
         this->SetGeometryFileName(subLine);
         vtkDebugMacro(<< this->GetGeometryFileName());
       }
-      else if (sscanf(line, " %*s %d%*[ \t]%s", &timeSet, subLine) == 2)
+      else if (sscanf(line, " %*s %d%*[ \t]%[^\t\r\n]", &timeSet, subLine) == 2)
       {
         this->GeometryTimeSet = timeSet;
         this->SetGeometryFileName(subLine);
         vtkDebugMacro(<< this->GetGeometryFileName());
       }
-      else if (sscanf(line, " %*s %s", subLine) == 1)
+      else if (sscanf(line, " %*s %[^\t\r\n]", subLine) == 1)
       {
         this->SetGeometryFileName(subLine);
         vtkDebugMacro(<< this->GetGeometryFileName());
@@ -476,20 +483,20 @@ int vtkEnSightReader::ReadCaseFileGeometry(char* line)
     }
     else if (strncmp(line, "measured:", 9) == 0)
     {
-      if (sscanf(line, " %*s %d%*[ \t]%d%*[ \t]%s", &timeSet, &fileSet, subLine) == 3)
+      if (sscanf(line, " %*s %d%*[ \t]%d%*[ \t]%[^\t\r\n]", &timeSet, &fileSet, subLine) == 3)
       {
         this->MeasuredTimeSet = timeSet;
         this->MeasuredFileSet = fileSet;
         this->SetMeasuredFileName(subLine);
         vtkDebugMacro(<< this->GetMeasuredFileName());
       }
-      else if (sscanf(line, " %*s %d%*[ \t]%s", &timeSet, subLine) == 2)
+      else if (sscanf(line, " %*s %d%*[ \t]%[^\t\r\n]", &timeSet, subLine) == 2)
       {
         this->MeasuredTimeSet = timeSet;
         this->SetMeasuredFileName(subLine);
         vtkDebugMacro(<< this->GetMeasuredFileName());
       }
-      else if (sscanf(line, " %*s %s", subLine) == 1)
+      else if (sscanf(line, " %*s %[^\t\r\n]", subLine) == 1)
       {
         this->SetMeasuredFileName(subLine);
         vtkDebugMacro(<< this->GetMeasuredFileName());
@@ -497,7 +504,7 @@ int vtkEnSightReader::ReadCaseFileGeometry(char* line)
     }
     else if (strncmp(line, "match:", 6) == 0)
     {
-      sscanf(line, " %*s %s", subLine);
+      sscanf(line, " %*s %[^\t\r\n]", subLine);
       this->SetMatchFileName(subLine);
       vtkDebugMacro(<< this->GetMatchFileName());
     }
@@ -508,7 +515,7 @@ int vtkEnSightReader::ReadCaseFileGeometry(char* line)
   return lineRead;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::ReadCaseFileVariable(char* line)
 {
   char subLine[256], subLine2[256];
@@ -516,9 +523,11 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
 
   this->NumberOfScalarsPerNode = 0;
   this->NumberOfVectorsPerNode = 0;
+  this->NumberOfTensorsAsymPerNode = 0;
   this->NumberOfTensorsSymmPerNode = 0;
   this->NumberOfScalarsPerElement = 0;
   this->NumberOfVectorsPerElement = 0;
+  this->NumberOfTensorsAsymPerElement = 0;
   this->NumberOfTensorsSymmPerElement = 0;
   this->NumberOfScalarsPerMeasuredNode = 0;
   this->NumberOfVectorsPerMeasuredNode = 0;
@@ -530,7 +539,7 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
   lineRead = this->ReadNextDataLine(line);
   while (lineRead && strncmp(line, "FORMAT", 6) != 0 && strncmp(line, "GEOMETRY", 8) != 0 &&
     strncmp(line, "VARIABLE", 8) != 0 && strncmp(line, "TIME", 4) != 0 &&
-    strncmp(line, "FILE", 4) != 0)
+    strncmp(line, "FILE", 4) != 0 && strncmp(line, "SCRIPTS", 7) != 0)
   {
     if (strncmp(line, "constant", 8) == 0)
     {
@@ -548,19 +557,19 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
         this->NumberOfScalarsPerNode++;
@@ -574,19 +583,19 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
         this->NumberOfScalarsPerElement++;
@@ -600,19 +609,19 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
         this->NumberOfScalarsPerMeasuredNode++;
@@ -632,19 +641,19 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
         this->NumberOfVectorsPerNode++;
@@ -658,19 +667,19 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
         this->NumberOfVectorsPerElement++;
@@ -684,19 +693,19 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
         this->NumberOfVectorsPerMeasuredNode++;
@@ -713,11 +722,12 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
       // Let handle this case here:
       char symm[10];
       char per[10];
+      bool asym = false;
       if (sscanf(line, " %*s %s %s %s", symm, per, subLine) != 3)
       {
         vtkErrorMacro("Error while reading: " << line);
       }
-      if (!(strcmp(symm, "symm") == 0 && strcmp(per, "per") == 0))
+      if (!((strcmp(symm, "symm") == 0 || strcmp(symm, "asym") == 0) && strcmp(per, "per") == 0))
       {
         if (sscanf(line, " %*s %s %s", per, subLine) != 2)
         {
@@ -726,64 +736,85 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
         if (strcmp(per, "per") == 0)
         {
           // Not valid file but seems alright, only 'symm' is missing
-          vtkWarningMacro("Looks almost like a valid case file, continuing");
+          vtkWarningMacro(
+            "Looks almost like a valid case file, continuing assuming a symmetric tensor");
         }
         else
         {
           vtkErrorMacro("Trouble reading: " << line);
         }
       }
+      if (strcmp(symm, "asym") == 0)
+      {
+        asym = true;
+      }
       if (strcmp(subLine, "node:") == 0)
       {
         vtkDebugMacro("tensor symm per node");
-        this->VariableMode = vtkEnSightReader::TENSOR_SYMM_PER_NODE;
+        this->VariableMode =
+          asym ? vtkEnSightReader::TENSOR_ASYM_PER_NODE : vtkEnSightReader::TENSOR_SYMM_PER_NODE;
         if (sscanf(line, " %*s %*s %*s %*s %d %d %s", &timeSet, &fileSet, subLine) == 3)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
-        this->NumberOfTensorsSymmPerNode++;
+        if (asym)
+        {
+          this->NumberOfTensorsAsymPerNode++;
+        }
+        else
+        {
+          this->NumberOfTensorsSymmPerNode++;
+        }
       }
       else if (strcmp(subLine, "element:") == 0)
       {
         vtkDebugMacro("tensor symm per element");
-        this->VariableMode = vtkEnSightReader::TENSOR_SYMM_PER_ELEMENT;
+        this->VariableMode = asym ? vtkEnSightReader::TENSOR_ASYM_PER_ELEMENT
+                                  : vtkEnSightReader::TENSOR_SYMM_PER_ELEMENT;
         if (sscanf(line, " %*s %*s %*s %*s %d %d %s", &timeSet, &fileSet, subLine) == 3)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->VariableFileSetIds->InsertNextId(fileSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %d %s", &timeSet, subLine) == 2)
         {
           this->VariableTimeSetIds->InsertNextId(timeSet);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*d %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*d %*s %[^\t\r\n]", subLine);
         }
         else if (sscanf(line, " %*s %*s %*s %*s %s", subLine) == 1)
         {
           this->VariableTimeSetIds->InsertNextId(1);
           this->AddVariableDescription(subLine);
-          sscanf(line, " %*s %*s %*s %*s %*s %s", subLine);
+          sscanf(line, " %*s %*s %*s %*s %*s %[^\t\r\n]", subLine);
         }
         this->AddVariableType();
-        this->NumberOfTensorsSymmPerElement++;
+        if (asym)
+        {
+          this->NumberOfTensorsAsymPerElement++;
+        }
+        else
+        {
+          this->NumberOfTensorsSymmPerElement++;
+        }
       }
       else
       {
@@ -925,7 +956,7 @@ int vtkEnSightReader::ReadCaseFileVariable(char* line)
   return lineRead;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::ReadCaseFileTime(char* line)
 {
   char formatLine[256];
@@ -973,7 +1004,7 @@ int vtkEnSightReader::ReadCaseFileTime(char* line)
     // --- to obtain a sequence of filenameNum(s) which might span multiple lines
     if (this->ReadNextDataLine(line) == 0)
     {
-      vtkErrorMacro("Error with vtkEnSightReader: 'filename ......' not found!!!");
+      vtkErrorMacro("Error with vtkEnSightReader: 'filename ......' entry not found!!!");
       return 0;
     }
 
@@ -1195,7 +1226,7 @@ int vtkEnSightReader::ReadCaseFileTime(char* line)
   return lineRead;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::ReadCaseFileFile(char* line)
 {
   int fileSet, numTimeSteps, filenameNum, lineRead;
@@ -1241,7 +1272,7 @@ int vtkEnSightReader::ReadCaseFileFile(char* line)
   return lineRead;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::ReadCaseFile()
 {
   char line[256];
@@ -1267,7 +1298,7 @@ int vtkEnSightReader::ReadCaseFile()
       sfilename += "/";
     }
     sfilename += this->CaseFileName;
-    vtkDebugMacro("full path to case file: " << sfilename.c_str());
+    vtkDebugMacro("full path to case file: " << sfilename);
   }
   else
   {
@@ -1277,7 +1308,7 @@ int vtkEnSightReader::ReadCaseFile()
   this->IS = new vtksys::ifstream(sfilename.c_str(), ios::in);
   if (this->IS->fail())
   {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
+    vtkErrorMacro("Unable to open file: " << sfilename);
     delete this->IS;
     this->IS = nullptr;
     return 0;
@@ -1388,6 +1419,12 @@ int vtkEnSightReader::ReadCaseFile()
       vtkDebugMacro(<< "*** FILE section");
       ret = this->ReadCaseFileFile(line);
     }
+    else if (strncmp(line, "SCRIPTS", 7) == 0)
+    {
+      // found SCRIPTS section
+      vtkDebugMacro(<< "*** SCRIPTS section");
+      ret = this->ReadCaseFileScripts(line);
+    }
   }
 
   delete this->IS;
@@ -1400,7 +1437,7 @@ int vtkEnSightReader::ReadCaseFile()
   //  return ret;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
 {
   int i, j;
@@ -1419,6 +1456,7 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
     {
       case SCALAR_PER_NODE:
       case VECTOR_PER_NODE:
+      case TENSOR_ASYM_PER_NODE:
       case TENSOR_SYMM_PER_NODE:
       case SCALAR_PER_MEASURED_NODE:
       case VECTOR_PER_MEASURED_NODE:
@@ -1429,6 +1467,7 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
         break;
       case SCALAR_PER_ELEMENT:
       case VECTOR_PER_ELEMENT:
+      case TENSOR_ASYM_PER_ELEMENT:
       case TENSOR_SYMM_PER_ELEMENT:
         if (!this->GetCellArrayStatus(this->VariableDescriptions[i]))
         {
@@ -1475,10 +1514,9 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
         {
           filenameNumbers = this->TimeSetFileNameNumbers->GetItem(collectionNum);
           filenameNum = filenameNumbers->GetId(timeStep - 1);
-          // this->ReplaceWildcards(fileName, filenameNum);
           if (!this->UseFileSets)
           {
-            this->ReplaceWildcards(fileName, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
           }
         }
       }
@@ -1514,7 +1552,7 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
           {
             filenameNumbers = this->FileSetFileNameNumbers->GetItem(collectionNum);
             filenameNum = filenameNumbers->GetId(fileNum);
-            this->ReplaceWildcards(fileName, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
           }
         }
       }
@@ -1538,6 +1576,10 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
           this->ReadVectorsPerNode(
             fileName, this->VariableDescriptions[i], timeStepInFile, output, 1);
           break;
+        case vtkEnSightReader::TENSOR_ASYM_PER_NODE:
+          this->ReadAsymmetricTensorsPerNode(
+            fileName, this->VariableDescriptions[i], timeStepInFile, output);
+          break;
         case vtkEnSightReader::TENSOR_SYMM_PER_NODE:
           this->ReadTensorsPerNode(fileName, this->VariableDescriptions[i], timeStepInFile, output);
           break;
@@ -1549,6 +1591,10 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
           this->ReadVectorsPerElement(
             fileName, this->VariableDescriptions[i], timeStepInFile, output);
           break;
+        case vtkEnSightReader::TENSOR_ASYM_PER_ELEMENT:
+          this->ReadAsymmetricTensorsPerElement(
+            fileName, this->VariableDescriptions[i], timeStepInFile, output);
+          break;
         case vtkEnSightReader::TENSOR_SYMM_PER_ELEMENT:
           this->ReadTensorsPerElement(
             fileName, this->VariableDescriptions[i], timeStepInFile, output);
@@ -1616,8 +1662,8 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
         {
           filenameNumbers = this->TimeSetFileNameNumbers->GetItem(collectionNum);
           filenameNum = filenameNumbers->GetId(timeStep - 1);
-          this->ReplaceWildcards(fileName, filenameNum);
-          this->ReplaceWildcards(fileName2, filenameNum);
+          vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
+          vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName2, filenameNum);
         }
       }
 
@@ -1652,8 +1698,8 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
           {
             filenameNumbers = this->FileSetFileNameNumbers->GetItem(collectionNum);
             filenameNum = filenameNumbers->GetId(timeStep - 1);
-            this->ReplaceWildcards(fileName, filenameNum);
-            this->ReplaceWildcards(fileName2, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName, filenameNum);
+            vtkGenericEnSightReader::ReplaceWildcardsHelper(fileName2, filenameNum);
           }
         }
       }
@@ -1700,13 +1746,17 @@ int vtkEnSightReader::ReadVariableFiles(vtkMultiBlockDataSet* output)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::AddVariableFileName(const char* fileName1, const char* fileName2)
 {
   int size;
   int i;
+  bool complexType = this->VariableMode == vtkEnSightReader::COMPLEX_SCALAR_PER_NODE ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_VECTOR_PER_NODE ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_SCALAR_PER_ELEMENT ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_VECTOR_PER_ELEMENT;
 
-  if (this->VariableMode < 8)
+  if (!complexType)
   {
     size = this->NumberOfVariables;
 
@@ -1775,13 +1825,17 @@ void vtkEnSightReader::AddVariableFileName(const char* fileName1, const char* fi
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::AddVariableDescription(const char* description)
 {
   int size;
   int i;
+  bool complexType = this->VariableMode == vtkEnSightReader::COMPLEX_SCALAR_PER_NODE ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_VECTOR_PER_NODE ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_SCALAR_PER_ELEMENT ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_VECTOR_PER_ELEMENT;
 
-  if (this->VariableMode < 8)
+  if (!complexType)
   {
     size = this->NumberOfVariables;
 
@@ -1847,15 +1901,19 @@ void vtkEnSightReader::AddVariableDescription(const char* description)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::AddVariableType()
 {
   int size;
   int i;
   int* types = nullptr;
+  bool complexType = this->VariableMode == vtkEnSightReader::COMPLEX_SCALAR_PER_NODE ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_VECTOR_PER_NODE ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_SCALAR_PER_ELEMENT ||
+    this->VariableMode == vtkEnSightReader::COMPLEX_VECTOR_PER_ELEMENT;
 
-  // Figure out what the size of the variable type array is.
-  if (this->VariableMode < 8)
+  // Figure out what the size of the variable type array is
+  if (!complexType)
   {
     size = this->NumberOfVariables;
 
@@ -1905,7 +1963,7 @@ void vtkEnSightReader::AddVariableType()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::GetSectionType(const char* line)
 {
   if (strncmp(line, "coordinates", 5) == 0)
@@ -1926,7 +1984,7 @@ int vtkEnSightReader::GetSectionType(const char* line)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightReader::GetElementType(const char* line)
 {
   if (strncmp(line, "point", 5) == 0)
@@ -2003,47 +2061,7 @@ int vtkEnSightReader::GetElementType(const char* line)
   }
 }
 
-void vtkEnSightReader::ReplaceWildcards(char* filename, int num)
-{
-  int wildcardPos, numWildcards, i, j;
-  char pattern[32];
-  char numStr[32];
-  char filenameTmp[2048];
-  int len, cnt, numStrLen;
-  int foundWildcard = 0;
-
-  wildcardPos = static_cast<int>(strcspn(filename, "*"));
-  numWildcards = static_cast<int>(strspn(filename + wildcardPos, "*"));
-
-  if (numWildcards < 1)
-    return;
-  else if (numWildcards == 1)
-    strcpy(pattern, "%d");
-  else
-    snprintf(pattern, sizeof(pattern), "%%0%dd", numWildcards);
-  snprintf(numStr, sizeof(numStr), pattern, num);
-  numStrLen = static_cast<int>(strlen(numStr));
-  len = static_cast<int>(strlen(filename));
-  cnt = 0;
-  for (i = 0; i < len; i++)
-  {
-    if (filename[i] == '*')
-    {
-      if (foundWildcard == 0)
-      {
-        for (j = 0; j < numStrLen; j++)
-          filenameTmp[cnt++] = numStr[j];
-        foundWildcard = 1;
-      }
-    }
-    else
-      filenameTmp[cnt++] = filename[i];
-  }
-  filenameTmp[cnt] = '\0';
-  strcpy(filename, filenameTmp);
-}
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::RemoveLeadingBlanks(char* line)
 {
   int count = 0;
@@ -2054,7 +2072,7 @@ void vtkEnSightReader::RemoveLeadingBlanks(char* line)
   memmove(line, line + count, strlen(line + count) + 1);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdList* vtkEnSightReader::GetCellIds(int index, int cellType)
 {
   // Check argument range.
@@ -2098,7 +2116,7 @@ vtkIdList* vtkEnSightReader::GetCellIds(int index, int cellType)
   return (*this->CellIds)[cellIdsIndex];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::AddToBlock(
   vtkMultiBlockDataSet* output, unsigned int blockNo, vtkDataSet* dataset)
 {
@@ -2112,21 +2130,21 @@ void vtkEnSightReader::AddToBlock(
   output->SetBlock(blockNo, dataset);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataSet* vtkEnSightReader::GetDataSetFromBlock(
   vtkMultiBlockDataSet* output, unsigned int blockno)
 {
   return vtkDataSet::SafeDownCast(output->GetBlock(blockno));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::SetBlockName(
   vtkMultiBlockDataSet* output, unsigned int blockNo, const char* name)
 {
   output->GetMetaData(blockNo)->Set(vtkCompositeDataSet::NAME(), name);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -2135,6 +2153,7 @@ void vtkEnSightReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "FilePath: " << (this->FilePath ? this->FilePath : "(none)") << endl;
   os << indent << "NumberOfComplexScalarsPerNode: " << this->NumberOfComplexScalarsPerNode << endl;
   os << indent << "NumberOfVectorsPerElement :" << this->NumberOfVectorsPerElement << endl;
+  os << indent << "NumberOfTensorsAsymPerElement: " << this->NumberOfTensorsAsymPerElement << endl;
   os << indent << "NumberOfTensorsSymmPerElement: " << this->NumberOfTensorsSymmPerElement << endl;
   os << indent << "NumberOfComplexVectorsPerNode: " << this->NumberOfComplexVectorsPerNode << endl;
   os << indent << "NumberOfScalarsPerElement: " << this->NumberOfScalarsPerElement << endl;
@@ -2142,6 +2161,7 @@ void vtkEnSightReader::PrintSelf(ostream& os, vtkIndent indent)
      << endl;
   os << indent << "NumberOfComplexScalarsPerElement: " << this->NumberOfComplexScalarsPerElement
      << endl;
+  os << indent << "NumberOfTensorsAsymPerNode: " << this->NumberOfTensorsAsymPerNode << endl;
   os << indent << "NumberOfTensorsSymmPerNode: " << this->NumberOfTensorsSymmPerNode << endl;
   os << indent << "NumberOfScalarsPerMeasuredNode: " << this->NumberOfScalarsPerMeasuredNode
      << endl;
@@ -2161,3 +2181,4 @@ void vtkEnSightReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "UseTimeSets: " << this->UseTimeSets << endl;
   os << indent << "UseFileSets: " << this->UseFileSets << endl;
 }
+VTK_ABI_NAMESPACE_END
