@@ -1,23 +1,8 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkFFMPEGVideoSource.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkFFMPEGVideoSource.h"
 
-#include "vtkConditionVariable.h"
-#include "vtkCriticalSection.h"
 #include "vtkMultiThreader.h"
-#include "vtkMutexLock.h"
 #include "vtkObjectFactory.h"
 #include "vtkTimerLog.h"
 #include "vtkUnsignedCharArray.h"
@@ -32,6 +17,8 @@ extern "C"
 }
 
 #include <cctype>
+#include <condition_variable>
+#include <mutex>
 
 /////////////////////////////////////////////////////////////////////////
 // building ffmpeg on windows
@@ -66,10 +53,11 @@ extern "C"
 //
 /////////////////////////////////////////////////////////////////////////
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFFMPEGVideoSourceInternal
 {
 public:
-  vtkFFMPEGVideoSourceInternal() {}
+  vtkFFMPEGVideoSourceInternal() = default;
   void ReleaseSystemResources()
   {
     if (this->Frame)
@@ -113,13 +101,26 @@ public:
   int AudioStreamIndex = -1;
   AVFrame* Frame = nullptr;
   AVFrame* AudioFrame = nullptr;
-  AVPacket Packet;
+  AVPacket* Packet = nullptr;
   struct SwsContext* RGBContext = nullptr;
 };
 
 vtkStandardNewMacro(vtkFFMPEGVideoSource);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+void vtkFFMPEGVideoSource::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+  os << indent << "DecodingThreads: " << this->DecodingThreads << endl;
+  os << indent << "DrainAudioThreadId: " << this->DrainAudioThreadId << endl;
+  os << indent << "DrainThreadId: " << this->DrainThreadId << endl;
+  os << indent << "EndOfFile: " << this->EndOfFile << endl;
+  os << indent << "FeedThreadId: " << this->FeedThreadId << endl;
+  os << indent << "FileName: " << (this->FileName ? this->FileName : "(null)") << endl;
+  os << indent << "Stereo3D: " << this->Stereo3D << endl;
+}
+
+//------------------------------------------------------------------------------
 vtkFFMPEGVideoSource::vtkFFMPEGVideoSource()
   : AudioCallback(nullptr)
   , AudioCallbackClientData(nullptr)
@@ -141,15 +142,17 @@ vtkFFMPEGVideoSource::vtkFFMPEGVideoSource()
   this->Stereo3D = false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkFFMPEGVideoSource::~vtkFFMPEGVideoSource()
 {
+  this->Stop();
   this->vtkFFMPEGVideoSource::ReleaseSystemResources();
   delete[] this->FileName;
+  av_packet_free(&this->Internal->Packet);
   delete this->Internal;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::Initialize()
 {
   if (this->Initialized)
@@ -192,7 +195,7 @@ void vtkFFMPEGVideoSource::Initialize()
 
   this->Internal->VideoStream = fcontext->streams[this->Internal->VideoStreamIndex];
 
-  AVCodec* dec = avcodec_find_decoder(this->Internal->VideoStream->codecpar->codec_id);
+  const AVCodec* dec = avcodec_find_decoder(this->Internal->VideoStream->codecpar->codec_id);
   if (!dec)
   {
     vtkErrorMacro("Failed to find codec for video");
@@ -258,7 +261,7 @@ void vtkFFMPEGVideoSource::Initialize()
   {
     this->Internal->AudioStream = fcontext->streams[this->Internal->AudioStreamIndex];
 
-    AVCodec* adec = avcodec_find_decoder(this->Internal->AudioStream->codecpar->codec_id);
+    const AVCodec* adec = avcodec_find_decoder(this->Internal->AudioStream->codecpar->codec_id);
     if (!adec)
     {
       vtkErrorMacro("Failed to find codec for audio");
@@ -297,9 +300,9 @@ void vtkFFMPEGVideoSource::Initialize()
   }
 
   /* initialize packet, set data to nullptr, let the demuxer fill it */
-  av_init_packet(&this->Internal->Packet);
-  this->Internal->Packet.data = nullptr;
-  this->Internal->Packet.size = 0;
+  this->Internal->Packet = av_packet_alloc();
+  this->Internal->Packet->data = nullptr;
+  this->Internal->Packet->size = 0;
 
   // update framebuffer again to reflect any changes which
   // might have occurred
@@ -308,7 +311,7 @@ void vtkFFMPEGVideoSource::Initialize()
   this->Initialized = 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Feed frames to the decoder
 void* vtkFFMPEGVideoSource::FeedThread(vtkMultiThreader::ThreadInfo* data)
 {
@@ -332,64 +335,64 @@ void* vtkFFMPEGVideoSource::Feed(vtkMultiThreader::ThreadInfo* data)
     // read in the packet
     if (!retryPacket)
     {
-      av_packet_unref(&this->Internal->Packet);
-      fret = av_read_frame(this->Internal->FormatContext, &this->Internal->Packet);
+      av_packet_unref(this->Internal->Packet);
+      fret = av_read_frame(this->Internal->FormatContext, this->Internal->Packet);
     }
     retryPacket = false;
     // feed video
-    if (fret >= 0 && this->Internal->Packet.stream_index == this->Internal->VideoStreamIndex)
+    if (fret >= 0 && this->Internal->Packet->stream_index == this->Internal->VideoStreamIndex)
     {
       // lock the decoder
-      this->FeedMutex->Lock();
+      this->FeedMutex.lock();
 
-      int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, &this->Internal->Packet);
+      int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, this->Internal->Packet);
       if (sret == 0) // good decode
       {
-        this->FeedCondition->Signal();
+        this->FeedCondition.notify_one();
       }
       else if (sret == AVERROR(EAGAIN))
       {
         // Signal the draining loop
-        this->FeedCondition->Signal();
+        this->FeedCondition.notify_one();
         // Wait here
-        this->FeedCondition->Wait(this->FeedMutex);
+        this->FeedCondition.wait(this->FeedMutex);
         retryPacket = true;
       }
       else if (sret < 0) // error
       {
-        this->FeedMutex->Unlock();
+        this->FeedMutex.unlock();
         return nullptr;
       }
 
-      this->FeedMutex->Unlock();
+      this->FeedMutex.unlock();
     }
 
     // feed audio
-    if (fret >= 0 && this->Internal->Packet.stream_index == this->Internal->AudioStreamIndex)
+    if (fret >= 0 && this->Internal->Packet->stream_index == this->Internal->AudioStreamIndex)
     {
       // lock the decoder
-      this->FeedAudioMutex->Lock();
+      this->FeedAudioMutex.lock();
 
-      int sret = avcodec_send_packet(this->Internal->AudioDecodeContext, &this->Internal->Packet);
+      int sret = avcodec_send_packet(this->Internal->AudioDecodeContext, this->Internal->Packet);
       if (sret == 0) // good decode
       {
-        this->FeedAudioCondition->Signal();
+        this->FeedAudioCondition.notify_one();
       }
       else if (sret == AVERROR(EAGAIN))
       {
         // Signal the draining loop
-        this->FeedAudioCondition->Signal();
+        this->FeedAudioCondition.notify_one();
         // Wait here
-        this->FeedAudioCondition->Wait(this->FeedAudioMutex);
+        this->FeedAudioCondition.wait(this->FeedAudioMutex);
         retryPacket = true;
       }
       else if (sret < 0) // error
       {
-        this->FeedAudioMutex->Unlock();
+        this->FeedAudioMutex.unlock();
         return nullptr;
       }
 
-      this->FeedAudioMutex->Unlock();
+      this->FeedAudioMutex.unlock();
     }
 
     // are we out of data?
@@ -401,7 +404,7 @@ void* vtkFFMPEGVideoSource::Feed(vtkMultiThreader::ThreadInfo* data)
     // check to see if we are being told to quit every so often
     if (count == 10)
     {
-      std::lock_guard<std::mutex>(*data->ActiveFlagLock);
+      std::lock_guard<std::mutex> guard(*data->ActiveFlagLock);
       done = done || (*(data->ActiveFlag) == 0);
       count = 0;
     }
@@ -409,24 +412,24 @@ void* vtkFFMPEGVideoSource::Feed(vtkMultiThreader::ThreadInfo* data)
   }
 
   // flush remaining data
-  this->FeedMutex->Lock();
+  this->FeedMutex.lock();
   avcodec_send_packet(this->Internal->VideoDecodeContext, nullptr);
-  this->FeedCondition->Signal();
-  this->FeedMutex->Unlock();
+  this->FeedCondition.notify_one();
+  this->FeedMutex.unlock();
 
   if (this->Internal->AudioDecodeContext)
   {
-    this->FeedAudioMutex->Lock();
+    this->FeedAudioMutex.lock();
     avcodec_send_packet(this->Internal->AudioDecodeContext, nullptr);
-    this->FeedAudioCondition->Signal();
-    this->FeedAudioMutex->Unlock();
+    this->FeedAudioCondition.notify_one();
+    this->FeedAudioMutex.unlock();
   }
 
   this->EndOfFile = true;
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Sleep until the specified absolute time has arrived.
 // You must pass a handle to the current thread.
 // If '0' is returned, then the thread was aborted before or during the wait.
@@ -441,9 +444,9 @@ static void vtkThreadSleep(double time)
     double remaining = time - vtkTimerLog::GetUniversalTime();
 
     // check to see if we are being told to quit
-    // data->ActiveFlagLock->Lock();
+    // data->ActiveFlagLock.lock();
     // int activeFlag = *(data->ActiveFlag);
-    // data->ActiveFlagLock->Unlock();
+    // data->ActiveFlagLock.unlock();
 
     // if (activeFlag == 0)
     // {
@@ -487,32 +490,33 @@ void* vtkFFMPEGVideoSource::Drain(vtkMultiThreader::ThreadInfo* data)
 
   while (!done)
   {
-    this->FeedMutex->Lock();
+    this->FeedMutex.lock();
 
     int ret = avcodec_receive_frame(this->Internal->VideoDecodeContext, this->Internal->Frame);
     if (ret == 0)
     {
-      this->FeedCondition->Signal();
+      this->FeedCondition.notify_one();
     }
     else if (ret == AVERROR(EAGAIN))
     {
       // Signal the feeding loop
-      this->FeedCondition->Signal();
+      this->FeedCondition.notify_one();
       // Wait here
-      this->FeedCondition->Wait(this->FeedMutex);
+      this->FeedCondition.wait(this->FeedMutex);
     }
     else if (ret == AVERROR_EOF)
     {
+      this->FeedMutex.unlock();
       return nullptr;
     }
     else if (ret < 0) // error code
     {
-      this->FeedMutex->Unlock();
+      this->FeedMutex.unlock();
       cerr << "video drain thread exiting on error!\n";
       return nullptr;
     }
 
-    this->FeedMutex->Unlock();
+    this->FeedMutex.unlock();
 
     if (ret == 0)
     {
@@ -542,7 +546,7 @@ void* vtkFFMPEGVideoSource::Drain(vtkMultiThreader::ThreadInfo* data)
     // check to see if we are being told to quit every so often
     if (count == 10)
     {
-      std::lock_guard<std::mutex>(*data->ActiveFlagLock);
+      std::lock_guard<std::mutex> guard(*data->ActiveFlagLock);
       done = done || (*(data->ActiveFlag) == 0);
       count = 0;
     }
@@ -567,32 +571,33 @@ void* vtkFFMPEGVideoSource::DrainAudio(vtkMultiThreader::ThreadInfo* data)
 
   while (!done)
   {
-    this->FeedAudioMutex->Lock();
+    this->FeedAudioMutex.lock();
 
     int ret = avcodec_receive_frame(this->Internal->AudioDecodeContext, this->Internal->AudioFrame);
     if (ret == 0)
     {
-      this->FeedAudioCondition->Signal();
+      this->FeedAudioCondition.notify_one();
     }
     else if (ret == AVERROR(EAGAIN))
     {
       // Signal the feeding loop
-      this->FeedAudioCondition->Signal();
+      this->FeedAudioCondition.notify_one();
       // Wait here
-      this->FeedAudioCondition->Wait(this->FeedAudioMutex);
+      this->FeedAudioCondition.wait(this->FeedAudioMutex);
     }
     else if (ret == AVERROR_EOF)
     {
+      this->FeedAudioMutex.unlock();
       return nullptr;
     }
     else if (ret < 0) // error code
     {
-      this->FeedAudioMutex->Unlock();
+      this->FeedAudioMutex.unlock();
       cerr << "audio drain thread exiting on error!\n";
       return nullptr;
     }
 
-    this->FeedAudioMutex->Unlock();
+    this->FeedAudioMutex.unlock();
 
     if (ret == 0)
     {
@@ -647,7 +652,14 @@ void* vtkFFMPEGVideoSource::DrainAudio(vtkMultiThreader::ThreadInfo* data)
         cbd.NumberOfSamples = this->Internal->AudioFrame->nb_samples;
         cbd.BytesPerSample =
           av_get_bytes_per_sample(this->Internal->AudioDecodeContext->sample_fmt);
+#if defined(LIBAVCODEC_VERSION_MAJOR) &&                                                           \
+  (LIBAVCODEC_VERSION_MAJOR > 59 ||                                                                \
+    (LIBAVCODEC_VERSION_MAJOR == 59 && defined(LIBAVCODEC_VERSION_MINOR) &&                        \
+      LIBAVCODEC_VERSION_MINOR >= 24))
+        cbd.NumberOfChannels = this->Internal->AudioDecodeContext->ch_layout.nb_channels;
+#else
         cbd.NumberOfChannels = this->Internal->AudioDecodeContext->channels;
+#endif
         cbd.SampleRate = this->Internal->AudioDecodeContext->sample_rate;
         cbd.DataType = sampleFormat;
         cbd.Data = this->Internal->AudioFrame->extended_data;
@@ -662,7 +674,7 @@ void* vtkFFMPEGVideoSource::DrainAudio(vtkMultiThreader::ThreadInfo* data)
     // check to see if we are being told to quit every so often
     if (count == 10)
     {
-      std::lock_guard<std::mutex>(*data->ActiveFlagLock);
+      std::lock_guard<std::mutex> guard(*data->ActiveFlagLock);
       done = done || (*(data->ActiveFlag) == 0);
       count = 0;
     }
@@ -676,10 +688,10 @@ void vtkFFMPEGVideoSource::ReadFrame()
 {
   // first try to grab a frame from data we already have
   bool gotFrame = false;
-  while (!gotFrame && (!this->EndOfFile || this->Internal->Packet.size > 0))
+  while (!gotFrame && (!this->EndOfFile || this->Internal->Packet->size > 0))
   {
     int ret = AVERROR(EAGAIN);
-    if (this->Internal->Packet.size > 0)
+    if (this->Internal->Packet->size > 0)
     {
       ret = avcodec_receive_frame(this->Internal->VideoDecodeContext, this->Internal->Frame);
       if (ret < 0 && ret != AVERROR(EAGAIN) && ret != AVERROR_EOF)
@@ -702,11 +714,11 @@ void vtkFFMPEGVideoSource::ReadFrame()
     if (ret == AVERROR(EAGAIN) && !this->EndOfFile)
     {
       // if the packet is empty read more data from the file
-      av_packet_unref(&this->Internal->Packet);
-      int fret = av_read_frame(this->Internal->FormatContext, &this->Internal->Packet);
-      if (fret >= 0 && this->Internal->Packet.stream_index == this->Internal->VideoStreamIndex)
+      av_packet_unref(this->Internal->Packet);
+      int fret = av_read_frame(this->Internal->FormatContext, this->Internal->Packet);
+      if (fret >= 0 && this->Internal->Packet->stream_index == this->Internal->VideoStreamIndex)
       {
-        int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, &this->Internal->Packet);
+        int sret = avcodec_send_packet(this->Internal->VideoDecodeContext, this->Internal->Packet);
         if (sret < 0 && sret != AVERROR(EAGAIN) && sret != AVERROR_EOF)
         {
           vtkErrorMacro("codec did not send packet");
@@ -725,7 +737,7 @@ void vtkFFMPEGVideoSource::ReadFrame()
 void vtkFFMPEGVideoSource::InternalGrab()
 {
   // get a thread lock on the frame buffer
-  this->FrameBufferMutex->Lock();
+  this->FrameBufferMutex.lock();
 
   if (this->AutoAdvance)
   {
@@ -764,12 +776,12 @@ void vtkFFMPEGVideoSource::InternalGrab()
   sws_scale(this->Internal->RGBContext, this->Internal->Frame->data,
     this->Internal->Frame->linesize, 0, this->Internal->Frame->height, dst, dstStride);
 
-  this->FrameBufferMutex->Unlock();
+  this->FrameBufferMutex.unlock();
 
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::ReleaseSystemResources()
 {
   if (this->Initialized)
@@ -780,7 +792,7 @@ void vtkFFMPEGVideoSource::ReleaseSystemResources()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::Grab()
 {
   if (this->Recording)
@@ -799,13 +811,13 @@ void vtkFFMPEGVideoSource::Grab()
   this->InternalGrab();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::Play()
 {
   this->vtkVideoSource::Play();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::Record()
 {
   if (this->Playing)
@@ -837,7 +849,7 @@ void vtkFFMPEGVideoSource::Record()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::Stop()
 {
   if (this->Playing || this->Recording)
@@ -854,7 +866,7 @@ void vtkFFMPEGVideoSource::Stop()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // try for the specified frame size
 void vtkFFMPEGVideoSource::SetFrameSize(int x, int y, int z)
 {
@@ -876,13 +888,13 @@ void vtkFFMPEGVideoSource::SetFrameSize(int x, int y, int z)
 
   if (this->Initialized)
   {
-    this->FrameBufferMutex->Lock();
+    this->FrameBufferMutex.lock();
     this->UpdateFrameBuffer();
-    this->FrameBufferMutex->Unlock();
+    this->FrameBufferMutex.unlock();
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::SetFrameRate(float rate)
 {
   if (rate == this->FrameRate)
@@ -894,7 +906,7 @@ void vtkFFMPEGVideoSource::SetFrameRate(float rate)
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkFFMPEGVideoSource::SetOutputFormat(int format)
 {
   if (format == this->OutputFormat)
@@ -927,14 +939,15 @@ void vtkFFMPEGVideoSource::SetOutputFormat(int format)
 
   if (this->FrameBufferBitsPerPixel != numComponents * 8)
   {
-    this->FrameBufferMutex->Lock();
+    this->FrameBufferMutex.lock();
     this->FrameBufferBitsPerPixel = numComponents * 8;
     if (this->Initialized)
     {
       this->UpdateFrameBuffer();
     }
-    this->FrameBufferMutex->Unlock();
+    this->FrameBufferMutex.unlock();
   }
 
   this->Modified();
 }
+VTK_ABI_NAMESPACE_END
