@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkGDAL.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkGDAL
  * @brief   Shared data for GDAL classes
@@ -24,6 +12,7 @@
 #include "vtkObject.h"
 #include <vtkIOGDALModule.h> // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkInformationStringKey;
 class vtkInformationIntegerVectorKey;
 
@@ -31,6 +20,7 @@ class VTKIOGDAL_EXPORT vtkGDAL : public vtkObject
 {
 public:
   vtkTypeMacro(vtkGDAL, vtkObject);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
   // Key used to put GDAL map projection string in the output information
   // by readers.
   static vtkInformationStringKey* MAP_PROJECTION();
@@ -44,5 +34,5 @@ private:
   void operator=(const vtkGDAL&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif // vtkGDAL_h
-// VTK-HeaderTest-Exclude: vtkGDAL.h
