@@ -1,6 +1,23 @@
 #!/usr/bin/env python
-import vtk
-from vtk.util.misc import vtkGetDataRoot
+from vtkmodules.vtkFiltersCore import vtkHedgeHog
+from vtkmodules.vtkFiltersGeometry import vtkStructuredGridGeometryFilter
+from vtkmodules.vtkIOParallel import vtkMultiBlockPLOT3DReader
+from vtkmodules.vtkRenderingCore import (
+    vtkActor,
+    vtkActor2D,
+    vtkCamera,
+    vtkLight,
+    vtkPolyDataMapper,
+    vtkRenderWindow,
+    vtkRenderWindowInteractor,
+    vtkRenderer,
+    vtkTextMapper,
+    vtkTextProperty,
+)
+import vtkmodules.vtkInteractionStyle
+import vtkmodules.vtkRenderingFreeType
+import vtkmodules.vtkRenderingOpenGL2
+from vtkmodules.util.misc import vtkGetDataRoot
 VTK_DATA_ROOT = vtkGetDataRoot()
 
 #
@@ -8,30 +25,30 @@ VTK_DATA_ROOT = vtkGetDataRoot()
 #
 # Create the RenderWindow, Renderer and both Actors
 #
-renWin = vtk.vtkRenderWindow()
+renWin = vtkRenderWindow()
 renWin.SetMultiSamples(0)
-ren1 = vtk.vtkRenderer()
+ren1 = vtkRenderer()
 ren1.SetBackground(.8, .8, .2)
 renWin.AddRenderer(ren1)
-iren = vtk.vtkRenderWindowInteractor()
+iren = vtkRenderWindowInteractor()
 iren.SetRenderWindow(renWin)
 
 vectorLabels = ["Velocity", "Vorticity", "Momentum", "Pressure_Gradient"]
 vectorFunctions = ["200", "201", "202", "210"]
 
-camera = vtk.vtkCamera()
+camera = vtkCamera()
 
-light = vtk.vtkLight()
+light = vtkLight()
 
 # All text actors will share the same text prop
-textProp = vtk.vtkTextProperty()
+textProp = vtkTextProperty()
 textProp.SetFontSize(10)
 textProp.SetFontFamilyToArial()
 textProp.SetColor(.3, 1, 1)
 
 i = 0
 for vectorFunction in vectorFunctions:
-    exec("pl3d" + vectorFunction + " = vtk.vtkMultiBlockPLOT3DReader()")
+    exec("pl3d" + vectorFunction + " = vtkMultiBlockPLOT3DReader()")
     eval("pl3d" + vectorFunction).SetXYZFileName(
       VTK_DATA_ROOT + "/Data/bluntfinxyz.bin")
     eval("pl3d" + vectorFunction).SetQFileName(
@@ -41,11 +58,11 @@ for vectorFunction in vectorFunctions:
 
     output = eval("pl3d" + vectorFunction).GetOutput().GetBlock(0)
 
-    exec("plane" + vectorFunction + " = vtk.vtkStructuredGridGeometryFilter()")
+    exec("plane" + vectorFunction + " = vtkStructuredGridGeometryFilter()")
     eval("plane" + vectorFunction).SetInputData(output)
     eval("plane" + vectorFunction).SetExtent(25, 25, 0, 100, 0, 100)
 
-    exec("hog" + vectorFunction + " = vtk.vtkHedgeHog()")
+    exec("hog" + vectorFunction + " = vtkHedgeHog()")
     eval("hog" + vectorFunction).SetInputConnection(
       eval("plane" + vectorFunction).GetOutputPort())
 
@@ -53,14 +70,14 @@ for vectorFunction in vectorFunctions:
 
     eval("hog" + vectorFunction).SetScaleFactor(1.0 / maxnorm)
 
-    exec("mapper" + vectorFunction + " = vtk.vtkPolyDataMapper()")
+    exec("mapper" + vectorFunction + " = vtkPolyDataMapper()")
     eval("mapper" + vectorFunction).SetInputConnection(
       eval("hog" + vectorFunction).GetOutputPort())
 
-    exec("actor" + vectorFunction + " = vtk.vtkActor()")
+    exec("actor" + vectorFunction + " = vtkActor()")
     eval("actor" + vectorFunction).SetMapper(eval("mapper" + vectorFunction))
 
-    exec("ren" + vectorFunction + " = vtk.vtkRenderer()")
+    exec("ren" + vectorFunction + " = vtkRenderer()")
     eval("ren" + vectorFunction).SetBackground(0.5, .5, .5)
     eval("ren" + vectorFunction).SetActiveCamera(camera)
     eval("ren" + vectorFunction).AddLight(light)
@@ -69,10 +86,10 @@ for vectorFunction in vectorFunctions:
 
     eval("ren" + vectorFunction).AddActor(eval("actor" + vectorFunction))
 
-    exec("textMapper" + vectorFunction + " = vtk.vtkTextMapper()")
+    exec("textMapper" + vectorFunction + " = vtkTextMapper()")
     eval("textMapper" + vectorFunction).SetInput(vectorLabels[i])
     eval("textMapper" + vectorFunction).SetTextProperty(textProp)
-    exec("text" + vectorFunction + " = vtk.vtkActor2D()")
+    exec("text" + vectorFunction + " = vtkActor2D()")
 
     eval("text" + vectorFunction).SetMapper(eval("textMapper" + vectorFunction))
     eval("text" + vectorFunction).SetPosition(2, 5)
