@@ -1,21 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkChacoReader.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*----------------------------------------------------------------------------
- Copyright (c) Sandia Corporation
- See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-----------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Sandia Corporation
+// SPDX-License-Identifier: BSD-3-Clause
 
 /**
  * @class   vtkChacoReader
@@ -36,6 +21,7 @@
 #include "vtkIOGeometryModule.h" // For export macro
 #include "vtkUnstructuredGridAlgorithm.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKIOGEOMETRY_EXPORT vtkChacoReader : public vtkUnstructuredGridAlgorithm
 {
 public:
@@ -135,14 +121,14 @@ public:
 
   const char* GetEdgeWeightArrayName(int weight);
 
-  //@{
+  ///@{
   /**
    * Access to meta data generated by RequestInformation.
    */
   vtkGetMacro(Dimensionality, int);
   vtkGetMacro(NumberOfEdges, vtkIdType);
   vtkGetMacro(NumberOfVertices, vtkIdType);
-  //@}
+  ///@}
 
   /**
    * After this filter executes, this method returns the number of
@@ -238,8 +224,8 @@ private:
   void FlushLine(FILE* infile);
   void ResetInputBuffers();
 
-  char* Line;
-  int Line_length;
+  char Line[200];
+  const int Line_length = 200;
   int Offset;
   int Break_pnt;
   int Save_pnt;
@@ -247,4 +233,5 @@ private:
   void ClearWeightArrayNames();
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
