@@ -1,31 +1,28 @@
-// -*- c++ -*-
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkNrrdReader.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*----------------------------------------------------------------------------
- Copyright (c) Sandia Corporation
- See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-----------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Sandia Corporation
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkNrrdReader.h"
 
 #include "vtkCharArray.h"
+#include "vtkErrorCode.h"
 #include "vtkImageData.h"
 #include "vtkInformationVector.h"
 #include "vtkObjectFactory.h"
 #include "vtkStringArray.h"
 
+// Header for zlib
+#include "vtk_zlib.h"
+
+#include <fcntl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#ifdef _WIN32
+#include <io.h>
+#else
+#include <unistd.h>
+#endif
+
 #include <algorithm>
 #include <istream>
 #include <sstream>
@@ -43,6 +40,7 @@
 #define VTK_CREATE(type, name) vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
 //=============================================================================
+VTK_ABI_NAMESPACE_BEGIN
 static std::string trim(std::string s)
 {
   size_t start = 0;
@@ -58,7 +56,7 @@ static std::string trim(std::string s)
   return s.substr(start, end - start);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static std::vector<std::string> split(std::string s)
 {
   std::vector<std::string> result;
@@ -81,7 +79,7 @@ static std::vector<std::string> split(std::string s)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static void GetVector(std::string& s, std::vector<int>& dest)
 {
   std::vector<std::string> strlist = split(s);
@@ -98,7 +96,7 @@ static void GetVector(std::string& s, std::vector<int>& dest)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static void GetVector(std::string& s, std::vector<double>& dest)
 {
   std::vector<std::string> strlist = split(s);
@@ -115,7 +113,7 @@ static void GetVector(std::string& s, std::vector<double>& dest)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static std::vector<double> ParseVector(std::string s)
 {
   std::vector<double> result;
@@ -129,7 +127,7 @@ static std::vector<double> ParseVector(std::string s)
     size_t i = s.find(',');
     std::string value = s.substr(0, i);
     result.push_back(atof(value.c_str()));
-    if (i == s.npos)
+    if (i == std::string::npos)
       break;
     s = s.substr(i + 1);
   }
@@ -137,7 +135,7 @@ static std::vector<double> ParseVector(std::string s)
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static int NrrdType2VTKType(std::string nrrdType)
 {
   nrrdType = trim(nrrdType);
@@ -201,11 +199,11 @@ static int NrrdType2VTKType(std::string nrrdType)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkObjectFactoryNewMacro(vtkNrrdReader);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkNrrdReader::vtkNrrdReader()
 {
   this->DataFiles = vtkStringArray::New();
@@ -230,13 +228,16 @@ void vtkNrrdReader::PrintSelf(ostream& os, vtkIndent indent)
     case ENCODING_ASCII:
       os << "ascii" << endl;
       break;
+    case ENCODING_GZIP:
+      os << "gzip" << endl;
+      break;
     default:
       os << "UNKNOWN!" << endl;
       break;
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkNrrdReader::CanReadFile(const char* filename)
 {
   vtksys::ifstream file(filename, ios::in | ios::binary);
@@ -252,7 +253,7 @@ int vtkNrrdReader::CanReadFile(const char* filename)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkNrrdReader::RequestInformation(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -262,7 +263,7 @@ int vtkNrrdReader::RequestInformation(
   return this->Superclass::RequestInformation(request, inputVector, outputVector);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkNrrdReader::ReadHeaderInternal(vtkCharArray* headerBuffer)
 {
   if (!this->FileName)
@@ -305,7 +306,7 @@ int vtkNrrdReader::ReadHeaderInternal(vtkCharArray* headerBuffer)
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkNrrdReader::ReadHeader()
 {
   VTK_CREATE(vtkCharArray, headerBuffer);
@@ -318,10 +319,11 @@ int vtkNrrdReader::ReadHeader()
   return this->ReadHeader(headerBuffer);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
 {
-  this->HeaderSize = headerBuffer->GetNumberOfTuples();
+  this->HeaderSize = headerBuffer->GetNumberOfTuples() - 1;
+  this->ManualHeaderSize = 1;
 
   std::string headerStringBuffer = headerBuffer->GetPointer(0);
   std::stringstream header(headerStringBuffer);
@@ -341,7 +343,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
   std::vector<double> dimSpacing;
   this->FileLowerLeft = 1;
   this->Encoding = ENCODING_RAW;
-  while (1)
+  while (true)
   {
     getline(header, line);
     if (line.length() < 1)
@@ -354,7 +356,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
     }
 
     size_t delm = line.find(": ");
-    if (delm != line.npos)
+    if (delm != std::string::npos)
     {
       // A field/description pair.
       std::string field = line.substr(0, delm);
@@ -390,6 +392,10 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
         {
           this->Encoding = ENCODING_ASCII;
         }
+        else if (description == "gzip" || description == "gz")
+        {
+          this->Encoding = ENCODING_GZIP;
+        }
         else
         {
           vtkErrorMacro(<< "Unsupported encoding: " << description);
@@ -406,7 +412,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
             ((filepatterninfo.size() > 1) ? atoi(filepatterninfo[1].c_str()) : numDimensions);
 
           // In this mode files are listed one per line to the end of the file.
-          while (1)
+          while (true)
           {
             getline(header, line);
             trim(line);
@@ -446,7 +452,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
       else if (field == "space")
       {
         // All spaces are either 3D or 3D with time.
-        if (description.find("time") != description.npos)
+        if (description.find("time") != std::string::npos)
         {
           vtkErrorMacro(<< "Time in NRRD array not supported (yet).");
           return 0;
@@ -557,7 +563,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
     }
 
     delm = line.find(":=");
-    if (delm != line.npos)
+    if (delm != std::string::npos)
     {
       // A key/value pair.
       continue;
@@ -621,6 +627,7 @@ int vtkNrrdReader::ReadHeader(vtkCharArray* headerBuffer)
     }
     // Header file pointing to data files.  Data files should have no header.
     this->HeaderSize = 0;
+    this->ManualHeaderSize = 0;
   }
 
   return 1;
@@ -669,6 +676,18 @@ int vtkNrrdReader::RequestData(
 
     result = this->ReadDataAscii(outputData);
   }
+  else if (this->Encoding == ENCODING_GZIP)
+  {
+    vtkImageData* outputData = vtkImageData::GetData(outputVector);
+    this->AllocateOutputData(outputData, outputVector->GetInformationObject(0));
+    if (outputData == nullptr)
+    {
+      vtkErrorMacro(<< "Data not created correctly?");
+      return 0;
+    }
+
+    result = this->ReadDataGZip(outputData);
+  }
   else
   {
     vtkErrorMacro(<< "Bad encoding set");
@@ -698,7 +717,7 @@ int vtkNrrdReaderReadDataAsciiTemplate(vtkNrrdReader* self, vtkImageData* output
   fileDataIncrements[2] = fileDataIncrements[1] * fileDataExtent[3];
 
   vtkStringArray* filenames = self->GetFileNames();
-  vtkStdString filename = self->GetFileName();
+  std::string filename = self->GetFileName();
 
   vtksys::ifstream file;
   if (self->GetFileDimensionality() == 3)
@@ -796,3 +815,108 @@ int vtkNrrdReader::ReadDataAscii(vtkImageData* output)
 
   return 1;
 }
+
+//=============================================================================
+template <typename T>
+int vtkNrrdReader::vtkNrrdReaderReadDataGZipTemplate(vtkImageData* output, T* outBuffer)
+{
+  vtkIdType inIncr[3];
+  output->GetIncrements(inIncr);
+
+  vtkStringArray* filenames = this->GetFileNames();
+  std::string filename = this->GetFileName();
+
+  int outExtent[6];
+  output->GetExtent(outExtent);
+
+  int fileDataExtent[6];
+  this->GetDataExtent(fileDataExtent);
+
+  // cannot do partial reads efficiently from gzipped data stream
+  for (int i = 0; i < 6; i++)
+  {
+    if (fileDataExtent[i] != outExtent[i])
+    {
+      vtkErrorMacro(<< "File and requested extents must agree: " << filename);
+      this->SetErrorCode(vtkErrorCode::UnknownError);
+      return 0;
+    }
+  }
+
+  if ((this->GetFileDimensionality() == 2) || (this->GetFileDimensionality() == 3))
+  {
+    if (filenames != nullptr)
+    {
+      filename = filenames->GetValue(0);
+    }
+
+    int flags = O_RDONLY;
+#ifdef _WIN32
+    flags |= O_BINARY;
+#endif
+    int fd = open(filename.c_str(), flags);
+    if (fd < 0)
+    {
+      vtkErrorMacro(<< "Couldn't open nrrd file: " << filename);
+      this->SetErrorCode(vtkErrorCode::CannotOpenFileError);
+      return 0;
+    }
+    else
+    {
+      off_t offset = this->GetHeaderSize();
+      lseek(fd, offset, SEEK_SET);
+      gzFile gf = gzdopen(fd, "r");
+      if (gf == nullptr)
+      {
+        vtkErrorMacro(<< "Couldn't open gzip stream from nrrd file: " << filename);
+        this->SetErrorCode(vtkErrorCode::CannotOpenFileError);
+        close(fd);
+        return 0;
+      }
+
+      unsigned numBytes = static_cast<unsigned>(inIncr[2]) * sizeof(T);
+      if (this->GetFileDimensionality() == 3)
+      {
+        auto width = fileDataExtent[1] - fileDataExtent[0] + 1;
+        auto height = fileDataExtent[3] - fileDataExtent[2] + 1;
+        auto depth = fileDataExtent[5] - fileDataExtent[4] + 1;
+        numBytes = static_cast<unsigned>(width) * height * depth * sizeof(T);
+      }
+
+      int rsize = gzread(gf, outBuffer, numBytes);
+      if ((rsize < 0) || (static_cast<unsigned>(rsize) != numBytes))
+      {
+        vtkErrorMacro(<< "Couldn't read gzip data from nrrd file: " << filename << " " << numBytes
+                      << "/" << rsize << ", GetHeaderSize(): " << this->GetHeaderSize());
+        this->SetErrorCode(vtkErrorCode::PrematureEndOfFileError);
+        gzclose(gf);
+        return 0;
+      }
+      gzclose(gf);
+    }
+  }
+  else
+  {
+    vtkErrorMacro(<< "Unsupported dimensionality in nrrd file: " << filename);
+    this->SetErrorCode(vtkErrorCode::UnrecognizedFileTypeError);
+    return 0;
+  }
+
+  return 1;
+}
+
+//=============================================================================
+int vtkNrrdReader::ReadDataGZip(vtkImageData* output)
+{
+  void* outBuffer = output->GetScalarPointer();
+  switch (output->GetScalarType())
+  {
+    vtkTemplateMacro(vtkNrrdReaderReadDataGZipTemplate(output, (VTK_TT*)(outBuffer)));
+    default:
+      vtkErrorMacro("Unknown data type");
+      return 0;
+  }
+
+  return 1;
+}
+VTK_ABI_NAMESPACE_END
