@@ -1,22 +1,11 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkGLTFImporter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkGLTFImporter.h"
 
 #include "vtkActor.h"
 #include "vtkCamera.h"
+#include "vtkDoubleArray.h"
 #include "vtkEventForwarderCommand.h"
 #include "vtkFloatArray.h"
 #include "vtkGLTFDocumentLoader.h"
@@ -29,29 +18,33 @@
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
+#include "vtkPolyDataNormals.h"
 #include "vtkPolyDataTangents.h"
 #include "vtkProperty.h"
 #include "vtkRenderer.h"
+#include "vtkShaderProperty.h"
 #include "vtkSmartPointer.h"
 #include "vtkTexture.h"
 #include "vtkTransform.h"
+#include "vtkUniforms.h"
 #include "vtksys/SystemTools.hxx"
 
 #include <algorithm>
 #include <array>
 #include <stack>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGLTFImporter);
 
 namespace
 {
 // Desired attenuation value when distanceToLight == lightRange
-static const float MIN_LIGHT_ATTENUATION = 0.01;
+const float MIN_LIGHT_ATTENUATION = 0.01;
 
 /**
  * Builds a new vtkCamera object with properties from a glTF Camera struct
  */
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSmartPointer<vtkCamera> GLTFCameraToVTKCamera(const vtkGLTFDocumentLoader::Camera& gltfCam)
 {
   vtkNew<vtkCamera> vtkCam;
@@ -72,10 +65,10 @@ vtkSmartPointer<vtkCamera> GLTFCameraToVTKCamera(const vtkGLTFDocumentLoader::Ca
 /**
  * Create a vtkTexture object with a glTF texture as model. Sampling options are approximated.
  */
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSmartPointer<vtkTexture> CreateVTKTextureFromGLTFTexture(
   std::shared_ptr<vtkGLTFDocumentLoader::Model> model, int textureIndex,
-  std::map<int, vtkSmartPointer<vtkTexture> >& existingTextures)
+  std::map<int, vtkSmartPointer<vtkTexture>>& existingTextures)
 {
 
   if (existingTextures.count(textureIndex))
@@ -100,16 +93,14 @@ vtkSmartPointer<vtkTexture> CreateVTKTextureFromGLTFTexture(
   if (glTFTex.Sampler >= 0 && glTFTex.Sampler < nbSamplers)
   {
     const vtkGLTFDocumentLoader::Sampler& sampler = model->Samplers[glTFTex.Sampler];
-    if ((sampler.MinFilter == vtkGLTFDocumentLoader::Sampler::FilterType::NEAREST ||
-          sampler.MinFilter == vtkGLTFDocumentLoader::Sampler::FilterType::LINEAR) &&
-      (sampler.MagFilter == vtkGLTFDocumentLoader::Sampler::FilterType::NEAREST ||
-        sampler.MagFilter == vtkGLTFDocumentLoader::Sampler::FilterType::LINEAR))
+    if (sampler.MinFilter == vtkGLTFDocumentLoader::Sampler::FilterType::NEAREST ||
+      sampler.MinFilter == vtkGLTFDocumentLoader::Sampler::FilterType::LINEAR)
     {
-      texture->MipmapOn();
+      texture->MipmapOff();
     }
     else
     {
-      texture->MipmapOff();
+      texture->MipmapOn();
     }
 
     if (sampler.WrapS == vtkGLTFDocumentLoader::Sampler::WrapType::CLAMP_TO_EDGE ||
@@ -156,7 +147,7 @@ vtkSmartPointer<vtkTexture> CreateVTKTextureFromGLTFTexture(
   return texture;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool MaterialHasMultipleUVs(const vtkGLTFDocumentLoader::Material& material)
 {
   int firstUV = material.PbrMetallicRoughness.BaseColorTexture.TexCoord;
@@ -167,7 +158,7 @@ bool MaterialHasMultipleUVs(const vtkGLTFDocumentLoader::Material& material)
       material.PbrMetallicRoughness.MetallicRoughnessTexture.TexCoord != firstUV);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool PrimitiveNeedsTangents(const std::shared_ptr<vtkGLTFDocumentLoader::Model> model,
   const vtkGLTFDocumentLoader::Primitive& primitive)
 {
@@ -182,10 +173,10 @@ bool PrimitiveNeedsTangents(const std::shared_ptr<vtkGLTFDocumentLoader::Model>
   return normalMapIndex >= 0 && normalMapIndex < static_cast<int>(model->Textures.size());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void ApplyGLTFMaterialToVTKActor(std::shared_ptr<vtkGLTFDocumentLoader::Model> model,
   vtkGLTFDocumentLoader::Primitive& primitive, vtkSmartPointer<vtkActor> actor,
-  std::map<int, vtkSmartPointer<vtkTexture> >& existingTextures)
+  std::map<int, vtkSmartPointer<vtkTexture>>& existingTextures)
 {
   vtkGLTFDocumentLoader::Material& material = model->Materials[primitive.Material];
 
@@ -310,26 +301,44 @@ void ApplyGLTFMaterialToVTKActor(std::shared_ptr<vtkGLTFDocumentLoader::Model> m
       property->SetNormalTexture(normalTex);
     }
   }
+
+  // extension KHR_materials_unlit
+  actor->GetProperty()->SetLighting(!material.Unlit);
+  if (material.Unlit)
+  {
+    // the polydata mapper does not convert to sRGB when Unlit, so convert it there
+    double r, g, b;
+    actor->GetProperty()->GetColor(r, g, b);
+    r = pow(r, 1.f / 2.2f);
+    g = pow(g, 1.f / 2.2f);
+    b = pow(b, 1.f / 2.2f);
+    actor->GetProperty()->SetColor(r, g, b);
+  }
 };
 
-//----------------------------------------------------------------------------
-void ApplyTransformToCamera(vtkSmartPointer<vtkCamera> cam, vtkSmartPointer<vtkTransform> transform)
+//------------------------------------------------------------------------------
+void ApplyTransformToCamera(vtkSmartPointer<vtkCamera> cam, vtkSmartPointer<vtkMatrix4x4> transform)
 {
   if (!cam || !transform)
   {
     return;
   }
 
-  double position[3] = { 0.0 };
-  double viewUp[3] = { 0.0 };
-  double focus[3] = { 0.0 };
+  // At identity, camera position is origin, +y up, -z view direction
+  double position[3] = { 0.0, 0.0, 0.0 };
+  double viewUp[3] = { 0.0, 1.0, 0.0 };
+  double focus[3] = { 0.0, 0.0, -1.0 };
 
-  transform->TransformPoint(cam->GetPosition(), position);
-  transform->TransformVector(cam->GetViewUp(), viewUp);
-  transform->TransformVector(cam->GetDirectionOfProjection(), focus);
-  focus[0] -= position[0];
-  focus[1] -= position[1];
-  focus[2] -= position[2];
+  vtkNew<vtkTransform> t;
+  t->SetMatrix(transform);
+
+  t->TransformPoint(position, position);
+  t->TransformVector(viewUp, viewUp);
+  t->TransformVector(focus, focus);
+
+  focus[0] += position[0];
+  focus[1] += position[1];
+  focus[2] += position[2];
 
   cam->SetPosition(position);
   cam->SetFocalPoint(focus);
@@ -337,13 +346,13 @@ void ApplyTransformToCamera(vtkSmartPointer<vtkCamera> cam, vtkSmartPointer<vtkT
 }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGLTFImporter::~vtkGLTFImporter()
 {
   this->SetFileName(nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGLTFImporter::ImportBegin()
 {
   // Make sure we have a file to read.
@@ -389,13 +398,21 @@ int vtkGLTFImporter::ImportBegin()
     return 0;
   }
 
+  this->EnabledAnimations.resize(this->GetNumberOfAnimations());
+  std::fill(std::begin(this->EnabledAnimations), std::end(this->EnabledAnimations), false);
+
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFImporter::ImportActors(vtkRenderer* renderer)
 {
   auto model = this->Loader->GetInternalModel();
+  if (!model)
+  {
+    vtkErrorMacro("The GLTF model is nullptr, aborting.");
+    return;
+  }
 
   int scene = model->DefaultScene;
 
@@ -410,6 +427,8 @@ void vtkGLTFImporter::ImportActors(vtkRenderer* renderer)
 
   this->OutputsDescription = "";
 
+  this->Actors.clear();
+
   // Iterate over tree
   while (!nodeIdStack.empty())
   {
@@ -435,7 +454,19 @@ void vtkGLTFImporter::ImportActors(vtkRenderer* renderer)
         {
           // Generate tangents
           vtkNew<vtkPolyDataTangents> tangents;
-          tangents->SetInputData(primitive.Geometry);
+
+          if (pointData->GetNormals() == nullptr)
+          {
+            // Generate normals first
+            vtkNew<vtkPolyDataNormals> normals;
+            normals->SetInputData(primitive.Geometry);
+            tangents->SetInputConnection(normals->GetOutputPort());
+          }
+          else
+          {
+            tangents->SetInputData(primitive.Geometry);
+          }
+
           tangents->Update();
           mapper->SetInputConnection(tangents->GetOutputPort(0));
         }
@@ -445,7 +476,7 @@ void vtkGLTFImporter::ImportActors(vtkRenderer* renderer)
         }
 
         actor->SetMapper(mapper);
-        actor->SetUserTransform(node.GlobalTransform);
+        actor->SetUserMatrix(node.GlobalTransform);
 
         if (!mesh.Name.empty())
         {
@@ -461,6 +492,10 @@ void vtkGLTFImporter::ImportActors(vtkRenderer* renderer)
           ApplyGLTFMaterialToVTKActor(model, primitive, actor, this->Textures);
         }
         renderer->AddActor(actor);
+
+        this->Actors[nodeId].emplace_back(actor);
+
+        this->InvokeEvent(vtkCommand::UpdateDataEvent);
       }
     }
 
@@ -470,12 +505,19 @@ void vtkGLTFImporter::ImportActors(vtkRenderer* renderer)
       nodeIdStack.push(childNodeId);
     }
   }
+
+  this->ApplySkinningMorphing();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGLTFImporter::ImportCameras(vtkRenderer* renderer)
 {
   auto model = this->Loader->GetInternalModel();
+  if (!model)
+  {
+    vtkErrorMacro("The GLTF model is nullptr, aborting.");
+    return;
+  }
 
   int scene = model->DefaultScene;
 
@@ -488,6 +530,13 @@ void vtkGLTFImporter::ImportCameras(vtkRenderer* renderer)
     nodeIdStack.push(nodeId);
   }
 
+  this->Cameras.clear();
+  for (size_t i = 0; i < model->Cameras.size(); i++)
+  {
+    vtkGLTFDocumentLoader::Camera const& camera = model->Cameras[i];
+    this->Cameras[static_cast<int>(i)] = GLTFCameraToVTKCamera(camera);
+  }
+
   // Iterate over tree
   while (!nodeIdStack.empty())
   {
@@ -499,14 +548,7 @@ void vtkGLTFImporter::ImportCameras(vtkRenderer* renderer)
     // Import node's camera
     if (node.Camera >= 0 && node.Camera < static_cast<int>(model->Cameras.size()))
     {
-      vtkGLTFDocumentLoader::Camera const& camera = model->Cameras[node.Camera];
-      auto vtkCam = GLTFCameraToVTKCamera(camera);
-      ApplyTransformToCamera(vtkCam, node.GlobalTransform);
-      renderer->SetActiveCamera(vtkCam);
-      // Since the same glTF camera object can be used by multiple nodes (so with different
-      // transforms), multiple vtkCameras are generated for the same glTF camera object, but with
-      // different transforms.
-      this->Cameras.push_back(vtkCam);
+      ApplyTransformToCamera(this->Cameras[node.Camera], node.GlobalTransform);
     }
 
     // Add node's children to stack
@@ -515,9 +557,56 @@ void vtkGLTFImporter::ImportCameras(vtkRenderer* renderer)
       nodeIdStack.push(childNodeId);
     }
   }
+
+  // update enabled camera
+  if (this->EnabledCamera >= this->GetNumberOfCameras())
+  {
+    vtkErrorMacro("Camera index " << this->EnabledCamera << "is invalid");
+    this->EnabledCamera = -1;
+    return;
+  }
+
+  if (this->EnabledCamera >= 0)
+  {
+    renderer->SetActiveCamera(this->Cameras[this->EnabledCamera]);
+  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+vtkIdType vtkGLTFImporter::GetNumberOfCameras()
+{
+  auto model = this->Loader->GetInternalModel();
+  if (!model)
+  {
+    vtkErrorMacro("The GLTF model is nullptr, aborting.");
+    return 0;
+  }
+
+  return model->Cameras.size();
+}
+
+//------------------------------------------------------------------------------
+std::string vtkGLTFImporter::GetCameraName(vtkIdType camIndex)
+{
+  if (camIndex < 0 || camIndex >= this->GetNumberOfCameras())
+  {
+    vtkErrorMacro("Camera index invalid");
+    return "";
+  }
+  auto model = this->Loader->GetInternalModel();
+  assert(model);
+  return model->Cameras[camIndex].Name;
+}
+
+//------------------------------------------------------------------------------
+void vtkGLTFImporter::SetCamera(vtkIdType camIndex)
+{
+  // if the user sets the camera before the import, we do not know how many
+  // cameras there are, so do not check if the index if valid here
+  this->EnabledCamera = camIndex;
+}
+
+//------------------------------------------------------------------------------
 void vtkGLTFImporter::ImportLights(vtkRenderer* renderer)
 {
   // Check that lights extension is enabled
@@ -531,6 +620,12 @@ void vtkGLTFImporter::ImportLights(vtkRenderer* renderer)
   std::stack<int> nodeIdStack;
 
   const auto& model = this->Loader->GetInternalModel();
+  if (!model)
+  {
+    vtkErrorMacro("The GLTF model is nullptr, aborting.");
+    return;
+  }
+
   const auto& lights = model->ExtensionMetaData.KHRLightsPunctualMetaData.Lights;
 
   // Add root nodes to the stack
@@ -554,7 +649,7 @@ void vtkGLTFImporter::ImportLights(vtkRenderer* renderer)
       // Add light
       vtkNew<vtkLight> light;
       light->SetColor(glTFLight.Color.data());
-      light->SetTransformMatrix(node.GlobalTransform->GetMatrix());
+      light->SetTransformMatrix(node.GlobalTransform);
       // Handle range
       if (glTFLight.Range > 0)
       {
@@ -590,25 +685,204 @@ void vtkGLTFImporter::ImportLights(vtkRenderer* renderer)
 }
 
 //----------------------------------------------------------------------------
+void vtkGLTFImporter::UpdateTimeStep(double timeValue)
+{
+  for (int animationId = 0; animationId < this->GetNumberOfAnimations(); animationId++)
+  {
+    if (this->EnabledAnimations[animationId])
+    {
+      this->Loader->ApplyAnimation(static_cast<float>(timeValue), animationId);
+    }
+  }
+  this->Loader->BuildGlobalTransforms();
+
+  this->ImportCameras(this->Renderer);
+
+  this->ApplySkinningMorphing();
+}
+
+//----------------------------------------------------------------------------
+void vtkGLTFImporter::ApplySkinningMorphing()
+{
+  const auto& model = this->Loader->GetInternalModel();
+  if (!model)
+  {
+    vtkErrorMacro("The GLTF model is nullptr, aborting.");
+    return;
+  }
+
+  int scene = model->DefaultScene;
+
+  // List of nodes to import
+  std::stack<int> nodeIdStack;
+
+  // Add root nodes to the stack
+  for (int nodeId : model->Scenes[scene].Nodes)
+  {
+    nodeIdStack.push(nodeId);
+  }
+
+  // Iterate over tree
+  while (!nodeIdStack.empty())
+  {
+    // Get current node
+    int nodeId = nodeIdStack.top();
+    nodeIdStack.pop();
+    vtkGLTFDocumentLoader::Node& node = model->Nodes[nodeId];
+
+    std::vector<vtkSmartPointer<vtkMatrix4x4>> jointMats;
+    if (node.Skin >= 0)
+    {
+      vtkGLTFDocumentLoader::ComputeJointMatrices(*model, model->Skins[node.Skin], node, jointMats);
+    }
+
+    for (const auto& actor : this->Actors[nodeId])
+    {
+      actor->SetUserMatrix(node.GlobalTransform);
+
+      vtkShaderProperty* shaderProp = actor->GetShaderProperty();
+      vtkUniforms* uniforms = shaderProp->GetVertexCustomUniforms();
+      uniforms->RemoveAllUniforms();
+
+      if (!jointMats.empty())
+      {
+        std::vector<float> vec;
+        vec.reserve(16 * jointMats.size());
+        for (size_t i = 0; i < jointMats.size(); i++)
+        {
+          vtkMatrix4x4* mat = jointMats[i];
+          for (int j = 0; j < 4; j++)
+          {
+            for (int k = 0; k < 4; k++)
+            {
+              vec.push_back(static_cast<float>(mat->GetElement(k, j)));
+            }
+          }
+        }
+        uniforms->SetUniformMatrix4x4v(
+          "jointMatrices", static_cast<int>(jointMats.size()), vec.data());
+      }
+
+      if (!node.Weights.empty())
+      {
+        size_t nbWeights = vtkMath::Min<size_t>(node.Weights.size(), 4);
+        uniforms->SetUniform1fv("morphWeights", static_cast<int>(nbWeights), node.Weights.data());
+      }
+      else
+      {
+        vtkGLTFDocumentLoader::Mesh& mesh = model->Meshes[node.Mesh];
+        if (!mesh.Weights.empty())
+        {
+          size_t nbWeights = vtkMath::Min<size_t>(mesh.Weights.size(), 4);
+          uniforms->SetUniform1fv("morphWeights", static_cast<int>(nbWeights), mesh.Weights.data());
+        }
+      }
+    }
+
+    // Add node's children to stack
+    for (int childNodeId : node.Children)
+    {
+      nodeIdStack.push(childNodeId);
+    }
+  }
+}
+
+//----------------------------------------------------------------------------
+vtkIdType vtkGLTFImporter::GetNumberOfAnimations()
+{
+  const auto& model = this->Loader->GetInternalModel();
+  if (!model)
+  {
+    vtkErrorMacro("The GLTF model is nullptr, aborting.");
+    return 0;
+  }
+
+  return static_cast<vtkIdType>(model->Animations.size());
+}
+
+//----------------------------------------------------------------------------
+std::string vtkGLTFImporter::GetAnimationName(vtkIdType animationIndex)
+{
+  if (animationIndex >= 0 && animationIndex < this->GetNumberOfAnimations())
+  {
+    const auto& model = this->Loader->GetInternalModel();
+    assert(model);
+    return model->Animations[animationIndex].Name;
+  }
+  return "";
+}
+
+//----------------------------------------------------------------------------
+void vtkGLTFImporter::EnableAnimation(vtkIdType animationIndex)
+{
+  if (animationIndex >= 0 && animationIndex < this->GetNumberOfAnimations())
+  {
+    this->EnabledAnimations[animationIndex] = true;
+  }
+}
+
+//----------------------------------------------------------------------------
+void vtkGLTFImporter::DisableAnimation(vtkIdType animationIndex)
+{
+  if (animationIndex >= 0 && animationIndex < this->GetNumberOfAnimations())
+  {
+    this->EnabledAnimations[animationIndex] = false;
+  }
+}
+
+//----------------------------------------------------------------------------
+bool vtkGLTFImporter::IsAnimationEnabled(vtkIdType animationIndex)
+{
+  return this->EnabledAnimations[animationIndex];
+}
+
+//----------------------------------------------------------------------------
+bool vtkGLTFImporter::GetTemporalInformation(vtkIdType animationIndex, double frameRate,
+  int& nbTimeSteps, double timeRange[2], vtkDoubleArray* timeSteps)
+{
+  if (animationIndex < this->GetNumberOfAnimations())
+  {
+    const auto& model = this->Loader->GetInternalModel();
+    assert(model);
+
+    timeRange[0] = 0;
+    timeRange[1] = model->Animations[animationIndex].Duration;
+
+    if (frameRate > 0)
+    {
+      nbTimeSteps = 0;
+      timeSteps->SetNumberOfComponents(1);
+      timeSteps->SetNumberOfTuples(0);
+
+      std::vector<double> ts;
+      double period = (1.0 / frameRate);
+      for (double i = timeRange[0]; i < timeRange[1]; i += period)
+      {
+        timeSteps->InsertNextTuple(&i);
+        nbTimeSteps++;
+      }
+    }
+    return true;
+  }
+  return false;
+}
+
+//------------------------------------------------------------------------------
 void vtkGLTFImporter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "File Name: " << (this->FileName ? this->FileName : "(none)") << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkSmartPointer<vtkCamera> vtkGLTFImporter::GetCamera(unsigned int id)
 {
-  if (id >= this->Cameras.size())
+  auto it = this->Cameras.find(id);
+  if (it == this->Cameras.end())
   {
     vtkErrorMacro("Out of range camera index");
     return nullptr;
   }
-  return this->Cameras[id];
-}
-
-//----------------------------------------------------------------------------
-size_t vtkGLTFImporter::GetNumberOfCameras()
-{
-  return this->Cameras.size();
+  return it->second;
 }
+VTK_ABI_NAMESPACE_END
