@@ -1,21 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    LSDynaFamily.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*----------------------------------------------------------------------------
- Copyright (c) Sandia Corporation
- See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-----------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Sandia Corporation
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "LSDynaFamily.h"
 #include <vtksys/SystemTools.hxx>
@@ -30,6 +15,7 @@
 #include <string>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 // Decide which of 3 stat varieties to use: stat, stat64, __stat64
@@ -136,7 +122,7 @@ private:
   LSDynaFamily::BufferingInfo& operator=(const LSDynaFamily::BufferingInfo&) = delete;
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 LSDynaFamily::LSDynaFamily()
 {
   this->FD = VTK_LSDYNA_BADFILE; // No file open
@@ -150,7 +136,7 @@ LSDynaFamily::LSDynaFamily()
   this->TimeStep = 0;  // Initial time step
   this->StateSize = 0; // Time steps take up no room on disk
 
-  this->AdaptationsMarkers.push_back(LSDynaFamilyAdaptLevel());
+  this->AdaptationsMarkers.emplace_back();
   this->Chunk = nullptr;
   this->ChunkWord = 0;
   this->ChunkAlloc = 0;
@@ -160,7 +146,7 @@ LSDynaFamily::LSDynaFamily()
   this->BufferInfo = new LSDynaFamily::BufferingInfo();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 LSDynaFamily::~LSDynaFamily()
 {
   if (!VTK_LSDYNA_ISBADFILE(this->FD))
@@ -173,7 +159,7 @@ LSDynaFamily::~LSDynaFamily()
   delete this->BufferInfo;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::SetDatabaseDirectory(const std::string& dd)
 {
   this->DatabaseDirectory = dd;
@@ -183,7 +169,7 @@ std::string LSDynaFamily::GetDatabaseDirectory()
   return this->DatabaseDirectory;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::SetDatabaseBaseName(const std::string& bn)
 {
   this->DatabaseBaseName = bn;
@@ -193,7 +179,7 @@ std::string LSDynaFamily::GetDatabaseBaseName()
   return this->DatabaseBaseName;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::ScanDatabaseDirectory()
 {
   // FIXME: None of this need be cleared if we are trying to track a
@@ -246,13 +232,13 @@ int LSDynaFamily::ScanDatabaseDirectory()
   return this->Files.empty();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* LSDynaFamily::SectionTypeToString(SectionType s)
 {
   return SectionTypeNames[s];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::SkipToWord(SectionType sType, vtkIdType sId, vtkIdType wordNumber)
 {
   LSDynaFamilySectionMark mark;
@@ -326,7 +312,7 @@ int LSDynaFamily::SkipToWord(SectionType sType, vtkIdType sId, vtkIdType wordNum
 // FIXME: Assumes there is a valid file open and that
 // lseek will return the byte just past the time value word.
 // the BufferChunks buffer).
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::MarkTimeStep()
 {
   LSDynaFamilySectionMark mark;
@@ -337,7 +323,7 @@ int LSDynaFamily::MarkTimeStep()
   return 0;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::SkipWords(vtkIdType numWords)
 {
   if (numWords <= 0)
@@ -390,7 +376,7 @@ int LSDynaFamily::SkipWords(vtkIdType numWords)
   return 0;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::BufferChunk(WordType wType, vtkIdType chunkSizeInWords)
 {
   if (chunkSizeInWords == 0)
@@ -490,7 +476,7 @@ int LSDynaFamily::BufferChunk(WordType wType, vtkIdType chunkSizeInWords)
   return 0;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::ClearBuffer()
 {
   if (this->Chunk)
@@ -505,7 +491,7 @@ int LSDynaFamily::ClearBuffer()
   return 0;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType LSDynaFamily::InitPartialChunkBuffering(
   const vtkIdType& numTuples, const vtkIdType& numComps)
 {
@@ -530,7 +516,7 @@ vtkIdType LSDynaFamily::InitPartialChunkBuffering(
   return numChunks;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType LSDynaFamily::GetNextChunk(const WordType& wType)
 {
   vtkIdType size;
@@ -552,7 +538,7 @@ vtkIdType LSDynaFamily::GetNextChunk(const WordType& wType)
   return size;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::AdvanceFile()
 {
   if (this->FNum < 0 && VTK_LSDYNA_ISBADFILE(this->FD))
@@ -613,7 +599,7 @@ void LSDynaFamily::MarkSectionStart(int adaptLevel, SectionType m)
   mark.Offset = myWord;
   while (adaptLevel >= (int)this->AdaptationsMarkers.size())
   {
-    this->AdaptationsMarkers.push_back(LSDynaFamilyAdaptLevel());
+    this->AdaptationsMarkers.emplace_back();
   }
   this->AdaptationsMarkers[adaptLevel].Marks[m] = mark;
 
@@ -621,13 +607,13 @@ void LSDynaFamily::MarkSectionStart(int adaptLevel, SectionType m)
   // mark.Offset );
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::JumpToMark(SectionType m)
 {
   return this->SkipToWord(m, this->TimeStep, 0);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::DetermineStorageModel()
 {
   double test;
@@ -678,37 +664,37 @@ int LSDynaFamily::DetermineStorageModel()
   return 1;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::SetStateSize(vtkIdType sz)
 {
   this->StateSize = sz;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType LSDynaFamily::GetStateSize() const
 {
   return this->StateSize;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType LSDynaFamily::GetNumberOfFiles()
 {
   return static_cast<vtkIdType>(this->Files.size());
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::string LSDynaFamily::GetFileName(int i)
 {
   return this->Files[i];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType LSDynaFamily::GetFileSize(int i)
 {
   return this->FileSizes[i];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int LSDynaFamily::GetWordSize() const
 {
   return this->WordSize;
@@ -716,7 +702,7 @@ int LSDynaFamily::GetWordSize() const
 
 // Reset erases all information about the current database.
 // It does not free memory allocated for the current chunk.
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::Reset()
 {
   if (!VTK_LSDYNA_ISBADFILE(this->FD))
@@ -744,7 +730,7 @@ void LSDynaFamily::Reset()
   this->BufferInfo = new LSDynaFamily::BufferingInfo();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::DumpMarks(std::ostream& os)
 {
   int i, j;
@@ -777,7 +763,7 @@ void LSDynaFamily::DumpMarks(std::ostream& os)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::CloseFileHandles()
 {
   if (!VTK_LSDYNA_ISBADFILE(this->FD) && !this->FileHandlesClosed)
@@ -789,7 +775,7 @@ void LSDynaFamily::CloseFileHandles()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void LSDynaFamily::OpenFileHandles()
 {
   if (VTK_LSDYNA_ISBADFILE(this->FD) && this->FileHandlesClosed)
@@ -799,3 +785,4 @@ void LSDynaFamily::OpenFileHandles()
     this->FileHandlesClosed = false;
   }
 }
+VTK_ABI_NAMESPACE_END
