@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkLSDynaSummaryParser.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkLSDynaSummaryParser.h"
 #include "LSDynaMetaData.h"
@@ -19,11 +7,12 @@
 
 #include <string>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkLSDynaSummaryParser);
 
 namespace
 {
-static void vtkLSTrimWhitespace(std::string& line)
+void vtkLSTrimWhitespace(std::string& line)
 {
   std::string::size_type llen = line.length();
   while (llen &&
@@ -44,7 +33,7 @@ static void vtkLSTrimWhitespace(std::string& line)
 
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkLSDynaSummaryParser::vtkLSDynaSummaryParser()
   : MetaData(nullptr)
   , PartId(-1)
@@ -56,7 +45,7 @@ vtkLSDynaSummaryParser::vtkLSDynaSummaryParser()
 {
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLSDynaSummaryParser::StartElement(const char* name, const char** atts)
 {
   int i;
@@ -164,7 +153,7 @@ void vtkLSDynaSummaryParser::StartElement(const char* name, const char** atts)
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLSDynaSummaryParser::EndElement(const char* name)
 {
   if (!strcmp(name, "part"))
@@ -193,7 +182,7 @@ void vtkLSDynaSummaryParser::EndElement(const char* name)
     this->InDyna = this->InPart = this->InName = 0;
   }
 }
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLSDynaSummaryParser::CharacterDataHandler(const char* data, int length)
 {
   if (!this->InName)
@@ -202,14 +191,14 @@ void vtkLSDynaSummaryParser::CharacterDataHandler(const char* data, int length)
   }
   // skip leading whitespace
   int i = 0;
-  while (this->PartName.empty() && i < length && this->IsSpace(data[i]))
+  while (this->PartName.empty() && i < length && vtkLSDynaSummaryParser::IsSpace(data[i]))
     ++i;
 
   if (i < length)
     this->PartName.append(data + i, length - i);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkLSDynaSummaryParser::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -222,3 +211,4 @@ void vtkLSDynaSummaryParser::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "InDyna: " << this->InDyna << endl;
   os << indent << "InName: " << this->InName << endl;
 }
+VTK_ABI_NAMESPACE_END
