@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkDataReader.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkDataReader.h"
 
 #include "vtkBitArray.h"
@@ -51,7 +40,6 @@
 #include "vtkTable.h"
 #include "vtkTypeInt64Array.h"
 #include "vtkTypeUInt64Array.h"
-#include "vtkUnicodeStringArray.h"
 #include "vtkUnsignedCharArray.h"
 #include "vtkUnsignedIntArray.h"
 #include "vtkUnsignedLongArray.h"
@@ -71,22 +59,18 @@
 // myself.
 // This function is also defined in Infovis/vtkDelimitedTextReader.cxx,
 // so it would be nice to put this in a common file.
-static int my_getline(istream& stream, vtkStdString& output, char delim = '\n');
+VTK_ABI_NAMESPACE_BEGIN
+static int my_getline(istream& in, std::string& output, char delim = '\n');
 
 vtkStandardNewMacro(vtkDataReader);
 
 vtkCxxSetObjectMacro(vtkDataReader, InputArray, vtkCharArray);
 
-// this undef is required on the hp. vtkMutexLock ends up including
-// /usr/include/dce/cma_ux.h which has the gall to #define read as cma_read
-
-#ifdef read
-#undef read
-#endif
-
+//------------------------------------------------------------------------------
 // Construct object.
 vtkDataReader::vtkDataReader()
 {
+  this->FileVersion = 0;
   this->FileType = VTK_ASCII;
   this->ScalarsName = nullptr;
   this->VectorsName = nullptr;
@@ -138,6 +122,7 @@ vtkDataReader::vtkDataReader()
   this->SetNumberOfOutputPorts(1);
 }
 
+//------------------------------------------------------------------------------
 vtkDataReader::~vtkDataReader()
 {
   delete[] this->ScalarsName;
@@ -156,6 +141,7 @@ vtkDataReader::~vtkDataReader()
   delete this->IS;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetFileName(const char* fname)
 {
   if (this->GetNumberOfFileNames() == 1 && this->GetFileName(0) && fname &&
@@ -171,6 +157,7 @@ void vtkDataReader::SetFileName(const char* fname)
   this->Modified();
 }
 
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetFileName() const
 {
   if (this->GetNumberOfFileNames() < 1)
@@ -180,6 +167,7 @@ const char* vtkDataReader::GetFileName() const
   return this->vtkSimpleReader::GetFileName(0);
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadTimeDependentMetaData(int timestep, vtkInformation* metadata)
 {
   if (this->ReadFromInputString)
@@ -190,6 +178,7 @@ int vtkDataReader::ReadTimeDependentMetaData(int timestep, vtkInformation* metad
   return this->Superclass::ReadTimeDependentMetaData(timestep, metadata);
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadMesh(
   int piece, int npieces, int nghosts, int timestep, vtkDataObject* output)
 {
@@ -208,6 +197,7 @@ int vtkDataReader::ReadMesh(
   return this->Superclass::ReadMesh(piece, npieces, nghosts, timestep, output);
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetInputString(const char* in)
 {
   int len = 0;
@@ -218,11 +208,13 @@ void vtkDataReader::SetInputString(const char* in)
   this->SetInputString(in, len);
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetBinaryInputString(const char* in, int len)
 {
   this->SetInputString(in, len);
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::SetInputString(const char* in, int len)
 {
   if (this->Debug)
@@ -257,6 +249,7 @@ void vtkDataReader::SetInputString(const char* in, int len)
   this->Modified();
 }
 
+//------------------------------------------------------------------------------
 // Internal function to read in a line up to 256 characters.
 // Returns zero if there was an error.
 int vtkDataReader::ReadLine(char result[256])
@@ -284,12 +277,16 @@ int vtkDataReader::ReadLine(char result[256])
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Internal function to read in a string up to 256 characters.
 // Returns zero if there was an error.
-int vtkDataReader::ReadString(char result[256])
+int vtkDataReader::ReadString(char (&result)[256])
 {
+  // Force the parameter to be seen as a 256-byte array rather than a decayed
+  // pointer.
+  char(&result_ref)[256] = *reinterpret_cast<char(*)[256]>(result);
   this->IS->width(256);
-  *this->IS >> result;
+  *this->IS >> result_ref;
   if (this->IS->fail())
   {
     return 0;
@@ -297,6 +294,7 @@ int vtkDataReader::ReadString(char result[256])
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Internal function to read in an integer value.
 // Returns zero if there was an error.
 int vtkDataReader::Read(char* result)
@@ -312,6 +310,7 @@ int vtkDataReader::Read(char* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned char* result)
 {
   int intData;
@@ -325,6 +324,7 @@ int vtkDataReader::Read(unsigned char* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(short* result)
 {
   *this->IS >> *result;
@@ -335,6 +335,7 @@ int vtkDataReader::Read(short* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned short* result)
 {
   *this->IS >> *result;
@@ -345,6 +346,7 @@ int vtkDataReader::Read(unsigned short* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(int* result)
 {
   *this->IS >> *result;
@@ -355,6 +357,7 @@ int vtkDataReader::Read(int* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned int* result)
 {
   *this->IS >> *result;
@@ -365,6 +368,7 @@ int vtkDataReader::Read(unsigned int* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(long* result)
 {
   *this->IS >> *result;
@@ -375,6 +379,7 @@ int vtkDataReader::Read(long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned long* result)
 {
   *this->IS >> *result;
@@ -385,6 +390,7 @@ int vtkDataReader::Read(unsigned long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(long long* result)
 {
   *this->IS >> *result;
@@ -395,6 +401,7 @@ int vtkDataReader::Read(long long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(unsigned long long* result)
 {
   *this->IS >> *result;
@@ -405,6 +412,7 @@ int vtkDataReader::Read(unsigned long long* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(float* result)
 {
   *this->IS >> *result;
@@ -415,6 +423,7 @@ int vtkDataReader::Read(float* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::Read(double* result)
 {
   *this->IS >> *result;
@@ -425,6 +434,7 @@ int vtkDataReader::Read(double* result)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 size_t vtkDataReader::Peek(char* str, size_t n)
 {
   if (n == 0)
@@ -445,6 +455,7 @@ size_t vtkDataReader::Peek(char* str, size_t n)
   return len;
 }
 
+//------------------------------------------------------------------------------
 // Open a vtk data file. Returns zero if error.
 int vtkDataReader::OpenVTKFile(const char* fname)
 {
@@ -517,6 +528,7 @@ int vtkDataReader::OpenVTKFile(const char* fname)
   return 0;
 }
 
+//------------------------------------------------------------------------------
 // Read the header of a vtk data file. Returns 0 if error.
 int vtkDataReader::ReadHeader(const char* fname)
 {
@@ -538,7 +550,7 @@ int vtkDataReader::ReadHeader(const char* fname)
     return 0;
   }
   const int VERSION_PREFIX_LENGTH = 22;
-  if (strncmp("# vtk DataFile Version", line, VERSION_PREFIX_LENGTH))
+  if (strncmp("# vtk DataFile Version", line, VERSION_PREFIX_LENGTH) != 0)
   {
     vtkErrorMacro(<< "Unrecognized file type: " << line
                   << " for file: " << (fname ? fname : "(Null FileName)"));
@@ -563,6 +575,8 @@ int vtkDataReader::ReadHeader(const char* fname)
                     << this->FileMinorVersion << " with older reader version "
                     << vtkLegacyReaderMajorVersion << "." << vtkLegacyReaderMinorVersion);
   }
+  // Compose FileVersion
+  this->FileVersion = 10 * this->FileMajorVersion + this->FileMinorVersion;
 
   //
   // read title
@@ -639,9 +653,10 @@ int vtkDataReader::ReadHeader(const char* fname)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::IsFileValid(const char* dstype)
 {
-  char line[1024];
+  char line[256];
 
   if (!dstype)
   {
@@ -662,7 +677,7 @@ int vtkDataReader::IsFileValid(const char* dstype)
     return 0;
   }
 
-  if (!strncmp(this->LowerCase(line), "dataset", (unsigned long)7))
+  if (!strncmp(this->LowerCase(line), "dataset", 7))
   {
     if (!this->ReadString(line))
     {
@@ -671,7 +686,7 @@ int vtkDataReader::IsFileValid(const char* dstype)
       this->SetErrorCode(vtkErrorCode::PrematureEndOfFileError);
       return 0;
     }
-    if (strncmp(this->LowerCase(line), dstype, strlen(dstype)))
+    if (strncmp(this->LowerCase(line), dstype, strlen(dstype)) != 0)
     {
       this->CloseVTKFile();
       return 0;
@@ -685,6 +700,7 @@ int vtkDataReader::IsFileValid(const char* dstype)
   return 0;
 }
 
+//------------------------------------------------------------------------------
 // Read the cell data of a vtk data file. The number of cells (from the
 // dataset) must match the number of cells defined in cell attributes (unless
 // no geometry was defined).
@@ -843,6 +859,7 @@ int vtkDataReader::ReadCellData(vtkDataSet* ds, vtkIdType numCells)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the point data of a vtk data file. The number of points (from the
 // dataset) must match the number of points defined in point attributes (unless
 // no geometry was defined).
@@ -1011,6 +1028,7 @@ int vtkDataReader::ReadPointData(vtkDataSet* ds, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the vertex data of a vtk data file. The number of vertices (from the
 // graph) must match the number of vertices defined in vertex attributes (unless
 // no geometry was defined).
@@ -1145,7 +1163,7 @@ int vtkDataReader::ReadVertexData(vtkGraph* g, vtkIdType numVertices)
     //
     // maybe bumped into edge data
     //
-    else if (!strncmp(line, "edge_data", 10))
+    else if (!strncmp(line, "edge_data", 9))
     {
       vtkIdType npts;
       if (!this->Read(&npts))
@@ -1169,6 +1187,7 @@ int vtkDataReader::ReadVertexData(vtkGraph* g, vtkIdType numVertices)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the edge data of a vtk data file. The number of edges (from the
 // graph) must match the number of edges defined in edge attributes (unless
 // no geometry was defined).
@@ -1327,6 +1346,7 @@ int vtkDataReader::ReadEdgeData(vtkGraph* g, vtkIdType numEdges)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the row data of a vtk data file.
 int vtkDataReader::ReadRowData(vtkTable* t, vtkIdType numEdges)
 {
@@ -1511,6 +1531,7 @@ int vtkReadASCIIData(vtkDataReader* self, T* data, vtkIdType numTuples, vtkIdTyp
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Description:
 // Read data array. Return pointer to array object if successful read;
 // otherwise return nullptr. Note: this method instantiates a reference counted
@@ -1794,7 +1815,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
     }
   }
 
-  else if (!strncmp(type, "string", 6))
+  else if (!strncmp(type, "string", 6) || !strncmp(type, "utf8_string", 11))
   {
     array = vtkStringArray::New();
     array->SetNumberOfComponents(numComp);
@@ -1811,7 +1832,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
         {
           vtkTypeUInt8 firstByte;
           vtkTypeUInt8 headerType;
-          vtkStdString::size_type stringLength;
+          std::string::size_type stringLength;
           firstByte = IS->peek();
           headerType = firstByte >> 6;
           if (headerType == 3)
@@ -1843,12 +1864,12 @@ vtkAbstractArray* vtkDataReader::ReadArray(
           {
             vtkTypeUInt64 length;
             IS->read(reinterpret_cast<char*>(&length), 8);
-            vtkByteSwap::Swap4BE(&length);
+            vtkByteSwap::Swap8BE(&length);
             stringLength = length;
           }
           std::vector<char> str(stringLength);
           IS->read(str.data(), stringLength);
-          vtkStdString s(str.data(), stringLength);
+          std::string s(str.data(), stringLength);
           ((vtkStringArray*)array)->InsertNextValue(s);
         }
       }
@@ -1856,7 +1877,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
     else
     {
       // read in newline
-      vtkStdString s;
+      std::string s;
       my_getline(*(this->IS), s);
 
       for (vtkIdType i = 0; i < numTuples; i++)
@@ -1867,92 +1888,12 @@ vtkAbstractArray* vtkDataReader::ReadArray(
           int length = static_cast<int>(s.length());
           std::vector<char> decoded(length + 1);
           int decodedLength = this->DecodeString(decoded.data(), s.c_str());
-          vtkStdString decodedStr(decoded.data(), decodedLength);
+          std::string decodedStr(decoded.data(), decodedLength);
           ((vtkStringArray*)array)->InsertNextValue(decodedStr);
         }
       }
     }
   }
-  else if (!strncmp(type, "utf8_string", 11))
-  {
-    array = vtkUnicodeStringArray::New();
-    array->SetNumberOfComponents(numComp);
-
-    if (this->FileType == VTK_BINARY)
-    {
-      // read in newline
-      char line[256];
-      IS->getline(line, 256);
-
-      for (vtkIdType i = 0; i < numTuples; i++)
-      {
-        for (vtkIdType j = 0; j < numComp; j++)
-        {
-          vtkTypeUInt8 firstByte;
-          vtkTypeUInt8 headerType;
-          vtkStdString::size_type stringLength;
-          firstByte = IS->peek();
-          headerType = firstByte >> 6;
-          if (headerType == 3)
-          {
-            vtkTypeUInt8 length = IS->get();
-            length <<= 2;
-            length >>= 2;
-            stringLength = length;
-          }
-          else if (headerType == 2)
-          {
-            vtkTypeUInt16 length;
-            IS->read(reinterpret_cast<char*>(&length), 2);
-            vtkByteSwap::Swap2BE(&length);
-            length <<= 2;
-            length >>= 2;
-            stringLength = length;
-          }
-          else if (headerType == 1)
-          {
-            vtkTypeUInt32 length;
-            IS->read(reinterpret_cast<char*>(&length), 4);
-            vtkByteSwap::Swap4BE(&length);
-            length <<= 2;
-            length >>= 2;
-            stringLength = length;
-          }
-          else
-          {
-            vtkTypeUInt64 length;
-            IS->read(reinterpret_cast<char*>(&length), 8);
-            vtkByteSwap::Swap4BE(&length);
-            stringLength = length;
-          }
-          std::vector<char> str(stringLength);
-          IS->read(str.data(), stringLength);
-          vtkUnicodeString s = vtkUnicodeString::from_utf8(str.data(), str.data() + stringLength);
-          ((vtkUnicodeStringArray*)array)->InsertNextValue(s);
-        }
-      }
-    }
-    else
-    {
-      // read in newline
-      vtkStdString s;
-      my_getline(*(this->IS), s);
-
-      for (vtkIdType i = 0; i < numTuples; i++)
-      {
-        for (vtkIdType j = 0; j < numComp; j++)
-        {
-          my_getline(*(this->IS), s);
-          int length = static_cast<int>(s.length());
-          std::vector<char> decoded(length + 1);
-          int decodedLength = this->DecodeString(decoded.data(), s.c_str());
-          vtkUnicodeString decodedStr =
-            vtkUnicodeString::from_utf8(decoded.data(), decoded.data() + decodedLength);
-          ((vtkUnicodeStringArray*)array)->InsertNextValue(decodedStr);
-        }
-      }
-    }
-  }
   else if (!strncmp(type, "variant", 7))
   {
     array = vtkVariantArray::New();
@@ -1962,11 +1903,11 @@ vtkAbstractArray* vtkDataReader::ReadArray(
       for (vtkIdType j = 0; j < numComp; j++)
       {
         int t;
-        vtkStdString str;
+        std::string str;
         *(this->IS) >> t >> str;
         std::vector<char> decoded(str.length() + 1);
         int decodedLength = this->DecodeString(decoded.data(), str.c_str());
-        vtkStdString decodedStr(decoded.data(), decodedLength);
+        std::string decodedStr(decoded.data(), decodedLength);
         vtkVariant sv(decodedStr);
         vtkVariant v;
         switch (t)
@@ -2142,6 +2083,7 @@ vtkAbstractArray* vtkDataReader::ReadArray(
   return array;
 }
 
+//------------------------------------------------------------------------------
 // Read point coordinates. Return 0 if error.
 int vtkDataReader::ReadPointCoordinates(vtkPointSet* ps, vtkIdType numPts)
 {
@@ -2177,6 +2119,7 @@ int vtkDataReader::ReadPointCoordinates(vtkPointSet* ps, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read point coordinates. Return 0 if error.
 int vtkDataReader::ReadPointCoordinates(vtkGraph* g, vtkIdType numPts)
 {
@@ -2212,6 +2155,7 @@ int vtkDataReader::ReadPointCoordinates(vtkGraph* g, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read the coordinates for a rectilinear grid. The axes parameter specifies
 // which coordinate axes (0,1,2) is being read.
 int vtkDataReader::ReadCoordinates(vtkRectilinearGrid* rg, int axes, int numCoords)
@@ -2255,6 +2199,7 @@ int vtkDataReader::ReadCoordinates(vtkRectilinearGrid* rg, int axes, int numCoor
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read scalar point attributes. Return 0 if error.
 int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
@@ -2262,7 +2207,7 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   int skipScalar = 0;
   vtkDataArray* data;
   int numComp = 1;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2283,7 +2228,7 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   }
 
   // the next string could be an integer number of components or a lookup table
-  if (strcmp(this->LowerCase(key), "lookup_table"))
+  if (strcmp(this->LowerCase(key), "lookup_table") != 0)
   {
     numComp = atoi(key);
     if (numComp < 1 || !this->ReadString(key))
@@ -2295,7 +2240,7 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
     }
   }
 
-  if (strcmp(this->LowerCase(key), "lookup_table"))
+  if (strcmp(this->LowerCase(key), "lookup_table") != 0)
   {
     vtkErrorMacro(<< "Lookup table must be specified with scalar.\n"
                   << "Use \"LOOKUP_TABLE default\" to use default table.");
@@ -2313,7 +2258,7 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   // See whether scalar has been already read or scalar name (if specified)
   // matches name in file.
   //
-  if (a->GetScalars() != nullptr || (this->ScalarsName && strcmp(name, this->ScalarsName)))
+  if (a->GetScalars() != nullptr || (this->ScalarsName && strcmp(name, this->ScalarsName) != 0))
   {
     skipScalar = 1;
   }
@@ -2348,13 +2293,14 @@ int vtkDataReader::ReadScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read vector point attributes. Return 0 if error.
 int vtkDataReader::ReadVectorData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipVector = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2369,7 +2315,7 @@ int vtkDataReader::ReadVectorData(vtkDataSetAttributes* a, vtkIdType numPts)
   // See whether vector has been already read or vector name (if specified)
   // matches name in file.
   //
-  if (a->GetVectors() != nullptr || (this->VectorsName && strcmp(name, this->VectorsName)))
+  if (a->GetVectors() != nullptr || (this->VectorsName && strcmp(name, this->VectorsName) != 0))
   {
     skipVector = 1;
   }
@@ -2399,13 +2345,14 @@ int vtkDataReader::ReadVectorData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read normal point attributes. Return 0 if error.
 int vtkDataReader::ReadNormalData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipNormal = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2420,7 +2367,7 @@ int vtkDataReader::ReadNormalData(vtkDataSetAttributes* a, vtkIdType numPts)
   // See whether normal has been already read or normal name (if specified)
   // matches name in file.
   //
-  if (a->GetNormals() != nullptr || (this->NormalsName && strcmp(name, this->NormalsName)))
+  if (a->GetNormals() != nullptr || (this->NormalsName && strcmp(name, this->NormalsName) != 0))
   {
     skipNormal = 1;
   }
@@ -2450,13 +2397,14 @@ int vtkDataReader::ReadNormalData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read tensor point attributes. Return 0 if error.
 int vtkDataReader::ReadTensorData(vtkDataSetAttributes* a, vtkIdType numPts, vtkIdType numComp)
 {
   int skipTensor = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2470,7 +2418,7 @@ int vtkDataReader::ReadTensorData(vtkDataSetAttributes* a, vtkIdType numPts, vtk
   // See whether tensor has been already read or tensor name (if specified)
   // matches name in file.
   //
-  if (a->GetTensors() != nullptr || (this->TensorsName && strcmp(name, this->TensorsName)))
+  if (a->GetTensors() != nullptr || (this->TensorsName && strcmp(name, this->TensorsName) != 0))
   {
     skipTensor = 1;
   }
@@ -2500,12 +2448,13 @@ int vtkDataReader::ReadTensorData(vtkDataSetAttributes* a, vtkIdType numPts, vtk
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read color scalar point attributes. Return 0 if error.
 int vtkDataReader::ReadCoScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int i, j, idx, numComp = 0, skipScalar = 0;
   char name[256];
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->Read(&numComp)))
   {
@@ -2519,7 +2468,7 @@ int vtkDataReader::ReadCoScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   // See whether scalar has been already read or scalar name (if specified)
   // matches name in file.
   //
-  if (a->GetScalars() != nullptr || (this->ScalarsName && strcmp(name, this->ScalarsName)))
+  if (a->GetScalars() != nullptr || (this->ScalarsName && strcmp(name, this->ScalarsName) != 0))
   {
     skipScalar = 1;
   }
@@ -2596,6 +2545,7 @@ int vtkDataReader::ReadCoScalarData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read texture coordinates point attributes. Return 0 if error.
 int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
 {
@@ -2603,7 +2553,7 @@ int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
   int skipTCoord = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->Read(&dim) && this->ReadString(line)))
   {
@@ -2626,7 +2576,7 @@ int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
   // See whether texture coords have been already read or texture coords name
   // (if specified) matches name in file.
   //
-  if (a->GetTCoords() != nullptr || (this->TCoordsName && strcmp(name, this->TCoordsName)))
+  if (a->GetTCoords() != nullptr || (this->TCoordsName && strcmp(name, this->TCoordsName) != 0))
   {
     skipTCoord = 1;
   }
@@ -2656,13 +2606,14 @@ int vtkDataReader::ReadTCoordsData(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read texture coordinates point attributes. Return 0 if error.
 int vtkDataReader::ReadGlobalIds(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipGlobalIds = 0;
   char line[256], name[256];
   vtkDataArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2702,13 +2653,14 @@ int vtkDataReader::ReadGlobalIds(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read pedigree ids. Return 0 if error.
 int vtkDataReader::ReadPedigreeIds(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipPedigreeIds = 0;
   char line[256], name[256];
   vtkAbstractArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2748,13 +2700,14 @@ int vtkDataReader::ReadPedigreeIds(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read edge flags. Return 0 if error.
 int vtkDataReader::ReadEdgeFlags(vtkDataSetAttributes* a, vtkIdType numPts)
 {
   int skipEdgeFlags = 0;
   char line[256], name[256];
   vtkAbstractArray* data;
-  char buffer[1024];
+  char buffer[256];
 
   if (!(this->ReadString(buffer) && this->ReadString(line)))
   {
@@ -2794,6 +2747,7 @@ int vtkDataReader::ReadEdgeFlags(vtkDataSetAttributes* a, vtkIdType numPts)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
 {
   // Assuming that the opening INFORMATION line has been read.
@@ -2879,7 +2833,7 @@ int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
         }
         if (values.size() == static_cast<size_t>(length))
         {
-          info->Set(dvKey, &values[0], length);
+          info->Set(dvKey, values.data(), length);
         }
 
         // Pop off the trailing newline:
@@ -2946,7 +2900,7 @@ int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
         }
         if (values.size() == static_cast<size_t>(length))
         {
-          info->Set(ivKey, &values[0], length);
+          info->Set(ivKey, values.data(), length);
         }
 
         // Pop off the trailing newline:
@@ -3051,6 +3005,7 @@ int vtkDataReader::ReadInformation(vtkInformation* info, vtkIdType numKeys)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read lookup table. Return 0 if error.
 int vtkDataReader::ReadLutData(vtkDataSetAttributes* a)
 {
@@ -3069,8 +3024,8 @@ int vtkDataReader::ReadLutData(vtkDataSetAttributes* a)
   }
 
   if (a->GetScalars() == nullptr ||
-    (this->LookupTableName && strcmp(name, this->LookupTableName)) ||
-    (this->ScalarLut && strcmp(name, this->ScalarLut)))
+    (this->LookupTableName && strcmp(name, this->LookupTableName) != 0) ||
+    (this->ScalarLut && strcmp(name, this->ScalarLut) != 0))
   {
     skipTable = 1;
   }
@@ -3121,6 +3076,7 @@ int vtkDataReader::ReadLutData(vtkDataSetAttributes* a)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadCells(vtkSmartPointer<vtkCellArray>& cellArray)
 {
   vtkIdType offsetsSize{ 0 };
@@ -3201,6 +3157,7 @@ int vtkDataReader::ReadCells(vtkSmartPointer<vtkCellArray>& cellArray)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 // Read lookup table. Return 0 if error.
 int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data)
 {
@@ -3241,6 +3198,7 @@ int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data)
   return 1;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data, int skip1, int read2, int skip3)
 {
   char line[256];
@@ -3353,6 +3311,7 @@ int vtkDataReader::ReadCellsLegacy(vtkIdType size, int* data, int skip1, int rea
   return 1;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::ConvertGhostLevelsToGhostType(FieldType fieldType, vtkAbstractArray* data) const
 {
   vtkUnsignedCharArray* ucData = vtkArrayDownCast<vtkUnsignedCharArray>(data);
@@ -3381,6 +3340,7 @@ void vtkDataReader::ConvertGhostLevelsToGhostType(FieldType fieldType, vtkAbstra
   }
 }
 
+//------------------------------------------------------------------------------
 vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
 {
   int i, numArrays = 0, skipField = 0;
@@ -3398,7 +3358,7 @@ vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
   }
 
   // See whether field data name (if specified)
-  if ((this->FieldDataName && strcmp(name, this->FieldDataName)))
+  if ((this->FieldDataName && strcmp(name, this->FieldDataName) != 0))
   {
     skipField = 1;
   }
@@ -3409,7 +3369,7 @@ vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
   // Read the number of arrays specified
   for (i = 0; i < numArrays; i++)
   {
-    char buffer[1024];
+    char buffer[256];
     this->ReadString(buffer);
     if (strcmp(buffer, "NULL_ARRAY") == 0)
     {
@@ -3448,7 +3408,8 @@ vtkFieldData* vtkDataReader::ReadFieldData(FieldType fieldType)
   }
 }
 
-char* vtkDataReader::LowerCase(char* str, const size_t len)
+//------------------------------------------------------------------------------
+char* vtkDataReader::LowerCase(char* str, size_t len)
 {
   size_t i;
   char* s;
@@ -3472,6 +3433,7 @@ void vtkDataReader::CloseVTKFile()
   this->IS = nullptr;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::InitializeCharacteristics()
 {
   int i;
@@ -3544,6 +3506,7 @@ void vtkDataReader::InitializeCharacteristics()
   }
 }
 
+//------------------------------------------------------------------------------
 // read entire file, storing important characteristics
 int vtkDataReader::CharacterizeFile()
 {
@@ -3583,6 +3546,7 @@ int vtkDataReader::CharacterizeFile()
   return 1;
 }
 
+//------------------------------------------------------------------------------
 void vtkDataReader::CheckFor(const char* name, char* line, int& num, char**& array, int& allocSize)
 {
   if (!strncmp(this->LowerCase(line, strlen(name)), name, strlen(name)))
@@ -3631,6 +3595,7 @@ void vtkDataReader::CheckFor(const char* name, char* line, int& num, char**& arr
   } // found one
 }
 
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetScalarsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3644,6 +3609,7 @@ const char* vtkDataReader::GetScalarsNameInFile(int i)
   }
 }
 
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetVectorsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3656,6 +3622,7 @@ const char* vtkDataReader::GetVectorsNameInFile(int i)
     return this->VectorsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetTensorsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3668,6 +3635,7 @@ const char* vtkDataReader::GetTensorsNameInFile(int i)
     return this->TensorsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetNormalsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3680,6 +3648,7 @@ const char* vtkDataReader::GetNormalsNameInFile(int i)
     return this->NormalsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetTCoordsNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3692,6 +3661,7 @@ const char* vtkDataReader::GetTCoordsNameInFile(int i)
     return this->TCoordsNameInFile[i];
   }
 }
+//------------------------------------------------------------------------------
 const char* vtkDataReader::GetFieldDataNameInFile(int i)
 {
   this->CharacterizeFile();
@@ -3705,33 +3675,13 @@ const char* vtkDataReader::GetFieldDataNameInFile(int i)
   }
 }
 
-vtkTypeBool vtkDataReader::ProcessRequest(
-  vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
-{
-  // generate the data
-  if (request->Has(vtkDemandDrivenPipeline::REQUEST_DATA()))
-  {
-    return this->RequestData(request, inputVector, outputVector);
-  }
-
-  if (request->Has(vtkStreamingDemandDrivenPipeline::REQUEST_UPDATE_EXTENT()))
-  {
-    return this->RequestUpdateExtent(request, inputVector, outputVector);
-  }
-
-  // execute information
-  if (request->Has(vtkDemandDrivenPipeline::REQUEST_INFORMATION()))
-  {
-    return this->RequestInformation(request, inputVector, outputVector);
-  }
-
-  return this->Superclass::ProcessRequest(request, inputVector, outputVector);
-}
-
+//------------------------------------------------------------------------------
 void vtkDataReader::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
+  os << indent << "File Version: " << this->FileVersion << "\n";
+
   if (this->FileType == VTK_BINARY)
   {
     os << indent << "File Type: BINARY\n";
@@ -3846,11 +3796,13 @@ void vtkDataReader::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "InputStringLength: " << this->InputStringLength << endl;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::ReadDataSetData(vtkDataSet* vtkNotUsed(ds))
 {
   return 0;
 }
 
+//------------------------------------------------------------------------------
 int vtkDataReader::DecodeString(char* resname, const char* name)
 {
   if (!resname || !name)
@@ -3890,9 +3842,9 @@ int vtkDataReader::DecodeString(char* resname, const char* name)
   return static_cast<int>(reslen);
 }
 
-static int my_getline(istream& in, vtkStdString& out, char delimiter)
+static int my_getline(istream& in, std::string& out, char delimiter)
 {
-  out = vtkStdString();
+  out = std::string();
   unsigned int numCharactersRead = 0;
   int nextValue = 0;
 
@@ -3914,24 +3866,24 @@ static int my_getline(istream& in, vtkStdString& out, char delimiter)
   return numCharactersRead;
 }
 
-//----------------------------------------------------------------------------
-void vtkDataReader::SetScalarLut(const char* sl)
+//------------------------------------------------------------------------------
+void vtkDataReader::SetScalarLut(const char* lut)
 {
-  if (!this->ScalarLut && !sl)
+  if (!this->ScalarLut && !lut)
   {
     return;
   }
-  if (this->ScalarLut && sl && (strcmp(this->ScalarLut, sl)) == 0)
+  if (this->ScalarLut && lut && (strcmp(this->ScalarLut, lut)) == 0)
   {
     return;
   }
   delete[] this->ScalarLut;
   this->ScalarLut = nullptr;
-  if (sl)
+  if (lut)
   {
-    size_t n = strlen(sl) + 1;
+    size_t n = strlen(lut) + 1;
     char* cp1 = new char[n];
-    const char* cp2 = sl;
+    const char* cp2 = lut;
     this->ScalarLut = cp1;
     do
     {
@@ -3939,3 +3891,4 @@ void vtkDataReader::SetScalarLut(const char* sl)
     } while (--n);
   }
 }
+VTK_ABI_NAMESPACE_END
