@@ -1,23 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkEnSightWriter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-
-/*----------------------------------------------------------------------------
- Copyright (c) Sandia Corporation
- See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-----------------------------------------------------------------------------*/
-
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright (c) Sandia Corporation
+// SPDX-License-Identifier: BSD-3-Clause
 /* TODO
  *
  *
@@ -29,16 +12,12 @@
 
 #include <vtksys/SystemTools.hxx>
 
-#include "vtkToolkits.h" // for VTK_USE_PARALLEL
-#ifdef VTK_USE_PARALLEL
-#include "vtkMultiProcessController.h"
-#endif
-
 #include "vtkBitArray.h"
 #include "vtkByteSwap.h"
 #include "vtkCellArray.h"
 #include "vtkCellData.h"
 #include "vtkCharArray.h"
+#include "vtkCommand.h"
 #include "vtkDataSet.h"
 #include "vtkDoubleArray.h"
 #include "vtkErrorCode.h"
@@ -46,9 +25,11 @@
 #include "vtkFloatArray.h"
 #include "vtkInformation.h"
 #include "vtkIntArray.h"
+#include "vtkLogger.h"
 #include "vtkLongArray.h"
 #include "vtkLookupTable.h"
 #include "vtkMath.h"
+#include "vtkMultiProcessController.h"
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 #include "vtkPoints.h"
@@ -80,17 +61,11 @@
 #define VTK_QUADRATIC_PYRAMID 27
 #endif
 
-// this undef is required on the hp. vtkMutexLock ends up including
-// /usr/include/dce/cma_ux.h which has the gall to #define write as cma_write
-
-#ifdef write
-#undef write
-#endif
-
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkEnSightWriter);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Created object with no filename and timestep 0
 vtkEnSightWriter::vtkEnSightWriter()
 {
@@ -101,6 +76,8 @@ vtkEnSightWriter::vtkEnSightWriter()
   this->Path = nullptr;
   this->GhostLevelMultiplier = 10000;
   this->GhostLevel = 0;
+  this->WriteNodeIDs = true;
+  this->WriteElementIDs = true;
   this->TransientGeometry = false;
   this->ProcessNumber = 0;
   this->NumberOfProcesses = 1;
@@ -109,7 +86,7 @@ vtkEnSightWriter::vtkEnSightWriter()
   this->TmpInput = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkEnSightWriter::~vtkEnSightWriter()
 {
   this->SetBaseName(nullptr);
@@ -117,7 +94,7 @@ vtkEnSightWriter::~vtkEnSightWriter()
   this->SetPath(nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -133,6 +110,8 @@ void vtkEnSightWriter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "NumberOfBlocks: " << this->NumberOfBlocks << endl;
   os << indent << "BlockIDs: " << this->BlockIDs << endl;
   os << indent << "GhostLevel: " << this->GhostLevel << endl;
+  os << indent << "WriteNodeIDs: " << this->WriteNodeIDs << endl;
+  os << indent << "WriteElementIDs: " << this->WriteElementIDs << endl;
 }
 
 int vtkEnSightWriter::FillInputPortInformation(int vtkNotUsed(port), vtkInformation* info)
@@ -141,14 +120,47 @@ int vtkEnSightWriter::FillInputPortInformation(int vtkNotUsed(port), vtkInformat
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+int vtkEnSightWriter::RequestData(vtkInformation* vtkNotUsed(request),
+  vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* vtkNotUsed(outputVector))
+{
+  this->SetErrorCode(vtkErrorCode::NoError);
+
+  vtkDataObject* input = this->GetInput();
+
+  // make sure input is available
+  if (!input)
+  {
+    vtkErrorMacro(<< "No input!");
+    return 0;
+  }
+
+  this->InvokeEvent(vtkCommand::StartEvent, nullptr);
+
+  this->WriteData();      // write geometry and variable files
+  this->WriteCaseFile(1); // write .case file with one timestep (0)
+
+  if (this->NumberOfProcesses > 1 && this->ProcessNumber == 0)
+  {
+    // write .sos file that contains paths to the .case pieces
+    this->WriteSOSCaseFile(this->NumberOfProcesses);
+  }
+
+  this->InvokeEvent(vtkCommand::EndEvent, nullptr);
+
+  this->WriteTime.Modified();
+
+  return 1;
+}
+
+//------------------------------------------------------------------------------
 // Specify the input data or filter.
 void vtkEnSightWriter::SetInputData(vtkUnstructuredGrid* input)
 {
   this->SetInputDataInternal(0, input);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Specify the input data or filter.
 vtkUnstructuredGrid* vtkEnSightWriter::GetInput()
 {
@@ -166,7 +178,7 @@ vtkUnstructuredGrid* vtkEnSightWriter::GetInput()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::WriteData()
 {
   int i;
@@ -185,7 +197,6 @@ void vtkEnSightWriter::WriteData()
   this->ProcessNumber = 0;
   this->NumberOfProcesses = 1;
 
-#ifdef VTK_USE_PARALLEL
   vtkMultiProcessController* c = vtkMultiProcessController::GetGlobalController();
 
   if (c != nullptr)
@@ -193,7 +204,6 @@ void vtkEnSightWriter::WriteData()
     this->ProcessNumber = c->GetLocalProcessId();
     this->NumberOfProcesses = c->GetNumberOfProcesses();
   }
-#endif
 
   vtkUnstructuredGrid* input = this->GetInput();
   vtkInformation* inInfo = this->GetInputInformation();
@@ -212,9 +222,10 @@ void vtkEnSightWriter::WriteData()
   // get the BlockID Cell Array
   vtkDataArray* BlockData = input->GetCellData()->GetScalars("BlockId");
 
-  if (BlockData == nullptr || strcmp(BlockData->GetName(), "BlockId"))
+  if (BlockData == nullptr || strcmp(BlockData->GetName(), "BlockId") != 0)
   {
     BlockData = nullptr;
+    vtkLog(WARNING, "No BlockID was found");
   }
 
   this->ComputeNames();
@@ -295,23 +306,37 @@ void vtkEnSightWriter::WriteData()
     // this->WriteStringToFile(this->Title,fd);
     // else
     this->WriteStringToFile("No Title was Specified", fd);
-    // we will specify node and element ID's
-    this->WriteStringToFile("node id given\n", fd);
-    this->WriteStringToFile("element id given\n", fd);
+    if (this->WriteNodeIDs)
+    {
+      this->WriteStringToFile("node id given\n", fd);
+    }
+    else
+    {
+      this->WriteStringToFile("node id off\n", fd);
+    }
+    if (this->WriteElementIDs)
+    {
+      this->WriteStringToFile("element id given\n", fd);
+    }
+    else
+    {
+      this->WriteStringToFile("element id off\n", fd);
+    }
   }
 
   // get the Ghost Cell Array if it exists
   vtkDataArray* GhostData =
     input->GetCellData()->GetScalars(vtkDataSetAttributes::GhostArrayName());
   // if the strings are not the same then we did not get the ghostData array
-  if (GhostData == nullptr || strcmp(GhostData->GetName(), vtkDataSetAttributes::GhostArrayName()))
+  if (GhostData == nullptr ||
+    strcmp(GhostData->GetName(), vtkDataSetAttributes::GhostArrayName()) != 0)
   {
     GhostData = nullptr;
   }
 
   // data structure to get all the cells for a certain part
   // basically sort by part# and cell type
-  std::map<int, std::vector<int> > CellsByPart;
+  std::map<int, std::vector<int>> CellsByPart;
 
   // just a list of part numbers
   std::list<int> partNumbers;
@@ -322,9 +347,9 @@ void vtkEnSightWriter::WriteData()
   {
     int key = 1;
     if (BlockData)
+    {
       key = (int)(BlockData->GetTuple(i)[0]);
-    else
-      cout << "No BlockID was found\n";
+    }
     if (CellsByPart.count(key) == 0)
     {
       CellsByPart[key] = std::vector<int>();
@@ -399,7 +424,11 @@ void vtkEnSightWriter::WriteData()
       int NodeCount = 0;
       for (iter2 = NodesPerPart.begin(); iter2 != NodesPerPart.end(); ++iter2)
       {
-        this->WriteIntToFile(*iter2, fd);
+        if (this->WriteNodeIDs)
+        {
+          this->WriteIntToFile(*iter2, fd);
+        }
+
         NodeIdToOrder[*iter2] = NodeCount + 1;
         NodeCount++;
       }
@@ -431,17 +460,18 @@ void vtkEnSightWriter::WriteData()
 
       for (int CurrentDimension = 0; CurrentDimension < DataSize; CurrentDimension++)
       {
+        int OutputComponent = this->GetDestinationComponent(CurrentDimension, DataSize);
         for (std::list<int>::iterator k = NodesPerPart.begin(); k != NodesPerPart.end(); ++k)
         {
           this->WriteFloatToFile(
-            (float)(DataArray->GetTuple(*k)[CurrentDimension]), pointArrayFiles[j]);
+            (float)(DataArray->GetTuple(*k)[OutputComponent]), pointArrayFiles[j]);
         }
       }
     }
 
     // now we need to sort the cell list by element type
     // map is indexed by cell type has a vector of cell ID's
-    std::map<int, std::vector<int> > CellsByElement;
+    std::map<int, std::vector<int>> CellsByElement;
     for (j = 0; j < CellsByPart[part].size(); j++)
     {
       int CellType = input->GetCell(CellsByPart[part][j])->GetCellType();
@@ -468,8 +498,6 @@ void vtkEnSightWriter::WriteData()
     std::vector<int> elementTypes;
 
     // list the types that EnSight understands
-    // the noticeable absences are the ones without a fixed number of Nodes
-    // for the ghost cell types
     elementTypes.push_back(VTK_VERTEX);
     elementTypes.push_back(VTK_LINE);
     elementTypes.push_back(VTK_TRIANGLE);
@@ -480,6 +508,7 @@ void vtkEnSightWriter::WriteData()
     elementTypes.push_back(VTK_WEDGE);
     elementTypes.push_back(VTK_PYRAMID);
     elementTypes.push_back(VTK_CONVEX_POINT_SET);
+    elementTypes.push_back(VTK_POLYHEDRON);
     elementTypes.push_back(VTK_QUADRATIC_EDGE);
     elementTypes.push_back(VTK_QUADRATIC_TRIANGLE);
     elementTypes.push_back(VTK_QUADRATIC_QUAD);
@@ -497,6 +526,7 @@ void vtkEnSightWriter::WriteData()
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_WEDGE);
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_PYRAMID);
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_CONVEX_POINT_SET);
+    elementTypes.push_back(this->GhostLevelMultiplier + VTK_POLYHEDRON);
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_QUADRATIC_EDGE);
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_QUADRATIC_TRIANGLE);
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_QUADRATIC_QUAD);
@@ -505,6 +535,57 @@ void vtkEnSightWriter::WriteData()
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_QUADRATIC_WEDGE);
     elementTypes.push_back(this->GhostLevelMultiplier + VTK_QUADRATIC_PYRAMID);
 
+    // EnSight Gold unstructured grid element block has the following general structure:
+    //
+    //     element-type         <--  80*char, eg. "tria3"
+    //     number-of-elements   <--  1*int
+    //     (element-ids)        <--  number-of-elements*int, optional
+    //     connectivity         <--  depends on element-type
+    //
+    // There are three variants of connectivity definition based on element type.
+    //
+    // Ghost cells have separate element types prefixed by "g_" but use the same representation
+    // as corresponding non-ghost types.
+    //
+    // For element types with fixed number of nodes, it simply lists nodes for the first element,
+    // for second element, etc.:
+    //
+    //     tetra4               <--  80*char (element-type)
+    //     2                    <--  1*int (number-of-elements)
+    //     100 101              <--  number-of-elements*int (element IDs)
+    //     1 2 3 4              <--  number-of-elements*nodes-per-element*int       [first tetra]
+    //     2 3 4 5                                                                  [second tetra]
+    //
+    // For "nsided" elements (ie. polygons), first the number of nodes for each polygon is given,
+    // followed by nodes for the first polygon, second polygon, etc.:
+    //
+    //     nsided               <--  80*char (element-type)
+    //     2                    <--  1*int (number-of-elements)
+    //     100 101              <--  number-of-elements*int (element IDs)
+    //     5 6                  <--  number-of-elements*int (nodes-per-polygon)
+    //     1 2 3 4 5            <--  sum(nodes-per-polygon)*int                     [first polygon]
+    //     4 5 6 7 8 9                                                              [second polygon]
+    //
+    // For "nfaced" elements (ie. polyhedra), definition is similar to "nsided" but it starts with
+    // defining the number of faces for each element, followed by number of nodes for each face, and
+    // then nodes for the faces. The following example defines the same two tetrahedrons as "tetra4"
+    // example above, but using "nfaced" elements.
+    //
+    //     nfaced               <--  80*char (element-type)
+    //     2                    <--  1*int (number-of-elements)
+    //     100 101              <--  number-of-elements*int (element IDs)
+    //     4 4                  <--  number-of-elements*int (faces-per-polyhedron)
+    //     3 3 3 3              <--  sum(faces-per-polyhedron)*int (nodes-per-face) [1st polyhedron]
+    //     3 3 3 3                                                                  [2nd polyhedron]
+    //     1 2 3                <--  sum(nodes-per-face)*int                        [cell 1, face 1]
+    //     1 2 4                                                                    [cell 1, face 2]
+    //     2 3 4                                                                    [cell 1, face 3]
+    //     1 3 4                                                                    [cell 1, face 4]
+    //     2 3 4                                                                    [cell 2, face 1]
+    //     2 3 5                                                                    [cell 2, face 2]
+    //     3 4 5                                                                    [cell 2, face 3]
+    //     2 4 5                                                                    [cell 2, face 4]
+
     // write out each type of element
     if (this->ShouldWriteGeometry())
     {
@@ -512,6 +593,7 @@ void vtkEnSightWriter::WriteData()
       {
         unsigned int k;
         int elementType = elementTypes[j];
+        int elementTypeWithoutGhostLevel = elementType % GhostLevelMultiplier;
         if (CellsByElement.count(elementType) > 0)
         {
           // switch on element type to write correct type to file
@@ -521,23 +603,181 @@ void vtkEnSightWriter::WriteData()
           this->WriteIntToFile(static_cast<int>(CellsByElement[elementType].size()), fd);
 
           // element ID's
-          for (k = 0; k < CellsByElement[elementType].size(); k++)
+          if (this->WriteElementIDs)
           {
-            int CellId = CellsByElement[elementType][k];
-            this->WriteIntToFile(CellId, fd);
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              this->WriteIntToFile(CellId, fd);
+            }
           }
 
-          // element conenctivity information
-          for (k = 0; k < CellsByElement[elementType].size(); k++)
+          // element connectivity information
+          if (elementTypeWithoutGhostLevel == VTK_POLYGON)
           {
-            int CellId = CellsByElement[elementType][k];
-            vtkIdList* PointIds = input->GetCell(CellId)->GetPointIds();
-            for (int m = 0; m < PointIds->GetNumberOfIds(); m++)
+            // VTK_POLYGON is represented as "nsided" EnSight element (which has special
+            // representation)
+
+            // write number of nodes per polygon
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              int NumberOfNodes = input->GetCellSize(CellId);
+              this->WriteIntToFile(NumberOfNodes, fd);
+            }
+
+            // write nodes for each polygon
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              vtkIdList* PointIds = input->GetCell(CellId)->GetPointIds();
+              for (int m = 0; m < PointIds->GetNumberOfIds(); m++)
+              {
+                int PointId = PointIds->GetId(m);
+                this->WriteIntToFile(NodeIdToOrder[PointId], fd);
+              }
+            }
+          }
+          else if (elementTypeWithoutGhostLevel == VTK_POLYHEDRON)
+          {
+            // VTK_POLYHEDRON is represented as "nfaced" EnSight element (which has special
+            // representation), we will use vtkUnstructuredGrid Faces and FaceLocations arrays to
+            // write the connectivity.
+
+            vtkIdTypeArray* Faces = input->GetFaces();
+            vtkIdTypeArray* FaceLocations = input->GetFaceLocations();
+
+            // write number of faces per polyhedron
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              int FacesIdx = FaceLocations->GetValue(CellId);
+              assert(FacesIdx >= 0);
+              int NumberOfFaces = Faces->GetValue(FacesIdx++);
+              this->WriteIntToFile(NumberOfFaces, fd);
+            }
+
+            // write number of nodes per face
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              int FacesIdx = FaceLocations->GetValue(CellId);
+              int NumberOfFaces = Faces->GetValue(FacesIdx++);
+              for (int m = 0; m < NumberOfFaces; m++)
+              {
+                int NumberOfNodes = Faces->GetValue(FacesIdx++);
+                FacesIdx += NumberOfNodes; // skip point IDs for the face
+                this->WriteIntToFile(NumberOfNodes, fd);
+              }
+            }
+
+            // write nodes for each face
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              int FacesIdx = FaceLocations->GetValue(CellId);
+              int NumberOfFaces = Faces->GetValue(FacesIdx++);
+              for (int m = 0; m < NumberOfFaces; m++)
+              {
+                int NumberOfNodes = Faces->GetValue(FacesIdx++);
+                for (int n = 0; n < NumberOfNodes; n++)
+                {
+                  int PointId = Faces->GetValue(FacesIdx++);
+                  this->WriteIntToFile(NodeIdToOrder[PointId], fd);
+                }
+              }
+            }
+          }
+          else if (elementTypeWithoutGhostLevel == VTK_CONVEX_POINT_SET)
+          {
+            // VTK_CONVEX_POINT_SET is represented as "nfaced" EnSight element (which has special
+            // representation) and unlike VTK_POLYHEDRON we have to compute its boundary faces since
+            // they are implicit.
+
+            std::vector<int> faceCountPerPolyhedron;
+            std::vector<int> nodeCountPerFace;
+            std::vector<int> pointIds;
+
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              vtkCell* cell = input->GetCell(CellId);
+              int NumberOfFaces = cell->GetNumberOfFaces();
+              faceCountPerPolyhedron.push_back(NumberOfFaces);
+
+              for (int m = 0; m < NumberOfFaces; m++)
+              {
+                vtkCell* cellFace = cell->GetFace(m);
+                int NumberOfNodes = cellFace->GetNumberOfPoints();
+                nodeCountPerFace.push_back(NumberOfNodes);
+                for (int n = 0; n < NumberOfNodes; n++)
+                {
+                  int PointId = cellFace->GetPointId(n);
+                  pointIds.push_back(PointId);
+                }
+              }
+            }
+
+            // write number of faces per polyhedron
+            for (int NumberOfFaces : faceCountPerPolyhedron)
+            {
+              this->WriteIntToFile(NumberOfFaces, fd);
+            }
+
+            // write number of nodes per face
+            for (int NumberOfNodes : nodeCountPerFace)
+            {
+              this->WriteIntToFile(NumberOfNodes, fd);
+            }
+
+            // write nodes for each face
+            for (int PointId : pointIds)
             {
-              int PointId = PointIds->GetId(m);
               this->WriteIntToFile(NodeIdToOrder[PointId], fd);
             }
           }
+          else
+          {
+            // VTK cell types with fixed number of nodes are represented with corresponding
+            // EnSight element types which all use the simple representation. VTK and EnSight
+            // mostly agree on implicit ordering of nodes, except for the following:
+            // - "bar3" (VTK_QUADRATIC_EDGE)
+            // - "penta6" (VTK_WEDGE)
+            // - "penta15" (VTK_QUADRATIC_WEDGE)
+            // See the code in vtkEnSightGoldBinaryReader::CreateUnstructuredGridOutput.
+            for (k = 0; k < CellsByElement[elementType].size(); k++)
+            {
+              int CellId = CellsByElement[elementType][k];
+              vtkIdList* PointIds = input->GetCell(CellId)->GetPointIds();
+
+              const unsigned char bar3Map[3] = { 0, 2, 1 };
+              const unsigned char penta6Map[6] = { 0, 2, 1, 3, 5, 4 };
+              const unsigned char penta15Map[15] = { 0, 2, 1, 3, 5, 4, 8, 7, 6, 11, 10, 9, 12, 14,
+                13 };
+
+              // write nodes for each cell, converting to EnSight ordering where necessary
+              for (int m = 0; m < PointIds->GetNumberOfIds(); m++)
+              {
+                int n = m;
+                switch (elementType)
+                {
+                  case VTK_QUADRATIC_EDGE:
+                    n = bar3Map[m];
+                    break;
+                  case VTK_WEDGE:
+                    n = penta6Map[m];
+                    break;
+                  case VTK_QUADRATIC_WEDGE:
+                    n = penta15Map[m];
+                    break;
+                  default:
+                    break;
+                }
+                int PointId = PointIds->GetId(n);
+                this->WriteIntToFile(NodeIdToOrder[PointId], fd);
+              }
+            }
+          }
         }
       }
     }
@@ -554,12 +794,13 @@ void vtkEnSightWriter::WriteData()
         if (!CellsByElement[elementTypes[k]].empty())
         {
           this->WriteElementTypeToFile(elementTypes[k], cellArrayFiles[j]);
-          for (unsigned int m = 0; m < CellsByElement[elementTypes[k]].size(); m++)
+          for (int CurrentDimension = 0; CurrentDimension < DataSize; CurrentDimension++)
           {
-            for (int CurrentDimension = 0; CurrentDimension < DataSize; CurrentDimension++)
+            int OutputComponent = this->GetDestinationComponent(CurrentDimension, DataSize);
+            for (unsigned int m = 0; m < CellsByElement[elementTypes[k]].size(); m++)
             {
               this->WriteFloatToFile(
-                (float)(DataArray->GetTuple(CellsByElement[elementTypes[k]][m])[CurrentDimension]),
+                (float)(DataArray->GetTuple(CellsByElement[elementTypes[k]][m])[OutputComponent]),
                 cellArrayFiles[j]);
             }
           }
@@ -622,7 +863,8 @@ void vtkEnSightWriter::WriteData()
       }
     }
   }
-  // cout << "wrote " << blockCount << "parts\n";
+  vtkLog(TRACE, "wrote " << blockCount << "parts\n");
+
   if (this->TmpInput)
   {
     this->TmpInput->Delete();
@@ -645,7 +887,7 @@ void vtkEnSightWriter::WriteData()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::WriteCaseFile(int TotalTimeSteps)
 {
 
@@ -723,10 +965,10 @@ void vtkEnSightWriter::WriteCaseFile(int TotalTimeSteps)
         strcpy(SmallBuffer, "vector");
         break;
       case (6):
-        strcpy(SmallBuffer, "tensor");
+        strcpy(SmallBuffer, "tensor symm");
         break;
       case (9):
-        strcpy(SmallBuffer, "tensor9");
+        strcpy(SmallBuffer, "tensor asym");
         break;
     }
     if (TotalTimeSteps <= 1)
@@ -772,10 +1014,10 @@ void vtkEnSightWriter::WriteCaseFile(int TotalTimeSteps)
         strcpy(SmallBuffer, "vector");
         break;
       case (6):
-        strcpy(SmallBuffer, "tensor");
+        strcpy(SmallBuffer, "tensor symm");
         break;
       case (9):
-        strcpy(SmallBuffer, "tensor9");
+        strcpy(SmallBuffer, "tensor asym");
         break;
     }
     if (TotalTimeSteps <= 1)
@@ -813,9 +1055,14 @@ void vtkEnSightWriter::WriteCaseFile(int TotalTimeSteps)
       }
     }
   }
+
+  if (fd)
+  {
+    fclose(fd);
+  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::WriteSOSCaseFile(int numProcs)
 {
   this->ComputeNames();
@@ -859,9 +1106,14 @@ void vtkEnSightWriter::WriteSOSCaseFile(int numProcs)
     snprintf(charBuffer, sizeof(charBuffer), "casefile: %s.%d.case\n\n", this->BaseName, i);
     this->WriteTerminatedStringToFile(charBuffer, fd);
   }
+
+  if (fd)
+  {
+    fclose(fd);
+  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::WriteStringToFile(const char* cstring, FILE* file)
 {
   char cbuffer[81];
@@ -876,25 +1128,25 @@ void vtkEnSightWriter::WriteStringToFile(const char* cstring, FILE* file)
   fwrite(cbuffer, sizeof(char), 80, file);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::WriteTerminatedStringToFile(const char* cstring, FILE* file)
 {
   fwrite(cstring, sizeof(char), std::min(strlen(cstring), static_cast<size_t>(512)), file);
 }
 
-//----------------------------------------------------------------------------
-void vtkEnSightWriter::WriteIntToFile(const int i, FILE* file)
+//------------------------------------------------------------------------------
+void vtkEnSightWriter::WriteIntToFile(int i, FILE* file)
 {
   fwrite(&i, sizeof(int), 1, file);
 }
 
-//----------------------------------------------------------------------------
-void vtkEnSightWriter::WriteFloatToFile(const float f, FILE* file)
+//------------------------------------------------------------------------------
+void vtkEnSightWriter::WriteFloatToFile(float f, FILE* file)
 {
   fwrite(&f, sizeof(float), 1, file);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::WriteElementTypeToFile(int elementType, FILE* fd)
 {
   int ghostLevel = elementType / GhostLevelMultiplier;
@@ -931,6 +1183,7 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType, FILE* fd)
         this->WriteStringToFile("pyramid5", fd);
         break;
       case (VTK_CONVEX_POINT_SET):
+      case (VTK_POLYHEDRON):
         this->WriteStringToFile("nfaced", fd);
         break;
       case (VTK_QUADRATIC_EDGE):
@@ -988,6 +1241,7 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType, FILE* fd)
         this->WriteStringToFile("g_pyramid5", fd);
         break;
       case (VTK_CONVEX_POINT_SET):
+      case (VTK_POLYHEDRON):
         this->WriteStringToFile("g_nfaced", fd);
         break;
       case (VTK_QUADRATIC_EDGE):
@@ -1015,13 +1269,13 @@ void vtkEnSightWriter::WriteElementTypeToFile(int elementType, FILE* fd)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkEnSightWriter::ShouldWriteGeometry()
 {
   return (this->TransientGeometry || (this->TimeStep == 0));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::SanitizeFileName(char* name)
 {
 
@@ -1044,7 +1298,7 @@ void vtkEnSightWriter::SanitizeFileName(char* name)
   name[strlen(buffer)] = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 FILE* vtkEnSightWriter::OpenFile(char* name)
 {
   FILE* fd = vtksys::SystemTools::Fopen(name, "wb");
@@ -1057,7 +1311,7 @@ FILE* vtkEnSightWriter::OpenFile(char* name)
   return fd;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkEnSightWriter::GetExodusModelIndex(int* elementArray, int numberElements, int partID)
 {
   int i;
@@ -1069,7 +1323,7 @@ int vtkEnSightWriter::GetExodusModelIndex(int* elementArray, int numberElements,
   return -1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::DefaultNames()
 {
   char* path = new char[4];
@@ -1081,7 +1335,7 @@ void vtkEnSightWriter::DefaultNames()
   this->SetBaseName(base);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkEnSightWriter::ComputeNames()
 {
   if (this->Path && this->BaseName)
@@ -1145,3 +1399,26 @@ void vtkEnSightWriter::ComputeNames()
 
   delete[] buf;
 }
+
+//------------------------------------------------------------------------------
+// Copied from vtkEnSightGoldBinaryReader::vtkUtilities::GetDestinationComponent
+int vtkEnSightWriter::GetDestinationComponent(int srcComponent, int numComponents)
+{
+  if (numComponents == 6)
+  {
+    // for 6 component tensors, the symmetric tensor components XZ and YZ are interchanged
+    // see Paraview issue #10637.
+    switch (srcComponent)
+    {
+      case 4:
+        return 5;
+
+      case 5:
+        return 4;
+    }
+  }
+
+  return srcComponent;
+}
+
+VTK_ABI_NAMESPACE_END
