@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkXMLPUnstructuredDataWriter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkXMLPUnstructuredDataWriter.h"
 
 #include "vtkErrorCode.h"
@@ -21,25 +9,26 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkXMLUnstructuredDataWriter.h"
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkXMLPUnstructuredDataWriter::vtkXMLPUnstructuredDataWriter() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLPUnstructuredDataWriter::~vtkXMLPUnstructuredDataWriter() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPUnstructuredDataWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPointSet* vtkXMLPUnstructuredDataWriter::GetInputAsPointSet()
 {
   return static_cast<vtkPointSet*>(this->GetInput());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLWriter* vtkXMLPUnstructuredDataWriter::CreatePieceWriter(int index)
 {
   vtkXMLUnstructuredDataWriter* pWriter = this->CreateUnstructuredPieceWriter();
@@ -50,7 +39,7 @@ vtkXMLWriter* vtkXMLPUnstructuredDataWriter::CreatePieceWriter(int index)
   return pWriter;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLPUnstructuredDataWriter::WritePData(vtkIndent indent)
 {
   this->Superclass::WritePData(indent);
@@ -61,3 +50,4 @@ void vtkXMLPUnstructuredDataWriter::WritePData(vtkIndent indent)
   vtkPointSet* input = this->GetInputAsPointSet();
   this->WritePPoints(input->GetPoints(), indent);
 }
+VTK_ABI_NAMESPACE_END
