@@ -1,17 +1,6 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkXMLUnstructuredDataWriter.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
 #include "vtkXMLUnstructuredDataWriter.h"
 
 #include "vtkCellArray.h"
@@ -40,7 +29,8 @@
 #include <cassert>
 #include <utility>
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 vtkXMLUnstructuredDataWriter::vtkXMLUnstructuredDataWriter()
 {
   this->NumberOfPieces = 1;
@@ -59,7 +49,7 @@ vtkXMLUnstructuredDataWriter::vtkXMLUnstructuredDataWriter()
   this->FaceOffsets->SetName("faceoffsets");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLUnstructuredDataWriter::~vtkXMLUnstructuredDataWriter()
 {
   this->Faces->Delete();
@@ -70,7 +60,7 @@ vtkXMLUnstructuredDataWriter::~vtkXMLUnstructuredDataWriter()
   delete this->CellDataOM;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -79,13 +69,13 @@ void vtkXMLUnstructuredDataWriter::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "GhostLevel: " << this->GhostLevel << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPointSet* vtkXMLUnstructuredDataWriter::GetInputAsPointSet()
 {
   return static_cast<vtkPointSet*>(this->Superclass::GetInput());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkXMLUnstructuredDataWriter::ProcessRequest(
   vtkInformation* request, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
 {
@@ -158,9 +148,18 @@ vtkTypeBool vtkXMLUnstructuredDataWriter::ProcessRequest(
         }
         else
         {
-          vtkNew<vtkCellTypes> cellTypes;
-          dataSet->GetCellTypes(cellTypes);
-          if (vtkNeedsNewFileVersionV8toV9(cellTypes))
+          vtkNew<vtkUnsignedCharArray> cellTypesArray;
+          if (auto ug = vtkUnstructuredGrid::SafeDownCast(dataSet))
+          {
+            cellTypesArray->ShallowCopy(ug->GetDistinctCellTypesArray());
+          }
+          else
+          {
+            vtkNew<vtkCellTypes> cellTypes;
+            dataSet->GetCellTypes(cellTypes);
+            cellTypesArray->ShallowCopy(cellTypes->GetCellTypesArray());
+          }
+          if (vtkNeedsNewFileVersionV8toV9(cellTypesArray))
           {
             this->UsePreviousVersion = false;
           }
@@ -245,7 +244,7 @@ vtkTypeBool vtkXMLUnstructuredDataWriter::ProcessRequest(
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::AllocatePositionArrays()
 {
   this->NumberOfPointsPositions = new vtkTypeInt64[this->NumberOfPieces];
@@ -255,14 +254,14 @@ void vtkXMLUnstructuredDataWriter::AllocatePositionArrays()
   this->CellDataOM->Allocate(this->NumberOfPieces);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::DeletePositionArrays()
 {
   delete[] this->NumberOfPointsPositions;
   this->NumberOfPointsPositions = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLUnstructuredDataWriter::WriteHeader()
 {
   vtkIndent indent = vtkIndent().GetNextIndent();
@@ -401,7 +400,7 @@ void CreateFaceStream(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLUnstructuredDataWriter::WriteAPiece()
 {
   vtkIndent indent = vtkIndent().GetNextIndent();
@@ -425,7 +424,7 @@ int vtkXMLUnstructuredDataWriter::WriteAPiece()
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLUnstructuredDataWriter::WriteFooter()
 {
   vtkIndent indent = vtkIndent().GetNextIndent();
@@ -451,7 +450,7 @@ int vtkXMLUnstructuredDataWriter::WriteFooter()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLUnstructuredDataWriter::WriteInlineMode(vtkIndent indent)
 {
   ostream& os = *(this->Stream);
@@ -478,14 +477,14 @@ int vtkXMLUnstructuredDataWriter::WriteInlineMode(vtkIndent indent)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteInlinePieceAttributes()
 {
   vtkPointSet* input = this->GetInputAsPointSet();
   this->WriteScalarAttribute("NumberOfPoints", input->GetNumberOfPoints());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteInlinePiece(vtkIndent indent)
 {
   vtkPointSet* input = this->GetInputAsPointSet();
@@ -523,13 +522,13 @@ void vtkXMLUnstructuredDataWriter::WriteInlinePiece(vtkIndent indent)
   this->WritePointsInline(input->GetPoints(), indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteAppendedPieceAttributes(int index)
 {
   this->NumberOfPointsPositions[index] = this->ReserveAttributeSpace("NumberOfPoints");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteAppendedPiece(int index, vtkIndent indent)
 {
   vtkPointSet* input = this->GetInputAsPointSet();
@@ -549,7 +548,7 @@ void vtkXMLUnstructuredDataWriter::WriteAppendedPiece(int index, vtkIndent inden
   this->WritePointsAppended(input->GetPoints(), indent, &this->PointsOM->GetPiece(index));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteAppendedPieceData(int index)
 {
   ostream& os = *(this->Stream);
@@ -602,7 +601,7 @@ void vtkXMLUnstructuredDataWriter::WriteAppendedPieceData(int index)
     input->GetPoints(), this->CurrentTimeIndex, &this->PointsOM->GetPiece(index));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsInline(const char* name, vtkCellIterator* cellIter,
   vtkIdType numCells, vtkIdType cellSizeEstimate, vtkIndent indent)
 {
@@ -636,14 +635,14 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInline(const char* name, vtkCellIte
   this->WriteCellsInlineWorker(name, types.GetPointer(), indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsInline(
   const char* name, vtkCellArray* cells, vtkDataArray* types, vtkIndent indent)
 {
   this->WriteCellsInline(name, cells, types, nullptr, nullptr, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsInline(const char* name, vtkCellArray* cells,
   vtkDataArray* types, vtkIdTypeArray* faces, vtkIdTypeArray* faceOffsets, vtkIndent indent)
 {
@@ -656,7 +655,7 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInline(const char* name, vtkCellArr
   this->WriteCellsInlineWorker(name, types, indent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsInlineWorker(
   const char* name, vtkDataArray* types, vtkIndent indent)
 {
@@ -736,14 +735,14 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInlineWorker(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppended(
   const char* name, vtkDataArray* types, vtkIndent indent, OffsetsManagerGroup* cellsManager)
 {
   this->WriteCellsAppended(name, types, nullptr, nullptr, indent, cellsManager);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name, vtkDataArray* types,
   vtkIdTypeArray* faces, vtkIdTypeArray* faceOffsets, vtkIndent indent,
   OffsetsManagerGroup* cellsManager)
@@ -785,7 +784,7 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name, vtkDataA
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name, vtkCellIterator* cellIter,
   vtkIdType numCells, vtkIndent indent, OffsetsManagerGroup* cellsManager)
 {
@@ -816,14 +815,14 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name, vtkCellI
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(
   vtkCellArray* cells, vtkDataArray* types, int timestep, OffsetsManagerGroup* cellsManager)
 {
   this->WriteCellsAppendedData(cells, types, nullptr, nullptr, timestep, cellsManager);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(vtkCellIterator* cellIter,
   vtkIdType numCells, vtkIdType cellSizeEstimate, int timestep, OffsetsManagerGroup* cellsManager)
 {
@@ -859,7 +858,7 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(vtkCellIterator* cellI
   this->WriteCellsAppendedDataWorker(types.GetPointer(), timestep, cellsManager);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(vtkCellArray* cells, vtkDataArray* types,
   vtkIdTypeArray* faces, vtkIdTypeArray* faceOffsets, int timestep,
   OffsetsManagerGroup* cellsManager)
@@ -873,7 +872,7 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(vtkCellArray* cells, v
   this->WriteCellsAppendedDataWorker(types, timestep, cellsManager);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::WriteCellsAppendedDataWorker(
   vtkDataArray* types, int timestep, OffsetsManagerGroup* cellsManager)
 {
@@ -926,12 +925,12 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppendedDataWorker(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::ConvertCells(
   vtkCellIterator* cellIter, vtkIdType numCells, vtkIdType cellSizeEstimate)
 {
-  vtkNew<vtkAOSDataArrayTemplate<vtkIdType> > conn;
-  vtkNew<vtkAOSDataArrayTemplate<vtkIdType> > offsets;
+  vtkNew<vtkAOSDataArrayTemplate<vtkIdType>> conn;
+  vtkNew<vtkAOSDataArrayTemplate<vtkIdType>> offsets;
 
   conn->SetName("connectivity");
   offsets->SetName("offsets");
@@ -957,8 +956,8 @@ void vtkXMLUnstructuredDataWriter::ConvertCells(
   conn->Squeeze();
   offsets->Squeeze();
 
-  this->CellPoints = std::move(conn);
-  this->CellOffsets = std::move(offsets);
+  this->CellPoints = conn;
+  this->CellOffsets = offsets;
 }
 
 namespace
@@ -1000,16 +999,19 @@ struct ConvertCellsVisitor
 
 } // end anon namespace
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::ConvertCells(vtkCellArray* cells)
 {
   ConvertCellsVisitor visitor;
-  cells->Visit(visitor);
-  this->CellPoints = std::move(visitor.Connectivity);
-  this->CellOffsets = std::move(visitor.Offsets);
+  if (cells)
+  {
+    cells->Visit(visitor);
+  }
+  this->CellPoints = visitor.Connectivity;
+  this->CellOffsets = visitor.Offsets;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::ConvertFaces(vtkIdTypeArray* faces, vtkIdTypeArray* faceOffsets)
 {
   if (!faces || !faces->GetNumberOfTuples() || !faceOffsets || !faceOffsets->GetNumberOfTuples())
@@ -1068,7 +1070,7 @@ void vtkXMLUnstructuredDataWriter::ConvertFaces(vtkIdTypeArray* faces, vtkIdType
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkXMLUnstructuredDataWriter::GetNumberOfInputPoints()
 {
   vtkPointSet* input = this->GetInputAsPointSet();
@@ -1076,7 +1078,7 @@ vtkIdType vtkXMLUnstructuredDataWriter::GetNumberOfInputPoints()
   return points ? points->GetNumberOfPoints() : 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::CalculateDataFractions(float* fractions)
 {
   // Calculate the fraction of point/cell data and point
@@ -1097,7 +1099,7 @@ void vtkXMLUnstructuredDataWriter::CalculateDataFractions(float* fractions)
   fractions[3] = 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::CalculateCellFractions(float* fractions, vtkIdType typesSize)
 {
   // Calculate the fraction of cell specification data contributed by
@@ -1119,7 +1121,7 @@ void vtkXMLUnstructuredDataWriter::CalculateCellFractions(float* fractions, vtkI
   fractions[5] = 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLUnstructuredDataWriter::SetInputUpdateExtent(int piece, int numPieces, int ghostLevel)
 {
   vtkInformation* inInfo = this->GetExecutive()->GetInputInformation(0, 0);
@@ -1127,3 +1129,4 @@ void vtkXMLUnstructuredDataWriter::SetInputUpdateExtent(int piece, int numPieces
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), piece);
   inInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_GHOST_LEVELS(), ghostLevel);
 }
+VTK_ABI_NAMESPACE_END
