@@ -1,23 +1,12 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkXMLDataParser.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkXMLDataParser.h"
 
 #include "vtkBase64InputStream.h"
 #include "vtkByteSwap.h"
 #include "vtkCommand.h"
 #include "vtkDataCompressor.h"
+#include "vtkEndian.h"
 #include "vtkInputStream.h"
 #include "vtkObjectFactory.h"
 #include "vtkXMLDataElement.h"
@@ -34,10 +23,11 @@
 
 #include "vtkXMLUtilities.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkXMLDataParser);
 vtkCxxSetObjectMacro(vtkXMLDataParser, Compressor, vtkDataCompressor);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLDataParser::vtkXMLDataParser()
 {
   this->NumberOfOpenElements = 0;
@@ -77,7 +67,7 @@ vtkXMLDataParser::vtkXMLDataParser()
   this->IgnoreCharacterData = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLDataParser::~vtkXMLDataParser()
 {
   this->FreeAllElements();
@@ -93,7 +83,7 @@ vtkXMLDataParser::~vtkXMLDataParser()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -115,7 +105,7 @@ void vtkXMLDataParser::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "AttributesEncoding: " << this->AttributesEncoding << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::Parse()
 {
   // Delete any elements left from previous parsing.
@@ -133,21 +123,21 @@ int vtkXMLDataParser::Parse()
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::Parse(const char*)
 {
   vtkErrorMacro("Parsing from a string is not supported.");
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::Parse(const char*, unsigned int)
 {
   vtkErrorMacro("Parsing from a string is not supported.");
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::StartElement(const char* name, const char** atts)
 {
   vtkXMLDataElement* element = vtkXMLDataElement::New();
@@ -177,7 +167,7 @@ void vtkXMLDataParser::StartElement(const char* name, const char** atts)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::SeekInlineDataPosition(vtkXMLDataElement* element)
 {
   istream* stream = this->GetStream();
@@ -190,11 +180,9 @@ void vtkXMLDataParser::SeekInlineDataPosition(vtkXMLDataElement* element)
     this->SeekG(element->GetXMLByteIndex());
     while (stream->get(c) && (c != '>'))
     {
-      ;
     }
-    while (stream->get(c) && element->IsSpace(c))
+    while (stream->get(c) && vtkXMLDataElement::IsSpace(c))
     {
-      ;
     }
     vtkTypeInt64 pos = this->TellG();
     element->SetInlineDataPosition(pos - 1);
@@ -204,7 +192,7 @@ void vtkXMLDataParser::SeekInlineDataPosition(vtkXMLDataElement* element)
   this->SeekG(element->GetInlineDataPosition());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::EndElement(const char*)
 {
   vtkXMLDataElement* finished = this->PopOpenElement();
@@ -220,7 +208,7 @@ void vtkXMLDataParser::EndElement(const char*)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::ParsingComplete()
 {
   // If we have reached the appended data section, we stop parsing.
@@ -233,7 +221,7 @@ int vtkXMLDataParser::ParsingComplete()
   return this->Superclass::ParsingComplete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::CheckPrimaryAttributes()
 {
   const char* byte_order = this->RootElement->GetAttribute("byte_order");
@@ -272,7 +260,7 @@ int vtkXMLDataParser::CheckPrimaryAttributes()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::FindAppendedDataPosition()
 {
   // Clear stream fail and eof bits.  We may have already read past
@@ -286,11 +274,9 @@ void vtkXMLDataParser::FindAppendedDataPosition()
   this->SeekG(this->GetXMLByteIndex());
   while (this->Stream->get(c) && (c != '>'))
   {
-    ;
   }
-  while (this->Stream->get(c) && this->IsSpace(c))
+  while (this->Stream->get(c) && vtkXMLDataParser::IsSpace(c))
   {
-    ;
   }
 
   // Store the start of the appended data.  We skip the first
@@ -312,7 +298,7 @@ void vtkXMLDataParser::FindAppendedDataPosition()
   this->SeekG(returnPosition);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::PushOpenElement(vtkXMLDataElement* element)
 {
   if (this->NumberOfOpenElements == this->OpenElementsSize)
@@ -333,7 +319,7 @@ void vtkXMLDataParser::PushOpenElement(vtkXMLDataElement* element)
   this->OpenElements[pos] = element;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLDataElement* vtkXMLDataParser::PopOpenElement()
 {
   if (this->NumberOfOpenElements > 0)
@@ -344,7 +330,7 @@ vtkXMLDataElement* vtkXMLDataParser::PopOpenElement()
   return nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::FreeAllElements()
 {
   while (this->NumberOfOpenElements > 0)
@@ -360,7 +346,7 @@ void vtkXMLDataParser::FreeAllElements()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::ParseBuffer(const char* buffer, unsigned int count)
 {
   // Parsing must stop when "<AppendedData" is reached.  Use a search
@@ -452,14 +438,14 @@ int vtkXMLDataParser::ParseBuffer(const char* buffer, unsigned int count)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 size_t vtkXMLDataParserGetWordTypeSize(T*)
 {
   return sizeof(T);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::GetWordTypeSize(int wordType)
 {
   size_t size = 1;
@@ -480,7 +466,7 @@ size_t vtkXMLDataParser::GetWordTypeSize(int wordType)
   return size;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::PerformByteSwap(void* data, size_t numWords, size_t wordSize)
 {
   char* ptr = static_cast<char*>(data);
@@ -524,7 +510,7 @@ void vtkXMLDataParser::PerformByteSwap(void* data, size_t numWords, size_t wordS
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::ReadCompressionHeader()
 {
   std::unique_ptr<vtkXMLDataHeader> ch(vtkXMLDataHeader::New(this->HeaderType, 3));
@@ -587,7 +573,7 @@ int vtkXMLDataParser::ReadCompressionHeader()
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::FindBlockSize(vtkTypeUInt64 block)
 {
   if (block < this->NumberOfBlocks - (this->PartialLastBlockUncompressedSize ? 1 : 0))
@@ -600,7 +586,7 @@ size_t vtkXMLDataParser::FindBlockSize(vtkTypeUInt64 block)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::ReadBlock(vtkTypeUInt64 block, unsigned char* buffer)
 {
   size_t uncompressedSize = this->FindBlockSize(block);
@@ -626,7 +612,7 @@ int vtkXMLDataParser::ReadBlock(vtkTypeUInt64 block, unsigned char* buffer)
   return result > 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned char* vtkXMLDataParser::ReadBlock(vtkTypeUInt64 block)
 {
   unsigned char* decompressBuffer = new unsigned char[this->FindBlockSize(block)];
@@ -638,7 +624,7 @@ unsigned char* vtkXMLDataParser::ReadBlock(vtkTypeUInt64 block)
   return decompressBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::ReadUncompressedData(
   unsigned char* data, vtkTypeUInt64 startWord, size_t numWords, size_t wordSize)
 {
@@ -713,7 +699,7 @@ size_t vtkXMLDataParser::ReadUncompressedData(
   return length / wordSize;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::ReadCompressedData(
   unsigned char* data, vtkTypeUInt64 startWord, size_t numWords, size_t wordSize)
 {
@@ -852,13 +838,13 @@ size_t vtkXMLDataParser::ReadCompressedData(
   return (endOffset - beginOffset) / wordSize;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkXMLDataElement* vtkXMLDataParser::GetRootElement()
 {
   return this->RootElement;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::ReadBinaryData(
   void* in_buffer, vtkTypeUInt64 startWord, size_t numWords, int wordType)
 {
@@ -899,7 +885,7 @@ size_t vtkXMLDataParser::ReadBinaryData(
   return this->Abort ? 0 : actualWords;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::ReadAsciiData(
   void* buffer, vtkTypeUInt64 startWord, size_t numWords, int wordType)
 {
@@ -947,7 +933,7 @@ size_t vtkXMLDataParser::ReadAsciiData(
   return this->Abort ? 0 : actualWords;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::ReadInlineData(vtkXMLDataElement* element, int isAscii, void* buffer,
   vtkTypeUInt64 startWord, size_t numWords, int wordType)
 {
@@ -963,7 +949,7 @@ size_t vtkXMLDataParser::ReadInlineData(vtkXMLDataElement* element, int isAscii,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 size_t vtkXMLDataParser::ReadAppendedData(
   vtkTypeInt64 offset, void* buffer, vtkTypeUInt64 startWord, size_t numWords, int wordType)
 {
@@ -972,8 +958,8 @@ size_t vtkXMLDataParser::ReadAppendedData(
   return this->ReadBinaryData(buffer, startWord, numWords, wordType);
 }
 
-//----------------------------------------------------------------------------
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Define a parsing function template.  The extra "long" argument is used
 // to help broken compilers select the non-templates below for char and
 // unsigned char, and float/double by making them a better conversion than
@@ -1009,7 +995,7 @@ T* vtkXMLParseAsciiData(istream& is, int* length, T*, long)
   return dataBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static float* vtkXMLParseAsciiData(istream& is, int* length, float*, int)
 {
   int dataLength = 0;
@@ -1019,7 +1005,7 @@ static float* vtkXMLParseAsciiData(istream& is, int* length, float*, int)
   std::string stringBuffer;
   float element;
 
-  while (1)
+  while (true)
   {
     is >> element;
     if (!is.good())
@@ -1064,7 +1050,7 @@ static float* vtkXMLParseAsciiData(istream& is, int* length, float*, int)
   return dataBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static double* vtkXMLParseAsciiData(istream& is, int* length, double*, int)
 {
   int dataLength = 0;
@@ -1074,7 +1060,7 @@ static double* vtkXMLParseAsciiData(istream& is, int* length, double*, int)
   std::string stringBuffer;
   double element;
 
-  while (1)
+  while (true)
   {
     is >> element;
     if (!is.good())
@@ -1119,7 +1105,7 @@ static double* vtkXMLParseAsciiData(istream& is, int* length, double*, int)
   return dataBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static char* vtkXMLParseAsciiData(istream& is, int* length, char*, int)
 {
   int dataLength = 0;
@@ -1152,7 +1138,7 @@ static char* vtkXMLParseAsciiData(istream& is, int* length, char*, int)
   return dataBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static unsigned char* vtkXMLParseAsciiData(istream& is, int* length, unsigned char*, int)
 {
   int dataLength = 0;
@@ -1185,7 +1171,7 @@ static unsigned char* vtkXMLParseAsciiData(istream& is, int* length, unsigned ch
   return dataBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static signed char* vtkXMLParseAsciiData(istream& is, int* length, signed char*, int)
 {
   int dataLength = 0;
@@ -1218,7 +1204,7 @@ static signed char* vtkXMLParseAsciiData(istream& is, int* length, signed char*,
   return dataBuffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static unsigned char* vtkXMLParseAsciiBitData(istream& is, int* length)
 {
   size_t arrayCapacity = 64; // capacity in bytes
@@ -1273,7 +1259,7 @@ static unsigned char* vtkXMLParseAsciiBitData(istream& is, int* length)
   return array;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkXMLDataParser::ParseAsciiData(int wordType)
 {
   istream& is = *(this->Stream);
@@ -1313,14 +1299,14 @@ int vtkXMLDataParser::ParseAsciiData(int wordType)
   return (this->AsciiDataBuffer ? 1 : 0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkXMLDataParserFreeAsciiBuffer(T* buffer)
 {
   delete[] buffer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::FreeAsciiBuffer()
 {
   void* buffer = this->AsciiDataBuffer;
@@ -1335,10 +1321,11 @@ void vtkXMLDataParser::FreeAsciiBuffer()
   this->AsciiDataBuffer = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXMLDataParser::UpdateProgress(float progress)
 {
   this->Progress = progress;
   double dProgress = progress;
   this->InvokeEvent(vtkCommand::ProgressEvent, &dProgress);
 }
+VTK_ABI_NAMESPACE_END
