@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImageMask.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkImageMask.h"
 
 #include "vtkImageData.h"
@@ -20,9 +8,10 @@
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageMask);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageMask::vtkImageMask()
 {
   this->NotMask = 0;
@@ -33,25 +22,25 @@ vtkImageMask::vtkImageMask()
   this->SetNumberOfInputPorts(2);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageMask::~vtkImageMask()
 {
   delete[] this->MaskedOutputValue;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageMask::SetImageInputData(vtkImageData* in)
 {
   this->SetInput1Data(in);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageMask::SetMaskInputData(vtkImageData* in)
 {
   this->SetInput2Data(in);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageMask::SetMaskedOutputValue(int num, double* v)
 {
   int idx;
@@ -84,7 +73,7 @@ void vtkImageMask::SetMaskedOutputValue(int num, double* v)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This templated function executes the filter for any type of data.
 template <class T>
 void vtkImageMaskExecute(vtkImageMask* self, int ext[6], vtkImageData* in1Data, T* in1Ptr,
@@ -212,7 +201,7 @@ void vtkImageMaskExecute(vtkImageMask* self, int ext[6], vtkImageData* in1Data,
   delete[] maskedValue;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method is passed a input and output Datas, and executes the filter
 // algorithm to fill the output from the inputs.
 // It just executes a switch statement to call the correct function for
@@ -264,7 +253,7 @@ void vtkImageMask::ThreadedRequestData(vtkInformation* vtkNotUsed(request),
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // The output extent is the intersection.
 int vtkImageMask::RequestInformation(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -311,3 +300,4 @@ void vtkImageMask::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "NotMask: " << (this->NotMask ? "On\n" : "Off\n");
   os << indent << "MaskAlpha: " << this->MaskAlpha << "\n";
 }
+VTK_ABI_NAMESPACE_END
