@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImageWrapPad.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkImageWrapPad
  * @brief   Makes an image larger by wrapping existing data.
@@ -28,6 +16,7 @@
 #include "vtkImagePadFilter.h"
 #include "vtkImagingCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkInformation;
 class vtkInformationVector;
 
@@ -36,12 +25,13 @@ class VTKIMAGINGCORE_EXPORT vtkImageWrapPad : public vtkImagePadFilter
 public:
   static vtkImageWrapPad* New();
   vtkTypeMacro(vtkImageWrapPad, vtkImagePadFilter);
+  void PrintSelf(ostream& os, vtkIndent indent) override;
 
 protected:
-  vtkImageWrapPad() {}
-  ~vtkImageWrapPad() override {}
+  vtkImageWrapPad() = default;
+  ~vtkImageWrapPad() override = default;
 
-  void ComputeInputUpdateExtent(int inExt[6], int outExt[6], int wExt[6]) override;
+  void ComputeInputUpdateExtent(int inExt[6], int outExt[6], int wholeExtent[6]) override;
   void ThreadedRequestData(vtkInformation* request, vtkInformationVector** inputVector,
     vtkInformationVector* outputVector, vtkImageData*** inData, vtkImageData** outData, int ext[6],
     int id) override;
@@ -51,6 +41,5 @@ private:
   void operator=(const vtkImageWrapPad&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
-
-// VTK-HeaderTest-Exclude: vtkImageWrapPad.h
