@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImageCityBlockDistance.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkImageCityBlockDistance.h"
 
 #include "vtkImageData.h"
@@ -20,12 +8,19 @@
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageCityBlockDistance);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+void vtkImageCityBlockDistance::PrintSelf(ostream& os, vtkIndent indent)
+{
+  this->Superclass::PrintSelf(os, indent);
+}
+
+//------------------------------------------------------------------------------
 vtkImageCityBlockDistance::vtkImageCityBlockDistance() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImageCityBlockDistance::AllocateOutputScalars(
   vtkImageData* outData, int* uExt, int* wholeExtent, vtkInformation* outInfo)
 {
@@ -41,7 +36,7 @@ void vtkImageCityBlockDistance::AllocateOutputScalars(
   outData->AllocateScalars(outInfo);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method tells the superclass that the whole input array is needed
 // to compute any output region.
 int vtkImageCityBlockDistance::IterativeRequestUpdateExtent(
@@ -59,7 +54,7 @@ int vtkImageCityBlockDistance::IterativeRequestUpdateExtent(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This is written as a 1D execute method, but is called several times.
 int vtkImageCityBlockDistance::IterativeRequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -211,3 +206,4 @@ int vtkImageCityBlockDistance::IterativeRequestData(vtkInformation* vtkNotUsed(r
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
