@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImageSeparableConvolution.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkImageSeparableConvolution.h"
 
 #include "vtkFloatArray.h"
@@ -21,6 +9,7 @@
 #include "vtkObjectFactory.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImageSeparableConvolution);
 vtkCxxSetObjectMacro(vtkImageSeparableConvolution, XKernel, vtkFloatArray);
 vtkCxxSetObjectMacro(vtkImageSeparableConvolution, YKernel, vtkFloatArray);
@@ -110,7 +99,7 @@ vtkMTimeType vtkImageSeparableConvolution::GetMTime()
   return mTime;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageSeparableConvolution::~vtkImageSeparableConvolution()
 {
   if (this->XKernel)
@@ -127,13 +116,13 @@ vtkImageSeparableConvolution::~vtkImageSeparableConvolution()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImageSeparableConvolution::vtkImageSeparableConvolution()
 {
   XKernel = YKernel = ZKernel = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This extent of the components changes to real and imaginary values.
 int vtkImageSeparableConvolution::IterativeRequestInformation(
   vtkInformation* vtkNotUsed(input), vtkInformation* output)
@@ -142,7 +131,7 @@ int vtkImageSeparableConvolution::IterativeRequestInformation(
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method tells the superclass that the whole input array is needed
 // to compute any output region.
 
@@ -307,7 +296,7 @@ void vtkImageSeparableConvolutionExecute(vtkImageSeparableConvolution* self, vtk
   delete[] kernel;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This is written as a 1D execute method, but is called several times.
 int vtkImageSeparableConvolution::IterativeRequestData(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -407,3 +396,4 @@ void vtkImageSeparableConvolution::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "ZKernel: (not defined)\n";
   }
 }
+VTK_ABI_NAMESPACE_END
