@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkBooleanTexture.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkBooleanTexture.h"
 
 #include "vtkImageData.h"
@@ -22,6 +10,7 @@
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkUnsignedCharArray.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkBooleanTexture);
 
 vtkBooleanTexture::vtkBooleanTexture()
@@ -42,7 +31,7 @@ vtkBooleanTexture::vtkBooleanTexture()
   this->OutOn[0] = this->OutOn[1] = 255;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkBooleanTexture::RequestInformation(vtkInformation* vtkNotUsed(request),
   vtkInformationVector** vtkNotUsed(inputVector), vtkInformationVector* outputVector)
 {
@@ -168,3 +157,4 @@ void vtkBooleanTexture::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "In/On: (" << this->InOn[0] << "," << this->InOn[1] << ")\n";
   os << indent << "Out/On: (" << this->OutOn[0] << "," << this->OutOn[1] << ")\n";
 }
+VTK_ABI_NAMESPACE_END
