@@ -1,23 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkAdjacencyMatrixToEdgeTable.cxx
-
--------------------------------------------------------------------------
-  Copyright 2008 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-  the U.S. Government retains certain rights in this software.
--------------------------------------------------------------------------
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2008 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 
 #include "vtkAdjacencyMatrixToEdgeTable.h"
 #include "vtkArrayData.h"
@@ -35,11 +18,12 @@
 #include <functional>
 #include <map>
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkAdjacencyMatrixToEdgeTable);
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkAdjacencyMatrixToEdgeTable::vtkAdjacencyMatrixToEdgeTable()
   : SourceDimension(0)
@@ -53,14 +37,14 @@ vtkAdjacencyMatrixToEdgeTable::vtkAdjacencyMatrixToEdgeTable()
   this->SetNumberOfOutputPorts(1);
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkAdjacencyMatrixToEdgeTable::~vtkAdjacencyMatrixToEdgeTable()
 {
   this->SetValueArrayName(nullptr);
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 void vtkAdjacencyMatrixToEdgeTable::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -83,7 +67,7 @@ int vtkAdjacencyMatrixToEdgeTable::FillInputPortInformation(int port, vtkInforma
   return 0;
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 int vtkAdjacencyMatrixToEdgeTable::RequestData(
   vtkInformation*, vtkInformationVector** inputVector, vtkInformationVector* outputVector)
@@ -118,10 +102,10 @@ int vtkAdjacencyMatrixToEdgeTable::RequestData(
   vtkTable* const output_table = vtkTable::GetData(outputVector);
 
   vtkIdTypeArray* const source_array = vtkIdTypeArray::New();
-  source_array->SetName(input_array->GetDimensionLabel(source_dimension));
+  source_array->SetName(input_array->GetDimensionLabel(source_dimension).c_str());
 
   vtkIdTypeArray* const target_array = vtkIdTypeArray::New();
-  target_array->SetName(input_array->GetDimensionLabel(target_dimension));
+  target_array->SetName(input_array->GetDimensionLabel(target_dimension).c_str());
 
   vtkDoubleArray* const value_array = vtkDoubleArray::New();
   value_array->SetName(this->ValueArrayName);
@@ -134,7 +118,7 @@ int vtkAdjacencyMatrixToEdgeTable::RequestData(
     coordinates[source_dimension] = i;
 
     // Create a sorted list of source values ...
-    typedef std::multimap<double, vtkIdType, std::greater<double> > sorted_values_t;
+    typedef std::multimap<double, vtkIdType, std::greater<double>> sorted_values_t;
     sorted_values_t sorted_values;
     for (vtkIdType j = input_extents[target_dimension].GetBegin();
          j != input_extents[target_dimension].GetEnd(); ++j)
@@ -179,3 +163,4 @@ int vtkAdjacencyMatrixToEdgeTable::RequestData(
 
   return 1;
 }
+VTK_ABI_NAMESPACE_END
