@@ -1,22 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkGroupLeafVertices.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*-------------------------------------------------------------------------
-  Copyright 2008 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-  the U.S. Government retains certain rights in this software.
--------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2008 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 
 #include "vtkGroupLeafVertices.h"
 
@@ -32,7 +16,6 @@
 #include "vtkStringArray.h"
 #include "vtkTable.h"
 #include "vtkTree.h"
-#include "vtkUnicodeStringArray.h"
 #include "vtkVariant.h"
 #include "vtkVariantArray.h"
 
@@ -40,12 +23,13 @@
 #include <utility>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkGroupLeafVertices);
 
 // Forward function reference (definition at bottom :)
 static int splitString(const vtkStdString& input, std::vector<vtkStdString>& results);
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 class vtkGroupLeafVerticesCompare
 {
 public:
@@ -60,20 +44,20 @@ public:
   }
 };
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <typename T>
 vtkVariant vtkGroupLeafVerticesGetValue(T* arr, vtkIdType index)
 {
   return vtkVariant(arr[index]);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static vtkVariant vtkGroupLeafVerticesGetVariant(vtkAbstractArray* arr, vtkIdType i)
 {
   vtkVariant val;
   switch (arr->GetDataType())
   {
-    vtkSuperExtraExtendedTemplateMacro(
+    vtkExtraExtendedTemplateMacro(
       val = vtkGroupLeafVerticesGetValue(static_cast<VTK_TT*>(arr->GetVoidPointer(0)), i));
   }
   return val;
@@ -230,8 +214,8 @@ int vtkGroupLeafVertices::RequestData(
   // Copy everything into the new tree, adding group nodes.
   // Make a map of (parent id, group-by string) -> group vertex id.
   std::map<std::pair<vtkIdType, vtkVariant>, vtkIdType, vtkGroupLeafVerticesCompare> group_vertices;
-  std::vector<std::pair<vtkIdType, vtkIdType> > vertStack;
-  vertStack.push_back(std::make_pair(input->GetRoot(), builder->AddVertex()));
+  std::vector<std::pair<vtkIdType, vtkIdType>> vertStack;
+  vertStack.emplace_back(input->GetRoot(), builder->AddVertex());
   vtkSmartPointer<vtkOutEdgeIterator> it = vtkSmartPointer<vtkOutEdgeIterator>::New();
 
   while (!vertStack.empty())
@@ -260,7 +244,7 @@ int vtkGroupLeafVertices::RequestData(
         // and recurse.
         vtkEdgeType e = builder->AddEdge(v, child);
         builderEdgeData->CopyData(inputEdgeData, tree_e.Id, e.Id);
-        vertStack.push_back(std::make_pair(tree_child, child));
+        vertStack.emplace_back(tree_child, child);
       }
       else
       {
@@ -306,7 +290,7 @@ int vtkGroupLeafVertices::RequestData(
               vtkStringArray* data = vtkArrayDownCast<vtkStringArray>(arr2);
               for (int j = 0; j < comps; j++)
               {
-                data->InsertValue(group_vertex + j - 1, vtkStdString(""));
+                data->InsertValue(group_vertex + j - 1, vtkStdString());
               }
             }
             else if (vtkArrayDownCast<vtkVariantArray>(arr2))
@@ -317,14 +301,6 @@ int vtkGroupLeafVertices::RequestData(
                 data->InsertValue(group_vertex + j - 1, vtkVariant());
               }
             }
-            else if (vtkArrayDownCast<vtkUnicodeStringArray>(arr2))
-            {
-              vtkUnicodeStringArray* data = vtkArrayDownCast<vtkUnicodeStringArray>(arr2);
-              for (int j = 0; j < comps; j++)
-              {
-                data->InsertValue(group_vertex + j - 1, vtkUnicodeString::from_utf8(""));
-              }
-            }
             else
             {
               vtkErrorMacro(<< "Unsupported array type for InsertNextBlankRow");
@@ -360,7 +336,7 @@ int vtkGroupLeafVertices::RequestData(
         }
         vtkEdgeType e = builder->AddEdge(group_vertex, child);
         builderEdgeData->CopyData(inputEdgeData, tree_e.Id, e.Id);
-        vertStack.push_back(std::make_pair(tree_child, child));
+        vertStack.emplace_back(tree_child, child);
       }
     }
   }
@@ -375,7 +351,7 @@ int vtkGroupLeafVertices::RequestData(
   return 1;
 }
 
-// ----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 static int splitString(const vtkStdString& input, std::vector<vtkStdString>& results)
 {
@@ -453,9 +429,9 @@ static int splitString(const vtkStdString& input, std::vector<vtkStdString>& res
         // which case it's normal text and we won't even get here.
         if (!currentField.empty())
         {
-          results.push_back(currentField);
+          results.emplace_back(currentField);
         }
-        currentField = vtkStdString();
+        currentField = {};
       }
       else
       {
@@ -467,6 +443,7 @@ static int splitString(const vtkStdString& input, std::vector<vtkStdString>& res
     }
   }
 
-  results.push_back(currentField);
+  results.emplace_back(currentField);
   return static_cast<int>(results.size());
 }
+VTK_ABI_NAMESPACE_END
