@@ -1,22 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkStreamGraph.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*-------------------------------------------------------------------------
-  Copyright 2008 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-  the U.S. Government retains certain rights in this software.
--------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2008 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 /**
  * @class   vtkStreamGraph
  * @brief   combines two graphs
@@ -39,6 +23,7 @@
 #include "vtkGraphAlgorithm.h"
 #include "vtkInfovisCoreModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkBitArray;
 class vtkMergeGraphs;
 class vtkMutableDirectedGraph;
@@ -53,7 +38,7 @@ public:
   vtkTypeMacro(vtkStreamGraph, vtkGraphAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Whether to use an edge window array. The default is to
    * not use a window array.
@@ -61,17 +46,17 @@ public:
   vtkSetMacro(UseEdgeWindow, bool);
   vtkGetMacro(UseEdgeWindow, bool);
   vtkBooleanMacro(UseEdgeWindow, bool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The edge window array. The default array name is "time".
    */
   vtkSetStringMacro(EdgeWindowArrayName);
   vtkGetStringMacro(EdgeWindowArrayName);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * The time window amount. Edges with values lower
    * than the maximum value minus this window will be
@@ -80,7 +65,7 @@ public:
    */
   vtkSetMacro(EdgeWindow, double);
   vtkGetMacro(EdgeWindow, double);
-  //@}
+  ///@}
 
 protected:
   vtkStreamGraph();
@@ -99,4 +84,5 @@ private:
   void operator=(const vtkStreamGraph&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
