@@ -1,22 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPerturbCoincidentVertices.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-/*-------------------------------------------------------------------------
-  Copyright 2009 Sandia Corporation.
-  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-  the U.S. Government retains certain rights in this software.
--------------------------------------------------------------------------*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2009 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 /**
  * @class   vtkPerturbCoincidentVertices
  * @brief   Perturbs vertices that are coincident.
@@ -35,6 +19,7 @@
 #include "vtkInfovisLayoutModule.h" // For export macro
 #include "vtkSmartPointer.h"        // for ivars
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCoincidentPoints;
 class vtkDataSet;
 
@@ -45,13 +30,13 @@ public:
   vtkTypeMacro(vtkPerturbCoincidentVertices, vtkGraphAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent) override;
 
-  //@{
+  ///@{
   /**
    * Specify the perturbation factor (defaults to 1.0)
    */
   vtkSetMacro(PerturbFactor, double);
   vtkGetMacro(PerturbFactor, double);
-  //@}
+  ///@}
 
 protected:
   vtkPerturbCoincidentVertices();
@@ -70,4 +55,5 @@ private:
   void operator=(const vtkPerturbCoincidentVertices&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
