@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkInteractorStyleDrawPolygon.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkInteractorStyleDrawPolygon.h"
 
 #include "vtkCommand.h"
@@ -23,9 +11,10 @@
 #include "vtkUnsignedCharArray.h"
 #include "vtkVectorOperators.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInteractorStyleDrawPolygon);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 class vtkInteractorStyleDrawPolygon::vtkInternal
 {
 public:
@@ -73,7 +62,7 @@ public:
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleDrawPolygon::vtkInteractorStyleDrawPolygon()
 {
   this->Internal = new vtkInternal();
@@ -84,20 +73,20 @@ vtkInteractorStyleDrawPolygon::vtkInteractorStyleDrawPolygon()
   this->PixelArray = vtkUnsignedCharArray::New();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleDrawPolygon::~vtkInteractorStyleDrawPolygon()
 {
   this->PixelArray->Delete();
   delete this->Internal;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::vector<vtkVector2i> vtkInteractorStyleDrawPolygon::GetPolygonPoints()
 {
   return this->Internal->points;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleDrawPolygon::OnMouseMove()
 {
   if (!this->Interactor || !this->Moving)
@@ -137,7 +126,7 @@ void vtkInteractorStyleDrawPolygon::OnMouseMove()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleDrawPolygon::OnLeftButtonDown()
 {
   if (!this->Interactor)
@@ -164,7 +153,7 @@ void vtkInteractorStyleDrawPolygon::OnLeftButtonDown()
   this->InvokeEvent(vtkCommand::StartInteractionEvent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleDrawPolygon::OnLeftButtonUp()
 {
   if (!this->Interactor || !this->Moving)
@@ -185,7 +174,7 @@ void vtkInteractorStyleDrawPolygon::OnLeftButtonUp()
   this->InvokeEvent(vtkCommand::EndInteractionEvent);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleDrawPolygon::DrawPolygon()
 {
   vtkNew<vtkUnsignedCharArray> tmpPixelArray;
@@ -215,7 +204,7 @@ void vtkInteractorStyleDrawPolygon::DrawPolygon()
   this->Interactor->GetRenderWindow()->Frame();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleDrawPolygon::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -225,3 +214,4 @@ void vtkInteractorStyleDrawPolygon::PrintSelf(ostream& os, vtkIndent indent)
      << endl;
   os << indent << "EndPosition: " << this->EndPosition[0] << "," << this->EndPosition[1] << endl;
 }
+VTK_ABI_NAMESPACE_END
