@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkInteractorStyleUser.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkInteractorStyleUser.h"
 #include "vtkCellPicker.h"
 #include "vtkCommand.h"
@@ -19,9 +7,10 @@
 #include "vtkObjectFactory.h"
 #include "vtkRenderWindowInteractor.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInteractorStyleUser);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleUser::vtkInteractorStyleUser()
 {
   // Tell the parent class not to handle observers
@@ -36,10 +25,10 @@ vtkInteractorStyleUser::vtkInteractorStyleUser()
   this->Button = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyleUser::~vtkInteractorStyleUser() = default;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -53,7 +42,7 @@ void vtkInteractorStyleUser::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Button: " << this->Button << "\n";
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // checks for USERINTERACTION state, then defers to the superclass modes
 void vtkInteractorStyleUser::OnTimer()
 {
@@ -92,7 +81,7 @@ void vtkInteractorStyleUser::OnTimer()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnKeyPress()
 {
   if (this->HasObserver(vtkCommand::KeyPressEvent))
@@ -105,7 +94,7 @@ void vtkInteractorStyleUser::OnKeyPress()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnKeyRelease()
 {
   if (this->HasObserver(vtkCommand::KeyReleaseEvent))
@@ -119,7 +108,7 @@ void vtkInteractorStyleUser::OnKeyRelease()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnChar()
 {
   // otherwise pass the OnChar to the vtkInteractorStyle.
@@ -137,7 +126,7 @@ void vtkInteractorStyleUser::OnChar()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnRightButtonDown()
 {
   this->Button = 3;
@@ -159,7 +148,7 @@ void vtkInteractorStyleUser::OnRightButtonDown()
     this->vtkInteractorStyle::OnRightButtonDown();
   }
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnRightButtonUp()
 {
   if (this->HasObserver(vtkCommand::RightButtonReleaseEvent))
@@ -185,7 +174,7 @@ void vtkInteractorStyleUser::OnRightButtonUp()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnMouseWheelForward()
 {
   if (this->HasObserver(vtkCommand::MouseWheelForwardEvent))
@@ -206,7 +195,7 @@ void vtkInteractorStyleUser::OnMouseWheelForward()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnMouseWheelBackward()
 {
   if (this->HasObserver(vtkCommand::MouseWheelBackwardEvent))
@@ -227,7 +216,7 @@ void vtkInteractorStyleUser::OnMouseWheelBackward()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnMiddleButtonDown()
 {
   this->Button = 2;
@@ -249,7 +238,7 @@ void vtkInteractorStyleUser::OnMiddleButtonDown()
     this->vtkInteractorStyle::OnMiddleButtonDown();
   }
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnMiddleButtonUp()
 {
   if (this->HasObserver(vtkCommand::MiddleButtonReleaseEvent))
@@ -275,7 +264,7 @@ void vtkInteractorStyleUser::OnMiddleButtonUp()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnLeftButtonDown()
 {
   this->Button = 1;
@@ -297,7 +286,7 @@ void vtkInteractorStyleUser::OnLeftButtonDown()
     this->vtkInteractorStyle::OnLeftButtonDown();
   }
 }
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnLeftButtonUp()
 {
   if (this->HasObserver(vtkCommand::LeftButtonReleaseEvent))
@@ -323,7 +312,7 @@ void vtkInteractorStyleUser::OnLeftButtonUp()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnMouseMove()
 {
   this->vtkInteractorStyle::OnMouseMove();
@@ -343,7 +332,7 @@ void vtkInteractorStyleUser::OnMouseMove()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnExpose()
 {
   if (this->HasObserver(vtkCommand::ExposeEvent))
@@ -352,7 +341,7 @@ void vtkInteractorStyleUser::OnExpose()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnConfigure()
 {
   if (this->HasObserver(vtkCommand::ConfigureEvent))
@@ -361,7 +350,7 @@ void vtkInteractorStyleUser::OnConfigure()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnEnter()
 {
   if (this->HasObserver(vtkCommand::EnterEvent))
@@ -372,7 +361,7 @@ void vtkInteractorStyleUser::OnEnter()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyleUser::OnLeave()
 {
   if (this->HasObserver(vtkCommand::LeaveEvent))
@@ -382,3 +371,4 @@ void vtkInteractorStyleUser::OnLeave()
     this->InvokeEvent(vtkCommand::LeaveEvent, nullptr);
   }
 }
+VTK_ABI_NAMESPACE_END
