@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestHandleWidget.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 //
 // This example tests the vtkHandleWidget.
 //
@@ -46,7 +34,7 @@
 #include "vtkSphereSource.h"
 #include "vtkTestUtilities.h"
 
-// -----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This does the actual work: updates the vtkPline implicit function.
 // This in turn causes the pipeline to update and clip the object.
 // Callback for the interaction
@@ -74,7 +62,7 @@ public:
   vtkActor* Actor;
 };
 
-// -----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static char HandleWidgetLog[] = "# StreamVersion> 1\n"
                                 "RenderEvent 0 0 0 0 0 0 0\n"
                                 "RenderEvent 0 0 0 0 0 0 0\n"
@@ -570,7 +558,7 @@ static char HandleWidgetLog[] = "# StreamVersion> 1\n"
                                 "CharEvent 141 164 0 0 113 1 q\n"
                                 "ExitEvent 141 164 0 0 113 1 q\n";
 
-// -----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int TestHandleWidget(int argc, char* argv[])
 {
   // Create a mace out of filters.
