@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    TestLineWidget.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkSmartPointer.h"
 
 #include "vtkActor.h"
@@ -275,7 +263,7 @@ int TestLineWidget(int argc, char* argv[])
   streamer->SetMaximumPropagation(100);
   streamer->SetInitialIntegrationStep(.2);
   streamer->SetIntegrationDirectionToForward();
-  streamer->SetComputeVorticity(1);
+  streamer->SetComputeVorticity(true);
   streamer->SetIntegrator(rk4);
 
   vtkSmartPointer<vtkRibbonFilter> rf = vtkSmartPointer<vtkRibbonFilter>::New();
