@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCenteredSliderWidget.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkCenteredSliderWidget.h"
 #include "vtkCallbackCommand.h"
 #include "vtkCommand.h"
@@ -25,6 +13,7 @@
 #include "vtkWidgetEvent.h"
 #include "vtkWidgetEventTranslator.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkCenteredSliderWidget);
 
 //------------------------------------------------------------
@@ -46,7 +35,7 @@ vtkCenteredSliderWidget::vtkCenteredSliderWidget()
     vtkCommand::TimerEvent, vtkWidgetEvent::TimedOut, this, vtkCenteredSliderWidget::TimerAction);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkCenteredSliderWidget::CreateDefaultRepresentation()
 {
   if (!this->WidgetRep)
@@ -193,3 +182,4 @@ void vtkCenteredSliderWidget::PrintSelf(ostream& os, vtkIndent indent)
   // Superclass typedef defined in vtkTypeMacro() found in vtkSetGet.h
   this->Superclass::PrintSelf(os, indent);
 }
+VTK_ABI_NAMESPACE_END
