@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkImplicitCylinderRepresentation.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkImplicitCylinderRepresentation.h"
 
 #include "vtkActor.h"
@@ -53,9 +41,10 @@
 #include <algorithm>
 #include <cfloat> //for FLT_EPSILON
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkImplicitCylinderRepresentation);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImplicitCylinderRepresentation::vtkImplicitCylinderRepresentation()
 {
   this->AlongXAxis = 0;
@@ -121,6 +110,8 @@ vtkImplicitCylinderRepresentation::vtkImplicitCylinderRepresentation()
   this->EdgesActor = vtkActor::New();
   this->EdgesActor->SetMapper(this->EdgesMapper);
   this->Tubing = 1; // control whether tubing is on
+  // The feature edges or tuber turns on scalar viz - we need it off.
+  this->EdgesMapper->ScalarVisibilityOff();
 
   // Create the + cylinder axis
   this->LineSource = vtkLineSource::New();
@@ -204,6 +195,7 @@ vtkImplicitCylinderRepresentation::vtkImplicitCylinderRepresentation()
   this->ConeActor2->SetProperty(this->AxisProperty);
   this->SphereActor->SetProperty(this->AxisProperty);
   this->CylActor->SetProperty(this->CylinderProperty);
+  this->EdgesActor->SetProperty(this->EdgesProperty);
   this->OutlineActor->SetProperty(this->OutlineProperty);
 
   // The bounding box
@@ -214,7 +206,7 @@ vtkImplicitCylinderRepresentation::vtkImplicitCylinderRepresentation()
   this->TranslationAxis = Axis::NONE;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkImplicitCylinderRepresentation::~vtkImplicitCylinderRepresentation()
 {
   this->Cylinder->Delete();
@@ -267,7 +259,7 @@ vtkImplicitCylinderRepresentation::~vtkImplicitCylinderRepresentation()
   this->BoundingBox->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkImplicitCylinderRepresentation::ComputeInteractionState(int X, int Y, int vtkNotUsed(modify))
 {
   // See if anything has been selected
@@ -337,7 +329,7 @@ int vtkImplicitCylinderRepresentation::ComputeInteractionState(int X, int Y, int
   return this->InteractionState;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::SetRepresentationState(int state)
 {
   if (this->RepresentationState == state)
@@ -355,6 +347,9 @@ void vtkImplicitCylinderRepresentation::SetRepresentationState(int state)
   this->RepresentationState = state;
   this->Modified();
 
+  this->HighlightNormal(0);
+  this->HighlightCylinder(0);
+  this->HighlightOutline(0);
   if (state == vtkImplicitCylinderRepresentation::RotatingAxis)
   {
     this->HighlightNormal(1);
@@ -382,15 +377,9 @@ void vtkImplicitCylinderRepresentation::SetRepresentationState(int state)
   {
     this->HighlightNormal(1);
   }
-  else
-  {
-    this->HighlightNormal(0);
-    this->HighlightCylinder(0);
-    this->HighlightOutline(0);
-  }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::StartWidgetInteraction(double e[2])
 {
   this->StartEventPosition[0] = e[0];
@@ -402,7 +391,7 @@ void vtkImplicitCylinderRepresentation::StartWidgetInteraction(double e[2])
   this->LastEventPosition[2] = 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::WidgetInteraction(double e[2])
 {
   // Do different things depending on state
@@ -458,13 +447,13 @@ void vtkImplicitCylinderRepresentation::WidgetInteraction(double e[2])
   this->LastEventPosition[2] = 0.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::EndWidgetInteraction(double vtkNotUsed(e)[2])
 {
   this->SetRepresentationState(vtkImplicitCylinderRepresentation::Outside);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double* vtkImplicitCylinderRepresentation::GetBounds()
 {
   this->BuildRepresentation();
@@ -480,7 +469,7 @@ double* vtkImplicitCylinderRepresentation::GetBounds()
   return this->BoundingBox->GetBounds();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::GetActors(vtkPropCollection* pc)
 {
   this->OutlineActor->GetActors(pc);
@@ -493,7 +482,7 @@ void vtkImplicitCylinderRepresentation::GetActors(vtkPropCollection* pc)
   this->SphereActor->GetActors(pc);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::ReleaseGraphicsResources(vtkWindow* w)
 {
   this->OutlineActor->ReleaseGraphicsResources(w);
@@ -506,7 +495,7 @@ void vtkImplicitCylinderRepresentation::ReleaseGraphicsResources(vtkWindow* w)
   this->SphereActor->ReleaseGraphicsResources(w);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkImplicitCylinderRepresentation::RenderOpaqueGeometry(vtkViewport* v)
 {
   int count = 0;
@@ -527,7 +516,7 @@ int vtkImplicitCylinderRepresentation::RenderOpaqueGeometry(vtkViewport* v)
   return count;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkImplicitCylinderRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport* v)
 {
   int count = 0;
@@ -548,7 +537,7 @@ int vtkImplicitCylinderRepresentation::RenderTranslucentPolygonalGeometry(vtkVie
   return count;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTypeBool vtkImplicitCylinderRepresentation::HasTranslucentPolygonalGeometry()
 {
   int result = 0;
@@ -568,7 +557,7 @@ vtkTypeBool vtkImplicitCylinderRepresentation::HasTranslucentPolygonalGeometry()
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -688,7 +677,7 @@ void vtkImplicitCylinderRepresentation::PrintSelf(ostream& os, vtkIndent indent)
   // this is commented to avoid PrintSelf errors
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::HighlightNormal(int highlight)
 {
   if (highlight)
@@ -709,20 +698,22 @@ void vtkImplicitCylinderRepresentation::HighlightNormal(int highlight)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::HighlightCylinder(int highlight)
 {
   if (highlight)
   {
     this->CylActor->SetProperty(this->SelectedCylinderProperty);
+    this->EdgesActor->SetProperty(this->SelectedCylinderProperty);
   }
   else
   {
     this->CylActor->SetProperty(this->CylinderProperty);
+    this->EdgesActor->SetProperty(this->EdgesProperty);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::HighlightOutline(int highlight)
 {
   if (highlight)
@@ -735,7 +726,7 @@ void vtkImplicitCylinderRepresentation::HighlightOutline(int highlight)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::Rotate(
   double X, double Y, double* p1, double* p2, double* vpn)
 {
@@ -774,7 +765,7 @@ void vtkImplicitCylinderRepresentation::Rotate(
   this->SetAxis(aNew);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Loop through all points and translate them
 void vtkImplicitCylinderRepresentation::TranslateOutline(double* p1, double* p2)
 {
@@ -813,7 +804,7 @@ void vtkImplicitCylinderRepresentation::TranslateOutline(double* p1, double* p2)
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Loop through all points and translate them
 void vtkImplicitCylinderRepresentation::TranslateCenter(double* p1, double* p2)
 {
@@ -847,7 +838,7 @@ void vtkImplicitCylinderRepresentation::TranslateCenter(double* p1, double* p2)
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Translate the center on the axis
 void vtkImplicitCylinderRepresentation::TranslateCenterOnAxis(double* p1, double* p2)
 {
@@ -887,7 +878,7 @@ void vtkImplicitCylinderRepresentation::TranslateCenterOnAxis(double* p1, double
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::Scale(
   double* p1, double* p2, double vtkNotUsed(X), double Y)
 {
@@ -932,7 +923,7 @@ void vtkImplicitCylinderRepresentation::Scale(
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::AdjustRadius(
   double vtkNotUsed(X), double Y, double* p1, double* p2)
 {
@@ -958,7 +949,7 @@ void vtkImplicitCylinderRepresentation::AdjustRadius(
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::CreateDefaultProperties()
 {
   // Cylinder properties
@@ -985,44 +976,41 @@ void vtkImplicitCylinderRepresentation::CreateDefaultProperties()
   // Outline properties
   this->OutlineProperty = vtkProperty::New();
   this->OutlineProperty->SetAmbient(1.0);
-  this->OutlineProperty->SetAmbientColor(1.0, 1.0, 1.0);
+  this->OutlineProperty->SetColor(1.0, 1.0, 1.0);
 
   this->SelectedOutlineProperty = vtkProperty::New();
   this->SelectedOutlineProperty->SetAmbient(1.0);
-  this->SelectedOutlineProperty->SetAmbientColor(0.0, 1.0, 0.0);
+  this->SelectedOutlineProperty->SetColor(0.0, 1.0, 0.0);
 
   // Edge property
   this->EdgesProperty = vtkProperty::New();
-  this->EdgesProperty->SetAmbient(1.0);
-  this->EdgesProperty->SetAmbientColor(1.0, 1.0, 1.0);
+  // don't want for 3D tubes: this->EdgesProperty->SetAmbient(1.0);
+  this->EdgesProperty->SetColor(1.0, 0.0, 0.0);
 }
 
-//----------------------------------------------------------------------------
-void vtkImplicitCylinderRepresentation::SetEdgeColor(vtkLookupTable* lut)
+//------------------------------------------------------------------------------
+void vtkImplicitCylinderRepresentation::SetInteractionColor(double r, double g, double b)
 {
-  this->EdgesMapper->SetLookupTable(lut);
+  this->SelectedAxisProperty->SetColor(r, g, b);
+  this->SelectedOutlineProperty->SetColor(r, g, b);
+  this->SelectedCylinderProperty->SetAmbientColor(r, g, b);
 }
 
-//----------------------------------------------------------------------------
-void vtkImplicitCylinderRepresentation::SetEdgeColor(double r, double g, double b)
+//------------------------------------------------------------------------------
+void vtkImplicitCylinderRepresentation::SetHandleColor(double r, double g, double b)
 {
-  vtkSmartPointer<vtkLookupTable> lookupTable = vtkSmartPointer<vtkLookupTable>::New();
-
-  lookupTable->SetTableRange(0.0, 1.0);
-  lookupTable->SetNumberOfTableValues(1);
-  lookupTable->SetTableValue(0, r, g, b);
-  lookupTable->Build();
-
-  this->SetEdgeColor(lookupTable);
+  this->AxisProperty->SetColor(r, g, b);
+  this->EdgesProperty->SetColor(r, g, b);
 }
 
-//----------------------------------------------------------------------------
-void vtkImplicitCylinderRepresentation::SetEdgeColor(double c[3])
+//------------------------------------------------------------------------------
+void vtkImplicitCylinderRepresentation::SetForegroundColor(double r, double g, double b)
 {
-  this->SetEdgeColor(c[0], c[1], c[2]);
+  this->CylinderProperty->SetAmbientColor(r, g, b);
+  this->OutlineProperty->SetColor(r, g, b);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::PlaceWidget(double bds[6])
 {
   int i;
@@ -1066,7 +1054,7 @@ void vtkImplicitCylinderRepresentation::PlaceWidget(double bds[6])
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the center of the cylinder.
 void vtkImplicitCylinderRepresentation::SetCenter(double x, double y, double z)
 {
@@ -1077,7 +1065,7 @@ void vtkImplicitCylinderRepresentation::SetCenter(double x, double y, double z)
   this->SetCenter(center);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the center of the cylinder. Note that the center is clamped slightly inside
 // the bounding box or the cylinder tends to disappear as it hits the boundary.
 void vtkImplicitCylinderRepresentation::SetCenter(double x[3])
@@ -1086,20 +1074,20 @@ void vtkImplicitCylinderRepresentation::SetCenter(double x[3])
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Get the center of the cylinder.
 double* vtkImplicitCylinderRepresentation::GetCenter()
 {
   return this->Cylinder->GetCenter();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::GetCenter(double xyz[3])
 {
   return this->Cylinder->GetCenter(xyz);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the axis of the cylinder.
 void vtkImplicitCylinderRepresentation::SetAxis(double x, double y, double z)
 {
@@ -1117,27 +1105,27 @@ void vtkImplicitCylinderRepresentation::SetAxis(double x, double y, double z)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the axis the cylinder.
 void vtkImplicitCylinderRepresentation::SetAxis(double n[3])
 {
   this->SetAxis(n[0], n[1], n[2]);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Get the axis of the cylinder.
 double* vtkImplicitCylinderRepresentation::GetAxis()
 {
   return this->Cylinder->GetAxis();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::GetAxis(double xyz[3])
 {
   return this->Cylinder->GetAxis(xyz);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Set the radius the cylinder. The radius must be a positive number.
 void vtkImplicitCylinderRepresentation::SetRadius(double radius)
 {
@@ -1152,14 +1140,14 @@ void vtkImplicitCylinderRepresentation::SetRadius(double radius)
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Get the radius the cylinder.
 double vtkImplicitCylinderRepresentation::GetRadius()
 {
   return this->Cylinder->GetRadius();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::SetDrawCylinder(vtkTypeBool drawCyl)
 {
   if (drawCyl == this->DrawCylinder)
@@ -1172,7 +1160,7 @@ void vtkImplicitCylinderRepresentation::SetDrawCylinder(vtkTypeBool drawCyl)
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::SetAlongXAxis(vtkTypeBool var)
 {
   if (this->AlongXAxis != var)
@@ -1187,7 +1175,7 @@ void vtkImplicitCylinderRepresentation::SetAlongXAxis(vtkTypeBool var)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::SetAlongYAxis(vtkTypeBool var)
 {
   if (this->AlongYAxis != var)
@@ -1202,7 +1190,7 @@ void vtkImplicitCylinderRepresentation::SetAlongYAxis(vtkTypeBool var)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::SetAlongZAxis(vtkTypeBool var)
 {
   if (this->AlongZAxis != var)
@@ -1217,13 +1205,13 @@ void vtkImplicitCylinderRepresentation::SetAlongZAxis(vtkTypeBool var)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::GetPolyData(vtkPolyData* pd)
 {
   pd->ShallowCopy(this->Cyl);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::GetCylinder(vtkCylinder* cyl)
 {
   if (cyl == nullptr)
@@ -1236,7 +1224,7 @@ void vtkImplicitCylinderRepresentation::GetCylinder(vtkCylinder* cyl)
   cyl->SetRadius(this->Cylinder->GetRadius());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::UpdatePlacement()
 {
   this->BuildRepresentation();
@@ -1244,7 +1232,7 @@ void vtkImplicitCylinderRepresentation::UpdatePlacement()
   this->Edges->Update();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::BumpCylinder(int dir, double factor)
 {
   // Compute the distance
@@ -1254,7 +1242,7 @@ void vtkImplicitCylinderRepresentation::BumpCylinder(int dir, double factor)
   this->PushCylinder((dir > 0 ? d : -d));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::PushCylinder(double d)
 {
   vtkCamera* camera = this->Renderer->GetActiveCamera();
@@ -1274,7 +1262,7 @@ void vtkImplicitCylinderRepresentation::PushCylinder(double d)
   this->BuildRepresentation();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::BuildRepresentation()
 {
   if (!this->Renderer || !this->Renderer->GetRenderWindow())
@@ -1411,7 +1399,7 @@ void vtkImplicitCylinderRepresentation::BuildRepresentation()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::SizeHandles()
 {
   double radius =
@@ -1427,7 +1415,7 @@ void vtkImplicitCylinderRepresentation::SizeHandles()
   this->EdgesTuber->SetRadius(0.25 * radius);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Create cylinder polydata.  Basically build an oriented cylinder of
 // specified resolution.  Trim cylinder facets by performing
 // intersection tests. Note that some facets may be outside the
@@ -1536,7 +1524,7 @@ void vtkImplicitCylinderRepresentation::BuildCylinder()
   polys->Modified();
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkImplicitCylinderRepresentation::RegisterPickers()
 {
   vtkPickingManager* pm = this->GetPickingManager();
@@ -1546,3 +1534,4 @@ void vtkImplicitCylinderRepresentation::RegisterPickers()
   }
   pm->AddPicker(this->Picker, this);
 }
+VTK_ABI_NAMESPACE_END
