@@ -1,24 +1,14 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkMultiProcessStream.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkMultiProcessStream.h"
 
+#include "vtkEndian.h"
 #include "vtkObjectFactory.h"
 #include "vtkSocketCommunicator.h" // for vtkSwap8 and vtkSwap4 macros.
 #include <cassert>
 #include <deque>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkMultiProcessStream::vtkInternals
 {
 public:
@@ -128,7 +118,7 @@ public:
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream::vtkMultiProcessStream()
 {
   this->Internals = new vtkMultiProcessStream::vtkInternals();
@@ -139,14 +129,14 @@ vtkMultiProcessStream::vtkMultiProcessStream()
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream::~vtkMultiProcessStream()
 {
   delete this->Internals;
   this->Internals = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream::vtkMultiProcessStream(const vtkMultiProcessStream& other)
 {
   this->Internals = new vtkMultiProcessStream::vtkInternals();
@@ -154,33 +144,38 @@ vtkMultiProcessStream::vtkMultiProcessStream(const vtkMultiProcessStream& other)
   this->Endianness = other.Endianness;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator=(const vtkMultiProcessStream& other)
 {
+  if (this == &other)
+  {
+    return *this;
+  }
+
   this->Internals->Data = other.Internals->Data;
   this->Endianness = other.Endianness;
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Reset()
 {
   this->Internals->Data.clear();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkMultiProcessStream::Size()
 {
   return (static_cast<int>(this->Internals->Data.size()));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkMultiProcessStream::Empty()
 {
   return (this->Internals->Data.empty());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(double array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -189,7 +184,7 @@ void vtkMultiProcessStream::Push(double array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(double) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(float array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -198,7 +193,7 @@ void vtkMultiProcessStream::Push(float array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(float) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(int array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -207,7 +202,7 @@ void vtkMultiProcessStream::Push(int array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(int) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(char array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -216,7 +211,7 @@ void vtkMultiProcessStream::Push(char array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(char) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(unsigned int array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -225,7 +220,7 @@ void vtkMultiProcessStream::Push(unsigned int array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(unsigned int) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(unsigned char array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -234,7 +229,7 @@ void vtkMultiProcessStream::Push(unsigned char array[], unsigned int size)
   this->Internals->Push(array, size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(vtkTypeInt64 array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -243,7 +238,7 @@ void vtkMultiProcessStream::Push(vtkTypeInt64 array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(vtkTypeUInt64) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Push(vtkTypeUInt64 array[], unsigned int size)
 {
   assert("pre: array is nullptr!" && (array != nullptr));
@@ -252,7 +247,7 @@ void vtkMultiProcessStream::Push(vtkTypeUInt64 array[], unsigned int size)
   this->Internals->Push(reinterpret_cast<unsigned char*>(array), sizeof(vtkTypeUInt64) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(double*& array, unsigned int& size)
 {
   assert("pre: stream data must be double" &&
@@ -281,7 +276,7 @@ void vtkMultiProcessStream::Pop(double*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(double) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(float*& array, unsigned int& size)
 {
   assert(
@@ -310,7 +305,7 @@ void vtkMultiProcessStream::Pop(float*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(float) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(int*& array, unsigned int& size)
 {
   assert(
@@ -339,7 +334,7 @@ void vtkMultiProcessStream::Pop(int*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(int) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(char*& array, unsigned int& size)
 {
   assert("pre: stream data must be of type char" &&
@@ -368,7 +363,7 @@ void vtkMultiProcessStream::Pop(char*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(char) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(unsigned int*& array, unsigned int& size)
 {
   assert("pre: stream data must be of type unsigned int" &&
@@ -397,7 +392,7 @@ void vtkMultiProcessStream::Pop(unsigned int*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(unsigned int) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(unsigned char*& array, unsigned int& size)
 {
   assert("pre: stream data must be of type unsigned char" &&
@@ -426,7 +421,7 @@ void vtkMultiProcessStream::Pop(unsigned char*& array, unsigned int& size)
   this->Internals->Pop(array, size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(vtkTypeInt64*& array, unsigned int& size)
 {
   assert("pre: stream data must be of type vtkTypeInt64" &&
@@ -455,7 +450,7 @@ void vtkMultiProcessStream::Pop(vtkTypeInt64*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(vtkTypeInt64) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::Pop(vtkTypeUInt64*& array, unsigned int& size)
 {
   assert("pre: stream data must be of type vtkTypeUInt64" &&
@@ -484,7 +479,7 @@ void vtkMultiProcessStream::Pop(vtkTypeUInt64*& array, unsigned int& size)
   this->Internals->Pop(reinterpret_cast<unsigned char*>(array), sizeof(vtkTypeUInt64) * size);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(double value)
 {
   this->Internals->Data.push_back(vtkInternals::double_value);
@@ -492,7 +487,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(double value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(float value)
 {
   this->Internals->Data.push_back(vtkInternals::float_value);
@@ -500,7 +495,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(float value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(int value)
 {
   this->Internals->Data.push_back(vtkInternals::int32_value);
@@ -508,7 +503,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(int value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(char value)
 {
   this->Internals->Data.push_back(vtkInternals::char_value);
@@ -516,7 +511,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(char value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(bool v)
 {
   char value = v;
@@ -525,7 +520,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(bool v)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(unsigned int value)
 {
   this->Internals->Data.push_back(vtkInternals::uint32_value);
@@ -533,7 +528,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(unsigned int value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(unsigned char value)
 {
   this->Internals->Data.push_back(vtkInternals::uchar_value);
@@ -541,7 +536,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(unsigned char value)
   return (*this);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(vtkTypeInt64 value)
 {
   this->Internals->Data.push_back(vtkInternals::int64_value);
@@ -549,7 +544,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(vtkTypeInt64 value)
   return (*this);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(vtkTypeUInt64 value)
 {
   this->Internals->Data.push_back(vtkInternals::uint64_value);
@@ -557,14 +552,14 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(vtkTypeUInt64 value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(const char* value)
 {
   this->operator<<(std::string(value));
   return *this;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(const std::string& value)
 {
   // Find the real string size
@@ -584,7 +579,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(const std::string& valu
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator<<(const vtkMultiProcessStream& value)
 {
   unsigned int size = static_cast<unsigned int>(value.Internals->Data.size());
@@ -597,7 +592,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator<<(const vtkMultiProcessSt
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(vtkMultiProcessStream& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::stream_value);
@@ -615,7 +610,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(vtkMultiProcessStream&
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(double& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::double_value);
@@ -624,7 +619,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(double& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(float& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::float_value);
@@ -633,7 +628,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(float& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(int& value)
 {
   // Automatically convert 64 bit values in case we are trying to transfer
@@ -651,7 +646,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(int& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(char& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::char_value);
@@ -660,7 +655,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(char& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(bool& v)
 {
   char value;
@@ -671,7 +666,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(bool& v)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(unsigned int& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::uint32_value);
@@ -680,7 +675,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(unsigned int& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(unsigned char& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::uchar_value);
@@ -689,7 +684,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(unsigned char& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(vtkTypeInt64& value)
 {
   // Automatically convert 64 bit values in case we are trying to transfer
@@ -707,7 +702,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(vtkTypeInt64& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(vtkTypeUInt64& value)
 {
   assert(this->Internals->Data.front() == vtkInternals::uint64_value);
@@ -716,7 +711,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(vtkTypeUInt64& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMultiProcessStream& vtkMultiProcessStream::operator>>(std::string& value)
 {
   value = "";
@@ -733,7 +728,7 @@ vtkMultiProcessStream& vtkMultiProcessStream::operator>>(std::string& value)
   return (*this);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 std::vector<unsigned char> vtkMultiProcessStream::GetRawData() const
 {
   std::vector<unsigned char> data;
@@ -741,7 +736,7 @@ std::vector<unsigned char> vtkMultiProcessStream::GetRawData() const
   return data;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::GetRawData(std::vector<unsigned char>& data) const
 {
   data.clear();
@@ -755,7 +750,7 @@ void vtkMultiProcessStream::GetRawData(std::vector<unsigned char>& data) const
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::SetRawData(const std::vector<unsigned char>& data)
 {
   this->Internals->Data.clear();
@@ -774,7 +769,7 @@ void vtkMultiProcessStream::SetRawData(const std::vector<unsigned char>& data)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::GetRawData(unsigned char*& data, unsigned int& size)
 {
   delete[] data;
@@ -791,7 +786,7 @@ void vtkMultiProcessStream::GetRawData(unsigned char*& data, unsigned int& size)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkMultiProcessStream::SetRawData(const unsigned char* data, unsigned int size)
 {
   this->Internals->Data.clear();
@@ -810,3 +805,4 @@ void vtkMultiProcessStream::SetRawData(const unsigned char* data, unsigned int s
     }
   }
 }
+VTK_ABI_NAMESPACE_END
