@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkScalarBarActor.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkScalarBarActor.h"
 #include "vtkScalarBarActorInternal.h"
 
@@ -50,6 +38,7 @@
 
 #undef VTK_DBG_LAYOUT
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkScalarBarActor);
 
 vtkCxxSetObjectMacro(vtkScalarBarActor, LookupTable, vtkScalarsToColors);
@@ -58,8 +47,9 @@ vtkCxxSetObjectMacro(vtkScalarBarActor, LabelTextProperty, vtkTextProperty);
 vtkCxxSetObjectMacro(vtkScalarBarActor, TitleTextProperty, vtkTextProperty);
 vtkCxxSetObjectMacro(vtkScalarBarActor, BackgroundProperty, vtkProperty2D);
 vtkCxxSetObjectMacro(vtkScalarBarActor, FrameProperty, vtkProperty2D);
+vtkCxxSetObjectMacro(vtkScalarBarActor, CustomLabels, vtkDoubleArray);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Instantiate object with 64 maximum colors; 5 labels; %%-#6.3g label
 // format, no title, and vertical orientation. The initial scalar bar
 // size is (0.05 x 0.8) of the viewport size.
@@ -267,7 +257,7 @@ vtkScalarBarActor::vtkScalarBarActor()
   this->UnconstrainedFontSize = false;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Release any graphics resources that are being consumed by this actor.
 // The parameter window could be used to determine which graphic
 // resources to release.
@@ -297,7 +287,7 @@ void vtkScalarBarActor::ReleaseGraphicsResources(vtkWindow* win)
   this->Texture->ReleaseGraphicsResources(win);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::GetScalarBarRect(int rect[4], vtkViewport* viewport)
 {
   vtkCoordinate* origin = this->ScalarBarActor->GetPositionCoordinate();
@@ -312,7 +302,7 @@ void vtkScalarBarActor::GetScalarBarRect(int rect[4], vtkViewport* viewport)
   rect[3] = static_cast<int>(bounds[3] - bounds[2] + 0.5);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScalarBarActor::~vtkScalarBarActor()
 {
   delete[] this->LabelFormat;
@@ -353,6 +343,10 @@ vtkScalarBarActor::~vtkScalarBarActor()
 
   this->SetLookupTable(nullptr);
   this->SetAnnotationTextProperty(nullptr);
+  if (this->CustomLabels != nullptr)
+  {
+    this->CustomLabels->Delete();
+  }
   this->SetLabelTextProperty(nullptr);
   this->SetTitleTextProperty(nullptr);
   this->Texture->Delete();
@@ -369,7 +363,7 @@ vtkScalarBarActor::~vtkScalarBarActor()
   delete this->P;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkScalarBarActor::RenderOverlay(vtkViewport* viewport)
 {
   if (!this->RebuildLayoutIfNeeded(viewport))
@@ -471,7 +465,7 @@ int vtkScalarBarActor::RebuildLayoutIfNeeded(vtkViewport* viewport)
 {
   if (!this->LookupTable)
   {
-    vtkWarningMacro(<< "Need a mapper to render a scalar bar");
+    vtkWarningMacro(<< "Need a lookup table to render a scalar bar");
     return 0;
   }
 
@@ -532,7 +526,7 @@ int vtkScalarBarActor::RebuildLayoutIfNeeded(vtkViewport* viewport)
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkScalarBarActor::RenderOpaqueGeometry(vtkViewport* viewport)
 {
   if (!this->RebuildLayoutIfNeeded(viewport))
@@ -602,7 +596,7 @@ int vtkScalarBarActor::RenderOpaqueGeometry(vtkViewport* viewport)
   return renderedSomething;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Does this prop have some translucent polygonal geometry?
 vtkTypeBool vtkScalarBarActor::HasTranslucentPolygonalGeometry()
@@ -613,7 +607,7 @@ vtkTypeBool vtkScalarBarActor::HasTranslucentPolygonalGeometry()
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -662,7 +656,10 @@ void vtkScalarBarActor::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "ComponentTitle: " << (this->ComponentTitle ? this->ComponentTitle : "(none)")
      << "\n";
   os << indent << "Maximum Number Of Colors: " << this->MaximumNumberOfColors << "\n";
-  os << indent << "Number Of Labels: " << this->NumberOfLabels << "\n";
+  os << indent << "Number Of Automatic Labels: " << this->NumberOfLabels << "\n";
+  os << indent << "Number Of Custom Labels: "
+     << (this->CustomLabels != nullptr ? this->CustomLabels->GetNumberOfTuples() : 0) << "\n";
+  os << indent << "Using Custom Labels: " << (this->UseCustomLabels ? "On" : "Off") << "\n";
   os << indent << "Number Of Labels Built: " << this->NumberOfLabelsBuilt << "\n";
 
   os << indent << "Orientation: ";
@@ -719,7 +716,7 @@ void vtkScalarBarActor::PrintSelf(ostream& os, vtkIndent indent)
   this->FrameProperty->PrintSelf(os, indent.GetNextIndent());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ShallowCopy(vtkProp* prop)
 {
   vtkScalarBarActor* a = vtkScalarBarActor::SafeDownCast(prop);
@@ -734,6 +731,8 @@ void vtkScalarBarActor::ShallowCopy(vtkProp* prop)
     this->SetTitleTextProperty(a->GetTitleTextProperty());
     this->SetLabelFormat(a->GetLabelFormat());
     this->SetTitle(a->GetTitle());
+    this->SetCustomLabels(a->GetCustomLabels());
+    this->SetUseCustomLabels(a->GetUseCustomLabels());
     this->GetPositionCoordinate()->SetCoordinateSystem(
       a->GetPositionCoordinate()->GetCoordinateSystem());
     this->GetPositionCoordinate()->SetValue(a->GetPositionCoordinate()->GetValue());
@@ -750,7 +749,7 @@ void vtkScalarBarActor::ShallowCopy(vtkProp* prop)
   this->vtkActor2D::ShallowCopy(prop);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::RebuildLayout(vtkViewport* viewport)
 {
   vtkDebugMacro(<< "Rebuilding subobjects");
@@ -840,13 +839,13 @@ void vtkScalarBarActor::DrawBoxes()
   AddBox(pts, lines, this->P->ScalarBarBox, this->P->TL);
   AddBox(pts, lines, this->P->NanBox, this->P->TL);
   AddBox(pts, lines, this->P->TitleBox, this->P->TL);
-  if (this->NumberOfLabels > 0)
+  if (this->NumberOfLabelsBuilt > 0)
   {
     AddBox(pts, lines, this->P->TickBox, this->P->TL);
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ComputeFrame()
 {
   // get the viewport size in display coordinates
@@ -877,7 +876,7 @@ void vtkScalarBarActor::ComputeFrame()
   this->LastSize[1] = size[1];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ComputeScalarBarThickness()
 {
   // We do not set Size[1] (length), since the title bounds may encroach
@@ -910,7 +909,7 @@ void vtkScalarBarActor::ComputeScalarBarThickness()
       (nudge * (this->TextPosition == PrecedeScalarBar ? -1 : 1)));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ComputeSwatchPad()
 {
   if (this->P->NumNotes)
@@ -925,7 +924,7 @@ void vtkScalarBarActor::ComputeSwatchPad()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutNanSwatch()
 {
   // We don't have ScalarBarBox.Size[1] set yet; use the frame width instead.
@@ -962,7 +961,7 @@ void vtkScalarBarActor::LayoutNanSwatch()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutBelowRangeSwatch()
 {
   // We don't have ScalarBarBox.Size[1] set yet; use the frame width instead.
@@ -1005,7 +1004,7 @@ void vtkScalarBarActor::LayoutBelowRangeSwatch()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutAboveRangeSwatch()
 {
   // We don't have ScalarBarBox.Size[1] set yet; use the frame width instead.
@@ -1022,7 +1021,7 @@ void vtkScalarBarActor::LayoutAboveRangeSwatch()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutAboveRangeSwatchPosn()
 {
   if (this->Orientation == VTK_ORIENT_VERTICAL)
@@ -1065,7 +1064,7 @@ void vtkScalarBarActor::LayoutAboveRangeSwatchPosn()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::PrepareTitleText()
 {
   // Update actor with the latest title/subtitle
@@ -1099,7 +1098,7 @@ void vtkScalarBarActor::PrepareTitleText()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutTitle()
 {
   if (this->Title == nullptr || !strlen(this->Title))
@@ -1163,7 +1162,7 @@ void vtkScalarBarActor::LayoutTitle()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ComputeScalarBarLength()
 {
   this->P->ScalarBarBox.Size[1] = this->Orientation == VTK_ORIENT_VERTICAL
@@ -1191,7 +1190,7 @@ void vtkScalarBarActor::ComputeScalarBarLength()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutTicks()
 {
   if (this->LookupTable->GetIndexedLookup())
@@ -1203,47 +1202,90 @@ void vtkScalarBarActor::LayoutTicks()
   // find the best size for the ticks
   const double* range = this->LookupTable->GetRange();
   char string[512];
-  double val;
+  double val, rng, offset;
   int i;
+  if (this->UseCustomLabels)
+  {
+    this->NumberOfLabelsBuilt =
+      this->CustomLabels != nullptr ? this->CustomLabels->GetNumberOfTuples() : 0;
+  }
+  else
+  {
+    this->NumberOfLabelsBuilt = this->NumberOfLabels;
+  }
 
   // TODO: this should be optimized, maybe by keeping a list of
   // allocated mappers, in order to avoid creation/destruction of
   // their underlying text properties (i.e. each time a mapper is
   // created, text properties are created and shallow-assigned a font size
   // which value might be "far" from the target font size).
-  this->P->TextActors.resize(this->NumberOfLabels);
+  this->P->TextActors.resize(this->NumberOfLabelsBuilt);
+  this->P->TextActorAnchors.resize(this->NumberOfLabelsBuilt);
 
   // Does this map have its scale set to log?
-  int isLogTable = this->LookupTable->UsingLogScale();
-
-  for (i = 0; i < this->NumberOfLabels; i++)
+  vtkTypeBool isLogTable = this->LookupTable->UsingLogScale();
+  if (isLogTable)
+  {
+    offset = log10(range[0]);
+    rng = (log10(range[1]) - offset);
+  }
+  else
+  {
+    offset = range[0];
+    rng = range[1] - offset;
+  }
+  for (i = 0; i < this->NumberOfLabelsBuilt; i++)
   {
     this->P->TextActors[i].TakeReference(vtkTextActor::New());
-
-    if (isLogTable)
+    // Get or compute the actual data value and its normalized position
+    if (this->UseCustomLabels)
     {
-      double lval;
-      if (this->NumberOfLabels > 1)
+      // We should be guaranteed above that this->CustomLabels is not null
+      // at this point (otherwise NumberOfLabelsBuilt == 0), but let's be extra
+      // careful
+      val = this->CustomLabels != nullptr ? this->CustomLabels->GetValue(i) : 1.0;
+      if (rng > 0)
       {
-        lval = log10(range[0]) +
-          static_cast<double>(i) / (this->NumberOfLabels - 1) * (log10(range[1]) - log10(range[0]));
+        if (isLogTable)
+        {
+          if (val > 0)
+          {
+            this->P->TextActorAnchors[i] = (log10(val) - offset) / rng;
+          }
+          else
+          {
+            this->P->TextActorAnchors[i] = -1.;
+          }
+        }
+        else
+        {
+          this->P->TextActorAnchors[i] = (val - offset) / rng;
+        }
+      }
+      else if (val == range[0])
+      {
+        this->P->TextActorAnchors[i] = 0.5;
       }
       else
       {
-        lval = log10(range[0]) + 0.5 * (log10(range[1]) - log10(range[0]));
+        this->P->TextActorAnchors[i] = -1.;
       }
-      val = pow(10.0, lval);
     }
     else
     {
-      if (this->NumberOfLabels > 1)
+      if (this->NumberOfLabelsBuilt > 1)
       {
-        val =
-          range[0] + static_cast<double>(i) / (this->NumberOfLabels - 1) * (range[1] - range[0]);
+        val = static_cast<double>(i) / (this->NumberOfLabelsBuilt - 1);
       }
       else
       {
-        val = range[0] + 0.5 * (range[1] - range[0]);
+        val = 0.5;
+      }
+      this->P->TextActorAnchors[i] = val;
+      val = offset + val * rng;
+      if (isLogTable)
+      {
+        val = pow(10., val);
       }
     }
 
@@ -1263,7 +1305,7 @@ void vtkScalarBarActor::LayoutTicks()
       this->PositionCoordinate);
   }
 
-  if (this->NumberOfLabels)
+  if (this->NumberOfLabelsBuilt > 0)
   {
     int labelSize[2];
     labelSize[0] = labelSize[1] = 0;
@@ -1306,9 +1348,9 @@ void vtkScalarBarActor::LayoutTicks()
       }
 
       targetWidth = this->P->TickBox.Size[0];
-      targetHeight =
-        static_cast<int>((this->P->TickBox.Size[1] - this->TextPad * (this->NumberOfLabels - 1)) /
-          this->NumberOfLabels);
+      targetHeight = static_cast<int>(
+        (this->P->TickBox.Size[1] - this->TextPad * (this->NumberOfLabelsBuilt - 1)) /
+        this->NumberOfLabelsBuilt);
     }
     else
     { // NB. Size[1] = width, Size[0] = height
@@ -1327,16 +1369,16 @@ void vtkScalarBarActor::LayoutTicks()
       {
         this->P->TickBox.Posn[1] += this->P->ScalarBarBox.Size[0];
       }
-      targetWidth =
-        static_cast<int>((this->P->TickBox.Size[1] - this->TextPad * (this->NumberOfLabels - 1)) /
-          this->NumberOfLabels);
+      targetWidth = static_cast<int>(
+        (this->P->TickBox.Size[1] - this->TextPad * (this->NumberOfLabelsBuilt - 1)) /
+        this->NumberOfLabelsBuilt);
       targetHeight = this->P->TickBox.Size[0];
     }
 
     if (!this->UnconstrainedFontSize)
     {
       vtkTextActor::SetMultipleConstrainedFontSize(this->P->Viewport, targetWidth, targetHeight,
-        this->P->TextActors.PointerArray(), this->NumberOfLabels, labelSize);
+        this->P->TextActors.PointerArray(), this->NumberOfLabelsBuilt, labelSize);
     }
 
     // Now adjust scalar bar size by the half-size of the first and last ticks
@@ -1356,10 +1398,9 @@ void vtkScalarBarActor::LayoutTicks()
       this->P->TickBox.Size[1] -= this->TextPad;
     }
   }
-  this->NumberOfLabelsBuilt = this->NumberOfLabels;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutForUnconstrainedFont()
 {
   if (this->UnconstrainedFontSize)
@@ -1408,7 +1449,7 @@ void vtkScalarBarActor::LayoutForUnconstrainedFont()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::LayoutAnnotations()
 {
   if (this->DrawAnnotations)
@@ -1420,7 +1461,7 @@ void vtkScalarBarActor::LayoutAnnotations()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureFrame()
 {
   // set frame structure
@@ -1479,7 +1520,7 @@ void vtkScalarBarActor::ConfigureFrame()
   frLines->InsertNextCell(5, bgIds);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureScalarBar()
 {
   vtkScalarsToColors* lut = this->LookupTable;
@@ -1587,7 +1628,7 @@ void vtkScalarBarActor::ConfigureScalarBar()
   tc->SetTuple2(3, 0.0, barHeight / this->TextureGridWidth);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureTitle()
 {
   this->TitleActor->SetPosition(
@@ -1597,17 +1638,16 @@ void vtkScalarBarActor::ConfigureTitle()
       : this->P->TitleBox.Posn[1] + this->P->TitleBox.Size[this->P->TL[1]]);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureTicks()
 {
-  double val;
+  double val, anchor;
   double sizeTextData[2];
   for (int i = 0; i < this->NumberOfLabelsBuilt; ++i)
   {
-    val = (this->NumberOfLabelsBuilt > 1 ? static_cast<double>(i) / (this->NumberOfLabelsBuilt - 1)
-                                         : 0.5) *
-        this->P->TickBox.Size[1] +
-      this->P->TickBox.Posn[this->P->TL[1]];
+    anchor = this->P->TextActorAnchors[i];
+    this->P->TextActors[i]->SetVisibility((anchor > -1e-6 && anchor < 1 + 1e-6));
+    val = anchor * this->P->TickBox.Size[1] + this->P->TickBox.Posn[this->P->TL[1]];
     this->P->TextActors[i]->GetSize(this->P->Viewport, sizeTextData);
     if (this->Orientation == VTK_ORIENT_VERTICAL)
     { // VERTICAL
@@ -1632,7 +1672,7 @@ void vtkScalarBarActor::ConfigureTicks()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureNanSwatch()
 {
   if (!this->DrawNanAnnotation)
@@ -1690,7 +1730,7 @@ void vtkScalarBarActor::ConfigureNanSwatch()
   rgb[3] = static_cast<unsigned char>(this->UseOpacity ? rgba[3] * 255. : 255.);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureAboveBelowRangeSwatch(bool above)
 {
   // Check above/below
@@ -1783,7 +1823,7 @@ void vtkScalarBarActor::ConfigureAboveBelowRangeSwatch(bool above)
   rgb[3] = static_cast<unsigned char>(this->UseOpacity ? rgba[3] * 255. : 255.);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::ConfigureAnnotations()
 {
   // I. Create an actor for each valid label.
@@ -1797,8 +1837,7 @@ void vtkScalarBarActor::ConfigureAnnotations()
   this->P->AnnotationAnchors.resize(numNotes);
   this->P->AnnotationColors.resize(numNotes);
   int i = 0;
-  std::map<double, vtkStdString>::iterator it;
-  for (it = this->P->Labels.begin(); it != this->P->Labels.end(); ++it, ++i)
+  for (auto it = this->P->Labels.begin(); it != this->P->Labels.end(); ++it, ++i)
   {
     this->P->AnnotationAnchors[i] = it->first;
     this->P->AnnotationColors[i] = this->P->LabelColors[it->first];
@@ -1947,7 +1986,7 @@ void vtkScalarBarActor::ConfigureAnnotations()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::FreeLayoutStorage()
 {
   // Delete previously constructed objects
@@ -1969,12 +2008,13 @@ void vtkScalarBarActor::FreeLayoutStorage()
   }
 
   this->P->TextActors.clear();
+  this->P->TextActorAnchors.clear();
   this->P->AnnotationLabels.clear();
   this->P->AnnotationAnchors.clear();
   this->P->AnnotationColors.clear();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScalarBarActor::SizeTitle(double* titleSize, int* size, vtkViewport* viewport)
 {
   titleSize[0] = titleSize[1] = 0;
@@ -2019,12 +2059,12 @@ void vtkScalarBarActor::SizeTitle(double* titleSize, int* size, vtkViewport* vie
   this->TitleActor->GetSize(viewport, titleSize);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkScalarBarActor::MapAnnotationLabels(
   vtkScalarsToColors* lkup, double start, double delta, const double* range)
 {
   int numNotes = lkup->GetNumberOfAnnotatedValues();
-  bool indexed = lkup->GetIndexedLookup() ? true : false;
+  bool indexed = lkup->GetIndexedLookup() != 0;
   bool vertical = (this->Orientation == VTK_ORIENT_VERTICAL);
   vtkColor4d fltCol;
   double drange = range[1] - range[0];
@@ -2038,7 +2078,7 @@ int vtkScalarBarActor::MapAnnotationLabels(
   {
     for (int i = 0; i < numNotes; ++i)
     {
-      vtkStdString label = lkup->GetAnnotation(i);
+      std::string label = lkup->GetAnnotation(i);
       lkup->GetAnnotationColor(lkup->GetAnnotatedValue(i), fltCol.GetData());
       double x;
       bool canPositionLabel = !label.empty();
@@ -2132,7 +2172,7 @@ int vtkScalarBarActor::MapAnnotationLabels(
   return static_cast<int>(this->P->Labels.size());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkScalarBarActor::PlaceAnnotationsVertically(double barX, double barY,
   double vtkNotUsed(barWidth), double barHeight, double vtkNotUsed(delta), double pad)
 {
@@ -2142,25 +2182,28 @@ int vtkScalarBarActor::PlaceAnnotationsVertically(double barX, double barY,
   }
 
 #define VTK_ANN_VLAYOUT(j, dir, delt)                                                              \
-  ctr = this->P->AnnotationAnchors[j];                                                             \
-  ll[0] = lpts->InsertNextPoint(xl0, ctr, 0.);                                                     \
-  this->P->AnnotationLabels[j]->GetSize(this->P->Viewport, tsz);                                   \
-  hh = (tsz[1] + pad) / 2.; /* label half-height, incl. padding */                                 \
-  if (((dir) < 0 && ctr + hh > dnCum) || ((dir) > 0 && ctr - hh < upCum))                          \
-    ctr = (delt) + (dir)*hh;                                                                       \
-  this->P->AnnotationLabels[j]->GetTextProperty()->SetJustification(                               \
-    this->TextPosition == PrecedeScalarBar ? VTK_TEXT_LEFT : VTK_TEXT_RIGHT);                      \
-  this->P->AnnotationLabels[j]->GetTextProperty()->SetVerticalJustificationToCentered();           \
-  this->P->AnnotationLabels[j]->SetPosition(barX +                                                 \
-      (this->TextPosition == PrecedeScalarBar ? 1 : -1) * (pad + this->AnnotationLeaderPadding),   \
-    ctr);                                                                                          \
-  ll[1] = lpts->InsertNextPoint(xl1, ctr, 0.);                                                     \
-  llines->InsertNextCell(2, ll);                                                                   \
-  llcolors->InsertNextTypedTuple(this->P->AnnotationColors[j].GetData());                          \
-  if (upCum < ctr + hh)                                                                            \
-    upCum = ctr + hh;                                                                              \
-  if (dnCum > ctr - hh)                                                                            \
-    dnCum = ctr - hh;
+  do                                                                                               \
+  {                                                                                                \
+    ctr = this->P->AnnotationAnchors[j];                                                           \
+    ll[0] = lpts->InsertNextPoint(xl0, ctr, 0.);                                                   \
+    this->P->AnnotationLabels[j]->GetSize(this->P->Viewport, tsz);                                 \
+    hh = (tsz[1] + pad) / 2.; /* label half-height, incl. padding */                               \
+    if (((dir) < 0 && ctr + hh > dnCum) || ((dir) > 0 && ctr - hh < upCum))                        \
+      ctr = (delt) + (dir)*hh;                                                                     \
+    this->P->AnnotationLabels[j]->GetTextProperty()->SetJustification(                             \
+      this->TextPosition == PrecedeScalarBar ? VTK_TEXT_LEFT : VTK_TEXT_RIGHT);                    \
+    this->P->AnnotationLabels[j]->GetTextProperty()->SetVerticalJustificationToCentered();         \
+    this->P->AnnotationLabels[j]->SetPosition(barX +                                               \
+        (this->TextPosition == PrecedeScalarBar ? 1 : -1) * (pad + this->AnnotationLeaderPadding), \
+      ctr);                                                                                        \
+    ll[1] = lpts->InsertNextPoint(xl1, ctr, 0.);                                                   \
+    llines->InsertNextCell(2, ll);                                                                 \
+    llcolors->InsertNextTypedTuple(this->P->AnnotationColors[j].GetData());                        \
+    if (upCum < ctr + hh)                                                                          \
+      upCum = ctr + hh;                                                                            \
+    if (dnCum > ctr - hh)                                                                          \
+      dnCum = ctr - hh;                                                                            \
+  } while (false)
 
   int numNotes = static_cast<int>(this->P->AnnotationLabels.size());
   vtkPoints* lpts = vtkPoints::New();
@@ -2239,7 +2282,7 @@ int vtkScalarBarActor::PlaceAnnotationsVertically(double barX, double barY,
   return numNotes;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 struct vtkScalarBarHLabelInfo
 {
   double X[2]; // padded left-right label bounds
@@ -2248,7 +2291,7 @@ struct vtkScalarBarHLabelInfo
   double Anchor[2]; // x-y coordinates of anchor point
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // A non-overlapping label placer for a horizontal array of annotated swatches.
 // When space is tight, It displaces labels vertically and uses broken leader
 // lines to relate labels back to swatches.
@@ -2273,7 +2316,7 @@ struct vtkScalarBarHLabelPlacer
     , Pad(pad)
     , LeaderPad(leaderPad)
     , Dir(dir < 0 ? -1. : 1.)
-    , HaveCtr(n % 2 ? true : false)
+    , HaveCtr(n % 2 != 0)
   {
     this->XBounds[0] = xmin;
     this->XBounds[1] = xmax;
@@ -2461,7 +2504,7 @@ struct vtkScalarBarHLabelPlacer
   }
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 /**\brief Non-overlapping label placer for a horizontal array of swatches.
  *
  * A set of rules are enforced during layout:
@@ -2499,12 +2542,15 @@ int vtkScalarBarActor::PlaceAnnotationsHorizontally(
   }
 
 #define VTK_ANN_HLAYOUT(j, placer)                                                                 \
-  this->P->AnnotationLabels[j]->GetTextProperty()->SetJustification(                               \
-    (placer).Places[j].Justification);                                                             \
-  this->P->AnnotationLabels[j]->GetTextProperty()->SetVerticalJustification(                       \
-    (placer).Dir > 0 ? VTK_TEXT_BOTTOM : VTK_TEXT_TOP);                                            \
-  this->P->AnnotationLabels[j]->SetPosition((placer).Places[j].Anchor);                            \
-  (placer).AddBrokenLeader(j, lpts, llines, llcolors, this->P->AnnotationColors[j]);
+  do                                                                                               \
+  {                                                                                                \
+    this->P->AnnotationLabels[j]->GetTextProperty()->SetJustification(                             \
+      (placer).Places[j].Justification);                                                           \
+    this->P->AnnotationLabels[j]->GetTextProperty()->SetVerticalJustification(                     \
+      (placer).Dir > 0 ? VTK_TEXT_BOTTOM : VTK_TEXT_TOP);                                          \
+    this->P->AnnotationLabels[j]->SetPosition((placer).Places[j].Anchor);                          \
+    (placer).AddBrokenLeader(j, lpts, llines, llcolors, this->P->AnnotationColors[j]);             \
+  } while (false)
 
   int numNotes = static_cast<int>(this->P->AnnotationLabels.size());
   bool precede = this->TextPosition == vtkScalarBarActor::PrecedeScalarBar;
@@ -2537,7 +2583,6 @@ int vtkScalarBarActor::PlaceAnnotationsHorizontally(
   int ic = numNotes / 2;
   int lf, rt;
   double tsz[2];
-  vtkColor3ub leaderColor;
   if (2 * ic == numNotes)
   {
     lf = ic - 1;
@@ -2566,3 +2611,4 @@ int vtkScalarBarActor::PlaceAnnotationsHorizontally(
   llcolors->Delete();
   return numNotes;
 }
+VTK_ABI_NAMESPACE_END
