@@ -1,44 +1,33 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkContextScene.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkContextScene.h"
 
-#include "vtkContextItem.h"
 #include "vtkContext2D.h"
-#include "vtkTransform2D.h"
-#include "vtkMatrix3x3.h"
-#include "vtkContextScenePrivate.h"
-#include "vtkContextMouseEvent.h"
+#include "vtkContextItem.h"
 #include "vtkContextKeyEvent.h"
+#include "vtkContextMouseEvent.h"
+#include "vtkContextScenePrivate.h"
+#include "vtkMatrix3x3.h"
 #include "vtkNew.h"
+#include "vtkTransform2D.h"
 
 // Get my new commands
 #include "vtkCommand.h"
 
-#include "vtkAnnotationLink.h"
-#include "vtkRenderWindowInteractor.h"
-#include "vtkRenderWindow.h"
-#include "vtkRenderer.h"
-#include "vtkObjectFactory.h"
 #include "vtkAbstractContextBufferId.h"
+#include "vtkAnnotationLink.h"
+#include "vtkObjectFactory.h"
+#include "vtkRenderWindow.h"
+#include "vtkRenderWindowInteractor.h"
+#include "vtkRenderer.h"
 
 // My STL containers
 #include <cassert>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Minimal storage class for STL containers etc.
+VTK_ABI_NAMESPACE_BEGIN
 class vtkContextScene::Private
 {
 public:
@@ -47,9 +36,7 @@ public:
     this->Event.SetButton(vtkContextMouseEvent::NO_BUTTON);
     this->IsDirty = true;
   }
-  ~Private()
-  {
-  }
+  ~Private() = default;
 
   // The item with a current mouse down
   vtkWeakPointer<vtkAbstractContextItem> itemMousePressCurrent;
@@ -60,35 +47,37 @@ public:
   bool IsDirty;
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkContextScene);
 vtkCxxSetObjectMacro(vtkContextScene, AnnotationLink, vtkAnnotationLink);
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkContextScene::vtkContextScene()
 {
   this->Storage = new Private;
-  this->AnnotationLink = NULL;
+  this->AnnotationLink = nullptr;
   this->Geometry[0] = 0;
   this->Geometry[1] = 0;
-  this->BufferId=0;
-  this->BufferIdDirty=true;
-  this->BufferIdSupportTested=false;
-  this->BufferIdSupported=false;
+  this->Origin[0] = 0;
+  this->Origin[1] = 0;
+  this->BufferId = nullptr;
+  this->BufferIdDirty = true;
+  this->BufferIdSupportTested = false;
+  this->BufferIdSupported = false;
   this->UseBufferId = true;
   this->ScaleTiles = true;
-  this->Transform = NULL;
-  this->Children = new vtkContextScenePrivate(NULL);
+  this->Transform = nullptr;
+  this->Children = new vtkContextScenePrivate(nullptr);
   this->Children->SetScene(this);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkContextScene::~vtkContextScene()
 {
   delete this->Storage;
-  this->Storage = NULL;
-  this->SetAnnotationLink(NULL);
-  if(this->BufferId!=0)
+  this->Storage = nullptr;
+  this->SetAnnotationLink(nullptr);
+  if (this->BufferId != nullptr)
   {
     this->BufferId->Delete();
   }
@@ -99,21 +88,21 @@ vtkContextScene::~vtkContextScene()
   delete this->Children;
 }
 
-//-----------------------------------------------------------------------------
-void vtkContextScene::SetRenderer(vtkRenderer *r)
+//------------------------------------------------------------------------------
+void vtkContextScene::SetRenderer(vtkRenderer* r)
 {
-  this->Renderer=r;
-  this->BufferIdSupportTested=false;
+  this->Renderer = r;
+  this->BufferIdSupportTested = false;
 }
 
-//-----------------------------------------------------------------------------
-vtkRenderer *vtkContextScene::GetRenderer()
+//------------------------------------------------------------------------------
+vtkRenderer* vtkContextScene::GetRenderer()
 {
   return this->Renderer;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::Paint(vtkContext2D *painter)
+//------------------------------------------------------------------------------
+bool vtkContextScene::Paint(vtkContext2D* painter)
 {
   vtkDebugMacro("Paint event called.");
   size_t size = this->Children->size();
@@ -127,54 +116,55 @@ bool vtkContextScene::Paint(vtkContext2D *painter)
   {
     painter->PopMatrix();
   }
-  if(this->Storage->IsDirty)
+  if (this->Storage->IsDirty)
   {
-    this->BufferIdDirty=true;
+    this->BufferIdDirty = true;
   }
   this->Storage->IsDirty = false;
-  this->LastPainter=painter;
+  this->LastPainter = painter;
   return true;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::PaintIds()
 {
   vtkDebugMacro("PaintId called.");
   size_t size = this->Children->size();
 
-  if(size>16777214) // 24-bit limit, 0 reserved for background encoding.
+  if (size > 16777214) // 24-bit limit, 0 reserved for background encoding.
   {
-    vtkWarningMacro(<<"picking will not work properly as there are two many items. Items over 16777214 will be ignored.");
-    size=16777214;
+    vtkWarningMacro(<< "picking will not work properly as there are two many items. Items over "
+                       "16777214 will be ignored.");
+    size = 16777214;
   }
   for (size_t i = 0; i < size; ++i)
   {
-    this->LastPainter->ApplyId(i+1);
+    this->LastPainter->ApplyId(static_cast<vtkIdType>(i + 1));
     (*this->Children)[i]->Paint(this->LastPainter);
   }
   this->Storage->IsDirty = false;
 }
 
-//-----------------------------------------------------------------------------
-unsigned int vtkContextScene::AddItem(vtkAbstractContextItem *item)
+//------------------------------------------------------------------------------
+unsigned int vtkContextScene::AddItem(vtkAbstractContextItem* item)
 {
   return this->Children->AddItem(item);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::RemoveItem(vtkAbstractContextItem* item)
 {
   return this->Children->RemoveItem(item);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::RemoveItem(unsigned int index)
 {
   return this->Children->RemoveItem(index);
 }
 
-//-----------------------------------------------------------------------------
-vtkAbstractContextItem * vtkContextScene::GetItem(unsigned int index)
+//------------------------------------------------------------------------------
+vtkAbstractContextItem* vtkContextScene::GetItem(unsigned int index)
 {
   if (index < this->Children->size())
   {
@@ -182,24 +172,23 @@ vtkAbstractContextItem * vtkContextScene::GetItem(unsigned int index)
   }
   else
   {
-    return 0;
+    return nullptr;
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkContextScene::GetNumberOfItems()
 {
   return static_cast<unsigned int>(this->Children->size());
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::ClearItems()
 {
   this->Children->Clear();
 }
 
-
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetViewWidth()
 {
   if (this->Renderer)
@@ -212,7 +201,7 @@ int vtkContextScene::GetViewWidth()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetViewHeight()
 {
   if (this->Renderer)
@@ -225,19 +214,31 @@ int vtkContextScene::GetViewHeight()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+int vtkContextScene::GetSceneLeft()
+{
+  return this->Origin[0];
+}
+
+//------------------------------------------------------------------------------
+int vtkContextScene::GetSceneBottom()
+{
+  return this->Origin[1];
+}
+
+//------------------------------------------------------------------------------
 int vtkContextScene::GetSceneWidth()
 {
   return this->Geometry[0];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkContextScene::GetSceneHeight()
 {
   return this->Geometry[1];
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkVector2i vtkContextScene::GetLogicalTileScale()
 {
   vtkVector2i result(1);
@@ -248,7 +249,7 @@ vtkVector2i vtkContextScene::GetLogicalTileScale()
   return result;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::SetDirty(bool isDirty)
 {
   if (this->Storage->IsDirty == isDirty)
@@ -256,47 +257,46 @@ void vtkContextScene::SetDirty(bool isDirty)
     return;
   }
   this->Storage->IsDirty = isDirty;
-  if(this->Storage->IsDirty)
+  if (this->Storage->IsDirty)
   {
-    this->BufferIdDirty=true;
+    this->BufferIdDirty = true;
   }
   this->Modified();
 }
 
-
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::GetDirty() const
 {
   return this->Storage->IsDirty;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::ReleaseGraphicsResources()
 {
-  if(this->BufferId!=0)
+  if (this->BufferId != nullptr)
   {
     this->BufferId->ReleaseGraphicsResources();
   }
-  for(vtkContextScenePrivate::const_iterator it = this->Children->begin();
-    it != this->Children->end(); ++it)
+  for (vtkContextScenePrivate::const_iterator it = this->Children->begin();
+       it != this->Children->end(); ++it)
   {
     (*it)->ReleaseGraphicsResources();
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkWeakPointer<vtkContext2D> vtkContextScene::GetLastPainter()
 {
   return this->LastPainter;
 }
 
-//-----------------------------------------------------------------------------
-vtkAbstractContextBufferId *vtkContextScene::GetBufferId()
+//------------------------------------------------------------------------------
+vtkAbstractContextBufferId* vtkContextScene::GetBufferId()
 {
   return this->BufferId;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::SetTransform(vtkTransform2D* transform)
 {
   if (this->Transform == transform)
@@ -308,7 +308,7 @@ void vtkContextScene::SetTransform(vtkTransform2D* transform)
   this->Transform->Register(this);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTransform2D* vtkContextScene::GetTransform()
 {
   if (this->Transform)
@@ -322,7 +322,7 @@ vtkTransform2D* vtkContextScene::GetTransform()
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkContextScene::ProcessSelectionEvent(unsigned int rect[5])
 {
   cout << "ProcessSelectionEvent called! " << endl;
@@ -335,7 +335,7 @@ bool vtkContextScene::ProcessSelectionEvent(unsigned int rect[5])
   return false;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::TestBufferIdSupport()
 {
   if (!this->BufferIdSupportTested)
@@ -348,20 +348,18 @@ void vtkContextScene::TestBufferIdSupport()
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkContextScene::UpdateBufferId()
 {
   int lowerLeft[2];
   int width;
   int height;
-  this->Renderer->GetTiledSizeAndOrigin(&width,&height,lowerLeft,
-                                        lowerLeft+1);
+  this->Renderer->GetTiledSizeAndOrigin(&width, &height, lowerLeft, lowerLeft + 1);
 
-  if (this->BufferId==0 || this->BufferIdDirty ||
-      width!=this->BufferId->GetWidth() ||
-      height!=this->BufferId->GetHeight())
+  if (this->BufferId == nullptr || this->BufferIdDirty || width != this->BufferId->GetWidth() ||
+    height != this->BufferId->GetHeight())
   {
-    if (this->BufferId == 0)
+    if (this->BufferId == nullptr)
     {
       this->BufferId = vtkAbstractContextBufferId::New();
       this->BufferId->SetContext(this->Renderer->GetRenderWindow());
@@ -378,12 +376,12 @@ void vtkContextScene::UpdateBufferId()
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAbstractContextItem* vtkContextScene::GetPickedItem()
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
-  for(vtkContextScenePrivate::const_reverse_iterator it =
-      this->Children->rbegin(); it != this->Children->rend(); ++it)
+  vtkContextMouseEvent& event = this->Storage->Event;
+  for (vtkContextScenePrivate::const_reverse_iterator it = this->Children->rbegin();
+       it != this->Children->rend(); ++it)
   {
     vtkAbstractContextItem* item = (*it)->GetPickedItem(event);
     if (item)
@@ -391,10 +389,10 @@ vtkAbstractContextItem* vtkContextScene::GetPickedItem()
       return item;
     }
   }
-  return NULL;
+  return nullptr;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkContextScene::GetPickedItem(int x, int y)
 {
   vtkIdType result = -1;
@@ -402,14 +400,14 @@ vtkIdType vtkContextScene::GetPickedItem(int x, int y)
   if (this->UseBufferId && this->BufferIdSupported)
   {
     this->UpdateBufferId();
-    result=this->BufferId->GetPickedItem(x,y);
+    result = this->BufferId->GetPickedItem(x, y);
   }
   else
   {
-    size_t i = this->Children->size()-1;
-    vtkContextMouseEvent &event = this->Storage->Event;
-    for(vtkContextScenePrivate::const_reverse_iterator it =
-        this->Children->rbegin(); it != this->Children->rend(); ++it, --i)
+    size_t i = this->Children->size() - 1;
+    vtkContextMouseEvent& event = this->Storage->Event;
+    for (vtkContextScenePrivate::const_reverse_iterator it = this->Children->rbegin();
+         it != this->Children->rend(); ++it, --i)
     {
       if ((*it)->Hit(event))
       {
@@ -428,21 +426,21 @@ vtkIdType vtkContextScene::GetPickedItem(int x, int y)
   // As a workaround, any value out of the scope of
   // [-1,this->GetNumberOfItems()-1] is set to -1 (<=> no hit)
 
-  if(result<-1 || result>=static_cast<vtkIdType>(this->GetNumberOfItems()))
+  if (result < -1 || result >= static_cast<vtkIdType>(this->GetNumberOfItems()))
   {
-    result=-1;
+    result = -1;
   }
 
-  assert("post: valid_result" && result>=-1 &&
-         result<static_cast<vtkIdType>(this->GetNumberOfItems()));
+  assert("post: valid_result" && result >= -1 &&
+    result < static_cast<vtkIdType>(this->GetNumberOfItems()));
   return result;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent& e)
 {
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
 
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
@@ -456,9 +454,9 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
     cerr << "picked nothing" << endl;
   }
 #endif
-  if (this->Storage->itemPicked.GetPointer() != newItemPicked)
+  if (this->Storage->itemPicked != newItemPicked)
   {
-    if (this->Storage->itemPicked.GetPointer())
+    if (this->Storage->itemPicked)
     {
       // Make sure last picked object is still part of this scene.
       if (this->Storage->itemPicked->GetScene() == this)
@@ -479,13 +477,13 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
   // Fire mouse move event regardless of where it occurred.
 
   // Check if there is a selected item that needs to receive a move event
-  if (this->Storage->itemMousePressCurrent.GetPointer() &&
-      this->Storage->itemMousePressCurrent->GetScene() == this)
+  if (this->Storage->itemMousePressCurrent &&
+    this->Storage->itemMousePressCurrent->GetScene() == this)
   {
     vtkAbstractContextItem* cur = this->Storage->itemMousePressCurrent;
     res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseMoveEvent) || res;
   }
-  else if (this->Storage->itemPicked.GetPointer())
+  else if (this->Storage->itemPicked)
   {
     vtkAbstractContextItem* cur = this->Storage->itemPicked;
     res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseMoveEvent) || res;
@@ -498,8 +496,8 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent& e)
 {
   switch (e.GetButton())
   {
@@ -517,7 +515,7 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
   }
 
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
   event.SetLastScreenPos(event.GetScreenPos());
   event.SetLastScenePos(event.GetScenePos());
@@ -528,15 +526,14 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
   if (newItemPicked)
   {
     vtkAbstractContextItem* cur = newItemPicked;
-    res = this->ProcessItem(cur, event,
-                            &vtkAbstractContextItem::MouseButtonPressEvent);
+    res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseButtonPressEvent);
   }
   this->Storage->itemMousePressCurrent = newItemPicked;
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent& e)
 {
   switch (e.GetButton())
   {
@@ -554,25 +551,24 @@ bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
   }
 
   bool res = false;
-  if (this->Storage->itemMousePressCurrent.GetPointer())
+  if (this->Storage->itemMousePressCurrent)
   {
-    vtkContextMouseEvent &event = this->Storage->Event;
+    vtkContextMouseEvent& event = this->Storage->Event;
     this->EventCopy(e);
     event.SetButton(e.GetButton());
     vtkAbstractContextItem* cur = this->Storage->itemMousePressCurrent;
-    res = this->ProcessItem(cur, event,
-                            &vtkAbstractContextItem::MouseButtonReleaseEvent);
-    this->Storage->itemMousePressCurrent = NULL;
+    res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseButtonReleaseEvent);
+    this->Storage->itemMousePressCurrent = nullptr;
   }
   this->Storage->Event.SetButton(vtkContextMouseEvent::NO_BUTTON);
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent& e)
 {
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
   event.SetLastScreenPos(event.GetScreenPos());
   event.SetLastScenePos(event.GetScenePos());
@@ -583,17 +579,16 @@ bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent &e)
   if (newItemPicked)
   {
     vtkAbstractContextItem* cur = newItemPicked;
-    res = this->ProcessItem(cur, event,
-                            &vtkAbstractContextItem::MouseDoubleClickEvent);
+    res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseDoubleClickEvent);
   }
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::MouseWheelEvent(int delta,const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+bool vtkContextScene::MouseWheelEvent(int delta, const vtkContextMouseEvent& e)
 {
   bool res = false;
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   this->EventCopy(e);
   event.SetLastScreenPos(event.GetScreenPos());
   event.SetLastScenePos(event.GetScenePos());
@@ -616,15 +611,15 @@ bool vtkContextScene::MouseWheelEvent(int delta,const vtkContextMouseEvent &e)
         itemEvent.SetLastPos(cur->MapToParent(itemEvent.GetLastPos()));
       }
     }
-    res = (cur != 0);
+    res = (cur != nullptr);
   }
   return res;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent &keyEvent)
+//------------------------------------------------------------------------------
+bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent& keyEvent)
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   event.SetScreenPos(keyEvent.GetPosition());
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
@@ -634,10 +629,10 @@ bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent &keyEvent)
   return false;
 }
 
-//-----------------------------------------------------------------------------
-bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent &keyEvent)
+//------------------------------------------------------------------------------
+bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent& keyEvent)
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
   event.SetScreenPos(keyEvent.GetPosition());
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
@@ -647,16 +642,15 @@ bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent &keyEvent)
   return false;
 }
 
-//-----------------------------------------------------------------------------
-inline bool vtkContextScene::ProcessItem(vtkAbstractContextItem* cur,
-                                         const vtkContextMouseEvent& event,
-                                         MouseEvents eventPtr)
+//------------------------------------------------------------------------------
+bool vtkContextScene::ProcessItem(
+  vtkAbstractContextItem* cur, const vtkContextMouseEvent& event, MouseEvents eventPtr)
 {
   bool res = false;
   vtkContextMouseEvent itemEvent = event;
   itemEvent.SetPos(cur->MapFromScene(event.GetPos()));
   itemEvent.SetLastPos(cur->MapFromScene(event.GetLastPos()));
-  while (cur && !(cur->*eventPtr)(itemEvent))
+  while (cur && !(cur->GetInteractive() && (cur->*eventPtr)(itemEvent)))
   {
     cur = cur->GetParent();
     if (cur)
@@ -665,25 +659,25 @@ inline bool vtkContextScene::ProcessItem(vtkAbstractContextItem* cur,
       itemEvent.SetLastPos(cur->MapToParent(itemEvent.GetLastPos()));
     }
   }
-  res = (cur != 0);
+  res = (cur != nullptr);
   return res;
 }
 
-//-----------------------------------------------------------------------------
-inline void vtkContextScene::EventCopy(const vtkContextMouseEvent &e)
+//------------------------------------------------------------------------------
+void vtkContextScene::EventCopy(const vtkContextMouseEvent& e)
 {
-  vtkContextMouseEvent &event = this->Storage->Event;
+  vtkContextMouseEvent& event = this->Storage->Event;
+  event.SetScreenPos(e.GetScreenPos());
+  event.SetScenePos(e.GetScenePos());
   event.SetPos(e.GetPos());
-  event.SetScreenPos(vtkVector2i(e.GetPos().Cast<int>().GetData()));
-  event.SetScenePos(e.GetPos());
   event.SetInteractor(e.GetInteractor());
 }
 
-//-----------------------------------------------------------------------------
-void vtkContextScene::PrintSelf(ostream &os, vtkIndent indent)
+//------------------------------------------------------------------------------
+void vtkContextScene::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   // Print out the chart's geometry if it has been set
-  os << indent << "Widthxheight: " << this->Geometry[0] << "\t" << this->Geometry[1]
-     << endl;
+  os << indent << "Widthxheight: " << this->Geometry[0] << "\t" << this->Geometry[1] << endl;
 }
+VTK_ABI_NAMESPACE_END
