@@ -1,16 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkRegressionTestImage.h"
 #include "vtkTestUtilities.h"
@@ -81,7 +70,7 @@ int TestGlyph3DMapperMasking(int argc, char* argv[])
   glypher->SetInputConnection(colors->GetOutputPort());
 #else
   vtkGlyph3DMapper* glypher = vtkGlyph3DMapper::New();
-  glypher->SetMasking(1);
+  glypher->SetMasking(true);
   glypher->SetMaskArray("mask");
   glypher->SetInputConnection(calc->GetOutputPort());
   // glypher->SetInputConnection(colors->GetOutputPort());
