@@ -1,26 +1,6 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkCellCenterDepthSort.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-
-/*
- * Copyright 2003 Sandia Corporation.
- * Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
- * license for use of this work by or on behalf of the
- * U.S. Government. Redistribution and use in source and binary forms, with
- * or without modification, are permitted provided that this Notice and any
- * statement of authorship are reproduced on all copies.
- */
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-FileCopyrightText: Copyright 2003 Sandia Corporation
+// SPDX-License-Identifier: LicenseRef-BSD-3-Clause-Sandia-USGov
 #include "vtkCellCenterDepthSort.h"
 
 #include "vtkCamera.h"
@@ -37,17 +17,18 @@
 #include <stack>
 #include <utility>
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 typedef std::pair<vtkIdType, vtkIdType> vtkIdPair;
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkCellCenterDepthSortStack
 {
 public:
   std::stack<vtkIdPair> Stack;
 };
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 vtkStandardNewMacro(vtkCellCenterDepthSort);
 
@@ -194,7 +175,7 @@ void vtkCellCenterDepthSort::InitTraversal()
 
   while (!this->ToSort->Stack.empty())
     this->ToSort->Stack.pop();
-  this->ToSort->Stack.push(vtkIdPair(0, numcells));
+  this->ToSort->Stack.emplace(0, numcells);
 
   this->LastSortTime.Modified();
 }
@@ -235,7 +216,7 @@ vtkIdTypeArray* vtkCellCenterDepthSort::GetNextCells()
       right--;
     }
 
-    this->ToSort->Stack.push(vtkIdPair(left, partition.second));
+    this->ToSort->Stack.emplace(left, partition.second);
     partition.second = left;
   }
 
@@ -256,3 +237,4 @@ vtkIdTypeArray* vtkCellCenterDepthSort::GetNextCells()
   vtkSortDataArray::Sort(this->CellPartitionDepths, this->SortedCellPartition);
   return this->SortedCellPartition;
 }
+VTK_ABI_NAMESPACE_END
