@@ -1,29 +1,20 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkColorTransferFunction.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkColorTransferFunction.h"
 
 #include "vtkCIEDE2000.h"
+#include "vtkDoubleArray.h"
 #include "vtkMath.h"
 #include "vtkObjectFactory.h"
 
 #include <algorithm>
 #include <cmath>
 #include <iterator>
+#include <limits>
 #include <set>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkColorTransferFunction);
 
 #define MY_MAX(x, y) ((x) > (y) ? (x) : (y))
@@ -263,7 +254,7 @@ inline void vtkColorTransferFunctionInterpolateLABCIEDE2000(double s, const doub
   result[2] = rgba[2] / 255.0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct a new vtkColorTransferFunction with default values
 vtkColorTransferFunction::vtkColorTransferFunction()
 {
@@ -308,7 +299,7 @@ vtkColorTransferFunction::vtkColorTransferFunction()
   this->Internal = new vtkColorTransferFunctionInternals;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Destruct a vtkColorTransferFunction
 vtkColorTransferFunction::~vtkColorTransferFunction()
 {
@@ -356,14 +347,14 @@ double* vtkColorTransferFunction::GetDataPointer()
   return this->Function;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a point defined in RGB
 int vtkColorTransferFunction::AddRGBPoint(double x, double r, double g, double b)
 {
   return this->AddRGBPoint(x, r, g, b, 0.5, 0.0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a point defined in RGB
 int vtkColorTransferFunction::AddRGBPoint(
   double x, double r, double g, double b, double midpoint, double sharpness)
@@ -428,6 +419,84 @@ int vtkColorTransferFunction::AddRGBPoint(
 }
 
 //----------------------------------------------------------------------------
+// Bulk add points defined in RGB
+int vtkColorTransferFunction::AddRGBPoints(vtkDoubleArray* x, vtkDoubleArray* rgbColors)
+{
+  return this->AddRGBPoints(x, rgbColors, 0.5, 0.0);
+}
+
+//----------------------------------------------------------------------------
+// Bulk add points defined in RGB
+int vtkColorTransferFunction::AddRGBPoints(
+  vtkDoubleArray* x, vtkDoubleArray* rgbColors, double midpoint, double sharpness)
+{
+  if (x == nullptr)
+  {
+    vtkErrorMacro("Points array is null");
+    return -1;
+  }
+  if (rgbColors == nullptr)
+  {
+    vtkErrorMacro("Colors array is null");
+    return -1;
+  }
+  if (x->GetNumberOfTuples() != rgbColors->GetNumberOfTuples())
+  {
+    vtkErrorMacro("Bulk arrays are of unequal length: x=" << x->GetNumberOfTuples() << " Colors="
+                                                          << rgbColors->GetNumberOfTuples());
+    return -1;
+  }
+  if (rgbColors->GetNumberOfComponents() != 3)
+  {
+    vtkErrorMacro(
+      "rgbColors doesn't contain rgb values: Components=" << rgbColors->GetNumberOfComponents());
+    return -1;
+  }
+
+  // Error check
+  if (midpoint < 0.0 || midpoint > 1.0)
+  {
+    vtkErrorMacro("Midpoint " << midpoint << " outside range [0.0, 1.0]");
+    return -1;
+  }
+
+  if (sharpness < 0.0 || sharpness > 1.0)
+  {
+    vtkErrorMacro("Sharpness " << sharpness << " outside range [0.0, 1.0]");
+    return -1;
+  }
+
+  // remove any node already at this X location
+  if (!this->AllowDuplicateScalars)
+  {
+    vtkErrorMacro("Adding points in bulk doesn't support checking for duplicates");
+    return -1;
+  }
+
+  auto numNodes = x->GetNumberOfValues();
+  for (vtkIdType i = 0; i < numNodes; i++)
+  {
+    // Create the new node
+    vtkCTFNode* node = new vtkCTFNode;
+    node->X = x->GetValue(i);
+    auto rgb = rgbColors->GetTuple3(i);
+    node->R = rgb[0];
+    node->G = rgb[1];
+    node->B = rgb[2];
+    node->Midpoint = midpoint;
+    node->Sharpness = sharpness;
+
+    // Add it
+    this->Internal->Nodes.push_back(node);
+  }
+
+  // Then sort to get everything in order
+  this->SortAndUpdateRange();
+
+  return static_cast<int>(this->Internal->Nodes.size()) - 1;
+}
+
+//------------------------------------------------------------------------------
 // Add a point defined in HSV
 int vtkColorTransferFunction::AddHSVPoint(double x, double h, double s, double v)
 {
@@ -437,7 +506,7 @@ int vtkColorTransferFunction::AddHSVPoint(double x, double h, double s, double v
   return this->AddRGBPoint(x, r, g, b);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a point defined in HSV
 int vtkColorTransferFunction::AddHSVPoint(
   double x, double h, double s, double v, double midpoint, double sharpness)
@@ -448,12 +517,13 @@ int vtkColorTransferFunction::AddHSVPoint(
   return this->AddRGBPoint(x, r, g, b, midpoint, sharpness);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Sort the vector in increasing order, then fill in
 // the Range
 void vtkColorTransferFunction::SortAndUpdateRange()
 {
-  std::sort(
+  // Use stable_sort to avoid shuffling of DuplicateScalars
+  std::stable_sort(
     this->Internal->Nodes.begin(), this->Internal->Nodes.end(), this->Internal->CompareNodes);
   bool modifiedInvoked = this->UpdateRange();
   // If range is updated, Modified() has been called, don't call it again.
@@ -463,7 +533,7 @@ void vtkColorTransferFunction::SortAndUpdateRange()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkColorTransferFunction::UpdateRange()
 {
   double oldRange[2];
@@ -492,7 +562,7 @@ bool vtkColorTransferFunction::UpdateRange()
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove a point
 int vtkColorTransferFunction::RemovePoint(double x)
 {
@@ -552,7 +622,7 @@ int vtkColorTransferFunction::RemovePoint(double x)
   return retVal;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::MovePoint(double oldX, double newX)
 {
   if (oldX == newX)
@@ -573,7 +643,7 @@ void vtkColorTransferFunction::MovePoint(double oldX, double newX)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Remove all points
 void vtkColorTransferFunction::RemoveAllPoints()
 {
@@ -586,7 +656,7 @@ void vtkColorTransferFunction::RemoveAllPoints()
   this->SortAndUpdateRange();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a line defined in RGB
 void vtkColorTransferFunction::AddRGBSegment(
   double x1, double r1, double g1, double b1, double x2, double r2, double g2, double b2)
@@ -619,7 +689,7 @@ void vtkColorTransferFunction::AddRGBSegment(
   this->AddRGBPoint(x2, r2, g2, b2, 0.5, 0.0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Add a line defined in HSV
 void vtkColorTransferFunction::AddHSVSegment(
   double x1, double h1, double s1, double v1, double x2, double h2, double s2, double v2)
@@ -631,7 +701,7 @@ void vtkColorTransferFunction::AddHSVSegment(
   this->AddRGBSegment(x1, r1, g1, b1, x2, r2, g2, b2);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the RGBA color evaluated at the specified location
 const unsigned char* vtkColorTransferFunction::MapValue(double x)
 {
@@ -645,7 +715,7 @@ const unsigned char* vtkColorTransferFunction::MapValue(double x)
   return this->UnsignedCharRGBAValue;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the RGB color evaluated at the specified location
 void vtkColorTransferFunction::GetColor(double x, double rgb[3])
 {
@@ -670,7 +740,7 @@ void vtkColorTransferFunction::GetColor(double x, double rgb[3])
   this->GetTable(x, x, 1, rgb);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the red color evaluated at the specified location
 double vtkColorTransferFunction::GetRedValue(double x)
 {
@@ -680,7 +750,7 @@ double vtkColorTransferFunction::GetRedValue(double x)
   return rgb[0];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the green color evaluated at the specified location
 double vtkColorTransferFunction::GetGreenValue(double x)
 {
@@ -690,7 +760,7 @@ double vtkColorTransferFunction::GetGreenValue(double x)
   return rgb[1];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns the blue color evaluated at the specified location
 double vtkColorTransferFunction::GetBlueValue(double x)
 {
@@ -700,7 +770,7 @@ double vtkColorTransferFunction::GetBlueValue(double x)
   return rgb[2];
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Returns a table of RGB colors at regular intervals along the function
 void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, double* table)
 {
@@ -1168,7 +1238,7 @@ void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, do
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, float* table)
 {
   double* tmpTable = new double[size * 3];
@@ -1188,7 +1258,7 @@ void vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size, fl
   delete[] tmpTable;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const unsigned char* vtkColorTransferFunction::GetTable(double xStart, double xEnd, int size)
 {
   if (this->GetMTime() <= this->BuildTime && this->TableSize == size)
@@ -1230,7 +1300,7 @@ const unsigned char* vtkColorTransferFunction::GetTable(double xStart, double xE
   return this->Table;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::BuildFunctionFromTable(
   double xStart, double xEnd, int size, double* table)
 {
@@ -1262,7 +1332,7 @@ void vtkColorTransferFunction::BuildFunctionFromTable(
   this->SortAndUpdateRange();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For a specified index value, get the node parameters
 int vtkColorTransferFunction::GetNodeValue(int index, double val[6])
 {
@@ -1284,7 +1354,7 @@ int vtkColorTransferFunction::GetNodeValue(int index, double val[6])
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // For a specified index value, get the node parameters
 int vtkColorTransferFunction::SetNodeValue(int index, double val[6])
 {
@@ -1320,7 +1390,7 @@ int vtkColorTransferFunction::SetNodeValue(int index, double val[6])
   return 1;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::DeepCopy(vtkScalarsToColors* o)
 {
   vtkColorTransferFunction* f = nullptr;
@@ -1349,7 +1419,7 @@ void vtkColorTransferFunction::DeepCopy(vtkScalarsToColors* o)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::ShallowCopy(vtkColorTransferFunction* f)
 {
   if (f != nullptr)
@@ -1373,7 +1443,7 @@ void vtkColorTransferFunction::ShallowCopy(vtkColorTransferFunction* f)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Accelerate the mapping by copying the data in 32-bit chunks instead
 // of 8-bit chunks.  The extra "long" argument is to help broken
 // compilers select the non-templates below for unsigned char
@@ -1420,7 +1490,7 @@ void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, T* input,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Special implementation for unsigned char input.
 static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, unsigned char* input,
   unsigned char* output, int length, int inIncr, int outFormat, int)
@@ -1480,7 +1550,7 @@ static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, unsi
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Special implementation for unsigned short input.
 static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, unsigned short* input,
   unsigned char* output, int length, int inIncr, int outFormat, int)
@@ -1540,7 +1610,7 @@ static void vtkColorTransferFunctionMapData(vtkColorTransferFunction* self, unsi
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 template <class T>
 void vtkColorTransferFunctionIndexedMapData(vtkColorTransferFunction* self, T* input,
   unsigned char* output, int length, int inIncr, int outFormat, long)
@@ -1702,7 +1772,7 @@ void vtkColorTransferFunctionIndexedMapData(vtkColorTransferFunction* self, T* i
   } // alpha blending
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::MapScalarsThroughTable2(void* input, unsigned char* output,
   int inputDataType, int numberOfValues, int inputIncrement, int outputFormat)
 {
@@ -1737,7 +1807,7 @@ void vtkColorTransferFunction::MapScalarsThroughTable2(void* input, unsigned cha
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkColorTransferFunction::GetNumberOfAvailableColors()
 {
   if (this->IndexedLookup && this->GetSize())
@@ -1754,7 +1824,7 @@ vtkIdType vtkColorTransferFunction::GetNumberOfAvailableColors()
   return 16777216; // 2^24
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::GetIndexedColor(vtkIdType idx, double rgba[4])
 {
   vtkIdType n = this->GetSize();
@@ -1773,7 +1843,7 @@ void vtkColorTransferFunction::GetIndexedColor(vtkIdType idx, double rgba[4])
   rgba[3] = this->GetNanOpacity();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkColorTransferFunction::FillFromDataPointer(int nb, double* ptr)
 {
   if (nb <= 0 || !ptr)
@@ -1791,7 +1861,7 @@ void vtkColorTransferFunction::FillFromDataPointer(int nb, double* ptr)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkColorTransferFunction::AdjustRange(double range[2])
 {
   if (!range)
@@ -1854,7 +1924,7 @@ int vtkColorTransferFunction::AdjustRange(double range[2])
   return 1;
 }
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkColorTransferFunction::EstimateMinNumberOfSamples(double const& x1, double const& x2)
 {
   double const d = this->FindMinimumXDistance();
@@ -1863,7 +1933,7 @@ int vtkColorTransferFunction::EstimateMinNumberOfSamples(double const& x1, doubl
   return idealWidth;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkColorTransferFunction::FindMinimumXDistance()
 {
   std::vector<vtkCTFNode*> const& nodes = this->Internal->Nodes;
@@ -1884,7 +1954,7 @@ double vtkColorTransferFunction::FindMinimumXDistance()
   return distance;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Print method for vtkColorTransferFunction
 void vtkColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -1953,3 +2023,4 @@ void vtkColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
        << " Midpoint: " << this->Internal->Nodes[i]->Midpoint << endl;
   }
 }
+VTK_ABI_NAMESPACE_END
