@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkDiscretizableColorTransferFunction.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkDiscretizableColorTransferFunction.h"
 
 #include "vtkCommand.h"
@@ -21,19 +9,21 @@
 #include "vtkPiecewiseFunction.h"
 #include "vtkTemplateAliasMacro.h"
 #include "vtkTuple.h"
+#include "vtkUnsignedCharArray.h"
 
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkDiscretizableColorTransferFunction::vtkInternals
 {
 public:
-  std::vector<vtkTuple<double, 4> > IndexedColors;
+  std::vector<vtkTuple<double, 4>> IndexedColors;
 };
 
 vtkStandardNewMacro(vtkDiscretizableColorTransferFunction);
 vtkCxxSetObjectMacro(
   vtkDiscretizableColorTransferFunction, ScalarOpacityFunction, vtkPiecewiseFunction);
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDiscretizableColorTransferFunction::vtkDiscretizableColorTransferFunction()
   : Internals(new vtkInternals())
 {
@@ -48,7 +38,7 @@ vtkDiscretizableColorTransferFunction::vtkDiscretizableColorTransferFunction()
   this->EnableOpacityMapping = false;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDiscretizableColorTransferFunction::~vtkDiscretizableColorTransferFunction()
 {
   // this removes any observer we may have setup for the
@@ -60,7 +50,7 @@ vtkDiscretizableColorTransferFunction::~vtkDiscretizableColorTransferFunction()
   this->Internals = nullptr;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkMTimeType vtkDiscretizableColorTransferFunction::GetMTime()
 {
   vtkMTimeType mtime = this->Superclass::GetMTime();
@@ -78,7 +68,7 @@ vtkMTimeType vtkDiscretizableColorTransferFunction::GetMTime()
   return mtime;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::SetNumberOfIndexedColors(unsigned int count)
 {
   if (static_cast<unsigned int>(this->Internals->IndexedColors.size()) != count)
@@ -88,13 +78,13 @@ void vtkDiscretizableColorTransferFunction::SetNumberOfIndexedColors(unsigned in
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkDiscretizableColorTransferFunction::GetNumberOfIndexedColors()
 {
   return static_cast<unsigned int>(this->Internals->IndexedColors.size());
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::SetIndexedColor(
   unsigned int index, double r, double g, double b, double a)
 {
@@ -132,7 +122,7 @@ void vtkDiscretizableColorTransferFunction::SetIndexedColor(
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::GetIndexedColor(vtkIdType i, double rgba[4])
 {
   if (this->IndexedLookup || this->Discretize)
@@ -145,8 +135,8 @@ void vtkDiscretizableColorTransferFunction::GetIndexedColor(vtkIdType i, double
   }
 }
 
-//-----------------------------------------------------------------------------
-void vtkDiscretizableColorTransferFunction::SetUseLogScale(int useLogScale)
+//------------------------------------------------------------------------------
+void vtkDiscretizableColorTransferFunction::SetUseLogScale(vtkTypeBool useLogScale)
 {
   if (this->UseLogScale != useLogScale)
   {
@@ -166,14 +156,22 @@ void vtkDiscretizableColorTransferFunction::SetUseLogScale(int useLogScale)
   }
 }
 
-//-----------------------------------------------------------------------------
-int vtkDiscretizableColorTransferFunction::IsOpaque()
+//------------------------------------------------------------------------------
+vtkTypeBool vtkDiscretizableColorTransferFunction::IsOpaque()
 {
   return !this->EnableOpacityMapping;
 }
 
-int vtkDiscretizableColorTransferFunction::IsOpaque(
+//------------------------------------------------------------------------------
+vtkTypeBool vtkDiscretizableColorTransferFunction::IsOpaque(
   vtkAbstractArray* scalars, int colorMode, int component)
+{
+  return this->IsOpaque(scalars, colorMode, component, nullptr);
+}
+
+//------------------------------------------------------------------------------
+vtkTypeBool vtkDiscretizableColorTransferFunction::IsOpaque(vtkAbstractArray* scalars,
+  int colorMode, int component, vtkUnsignedCharArray* ghosts, unsigned char ghostsToSkip)
 {
   // use superclass logic?
   vtkDataArray* dataArray = vtkArrayDownCast<vtkDataArray>(scalars);
@@ -181,13 +179,13 @@ int vtkDiscretizableColorTransferFunction::IsOpaque(
         vtkArrayDownCast<vtkUnsignedCharArray>(dataArray) != nullptr) ||
     (colorMode == VTK_COLOR_MODE_DIRECT_SCALARS && dataArray))
   {
-    return this->Superclass::IsOpaque(scalars, colorMode, component);
+    return this->Superclass::IsOpaque(scalars, colorMode, component, ghosts, ghostsToSkip);
   }
   // otherwise look at our basic approach
   return this->IsOpaque();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::Build()
 {
   this->Superclass::Build();
@@ -292,21 +290,21 @@ void vtkDiscretizableColorTransferFunction::Build()
   this->LookupTableUpdateTime.Modified();
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::SetAlpha(double alpha)
 {
   this->LookupTable->SetAlpha(alpha);
   this->Superclass::SetAlpha(alpha);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::SetNanColor(double r, double g, double b)
 {
   this->LookupTable->SetNanColor(r, g, b, this->GetNanOpacity());
   this->Superclass::SetNanColor(r, g, b);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::SetNanOpacity(double a)
 {
   double color[3];
@@ -315,7 +313,7 @@ void vtkDiscretizableColorTransferFunction::SetNanOpacity(double a)
   this->Superclass::SetNanOpacity(a);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const unsigned char* vtkDiscretizableColorTransferFunction::MapValue(double v)
 {
   this->Build();
@@ -327,7 +325,7 @@ const unsigned char* vtkDiscretizableColorTransferFunction::MapValue(double v)
   return this->Superclass::MapValue(v);
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::GetColor(double v, double rgb[3])
 {
   this->Build();
@@ -341,7 +339,7 @@ void vtkDiscretizableColorTransferFunction::GetColor(double v, double rgb[3])
   }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkDiscretizableColorTransferFunction::GetOpacity(double v)
 {
   if (this->IndexedLookup || !this->EnableOpacityMapping || !this->ScalarOpacityFunction)
@@ -351,7 +349,7 @@ double vtkDiscretizableColorTransferFunction::GetOpacity(double v)
   return this->ScalarOpacityFunction->GetValue(v);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Internal mapping of the opacity value through the lookup table
 template <class T>
 static void vtkDiscretizableColorTransferFunctionMapOpacity(
@@ -389,7 +387,7 @@ static void vtkDiscretizableColorTransferFunctionMapOpacity(
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::MapScalarsThroughTable2(void* input,
   unsigned char* output, int inputDataType, int numberOfValues, int inputIncrement,
   int outputFormat)
@@ -407,8 +405,8 @@ void vtkDiscretizableColorTransferFunction::MapScalarsThroughTable2(void* input,
   }
 
   // Calculate alpha values
-  if (this->IndexedLookup == false && // don't change alpha for IndexedLookup.
-    this->EnableOpacityMapping == true && this->ScalarOpacityFunction.GetPointer() != nullptr)
+  if (!this->IndexedLookup && // don't change alpha for IndexedLookup.
+    this->EnableOpacityMapping && this->ScalarOpacityFunction.GetPointer() != nullptr)
   {
     switch (inputDataType)
     {
@@ -421,23 +419,23 @@ void vtkDiscretizableColorTransferFunction::MapScalarsThroughTable2(void* input,
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkDiscretizableColorTransferFunction::GetNumberOfAvailableColors()
 {
-  if (this->Discretize == false)
+  if (!this->Discretize)
   {
     return 16777216; // 2^24
   }
   return this->NumberOfValues;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPiecewiseFunction* vtkDiscretizableColorTransferFunction::GetScalarOpacityFunction() const
 {
   return this->ScalarOpacityFunction;
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkDiscretizableColorTransferFunction::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -447,3 +445,4 @@ void vtkDiscretizableColorTransferFunction::PrintSelf(ostream& os, vtkIndent ind
   os << indent << "EnableOpacityMapping: " << this->EnableOpacityMapping << endl;
   os << indent << "ScalarOpacityFunction: " << this->ScalarOpacityFunction << endl;
 }
+VTK_ABI_NAMESPACE_END
