@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkGlyph3DMapper.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkGlyph3DMapper.h"
 
 #include "vtkActor.h"
@@ -44,6 +32,7 @@
 #include <cassert>
 #include <vector>
 
+VTK_ABI_NAMESPACE_BEGIN
 namespace
 {
 int getNumberOfChildren(vtkDataObjectTree* tree)
@@ -65,10 +54,10 @@ int getNumberOfChildren(vtkDataObjectTree* tree)
 }
 
 // Return nullptr if no override is supplied.
-vtkAbstractObjectFactoryNewMacro(vtkGlyph3DMapper);
+vtkObjectFactoryNewMacro(vtkGlyph3DMapper);
 vtkCxxSetObjectMacro(vtkGlyph3DMapper, BlockAttributes, vtkCompositeDataDisplayAttributes);
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct object with scaling on, scaling mode is by scalar value,
 // scale factor = 1.0, the range is (0,1), orient geometry is on, and
 // orientation is by vector. Clamping and indexing are turned off. No
@@ -100,27 +89,27 @@ vtkGlyph3DMapper::vtkGlyph3DMapper()
   this->SelectionColorId = 1;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkGlyph3DMapper::~vtkGlyph3DMapper()
 {
   this->SetBlockAttributes(nullptr);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetMaskArray(int fieldAttributeType)
 {
   this->SetInputArrayToProcess(
     vtkGlyph3DMapper::MASK, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, fieldAttributeType);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetMaskArray(const char* maskarrayname)
 {
   this->SetInputArrayToProcess(
     vtkGlyph3DMapper::MASK, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, maskarrayname);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArray* vtkGlyph3DMapper::GetMaskArray(vtkDataSet* input)
 {
   if (this->Masking)
@@ -131,21 +120,21 @@ vtkDataArray* vtkGlyph3DMapper::GetMaskArray(vtkDataSet* input)
   return nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetOrientationArray(const char* orientationarrayname)
 {
   this->SetInputArrayToProcess(vtkGlyph3DMapper::ORIENTATION, 0, 0,
     vtkDataObject::FIELD_ASSOCIATION_POINTS, orientationarrayname);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetOrientationArray(int fieldAttributeType)
 {
   this->SetInputArrayToProcess(vtkGlyph3DMapper::ORIENTATION, 0, 0,
     vtkDataObject::FIELD_ASSOCIATION_POINTS, fieldAttributeType);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArray* vtkGlyph3DMapper::GetOrientationArray(vtkDataSet* input)
 {
   if (this->Orient)
@@ -156,21 +145,21 @@ vtkDataArray* vtkGlyph3DMapper::GetOrientationArray(vtkDataSet* input)
   return nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetScaleArray(const char* scalarsarrayname)
 {
   this->SetInputArrayToProcess(
     vtkGlyph3DMapper::SCALE, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, scalarsarrayname);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetScaleArray(int fieldAttributeType)
 {
   this->SetInputArrayToProcess(
     vtkGlyph3DMapper::SCALE, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, fieldAttributeType);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArray* vtkGlyph3DMapper::GetScaleArray(vtkDataSet* input)
 {
   if (this->Scaling && this->ScaleMode != vtkGlyph3DMapper::NO_DATA_SCALING)
@@ -182,21 +171,21 @@ vtkDataArray* vtkGlyph3DMapper::GetScaleArray(vtkDataSet* input)
   return nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetSourceIndexArray(const char* arrayname)
 {
   this->SetInputArrayToProcess(
     vtkGlyph3DMapper::SOURCE_INDEX, 0, 0, vtkDataObject::FIELD_ASSOCIATION_POINTS, arrayname);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetSourceIndexArray(int fieldAttributeType)
 {
   this->SetInputArrayToProcess(vtkGlyph3DMapper::SOURCE_INDEX, 0, 0,
     vtkDataObject::FIELD_ASSOCIATION_POINTS, fieldAttributeType);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArray* vtkGlyph3DMapper::GetSourceIndexArray(vtkDataSet* input)
 {
   if (this->SourceIndexing)
@@ -207,21 +196,21 @@ vtkDataArray* vtkGlyph3DMapper::GetSourceIndexArray(vtkDataSet* input)
   return nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetSelectionIdArray(const char* selectionIdArrayName)
 {
   this->SetInputArrayToProcess(vtkGlyph3DMapper::SELECTIONID, 0, 0,
     vtkDataObject::FIELD_ASSOCIATION_POINTS, selectionIdArrayName);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetSelectionIdArray(int fieldAttributeType)
 {
   this->SetInputArrayToProcess(vtkGlyph3DMapper::SELECTIONID, 0, 0,
     vtkDataObject::FIELD_ASSOCIATION_POINTS, fieldAttributeType);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataArray* vtkGlyph3DMapper::GetSelectionIdArray(vtkDataSet* input)
 {
   if (this->UseSelectionIds)
@@ -234,13 +223,13 @@ vtkDataArray* vtkGlyph3DMapper::GetSelectionIdArray(vtkDataSet* input)
   return nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkUnsignedCharArray* vtkGlyph3DMapper::GetColors(vtkDataSet* input)
 {
   return vtkArrayDownCast<vtkUnsignedCharArray>(input->GetPointData()->GetScalars());
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Specify a source object at a specified table location.
 void vtkGlyph3DMapper::SetSourceConnection(int idx, vtkAlgorithmOutput* algOutput)
 {
@@ -268,7 +257,7 @@ void vtkGlyph3DMapper::SetSourceConnection(int idx, vtkAlgorithmOutput* algOutpu
   }
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Specify a source object at a specified table location.
 void vtkGlyph3DMapper::SetSourceData(int idx, vtkPolyData* pd)
 {
@@ -309,7 +298,7 @@ void vtkGlyph3DMapper::SetSourceData(int idx, vtkPolyData* pd)
   }
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetSourceTableTree(vtkDataObjectTree* tree)
 {
   vtkNew<vtkTrivialProducer> tp;
@@ -318,13 +307,13 @@ void vtkGlyph3DMapper::SetSourceTableTree(vtkDataObjectTree* tree)
   this->SetInputConnection(1, tp->GetOutputPort());
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetSourceData(vtkPolyData* pd)
 {
   this->SetSourceData(0, pd);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Get a pointer to a source object at a specified table location.
 vtkPolyData* vtkGlyph3DMapper::GetSource(int idx)
 {
@@ -336,7 +325,7 @@ vtkPolyData* vtkGlyph3DMapper::GetSource(int idx)
   return vtkPolyData::SafeDownCast(this->GetExecutive()->GetInputData(1, idx));
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkDataObjectTree* vtkGlyph3DMapper::GetSourceTableTree()
 {
   return this->UseSourceTableTree
@@ -344,7 +333,7 @@ vtkDataObjectTree* vtkGlyph3DMapper::GetSourceTableTree()
     : nullptr;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPolyData* vtkGlyph3DMapper::GetSource(int idx, vtkInformationVector* sourceInfo)
 {
   vtkInformation* info = sourceInfo->GetInformationObject(idx);
@@ -355,7 +344,7 @@ vtkPolyData* vtkGlyph3DMapper::GetSource(int idx, vtkInformationVector* sourceIn
   return vtkPolyData::SafeDownCast(info->Get(vtkDataObject::DATA_OBJECT()));
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 const char* vtkGlyph3DMapper::GetOrientationModeAsString()
 {
   switch (this->OrientationMode)
@@ -370,7 +359,7 @@ const char* vtkGlyph3DMapper::GetOrientationModeAsString()
   return "Invalid";
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -419,7 +408,7 @@ void vtkGlyph3DMapper::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGlyph3DMapper::RequestUpdateExtent(
   vtkInformation* vtkNotUsed(request), vtkInformationVector** inputVector, vtkInformationVector*)
 {
@@ -438,7 +427,7 @@ int vtkGlyph3DMapper::RequestUpdateExtent(
   return 1;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkGlyph3DMapper::FillInputPortInformation(int port, vtkInformation* info)
 {
   if (port == 0)
@@ -458,7 +447,7 @@ int vtkGlyph3DMapper::FillInputPortInformation(int port, vtkInformation* info)
   return 0;
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Return the method of scaling as a descriptive character string.
 const char* vtkGlyph3DMapper::GetScaleModeAsString()
@@ -475,7 +464,7 @@ const char* vtkGlyph3DMapper::GetScaleModeAsString()
   return "NoDataScaling";
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
 {
   if (ds == nullptr)
@@ -539,12 +528,14 @@ bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
     return true; // just return the dataset bounds.
   }
 
+  vtkPointData* pd = ds->GetPointData();
+
   int indexRange[2] = { 0, 0 };
   vtkDataArray* indexArray = this->GetSourceIndexArray(ds);
   if (indexArray)
   {
     double range[2];
-    indexArray->GetRange(range, -1);
+    pd->GetRange(indexArray->GetName(), range, -1);
     for (int i = 0; i < 2; i++)
     {
       indexRange[i] = static_cast<int>((range[i] - this->Range[0]) * numberOfSources / den);
@@ -563,7 +554,7 @@ bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
     switch (this->ScaleMode)
     {
       case SCALE_BY_MAGNITUDE:
-        scaleArray->GetRange(xScaleRange, -1);
+        pd->GetRange(scaleArray->GetName(), xScaleRange, -1);
         yScaleRange[0] = xScaleRange[0];
         yScaleRange[1] = xScaleRange[1];
         zScaleRange[0] = xScaleRange[0];
@@ -571,9 +562,9 @@ bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
         break;
 
       case SCALE_BY_COMPONENTS:
-        scaleArray->GetRange(xScaleRange, 0);
-        scaleArray->GetRange(yScaleRange, 1);
-        scaleArray->GetRange(zScaleRange, 2);
+        pd->GetRange(scaleArray->GetName(), xScaleRange, 0);
+        pd->GetRange(scaleArray->GetName(), yScaleRange, 1);
+        pd->GetRange(scaleArray->GetName(), zScaleRange, 2);
         break;
 
       default:
@@ -633,7 +624,7 @@ bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
           if (sourcePD)
           {
             double bounds[6];
-            sourcePD->GetBounds(bounds);
+            sourcePD->GetCellsBounds(bounds);
             if (vtkMath::AreBoundsInitialized(bounds))
             {
               bbox.AddBounds(bounds);
@@ -676,7 +667,7 @@ bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
       if (source != nullptr)
       {
         double bounds[6];
-        source->GetBounds(bounds); // can be invalid/uninitialized
+        source->GetCellsBounds(bounds); // can be invalid/uninitialized
         if (vtkMath::AreBoundsInitialized(bounds))
         {
           bbox.AddBounds(bounds);
@@ -731,7 +722,7 @@ bool vtkGlyph3DMapper::GetBoundsInternal(vtkDataSet* ds, double ds_bounds[6])
   return true;
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double* vtkGlyph3DMapper::GetBounds()
 {
   //  static double bounds[] = {-1.0,1.0, -1.0,1.0, -1.0,1.0};
@@ -788,26 +779,27 @@ double* vtkGlyph3DMapper::GetBounds()
   return this->Bounds;
 }
 
-//-------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::GetBounds(double bounds[6])
 {
   this->Superclass::GetBounds(bounds);
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::Render(vtkRenderer*, vtkActor*)
 {
   cerr << "Calling wrong render method!!\n";
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkGlyph3DMapper::SetInputData(vtkDataObject* input)
 {
   this->SetInputDataInternal(0, input);
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkGlyph3DMapper::GetMaxNumberOfLOD()
 {
   return 0;
 }
+VTK_ABI_NAMESPACE_END
