@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkInteractorStyle.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkInteractorStyle.h"
 
 #include "vtkActor.h"
@@ -33,10 +21,11 @@
 #include "vtkRenderer.h"
 #include "vtkTDxInteractorStyleCamera.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkInteractorStyle);
 vtkCxxSetObjectMacro(vtkInteractorStyle, TDxStyle, vtkTDxInteractorStyle);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyle::vtkInteractorStyle()
 {
   this->State = VTKIS_NONE;
@@ -82,7 +71,7 @@ vtkInteractorStyle::vtkInteractorStyle()
   this->TDxStyle = vtkTDxInteractorStyleCamera::New();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkInteractorStyle::~vtkInteractorStyle()
 {
   // Remove observers
@@ -115,7 +104,7 @@ vtkInteractorStyle::~vtkInteractorStyle()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::SetEnabled(int enabling)
 {
   if (!this->Interactor)
@@ -152,7 +141,7 @@ void vtkInteractorStyle::SetEnabled(int enabling)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // NOTE!!! This does not do any reference counting!!!
 // This is to avoid some ugly reference counting loops
 // and the benefit of being able to hold only an entire
@@ -187,19 +176,32 @@ void vtkInteractorStyle::SetInteractor(vtkRenderWindowInteractor* i)
 
     i->AddObserver(vtkCommand::LeftButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
 
+    i->AddObserver(
+      vtkCommand::LeftButtonDoubleClickEvent, this->EventCallbackCommand, this->Priority);
+
     i->AddObserver(vtkCommand::MiddleButtonPressEvent, this->EventCallbackCommand, this->Priority);
 
     i->AddObserver(
       vtkCommand::MiddleButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
 
+    i->AddObserver(
+      vtkCommand::MiddleButtonDoubleClickEvent, this->EventCallbackCommand, this->Priority);
+
     i->AddObserver(vtkCommand::RightButtonPressEvent, this->EventCallbackCommand, this->Priority);
 
     i->AddObserver(vtkCommand::RightButtonReleaseEvent, this->EventCallbackCommand, this->Priority);
 
+    i->AddObserver(
+      vtkCommand::RightButtonDoubleClickEvent, this->EventCallbackCommand, this->Priority);
+
     i->AddObserver(vtkCommand::MouseWheelForwardEvent, this->EventCallbackCommand, this->Priority);
 
     i->AddObserver(vtkCommand::MouseWheelBackwardEvent, this->EventCallbackCommand, this->Priority);
 
+    i->AddObserver(vtkCommand::MouseWheelLeftEvent, this->EventCallbackCommand, this->Priority);
+
+    i->AddObserver(vtkCommand::MouseWheelRightEvent, this->EventCallbackCommand, this->Priority);
+
     i->AddObserver(vtkCommand::ExposeEvent, this->EventCallbackCommand, this->Priority);
 
     i->AddObserver(vtkCommand::ConfigureEvent, this->EventCallbackCommand, this->Priority);
@@ -247,6 +249,14 @@ void vtkInteractorStyle::SetInteractor(vtkRenderWindowInteractor* i)
 
     i->AddObserver(vtkCommand::Move3DEvent, this->EventCallbackCommand, this->Priority);
     i->AddObserver(vtkCommand::Button3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::ViewerMovement3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::Select3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::Clip3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::NextPose3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::PositionProp3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::Pick3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::Menu3DEvent, this->EventCallbackCommand, this->Priority);
+    i->AddObserver(vtkCommand::Elevation3DEvent, this->EventCallbackCommand, this->Priority);
 
     i->AddObserver(vtkCommand::DropFilesEvent, this->EventCallbackCommand, this->Priority);
     i->AddObserver(vtkCommand::UpdateDropLocationEvent, this->EventCallbackCommand, this->Priority);
@@ -265,13 +275,13 @@ void vtkInteractorStyle::SetInteractor(vtkRenderWindowInteractor* i)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::FindPokedRenderer(int x, int y)
 {
   this->SetCurrentRenderer(this->Interactor->FindPokedRenderer(x, y));
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::HighlightProp(vtkProp* prop)
 {
   this->CurrentProp = prop;
@@ -301,7 +311,7 @@ void vtkInteractorStyle::HighlightProp(vtkProp* prop)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // When pick action successfully selects a vtkProp3Dactor, this method
 // highlights the vtkProp3D appropriately. Currently this is done by placing a
 // bounding box around the vtkProp3D.
@@ -353,7 +363,7 @@ void vtkInteractorStyle::HighlightProp3D(vtkProp3D* prop3D)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::HighlightActor2D(vtkActor2D* actor2D)
 {
   // If nothing has changed, just return
@@ -397,9 +407,9 @@ void vtkInteractorStyle::HighlightActor2D(vtkActor2D* actor2D)
   this->PickedActor2D = actor2D;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Implementation of motion state control methods
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartState(int newstate)
 {
   this->State = newstate;
@@ -423,7 +433,7 @@ void vtkInteractorStyle::StartState(int newstate)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StopState()
 {
   this->State = VTKIS_NONE;
@@ -447,7 +457,7 @@ void vtkInteractorStyle::StopState()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // JCP animation control
 void vtkInteractorStyle::StartAnimate()
 {
@@ -464,7 +474,7 @@ void vtkInteractorStyle::StartAnimate()
   rwi->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StopAnimate()
 {
   vtkRenderWindowInteractor* rwi = this->Interactor;
@@ -480,7 +490,7 @@ void vtkInteractorStyle::StopAnimate()
 }
 
 // JCP Animation control
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartRotate()
 {
   if (this->State != VTKIS_NONE)
@@ -490,7 +500,7 @@ void vtkInteractorStyle::StartRotate()
   this->StartState(VTKIS_ROTATE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndRotate()
 {
   if (this->State != VTKIS_ROTATE)
@@ -500,7 +510,7 @@ void vtkInteractorStyle::EndRotate()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartZoom()
 {
   if (this->State != VTKIS_NONE)
@@ -510,7 +520,7 @@ void vtkInteractorStyle::StartZoom()
   this->StartState(VTKIS_ZOOM);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndZoom()
 {
   if (this->State != VTKIS_ZOOM)
@@ -520,7 +530,7 @@ void vtkInteractorStyle::EndZoom()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartPan()
 {
   if (this->State != VTKIS_NONE)
@@ -530,7 +540,7 @@ void vtkInteractorStyle::StartPan()
   this->StartState(VTKIS_PAN);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndPan()
 {
   if (this->State != VTKIS_PAN)
@@ -540,7 +550,7 @@ void vtkInteractorStyle::EndPan()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartSpin()
 {
   if (this->State != VTKIS_NONE)
@@ -550,7 +560,7 @@ void vtkInteractorStyle::StartSpin()
   this->StartState(VTKIS_SPIN);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndSpin()
 {
   if (this->State != VTKIS_SPIN)
@@ -560,7 +570,7 @@ void vtkInteractorStyle::EndSpin()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartDolly()
 {
   if (this->State != VTKIS_NONE)
@@ -570,7 +580,7 @@ void vtkInteractorStyle::StartDolly()
   this->StartState(VTKIS_DOLLY);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndDolly()
 {
   if (this->State != VTKIS_DOLLY)
@@ -580,7 +590,7 @@ void vtkInteractorStyle::EndDolly()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartUniformScale()
 {
   if (this->State != VTKIS_NONE)
@@ -590,7 +600,7 @@ void vtkInteractorStyle::StartUniformScale()
   this->StartState(VTKIS_USCALE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndUniformScale()
 {
   if (this->State != VTKIS_USCALE)
@@ -600,7 +610,7 @@ void vtkInteractorStyle::EndUniformScale()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartTimer()
 {
   if (this->State != VTKIS_NONE)
@@ -610,7 +620,7 @@ void vtkInteractorStyle::StartTimer()
   this->StartState(VTKIS_TIMER);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndTimer()
 {
   if (this->State != VTKIS_TIMER)
@@ -620,7 +630,7 @@ void vtkInteractorStyle::EndTimer()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartTwoPointer()
 {
   if (this->State != VTKIS_NONE)
@@ -630,7 +640,7 @@ void vtkInteractorStyle::StartTwoPointer()
   this->StartState(VTKIS_TWO_POINTER);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndTwoPointer()
 {
   if (this->State != VTKIS_TWO_POINTER)
@@ -640,7 +650,7 @@ void vtkInteractorStyle::EndTwoPointer()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartGesture()
 {
   if (this->State != VTKIS_NONE)
@@ -650,7 +660,7 @@ void vtkInteractorStyle::StartGesture()
   this->StartState(VTKIS_GESTURE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndGesture()
 {
   if (this->State != VTKIS_GESTURE)
@@ -660,7 +670,7 @@ void vtkInteractorStyle::EndGesture()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::StartEnvRotate()
 {
   if (this->State != VTKIS_NONE)
@@ -670,7 +680,7 @@ void vtkInteractorStyle::StartEnvRotate()
   this->StartState(VTKIS_ENV_ROTATE);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::EndEnvRotate()
 {
   if (this->State != VTKIS_ENV_ROTATE)
@@ -680,10 +690,10 @@ void vtkInteractorStyle::EndEnvRotate()
   this->StopState();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // By overriding the Rotate, Rotate members we can
 // use this timer routine for Joystick or Trackball - quite tidy
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::OnTimer()
 {
   vtkRenderWindowInteractor* rwi = this->Interactor;
@@ -742,11 +752,16 @@ void vtkInteractorStyle::OnTimer()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::OnChar()
 {
   vtkRenderWindowInteractor* rwi = this->Interactor;
 
+  if (rwi->GetControlKey() || rwi->GetAltKey())
+  {
+    // Ignore keys when modifiers (other than shift) are pressed.
+    return;
+  }
   switch (rwi->GetKeyCode())
   {
     case 'm':
@@ -920,7 +935,7 @@ void vtkInteractorStyle::OnChar()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -970,7 +985,7 @@ void vtkInteractorStyle::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::DelegateTDxEvent(unsigned long event, void* calldata)
 {
   if (this->TDxStyle != nullptr)
@@ -979,7 +994,19 @@ void vtkInteractorStyle::DelegateTDxEvent(unsigned long event, void* calldata)
   }
 }
 
-//----------------------------------------------------------------------------
+#define vtkISEventDataMacro(eventname)                                                             \
+  case vtkCommand::eventname##Event:                                                               \
+    if (self->HandleObservers && self->HasObserver(vtkCommand::eventname##Event))                  \
+    {                                                                                              \
+      aborted = (self->InvokeEvent(vtkCommand::eventname##Event, calldata) == 1);                  \
+    }                                                                                              \
+    if (!aborted)                                                                                  \
+    {                                                                                              \
+      self->On##eventname(static_cast<vtkEventData*>(calldata));                                   \
+    }                                                                                              \
+    break
+
+//------------------------------------------------------------------------------
 void vtkInteractorStyle::ProcessEvents(
   vtkObject* vtkNotUsed(object), unsigned long event, void* clientdata, void* calldata)
 {
@@ -1126,6 +1153,39 @@ void vtkInteractorStyle::ProcessEvents(
       }
       break;
 
+    case vtkCommand::LeftButtonDoubleClickEvent:
+      if (self->HandleObservers && self->HasObserver(vtkCommand::LeftButtonDoubleClickEvent))
+      {
+        self->InvokeEvent(vtkCommand::vtkCommand::LeftButtonDoubleClickEvent, nullptr);
+      }
+      else
+      {
+        self->OnLeftButtonDoubleClick();
+      }
+      break;
+
+    case vtkCommand::MiddleButtonDoubleClickEvent:
+      if (self->HandleObservers && self->HasObserver(vtkCommand::MiddleButtonDoubleClickEvent))
+      {
+        self->InvokeEvent(vtkCommand::vtkCommand::MiddleButtonDoubleClickEvent, nullptr);
+      }
+      else
+      {
+        self->OnMiddleButtonDoubleClick();
+      }
+      break;
+
+    case vtkCommand::RightButtonDoubleClickEvent:
+      if (self->HandleObservers && self->HasObserver(vtkCommand::RightButtonDoubleClickEvent))
+      {
+        self->InvokeEvent(vtkCommand::vtkCommand::RightButtonDoubleClickEvent, nullptr);
+      }
+      else
+      {
+        self->OnRightButtonDoubleClick();
+      }
+      break;
+
     case vtkCommand::MouseWheelForwardEvent:
       if (self->HandleObservers && self->HasObserver(vtkCommand::MouseWheelForwardEvent))
       {
@@ -1148,6 +1208,28 @@ void vtkInteractorStyle::ProcessEvents(
       }
       break;
 
+    case vtkCommand::MouseWheelLeftEvent:
+      if (self->HandleObservers && self->HasObserver(vtkCommand::MouseWheelLeftEvent))
+      {
+        self->InvokeEvent(vtkCommand::MouseWheelLeftEvent, nullptr);
+      }
+      else
+      {
+        self->OnMouseWheelLeft();
+      }
+      break;
+
+    case vtkCommand::MouseWheelRightEvent:
+      if (self->HandleObservers && self->HasObserver(vtkCommand::MouseWheelRightEvent))
+      {
+        self->InvokeEvent(vtkCommand::MouseWheelRightEvent, nullptr);
+      }
+      else
+      {
+        self->OnMouseWheelRight();
+      }
+      break;
+
     case vtkCommand::KeyPressEvent:
       if (self->HandleObservers && self->HasObserver(vtkCommand::KeyPressEvent))
       {
@@ -1383,27 +1465,16 @@ void vtkInteractorStyle::ProcessEvents(
       }
       break;
 
-    case vtkCommand::Move3DEvent:
-      if (self->HandleObservers && self->HasObserver(vtkCommand::Move3DEvent))
-      {
-        aborted = (self->InvokeEvent(vtkCommand::Move3DEvent, calldata) == 1);
-      }
-      if (!aborted)
-      {
-        self->OnMove3D(static_cast<vtkEventData*>(calldata));
-      }
-      break;
-
-    case vtkCommand::Button3DEvent:
-      if (self->HandleObservers && self->HasObserver(vtkCommand::Button3DEvent))
-      {
-        aborted = (self->InvokeEvent(vtkCommand::Button3DEvent, calldata) == 1);
-      }
-      if (!aborted)
-      {
-        self->OnButton3D(static_cast<vtkEventData*>(calldata));
-      }
-      break;
+      vtkISEventDataMacro(Move3D);
+      vtkISEventDataMacro(Button3D);
+      vtkISEventDataMacro(Menu3D);
+      vtkISEventDataMacro(Select3D);
+      vtkISEventDataMacro(NextPose3D);
+      vtkISEventDataMacro(ViewerMovement3D);
+      vtkISEventDataMacro(Pick3D);
+      vtkISEventDataMacro(PositionProp3D);
+      vtkISEventDataMacro(Clip3D);
+      vtkISEventDataMacro(Elevation3D);
 
     case vtkCommand::DropFilesEvent:
       if (self->HandleObservers && self->HasObserver(vtkCommand::DropFilesEvent))
@@ -1428,3 +1499,4 @@ void vtkInteractorStyle::ProcessEvents(
       break;
   }
 }
+VTK_ABI_NAMESPACE_END
