@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkProp.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkProp.h"
 #include "vtkAssemblyPaths.h"
 #include "vtkCommand.h"
@@ -24,12 +12,13 @@
 #include "vtkShaderProperty.h"
 #include <cassert>
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkCxxSetObjectMacro(vtkProp, PropertyKeys, vtkInformation);
 
 vtkInformationKeyMacro(vtkProp, GeneralTextureUnit, Integer);
 vtkInformationKeyMacro(vtkProp, GeneralTextureTransform, DoubleVector);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Creates an Prop with the following defaults: visibility on.
 vtkProp::vtkProp()
 {
@@ -54,7 +43,7 @@ vtkProp::vtkProp()
   this->ShaderProperty = nullptr;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkProp::~vtkProp()
 {
   if (this->Paths)
@@ -75,14 +64,14 @@ vtkProp::~vtkProp()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method is invoked if the prop is picked.
 void vtkProp::Pick()
 {
   this->InvokeEvent(vtkCommand::PickEvent, nullptr);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Shallow copy of vtkProp.
 void vtkProp::ShallowCopy(vtkProp* prop)
 {
@@ -92,7 +81,7 @@ void vtkProp::ShallowCopy(vtkProp* prop)
   this->SetShaderProperty(prop->GetShaderProperty());
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkProp::InitPathTraversal()
 {
   if (this->Paths == nullptr)
@@ -106,7 +95,7 @@ void vtkProp::InitPathTraversal()
   this->Paths->InitTraversal();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkAssemblyPath* vtkProp::GetNextPath()
 {
   if (!this->Paths)
@@ -116,7 +105,7 @@ vtkAssemblyPath* vtkProp::GetNextPath()
   return this->Paths->GetNextItem();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // This method is used in conjunction with the assembly object to build a copy
 // of the assembly hierarchy. This hierarchy can then be traversed for
 // rendering, picking or other operations.
@@ -132,7 +121,7 @@ void vtkProp::BuildPaths(vtkAssemblyPaths* paths, vtkAssemblyPath* path)
   childPath->Delete(); // okay, reference counting
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkProp::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -160,7 +149,7 @@ void vtkProp::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "useBounds: " << this->UseBounds << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkProp::AddConsumer(vtkObject* c)
 {
   // make sure it isn't already there
@@ -181,7 +170,7 @@ void vtkProp::AddConsumer(vtkObject* c)
   delete[] tmp;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkProp::RemoveConsumer(vtkObject* c)
 {
   // make sure it is already there
@@ -207,7 +196,7 @@ void vtkProp::RemoveConsumer(vtkObject* c)
   delete[] tmp;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkProp::IsConsumer(vtkObject* c)
 {
   int i;
@@ -221,7 +210,7 @@ int vtkProp::IsConsumer(vtkObject* c)
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkObject* vtkProp::GetConsumer(int i)
 {
   if (i >= this->NumberOfConsumers)
@@ -231,7 +220,7 @@ vtkObject* vtkProp::GetConsumer(int i)
   return this->Consumers[i];
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Tells if the prop has all the required keys.
 // \pre keys_can_be_null: requiredKeys==0 || requiredKeys!=0
@@ -255,7 +244,7 @@ bool vtkProp::HasKeys(vtkInformation* requiredKeys)
   return result;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Render the opaque geometry only if the prop has all the requiredKeys.
 // This is recursive for composite props like vtkAssembly.
@@ -279,7 +268,7 @@ bool vtkProp::RenderFilteredOpaqueGeometry(vtkViewport* v, vtkInformation* requi
   return result;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Render the translucent polygonal geometry only if the prop has all the
 // requiredKeys.
@@ -305,7 +294,7 @@ bool vtkProp::RenderFilteredTranslucentPolygonalGeometry(
   return result;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Render the volumetric geometry only if the prop has all the
 // requiredKeys.
@@ -330,7 +319,7 @@ bool vtkProp::RenderFilteredVolumetricGeometry(vtkViewport* v, vtkInformation* r
   return result;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Render in the overlay of the viewport only if the prop has all the
 // requiredKeys.
@@ -382,3 +371,4 @@ vtkShaderProperty* vtkProp::GetShaderProperty()
   }
   return this->ShaderProperty;
 }
+VTK_ABI_NAMESPACE_END
