@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkRenderWindow.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkRenderWindow
  * @brief   create a window for renderers to draw into
@@ -41,14 +29,17 @@
 #ifndef vtkRenderWindow_h
 #define vtkRenderWindow_h
 
+#include "vtkEventData.h"           // for enums
 #include "vtkNew.h"                 // For vtkNew
 #include "vtkRenderingCoreModule.h" // For export macro
 #include "vtkSmartPointer.h"        // For vtkSmartPointer
 #include "vtkWindow.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkFloatArray;
 class vtkProp;
 class vtkCollection;
+class vtkMatrix4x4;
 class vtkRenderTimerLog;
 class vtkRenderWindowInteractor;
 class vtkRenderer;
@@ -80,6 +71,7 @@ class vtkUnsignedCharArray;
 #define VTK_CURSOR_SIZEALL 8
 #define VTK_CURSOR_HAND 9
 #define VTK_CURSOR_CROSSHAIR 10
+#define VTK_CURSOR_CUSTOM 11
 
 class VTKRENDERINGCORE_EXPORT vtkRenderWindow : public vtkWindow
 {
@@ -107,7 +99,7 @@ public:
   /**
    * Query if a renderer is in the list of renderers.
    */
-  int HasRenderer(vtkRenderer*);
+  vtkTypeBool HasRenderer(vtkRenderer*);
 
   /**
    * What rendering library has the user requested
@@ -138,12 +130,12 @@ public:
    */
   void CaptureGL2PSSpecialProps(vtkCollection* specialProps);
 
-  //@{
+  ///@{
   /**
    * Returns true if the render process is capturing text actors.
    */
   vtkGetMacro(CapturingGL2PSSpecialProps, int);
-  //@}
+  ///@}
 
   /**
    * Ask each renderer owned by this RenderWindow to render its image and
@@ -191,7 +183,7 @@ public:
    */
   virtual vtkRenderWindowInteractor* MakeRenderWindowInteractor();
 
-  //@{
+  ///@{
   /**
    * Hide or Show the mouse cursor, it is nice to be able to hide the
    * default cursor if you want VTK to display a 3D cursor instead.
@@ -201,26 +193,35 @@ public:
   virtual void HideCursor() {}
   virtual void ShowCursor() {}
   virtual void SetCursorPosition(int, int) {}
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Change the shape of the cursor.
    */
   vtkSetMacro(CurrentCursor, int);
   vtkGetMacro(CurrentCursor, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
+  /**
+   * Set/Get the full path to the custom cursor.
+   * This is used when the current cursor is set to VTK_CURSOR_CUSTOM.
+   */
+  vtkSetFilePathMacro(CursorFileName);
+  vtkGetFilePathMacro(CursorFileName);
+  ///@}
+
+  ///@{
   /**
    * Turn on/off rendering full screen window size.
    */
   virtual void SetFullScreen(vtkTypeBool) {}
   vtkGetMacro(FullScreen, vtkTypeBool);
   vtkBooleanMacro(FullScreen, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off window manager borders. Typically, you shouldn't turn the
    * borders off, because that bypasses the window manager and can cause
@@ -229,9 +230,9 @@ public:
   vtkSetMacro(Borders, vtkTypeBool);
   vtkGetMacro(Borders, vtkTypeBool);
   vtkBooleanMacro(Borders, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Prescribe that the window be created in a stereo-capable mode. This
    * method must be called before the window is realized. Default is off.
@@ -239,27 +240,27 @@ public:
   vtkGetMacro(StereoCapableWindow, vtkTypeBool);
   vtkBooleanMacro(StereoCapableWindow, vtkTypeBool);
   virtual void SetStereoCapableWindow(vtkTypeBool capable);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off stereo rendering.
    */
   vtkGetMacro(StereoRender, vtkTypeBool);
   void SetStereoRender(vtkTypeBool stereo);
   vtkBooleanMacro(StereoRender, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off the use of alpha bitplanes.
    */
   vtkSetMacro(AlphaBitPlanes, vtkTypeBool);
   vtkGetMacro(AlphaBitPlanes, vtkTypeBool);
   vtkBooleanMacro(AlphaBitPlanes, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off point smoothing. Default is off.
    * This must be applied before the first Render.
@@ -267,9 +268,9 @@ public:
   vtkSetMacro(PointSmoothing, vtkTypeBool);
   vtkGetMacro(PointSmoothing, vtkTypeBool);
   vtkBooleanMacro(PointSmoothing, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off line smoothing. Default is off.
    * This must be applied before the first Render.
@@ -277,9 +278,9 @@ public:
   vtkSetMacro(LineSmoothing, vtkTypeBool);
   vtkGetMacro(LineSmoothing, vtkTypeBool);
   vtkBooleanMacro(LineSmoothing, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Turn on/off polygon smoothing. Default is off.
    * This must be applied before the first Render.
@@ -287,9 +288,9 @@ public:
   vtkSetMacro(PolygonSmoothing, vtkTypeBool);
   vtkGetMacro(PolygonSmoothing, vtkTypeBool);
   vtkBooleanMacro(PolygonSmoothing, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get what type of stereo rendering to use.  CrystalEyes
    * mode uses frame-sequential capabilities available in OpenGL
@@ -327,15 +328,15 @@ public:
   }
   void SetStereoTypeToFake() { this->SetStereoType(VTK_STEREO_FAKE); }
   void SetStereoTypeToEmulate() { this->SetStereoType(VTK_STEREO_EMULATE); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Returns the stereo type as a string.
    */
   const char* GetStereoTypeAsString();
   static const char* GetStereoTypeAsString(int type);
-  //@}
+  ///@}
 
   /**
    * Update the system, if needed, due to stereo rendering. For some stereo
@@ -355,7 +356,7 @@ public:
    */
   virtual void StereoRenderComplete();
 
-  //@{
+  ///@{
   /**
    * Set/get the anaglyph color saturation factor.  This number ranges from
    * 0.0 to 1.0:  0.0 means that no color from the original object is
@@ -365,9 +366,9 @@ public:
    */
   vtkSetClampMacro(AnaglyphColorSaturation, float, 0.0f, 1.0f);
   vtkGetMacro(AnaglyphColorSaturation, float);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/get the anaglyph color mask values.  These two numbers are bits
    * mask that control which color channels of the original stereo
@@ -384,7 +385,7 @@ public:
    */
   vtkSetVector2Macro(AnaglyphColorMask, int);
   vtkGetVectorMacro(AnaglyphColorMask, int, 2);
-  //@}
+  ///@}
 
   /**
    * Remap the rendering window. This probably only works on UNIX right now.
@@ -393,16 +394,16 @@ public:
    */
   virtual void WindowRemap() {}
 
-  //@{
+  ///@{
   /**
    * Turn on/off buffer swapping between images.
    */
   vtkSetMacro(SwapBuffers, vtkTypeBool);
   vtkGetMacro(SwapBuffers, vtkTypeBool);
   vtkBooleanMacro(SwapBuffers, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the pixel data of an image, transmitted as RGBRGBRGB. The
    * front argument indicates if the front buffer should be used or the back
@@ -425,9 +426,9 @@ public:
   {
     return 0;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Same as Get/SetPixelData except that the image also contains an alpha
    * component. The image is transmitted as RGBARGBARGBA... each of which is a
@@ -476,9 +477,9 @@ public:
   {
     return 0;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the zbuffer data from the frame buffer.
    * (x,y) is any corner of the rectangle. (x2,y2) is its opposite corner on
@@ -507,16 +508,16 @@ public:
     this->GetZbufferData(x, y, x, y, &value);
     return value;
   }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This flag is set if the window hasn't rendered since it was created
    */
   vtkGetMacro(NeverRendered, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * This is a flag that can be set to interrupt a rendering that is in
    * progress.
@@ -526,17 +527,7 @@ public:
   vtkGetMacro(InAbortCheck, int);
   vtkSetMacro(InAbortCheck, int);
   virtual int CheckAbortStatus();
-  //@}
-
-  //@{
-  /**
-   * @deprecated in VTK 9.0
-   */
-  VTK_LEGACY(vtkTypeBool GetIsPicking());
-  VTK_LEGACY(void SetIsPicking(vtkTypeBool));
-  VTK_LEGACY(void IsPickingOn());
-  VTK_LEGACY(void IsPickingOff());
-  //@}
+  ///@}
 
   /**
    * Check to see if a mouse button has been pressed.  All other events
@@ -556,7 +547,7 @@ public:
    */
   virtual void ClearInRenderStatus() { this->InRender = 0; }
 
-  //@{
+  ///@{
   /**
    * Set/Get the desired update rate. This is used with
    * the vtkLODActor class. When using level of detail actors you
@@ -567,9 +558,9 @@ public:
    */
   virtual void SetDesiredUpdateRate(double);
   vtkGetMacro(DesiredUpdateRate, double);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the number of layers for renderers.  Each renderer should have
    * its layer set individually.  Some algorithms iterate through all layers,
@@ -578,19 +569,19 @@ public:
    */
   vtkGetMacro(NumberOfLayers, int);
   vtkSetClampMacro(NumberOfLayers, int, 1, VTK_INT_MAX);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Get the interactor associated with this render window
    */
   vtkGetObjectMacro(Interactor, vtkRenderWindowInteractor);
-  //@}
+  ///@}
 
   /**
    * Set the interactor to the render window
    */
-  void SetInteractor(vtkRenderWindowInteractor*);
+  virtual void SetInteractor(vtkRenderWindowInteractor*);
 
   /**
    * This Method detects loops of RenderWindow<->Interactor,
@@ -598,7 +589,7 @@ public:
    */
   void UnRegister(vtkObjectBase* o) override;
 
-  //@{
+  ///@{
   /**
    * Dummy stubs for vtkWindow API.
    */
@@ -614,7 +605,7 @@ public:
   void SetWindowInfo(const char*) override {}
   virtual void SetNextWindowInfo(const char*) {}
   void SetParentInfo(const char*) override {}
-  //@}
+  ///@}
 
   /**
    * Initialize the render window from the information associated
@@ -622,7 +613,7 @@ public:
    */
   virtual bool InitializeFromCurrentContext() { return false; }
 
-  //@{
+  ///@{
   /**
    * Set/Get an already existing window that this window should
    * share data with if possible. This must be set
@@ -633,13 +624,7 @@ public:
   virtual void SetSharedRenderWindow(vtkRenderWindow*);
   vtkGetObjectMacro(SharedRenderWindow, vtkRenderWindow);
   virtual bool GetPlatformSupportsRenderWindowSharing() { return false; }
-  //@}
-
-  /**
-   * Attempt to make this window the current graphics context for the calling
-   * thread.
-   */
-  void MakeCurrent() override {}
+  ///@}
 
   /**
    * Tells if this window is the current graphics context for the calling
@@ -647,14 +632,6 @@ public:
    */
   virtual bool IsCurrent() { return false; }
 
-  /**
-   * Test if the window has a valid drawable. This is
-   * currently only an issue on Mac OS X Cocoa where rendering
-   * to an invalid drawable results in all OpenGL calls to fail
-   * with "invalid framebuffer operation".
-   */
-  VTK_LEGACY(virtual bool IsDrawable());
-
   /**
    * If called, allow MakeCurrent() to skip cache-check when called.
    * MakeCurrent() reverts to original behavior of cache-checking
@@ -689,25 +666,25 @@ public:
    */
   virtual int GetColorBufferSizes(int* /*rgba*/) { return 0; }
 
-  //@{
+  ///@{
   /**
    * Set / Get the number of multisamples to use for hardware antialiasing.
    * A value of 1 will be set to 0.
    */
   virtual void SetMultiSamples(int);
   vtkGetMacro(MultiSamples, int);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set / Get the availability of the stencil buffer.
    */
   vtkSetMacro(StencilCapable, vtkTypeBool);
   vtkGetMacro(StencilCapable, vtkTypeBool);
   vtkBooleanMacro(StencilCapable, vtkTypeBool);
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * If there are several graphics card installed on a system,
    * this index can be used to specify which card you want to render to.
@@ -716,14 +693,14 @@ public:
    */
   vtkSetMacro(DeviceIndex, int);
   vtkGetMacro(DeviceIndex, int);
-  //@}
+  ///@}
   /**
    * Returns the number of devices (graphics cards) on a system.
    * This may not work on all derived render windows.
    */
   virtual int GetNumberOfDevices() { return 0; }
 
-  //@{
+  ///@{
   /**
    * Set/Get if we want this window to use the sRGB color space.
    * Some hardware/drivers do not fully support this.
@@ -731,7 +708,23 @@ public:
   vtkGetMacro(UseSRGBColorSpace, bool);
   vtkSetMacro(UseSRGBColorSpace, bool);
   vtkBooleanMacro(UseSRGBColorSpace, bool);
-  //@}
+  ///@}
+
+  /**
+   * Get physical to world transform matrix. Some subclasses may define a
+   * Physical coordinate system such as in VR. This method provides access
+   * to the matrix mapping that space to world coordinates.
+   */
+  virtual void GetPhysicalToWorldMatrix(vtkMatrix4x4* matrix);
+
+  /**
+   * Store in \p deviceToWorldMatrix the matrix that goes from device coordinates
+   * to world coordinates. e.g. if you push 0,0,0,1 through this matrix you will get
+   * the location of the device in world coordinates.
+   * Return true if the query is valid, else false.
+   */
+  virtual bool GetDeviceToWorldMatrixForDevice(
+    vtkEventDataDevice device, vtkMatrix4x4* deviceToWorldMatrix);
 
 protected:
   vtkRenderWindow();
@@ -770,6 +763,7 @@ protected:
   int DeviceIndex;
 
   bool UseSRGBColorSpace;
+  char* CursorFileName;
 
   /**
    * The universal time since the last abort check occurred.
@@ -785,4 +779,5 @@ private:
   vtkNew<vtkStereoCompositor> StereoCompositor;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
