@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkRenderWindowInteractor.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkRenderWindowInteractor.h"
 
 #include "vtkCamera.h"
@@ -21,6 +9,8 @@
 #include "vtkHardwareWindow.h"
 #include "vtkInteractorStyleSwitchBase.h"
 #include "vtkMath.h"
+#include "vtkNew.h"
+#include "vtkObjectFactory.h"
 #include "vtkObserverMediator.h"
 #include "vtkPickingManager.h"
 #include "vtkPropPicker.h"
@@ -32,6 +22,7 @@
 
 // PIMPL'd class to keep track of timers. It maps the ids returned by CreateTimer()
 // to the platform-specific representation for timer ids.
+VTK_ABI_NAMESPACE_BEGIN
 struct vtkTimerStruct
 {
   int Id;
@@ -60,11 +51,11 @@ typedef std::map<int, vtkTimerStruct>::iterator vtkTimerIdMapIterator;
 // render window interactors.
 static int vtkTimerId = 1;
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkCxxSetObjectMacro(vtkRenderWindowInteractor, Picker, vtkAbstractPicker);
 vtkCxxSetObjectMacro(vtkRenderWindowInteractor, HardwareWindow, vtkHardwareWindow);
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Construct object so that light follows camera motion.
 vtkRenderWindowInteractor::vtkRenderWindowInteractor()
 {
@@ -74,9 +65,7 @@ vtkRenderWindowInteractor::vtkRenderWindowInteractor()
   // object factory logic to create the correct instance, which should be the
   // vtkInteractorStyleSwitch when linked to the interactor styles, or
   // vtkInteractorStyleSwitchBase if the style module is not linked.
-  this->InteractorStyle = nullptr;
-  this->SetInteractorStyle(vtkInteractorStyleSwitchBase::New());
-  this->InteractorStyle->Delete();
+  this->SetInteractorStyle(vtkNew<vtkInteractorStyleSwitchBase>());
 
   this->LightFollowCamera = 1;
   this->Initialized = 0;
@@ -148,13 +137,9 @@ vtkRenderWindowInteractor::vtkRenderWindowInteractor()
   this->Done = false;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkRenderWindowInteractor::~vtkRenderWindowInteractor()
 {
-  if (this->InteractorStyle != nullptr)
-  {
-    this->InteractorStyle->UnRegister(this);
-  }
   if (this->Picker)
   {
     this->Picker->UnRegister(this);
@@ -171,22 +156,9 @@ vtkRenderWindowInteractor::~vtkRenderWindowInteractor()
   this->SetHardwareWindow(nullptr);
 }
 
-//----------------------------------------------------------------------
-vtkRenderWindowInteractor* vtkRenderWindowInteractor::New()
-{
-  // First try to create the object from the vtkObjectFactory
-  vtkObject* ret = vtkGraphicsFactory::CreateInstance("vtkRenderWindowInteractor");
-  if (ret)
-  {
-    return static_cast<vtkRenderWindowInteractor*>(ret);
-  }
+vtkObjectFactoryNewMacro(vtkRenderWindowInteractor);
 
-  vtkRenderWindowInteractor* o = new vtkRenderWindowInteractor;
-  o->InitializeObjectBase();
-  return o;
-}
-
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::Render()
 {
   if (this->RenderWindow && this->Enabled && this->EnableRender)
@@ -198,7 +170,7 @@ void vtkRenderWindowInteractor::Render()
   this->InvokeEvent(vtkCommand::RenderEvent, nullptr);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // treat renderWindow and interactor as one object.
 // it might be easier if the GetReference count method were redefined.
 void vtkRenderWindowInteractor::UnRegister(vtkObjectBase* o)
@@ -215,7 +187,7 @@ void vtkRenderWindowInteractor::UnRegister(vtkObjectBase* o)
   this->vtkObject::UnRegister(o);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::Start()
 {
   // Let the compositing handle the event loop if it wants to.
@@ -242,7 +214,7 @@ void vtkRenderWindowInteractor::Start()
   this->StartEventLoop();
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::SetRenderWindow(vtkRenderWindow* aren)
 {
   if (this->RenderWindow != aren)
@@ -265,31 +237,30 @@ void vtkRenderWindowInteractor::SetRenderWindow(vtkRenderWindow* aren)
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
+vtkInteractorObserver* vtkRenderWindowInteractor::GetInteractorStyle()
+{
+  return this->InteractorStyle;
+}
+
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::SetInteractorStyle(vtkInteractorObserver* style)
 {
   if (this->InteractorStyle != style)
   {
-    // to avoid destructor recursion
-    vtkInteractorObserver* temp = this->InteractorStyle;
-    this->InteractorStyle = style;
-    if (temp != nullptr)
+    if (this->InteractorStyle)
     {
-      temp->SetInteractor(nullptr);
-      temp->UnRegister(this);
+      this->InteractorStyle->SetInteractor(nullptr);
     }
+    this->InteractorStyle = style;
     if (this->InteractorStyle != nullptr)
     {
-      this->InteractorStyle->Register(this);
-      if (this->InteractorStyle->GetInteractor() != this)
-      {
-        this->InteractorStyle->SetInteractor(this);
-      }
+      this->InteractorStyle->SetInteractor(this);
     }
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::UpdateSize(int x, int y)
 {
   // if the size changed send this on to the RenderWindow
@@ -381,21 +352,21 @@ bool vtkRenderWindowInteractor::IsPointerIndexSet(int i)
   return false;
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Creates an instance of vtkPropPicker by default
 vtkAbstractPropPicker* vtkRenderWindowInteractor::CreateDefaultPicker()
 {
   return vtkPropPicker::New();
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Creates an instance of vtkPickingManager by default
 vtkPickingManager* vtkRenderWindowInteractor::CreateDefaultPickingManager()
 {
   return vtkPickingManager::New();
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::SetPickingManager(vtkPickingManager* pm)
 {
   if (this->PickingManager == pm)
@@ -420,7 +391,7 @@ void vtkRenderWindowInteractor::SetPickingManager(vtkPickingManager* pm)
   this->Modified();
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::ExitCallback()
 {
   if (this->HasObserver(vtkCommand::ExitEvent))
@@ -433,25 +404,25 @@ void vtkRenderWindowInteractor::ExitCallback()
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::UserCallback()
 {
   this->InvokeEvent(vtkCommand::UserEvent, nullptr);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::StartPickCallback()
 {
   this->InvokeEvent(vtkCommand::StartPickEvent, nullptr);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::EndPickCallback()
 {
   this->InvokeEvent(vtkCommand::EndPickEvent, nullptr);
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::FlyTo(vtkRenderer* ren, double x, double y, double z)
 {
   double flyFrom[3], flyTo[3];
@@ -483,7 +454,7 @@ void vtkRenderWindowInteractor::FlyTo(vtkRenderer* ren, double x, double y, doub
   }
 }
 
-//----------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::FlyToImage(vtkRenderer* ren, double x, double y)
 {
   double flyFrom[3], flyTo[3];
@@ -518,7 +489,7 @@ void vtkRenderWindowInteractor::FlyToImage(vtkRenderer* ren, double x, double y)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkRenderer* vtkRenderWindowInteractor::FindPokedRenderer(int x, int y)
 {
   if (this->RenderWindow == nullptr)
@@ -577,7 +548,7 @@ vtkRenderer* vtkRenderWindowInteractor::FindPokedRenderer(int x, int y)
   return currentRenderer;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::SetScale(double scale)
 {
   this->LastScale = this->Scale;
@@ -588,18 +559,18 @@ void vtkRenderWindowInteractor::SetScale(double scale)
   }
 }
 
-//----------------------------------------------------------------------------
-void vtkRenderWindowInteractor::SetRotation(double rot)
+//------------------------------------------------------------------------------
+void vtkRenderWindowInteractor::SetRotation(double rotation)
 {
   this->LastRotation = this->Rotation;
-  if (this->Rotation != rot)
+  if (this->Rotation != rotation)
   {
-    this->Rotation = rot;
+    this->Rotation = rotation;
     this->Modified();
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::SetTranslation(double val[2])
 {
   this->LastTranslation[0] = this->Translation[0];
@@ -612,7 +583,7 @@ void vtkRenderWindowInteractor::SetTranslation(double val[2])
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::RecognizeGesture(vtkCommand::EventIds event)
 {
   // we know we are in multitouch now, so start recognizing
@@ -954,7 +925,7 @@ int vtkRenderWindowInteractor::GetCurrentTimerId()
   return vtkTimerId;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -1008,7 +979,7 @@ void vtkRenderWindowInteractor::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Recognize Gestures: " << this->RecognizeGestures << endl;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::Initialize()
 {
   this->Initialized = 1;
@@ -1016,19 +987,19 @@ void vtkRenderWindowInteractor::Initialize()
   this->Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::HideCursor()
 {
   this->RenderWindow->HideCursor();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkRenderWindowInteractor::ShowCursor()
 {
   this->RenderWindow->ShowCursor();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkObserverMediator* vtkRenderWindowInteractor::GetObserverMediator()
 {
   if (!this->ObserverMediator)
@@ -1179,6 +1150,26 @@ void vtkRenderWindowInteractor::MouseWheelBackwardEvent()
   this->InvokeEvent(vtkCommand::MouseWheelBackwardEvent, nullptr);
 }
 
+//------------------------------------------------------------------
+void vtkRenderWindowInteractor::MouseWheelLeftEvent()
+{
+  if (!this->Enabled)
+  {
+    return;
+  }
+  this->InvokeEvent(vtkCommand::MouseWheelLeftEvent, nullptr);
+}
+
+//------------------------------------------------------------------
+void vtkRenderWindowInteractor::MouseWheelRightEvent()
+{
+  if (!this->Enabled)
+  {
+    return;
+  }
+  this->InvokeEvent(vtkCommand::MouseWheelRightEvent, nullptr);
+}
+
 //------------------------------------------------------------------
 void vtkRenderWindowInteractor::ExposeEvent()
 {
@@ -1418,3 +1409,4 @@ void vtkRenderWindowInteractor::SwipeEvent()
   }
   this->InvokeEvent(vtkCommand::SwipeEvent, nullptr);
 }
+VTK_ABI_NAMESPACE_END
