@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkScenePicker.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkScenePicker.h"
 
 #include "vtkCommand.h"
@@ -23,6 +11,7 @@
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRenderer.h"
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkScenePickerSelectionRenderCommand : public vtkCommand
 {
 public:
@@ -63,7 +52,7 @@ protected:
 
 vtkStandardNewMacro(vtkScenePicker);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScenePicker::vtkScenePicker()
 {
   this->EnableVertexPicking = 1;
@@ -78,7 +67,7 @@ vtkScenePicker::vtkScenePicker()
   this->SelectionRenderCommand->m_Picker = this;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkScenePicker::~vtkScenePicker()
 {
   this->SetRenderer(nullptr);
@@ -86,7 +75,7 @@ vtkScenePicker::~vtkScenePicker()
   this->SelectionRenderCommand->Delete();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScenePicker::SetRenderer(vtkRenderer* r)
 {
   vtkRenderWindowInteractor* rwi = nullptr;
@@ -122,7 +111,7 @@ void vtkScenePicker::SetRenderer(vtkRenderer* r)
   this->Selector->SetRenderer(this->Renderer);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScenePicker::SetInteractor(vtkRenderWindowInteractor* rwi)
 {
   if (this->Interactor == rwi)
@@ -145,7 +134,7 @@ void vtkScenePicker::SetInteractor(vtkRenderWindowInteractor* rwi)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Do a selection render.. for caching object selection stuff.
 // This is used for Object selection . We have to perform
 // "select" and "mouse over" and "mouse out" as the mouse moves around the
@@ -177,7 +166,7 @@ void vtkScenePicker::PickRender()
   this->PickRender(rx1, ry1, rx2, ry2);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Do a selection render.. for caching object selection stuff.
 void vtkScenePicker::PickRender(int x0, int y0, int x1, int y1)
 {
@@ -203,7 +192,7 @@ void vtkScenePicker::PickRender(int x0, int y0, int x1, int y1)
     vtkCommand::EndEvent, this->SelectionRenderCommand, 0.01);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScenePicker::GetCellId(int displayPos[2])
 {
   if (this->EnableVertexPicking)
@@ -214,14 +203,14 @@ vtkIdType vtkScenePicker::GetCellId(int displayPos[2])
   return this->CellId;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkProp* vtkScenePicker::GetViewProp(int displayPos[2])
 {
   this->Update(displayPos);
   return this->Prop;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkIdType vtkScenePicker::GetVertexId(int displayPos[2])
 {
   if (!this->EnableVertexPicking)
@@ -232,7 +221,7 @@ vtkIdType vtkScenePicker::GetVertexId(int displayPos[2])
   return this->CellId;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScenePicker::Update(int displayPos[2])
 {
   if (this->PickRenderTime <= this->GetMTime())
@@ -259,10 +248,11 @@ void vtkScenePicker::Update(int displayPos[2])
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkScenePicker::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Renderer: " << this->Renderer << endl;
   os << indent << "EnableVertexPicking: " << this->EnableVertexPicking << endl;
 }
+VTK_ABI_NAMESPACE_END
