@@ -1,16 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkOpenGLLight
  * @brief   OpenGL light
@@ -25,6 +14,7 @@
 #include "vtkLight.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkOpenGLRenderer;
 
 class VTKRENDERINGOPENGL2_EXPORT vtkOpenGLLight : public vtkLight
@@ -40,12 +30,13 @@ public:
   void Render(vtkRenderer* ren, int light_index) override;
 
 protected:
-  vtkOpenGLLight() {}
-  ~vtkOpenGLLight() override {}
+  vtkOpenGLLight() = default;
+  ~vtkOpenGLLight() override = default;
 
 private:
   vtkOpenGLLight(const vtkOpenGLLight&) = delete;
   void operator=(const vtkOpenGLLight&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
