@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkOpenGLRenderWindow.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkOpenGLRenderWindow
  * @brief   OpenGL rendering window
@@ -33,15 +21,16 @@
 #include <set>                         // for ivar
 #include <string>                      // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkOpenGLBufferObject;
 class vtkOpenGLFramebufferObject;
 class vtkOpenGLHardwareSupport;
+class vtkOpenGLQuadHelper;
 class vtkOpenGLShaderCache;
 class vtkOpenGLVertexBufferObjectCache;
 class vtkOpenGLVertexArrayObject;
 class vtkShaderProgram;
-class vtkStdString;
 class vtkTexture;
 class vtkTextureObject;
 class vtkTextureUnitManager;
@@ -57,7 +46,7 @@ public:
   /**
    * Begin the rendering process.
    */
-  void Start(void) override;
+  void Start() override;
 
   /**
    * A termination method performed at the end of the rendering process
@@ -70,17 +59,19 @@ public:
    */
   const char* GetRenderingBackend() override;
 
-  //@{
+  ///@{
   /**
    * Set/Get the maximum number of multisamples
    */
   static void SetGlobalMaximumNumberOfMultiSamples(int val);
   static int GetGlobalMaximumNumberOfMultiSamples();
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the pixel data of an image, transmitted as RGBRGB...
+   * front in this context indicates that the read should come from the
+   * display buffer versus the render buffer
    */
   unsigned char* GetPixelData(int x, int y, int x2, int y2, int front, int right) override;
   int GetPixelData(
@@ -89,9 +80,9 @@ public:
     int x, int y, int x2, int y2, unsigned char* data, int front, int right) override;
   int SetPixelData(
     int x, int y, int x2, int y2, vtkUnsignedCharArray* data, int front, int right) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the pixel data of an image, transmitted as RGBARGBA...
    */
@@ -111,18 +102,18 @@ public:
     int blend = 0, int right = 0) override;
   int SetRGBACharPixelData(int x, int y, int x2, int y2, vtkUnsignedCharArray* data, int front,
     int blend = 0, int right = 0) override;
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Set/Get the zbuffer data from an image
    */
   float* GetZbufferData(int x1, int y1, int x2, int y2) override;
   int GetZbufferData(int x1, int y1, int x2, int y2, float* z) override;
-  int GetZbufferData(int x1, int y1, int x2, int y2, vtkFloatArray* z) override;
+  int GetZbufferData(int x1, int y1, int x2, int y2, vtkFloatArray* buffer) override;
   int SetZbufferData(int x1, int y1, int x2, int y2, float* buffer) override;
   int SetZbufferData(int x1, int y1, int x2, int y2, vtkFloatArray* buffer) override;
-  //@}
+  ///@}
 
   /**
    * Activate a texture unit for this texture
@@ -162,19 +153,6 @@ public:
    */
   int GetColorBufferInternalFormat(int attachmentPoint);
 
-  //@{
-  /**
-   * Set the size (width and height) of the rendering window in
-   * screen coordinates (in pixels). This resizes the operating
-   * system's view/window and redraws it.
-   *
-   * If the size has changed, this method will fire
-   * vtkCommand::WindowResizeEvent.
-   */
-  void SetSize(int width, int height) override;
-  void SetSize(int a[2]) override { this->SetSize(a[0], a[1]); }
-  //@}
-
   /**
    * Initialize OpenGL for this window.
    */
@@ -193,54 +171,6 @@ public:
    */
   void GetOpenGLVersion(int& major, int& minor);
 
-  /**
-   * Return the OpenGL name of the back left buffer.
-   * It is GL_BACK_LEFT if GL is bound to the window-system-provided
-   * framebuffer. It is vtkgl::COLOR_ATTACHMENT0_EXT if GL is bound to an
-   * application-created framebuffer object (GPU-based offscreen rendering)
-   * It is used by vtkOpenGLCamera.
-   */
-  unsigned int GetBackLeftBuffer();
-
-  /**
-   * Return the OpenGL name of the back right buffer.
-   * It is GL_BACK_RIGHT if GL is bound to the window-system-provided
-   * framebuffer. It is vtkgl::COLOR_ATTACHMENT0_EXT+1 if GL is bound to an
-   * application-created framebuffer object (GPU-based offscreen rendering)
-   * It is used by vtkOpenGLCamera.
-   */
-  unsigned int GetBackRightBuffer();
-
-  /**
-   * Return the OpenGL name of the front left buffer.
-   * It is GL_FRONT_LEFT if GL is bound to the window-system-provided
-   * framebuffer. It is vtkgl::COLOR_ATTACHMENT0_EXT if GL is bound to an
-   * application-created framebuffer object (GPU-based offscreen rendering)
-   * It is used by vtkOpenGLCamera.
-   */
-  unsigned int GetFrontLeftBuffer();
-
-  /**
-   * Return the OpenGL name of the front right buffer.
-   * It is GL_FRONT_RIGHT if GL is bound to the window-system-provided
-   * framebuffer. It is vtkgl::COLOR_ATTACHMENT0_EXT+1 if GL is bound to an
-   * application-created framebuffer object (GPU-based offscreen rendering)
-   * It is used by vtkOpenGLCamera.
-   */
-  unsigned int GetFrontRightBuffer();
-
-  /**
-   * Return the OpenGL name of the back left buffer.
-   * Identical to GetBackLeftBuffer.
-   */
-  unsigned int GetBackBuffer();
-
-  /**
-   * Return the OpenGL name of the front left buffer.
-   * Identical to GetFrontLeftBuffer.
-   */
-  unsigned int GetFrontBuffer();
-
   /**
    * Get the time when the OpenGL context was created.
    */
@@ -256,12 +186,17 @@ public:
    */
   vtkOpenGLVertexBufferObjectCache* GetVBOCache();
 
-  //@{
+  ///@{
   /**
-   * Returns the offscreen framebuffer object if any
+   * Returns the render framebuffer object.
    */
-  vtkGetObjectMacro(OffScreenFramebuffer, vtkOpenGLFramebufferObject);
-  //@}
+  vtkGetObjectMacro(RenderFramebuffer, vtkOpenGLFramebufferObject);
+  ///@}
+
+  /**
+   * Returns the display framebuffer object.
+   */
+  vtkGetObjectMacro(DisplayFramebuffer, vtkOpenGLFramebufferObject);
 
   /**
    * Returns its texture unit manager object. A new one will be created if one
@@ -306,7 +241,7 @@ public:
    * because point sprites don't work correctly (gl_PointCoord is undefined) unless
    * glEnable(GL_POINT_SPRITE)
    */
-  virtual bool IsPointSpriteBugPresent() { return 0; }
+  virtual bool IsPointSpriteBugPresent() { return false; }
 
   /**
    * Get a mapping of vtk data types to native texture formats for this window
@@ -339,7 +274,7 @@ public:
    * should be possible to call them multiple times, even changing WindowId
    * in-between.  This is what WindowRemap does.
    */
-  virtual void Initialize(void) {}
+  virtual void Initialize() {}
 
   std::set<vtkGenericOpenGLResourceFreeCallback*> Resources;
 
@@ -379,15 +314,6 @@ public:
    */
   bool InitializeFromCurrentContext() override;
 
-  /**
-   * Returns the id for the frame buffer object, if any, used by the render window
-   * in which the window does all its rendering. This may be 0, in which case
-   * the render window is rendering to the default OpenGL render buffers.
-   *
-   * @returns the name (or id) of the frame buffer object to render to.
-   */
-  vtkGetMacro(DefaultFrameBufferId, unsigned int);
-
   /**
    * Set the number of vertical syncs required between frames.
    * A value of 0 means swap buffers as quickly as possible
@@ -410,7 +336,7 @@ public:
 
   // Activate and return thje texture unit for a generic 2d 64x64
   // float greyscale noise texture ranging from 0 to 1. The texture is
-  // generated using PerlinNoise.  This textur eunit will automatically
+  // a hard-coded blue noise texture.  This texture unit will automatically
   // be deactivated at the end of the render process.
   int GetNoiseTextureUnit();
 
@@ -439,10 +365,135 @@ public:
    */
   void ReleaseGraphicsResources(vtkWindow*) override;
 
+  /**
+   * Blit a display framebuffer into a currently bound draw destination
+   */
+  void BlitDisplayFramebuffer();
+
+  /**
+   * Blit a display buffer into a currently bound draw destination
+   */
+  void BlitDisplayFramebuffer(int right, int srcX, int srcY, int srcWidth, int srcHeight, int destX,
+    int destY, int destWidth, int destHeight, int bufferMode, int interpolation);
+
+  ///@{
+  /**
+   * Blit the currently bound read buffer to the renderbuffer. This is useful for
+   * taking rendering from an external system and then having VTK draw on top of it.
+   */
+  void BlitToRenderFramebuffer(bool includeDepth);
+  void BlitToRenderFramebuffer(int srcX, int srcY, int srcWidth, int srcHeight, int destX,
+    int destY, int destWidth, int destHeight, int bufferMode, int interpolation);
+  ///@}
+
+  /**
+   * Define how the resulting image should be blitted when at the end of the Frame() call if
+   * SwapBuffers is true
+   */
+  enum FrameBlitModes
+  {
+    BlitToHardware, // hardware buffers
+    BlitToCurrent,  // currently bound draw framebuffer
+    NoBlit          // no blit, GUI or external code will handle the blit
+  };
+
+  ///@{
+  /**
+   * SetGet how to handle blits at the end of a Frame() call.
+   * Only happens when SwapBuffers is true.
+   *
+   * The “blit” operation means copying something (pixels) from one region
+   * in memory to another. This is a common OpenGL operation: check out the
+   * glBlitFramebuffer OpenGL method. VTK OpenGL rasterizes 3D/2D geometry
+   * into color/depth attachments of an in-memory framebuffer: in the graphics
+   * world, this is called offscreen rendering.
+   *
+   * The FrameBlitMode tells VTK where to copy the offscreen
+   * buffer. Either the default hardware framebuffer or the currently bound
+   * framebuffer. Here are the available modes:
+   * - BlitToHardware: This mode blits to the default framebuffer managed by
+   *   platform(Win32/X/Cocoa) render windows. This is the default mode when VTK
+   *   is used through one of the platform render windows (with vtkRenderWindow).
+   * - BlitToCurrent: This mode blits to the currently bound framebuffer.
+   *   It is useful when an external framebuffer is bound just before
+   *   the vtkRenderWindow::Frame() call. You’ll need this when integrating
+   *   VTK with other UI frameworks because these UI frameworks create/have
+   *   their own framebuffers.
+   * - NoBlit: no blit. The GUI or external code will handle the blit.
+   */
+  vtkSetClampMacro(FrameBlitMode, FrameBlitModes, BlitToHardware, NoBlit);
+  vtkGetMacro(FrameBlitMode, FrameBlitModes);
+  void SetFrameBlitModeToBlitToHardware() { this->SetFrameBlitMode(BlitToHardware); }
+  void SetFrameBlitModeToBlitToCurrent() { this->SetFrameBlitMode(BlitToCurrent); }
+  void SetFrameBlitModeToNoBlit() { this->SetFrameBlitMode(NoBlit); }
+  ///@}
+
+  ///@{
+  /**
+   * Enable/Disable flipping the Y axis of the rendered texture.
+   */
+  vtkSetMacro(FramebufferFlipY, bool);
+  vtkGetMacro(FramebufferFlipY, bool);
+  vtkBooleanMacro(FramebufferFlipY, bool);
+  ///@}
+
+  ///@{
+  // copy depth values from a source framebuffer to a destination framebuffer
+  // using texture maps to do the copy. The source framebufferobject must be texture
+  // backed. This method is designed to work around issues with trying to blit depth
+  // values between framebuffers that have different depth formats.
+
+  // blit entire source texture to active viewport
+  virtual void TextureDepthBlit(vtkTextureObject* source);
+
+  // blit specified source texels to active viewport
+  virtual void TextureDepthBlit(vtkTextureObject* source, int srcX, int srcY, int srcX2, int srcY2);
+
+  // blit specified source texels to specified viewport
+  virtual void TextureDepthBlit(vtkTextureObject* source, int srcX, int srcY, int srcX2, int srcY2,
+    int destX, int destY, int destX2, int destY2);
+  ///@}
+
 protected:
   vtkOpenGLRenderWindow();
   ~vtkOpenGLRenderWindow() override;
 
+  // blits the display buffers to the appropriate hardware buffers
+  virtual void BlitDisplayFramebuffersToHardware();
+
+  // when frame is called, at the end blit to the hardware buffers
+  FrameBlitModes FrameBlitMode;
+
+  // a FSQ we use to resolve MSAA that handles gamma
+  vtkOpenGLQuadHelper* ResolveQuad;
+
+  // a FSQ we use to blit depth values
+  vtkOpenGLQuadHelper* DepthBlitQuad;
+
+  // a FSQ we use to flip framebuffer texture
+  vtkOpenGLQuadHelper* FlipQuad;
+
+  // a FSQ we use to read depth component on platforms with OpenGL ES implementations
+  // because `glReadPixels` cannot be used to read GL_DEPTH_COMPONENT
+  vtkOpenGLQuadHelper* DepthReadQuad;
+
+  // flip quad helpers Y tcoord
+  bool FramebufferFlipY;
+
+  // resolve and flip renderframebuffer as needed
+  // when copying to displayframebuffer. Returns
+  // true if the color buffer was copied.
+  virtual bool ResolveFlipRenderFramebuffer();
+
+  // On GLES, the depth attachment buffer cannot be downloaded from
+  // the GPU with `glReadPixels`.
+  // This method reads the depth buffer bits.
+  // The depth attachment size can be 8,16,24 or 32. The values are split into 4 8-bit numbers.
+  // These are stored in the form of an RGBA color attachment in DepthFrameBuffer.
+  // `glReadPixels` can read that RGBA format and reconstruct full 8,16,24 or 32-bit integer
+  // followed by scaling down to 0-1.
+  bool ReadDepthComponent(int depthSize);
+
   // used in testing for opengl support
   // in the SupportsOpenGL() method
   bool OpenGLSupportTested;
@@ -460,8 +511,17 @@ protected:
    * \pre not_initialized: !OffScreenUseFrameBuffer
    * \post valid_result: (result==0 || result==1)
    */
-  int CreateOffScreenFramebuffer(int width, int height);
-  vtkOpenGLFramebufferObject* OffScreenFramebuffer;
+  int CreateFramebuffers(int width, int height);
+  vtkOpenGLFramebufferObject* RenderFramebuffer;
+  vtkOpenGLFramebufferObject* DisplayFramebuffer;
+
+  // used when we need to resolve a multisampled
+  // framebuffer
+  vtkOpenGLFramebufferObject* ResolveFramebuffer;
+
+  // used when we need to read depth component
+  // with OpenGL ES 3
+  vtkOpenGLFramebufferObject* DepthFramebuffer;
 
   /**
    * Create a not-off-screen window.
@@ -485,16 +545,10 @@ protected:
 
   std::map<std::string, int> GLStateIntegers;
 
-  unsigned int BackLeftBuffer;
-  unsigned int BackRightBuffer;
-  unsigned int FrontLeftBuffer;
-  unsigned int FrontRightBuffer;
-  unsigned int DefaultFrameBufferId;
-
   /**
    * Flag telling if the context has been created here or was inherited.
    */
-  int OwnContext;
+  vtkTypeBool OwnContext;
 
   vtkTimeStamp ContextCreationTime;
 
@@ -529,4 +583,5 @@ private:
   vtkOpenGLState* State;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
