@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkShadowMapPass.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkShadowMapPass.h"
 #include "vtkObjectFactory.h"
@@ -48,7 +36,6 @@
 // debugging
 #include "vtkTimerLog.h"
 
-#include "vtkStdString.h"
 #include <cassert>
 #include <sstream>
 
@@ -57,13 +44,14 @@
 //#define VTK_SHADOW_MAP_PASS_DEBUG
 //#define DONT_DUPLICATE_LIGHTS
 
+VTK_ABI_NAMESPACE_BEGIN
 vtkStandardNewMacro(vtkShadowMapPass);
 vtkCxxSetObjectMacro(vtkShadowMapPass, ShadowMapBakerPass, vtkShadowMapBakerPass);
 vtkCxxSetObjectMacro(vtkShadowMapPass, OpaqueSequence, vtkRenderPass);
 
 vtkInformationKeyMacro(vtkShadowMapPass, ShadowMapPass, ObjectBase);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkShadowMapPass::vtkShadowMapPass()
 {
   this->ShadowMapBakerPass = nullptr;
@@ -84,7 +72,7 @@ vtkShadowMapPass::vtkShadowMapPass()
   this->SetShadowMapBakerPass(bp);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkShadowMapPass::~vtkShadowMapPass()
 {
   if (this->ShadowMapBakerPass != nullptr)
@@ -97,7 +85,7 @@ vtkShadowMapPass::~vtkShadowMapPass()
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkShadowMapPass::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -122,7 +110,7 @@ void vtkShadowMapPass::PrintSelf(ostream& os, vtkIndent indent)
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Perform rendering according to a render state \p s.
 // \pre s_exists: s!=0
@@ -463,7 +451,7 @@ void vtkShadowMapPass::BuildShaderCode()
   this->FragmentImplementation = toString.str();
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Release graphics resources and ask components to release their own
 // resources.
@@ -476,3 +464,4 @@ void vtkShadowMapPass::ReleaseGraphicsResources(vtkWindow* w)
     this->ShadowMapBakerPass->ReleaseGraphicsResources(w);
   }
 }
+VTK_ABI_NAMESPACE_END
