@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkTextureObject.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkTextureObject.h"
 
 #include "vtk_glew.h"
@@ -50,46 +38,47 @@
 #define BUFFER_OFFSET(i) (reinterpret_cast<char*>(i))
 
 // Mapping from DepthTextureCompareFunction values to OpenGL values.
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
 static GLint OpenGLDepthTextureCompareFunction[8] = { GL_LEQUAL, GL_GEQUAL, GL_LESS, GL_GREATER,
   GL_EQUAL, GL_NOTEQUAL, GL_ALWAYS, GL_NEVER };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static const char* DepthTextureCompareFunctionAsString[8] = { "Lequal", "Gequal", "Less", "Greater",
   "Equal", "NotEqual", "AlwaysTrue", "Never" };
 
 // Mapping from Wrap values to OpenGL values
 #ifndef GL_ES_VERSION_3_0
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static GLint OpenGLWrap[4] = { GL_CLAMP_TO_EDGE, GL_REPEAT, GL_MIRRORED_REPEAT,
   GL_CLAMP_TO_BORDER };
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static const char* WrapAsString[4] = { "ClampToEdge", "Repeat", "MirroredRepeat", "ClampToBorder" };
 
 #else
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static GLint OpenGLWrap[3] = { GL_CLAMP_TO_EDGE, GL_REPEAT, GL_MIRRORED_REPEAT };
 
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static const char* WrapAsString[3] = { "ClampToEdge", "Repeat", "MirroredRepeat" };
 
 #endif
 
 // Mapping MinificationFilter values to OpenGL values.
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static GLint OpenGLMinFilter[6] = { GL_NEAREST, GL_LINEAR, GL_NEAREST_MIPMAP_NEAREST,
   GL_NEAREST_MIPMAP_LINEAR, GL_LINEAR_MIPMAP_NEAREST, GL_LINEAR_MIPMAP_LINEAR };
 
 // Mapping MagnificationFilter values to OpenGL values.
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static GLint OpenGLMagFilter[6] = { GL_NEAREST, GL_LINEAR };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static const char* MinMagFilterAsString[6] = { "Nearest", "Linear", "NearestMipmapNearest",
   "NearestMipmapLinear", "LinearMipmapNearest", "LinearMipmapLinear" };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static GLenum OpenGLDepthInternalFormat[7] = {
   GL_DEPTH_COMPONENT,   // native
   GL_DEPTH_COMPONENT,   // fixed8
@@ -112,7 +101,7 @@ static GLenum OpenGLDepthInternalFormat[7] = {
 #endif
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static GLenum OpenGLDepthInternalFormatType[7] = {
   GL_UNSIGNED_INT, GL_UNSIGNED_INT, GL_UNSIGNED_INT, GL_UNSIGNED_INT, GL_UNSIGNED_INT,
 #ifdef GL_DEPTH_COMPONENT32F
@@ -122,10 +111,10 @@ static GLenum OpenGLDepthInternalFormatType[7] = {
 #endif
 };
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkTextureObject);
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTextureObject::vtkTextureObject()
 {
   this->Context = nullptr;
@@ -172,7 +161,7 @@ vtkTextureObject::vtkTextureObject()
   this->ResetFormatAndType();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkTextureObject::~vtkTextureObject()
 {
   if (this->ResourceCallback)
@@ -188,7 +177,7 @@ vtkTextureObject::~vtkTextureObject()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::SetContext(vtkOpenGLRenderWindow* renWin)
 {
   this->ResourceCallback->RegisterGraphicsResources(renWin);
@@ -214,13 +203,13 @@ void vtkTextureObject::SetContext(vtkOpenGLRenderWindow* renWin)
   this->Context->MakeCurrent();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkOpenGLRenderWindow* vtkTextureObject::GetContext()
 {
   return this->Context;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::DestroyTexture()
 {
   // deactivate it first
@@ -258,7 +247,7 @@ void vtkTextureObject::AssignToExistingTexture(unsigned int handle, unsigned int
   this->Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::CreateTexture()
 {
   assert(this->Context);
@@ -317,7 +306,7 @@ void vtkTextureObject::CreateTexture()
   }
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetTextureUnit()
 {
   if (this->Context)
@@ -327,7 +316,7 @@ int vtkTextureObject::GetTextureUnit()
   return -1;
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::Activate()
 {
   // activate a free texture unit for this texture
@@ -335,7 +324,7 @@ void vtkTextureObject::Activate()
   this->Bind();
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::Deactivate()
 {
   if (this->Context)
@@ -344,7 +333,7 @@ void vtkTextureObject::Deactivate()
   }
 }
 
-//---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::ReleaseGraphicsResources(vtkWindow* win)
 {
   if (!this->ResourceCallback->IsReleasing())
@@ -383,7 +372,7 @@ void vtkTextureObject::ReleaseGraphicsResources(vtkWindow* win)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::Bind()
 {
   assert(this->Context);
@@ -398,7 +387,7 @@ void vtkTextureObject::Bind()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::IsBound()
 {
   bool result = false;
@@ -446,7 +435,7 @@ bool vtkTextureObject::IsBound()
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::SendParameters()
 {
   assert("pre: is_bound" && this->IsBound());
@@ -515,7 +504,7 @@ void vtkTextureObject::SendParameters()
   this->SendParametersTime.Modified();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetInternalFormat(
   int vtktype, int numComps, bool shaderSupportsTextureInt)
 {
@@ -545,7 +534,7 @@ unsigned int vtkTextureObject::GetInternalFormat(
   return this->InternalFormat;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetDefaultInternalFormat(
   int vtktype, int numComps, bool shaderSupportsTextureInt)
 {
@@ -585,7 +574,7 @@ unsigned int vtkTextureObject::GetDefaultInternalFormat(
   return result;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::SetInternalFormat(unsigned int glInternalFormat)
 {
   if (this->InternalFormat != glInternalFormat)
@@ -595,7 +584,7 @@ void vtkTextureObject::SetInternalFormat(unsigned int glInternalFormat)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static int vtkGetVTKType(GLenum gltype)
 {
   // DON'T DEAL with VTK_CHAR as this is platform dependent.
@@ -667,7 +656,7 @@ void vtkTextureObject::GetShiftAndScale(float& shift, float& scale)
       shift = scale + VTK_INT_MIN;
       break;
     case GL_UNSIGNED_INT:
-      scale = VTK_UNSIGNED_INT_MAX;
+      scale = static_cast<float>(VTK_UNSIGNED_INT_MAX);
       shift = 0.0;
       break;
     case GL_FLOAT:
@@ -676,7 +665,7 @@ void vtkTextureObject::GetShiftAndScale(float& shift, float& scale)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetFormat(int vtktype, int numComps, bool shaderSupportsTextureInt)
 {
   if (!this->Format)
@@ -686,7 +675,7 @@ unsigned int vtkTextureObject::GetFormat(int vtktype, int numComps, bool shaderS
   return this->Format;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetDefaultFormat(
   int vtktype, int numComps, bool shaderSupportsTextureInt)
 {
@@ -726,6 +715,7 @@ unsigned int vtkTextureObject::GetDefaultFormat(
         return GL_RGBA;
     }
 #else
+  (void)shaderSupportsTextureInt;
   {
     switch (numComps)
     {
@@ -750,7 +740,7 @@ unsigned int vtkTextureObject::GetDefaultFormat(
   return GL_RGB;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::SetFormat(unsigned int glFormat)
 {
   if (this->Format != glFormat)
@@ -760,7 +750,7 @@ void vtkTextureObject::SetFormat(unsigned int glFormat)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::ResetFormatAndType()
 {
   this->Format = 0;
@@ -768,7 +758,7 @@ void vtkTextureObject::ResetFormatAndType()
   this->Type = 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetDefaultDataType(int vtk_scalar_type)
 {
   // DON'T DEAL with VTK_CHAR as this is platform dependent.
@@ -799,13 +789,13 @@ int vtkTextureObject::GetDefaultDataType(int vtk_scalar_type)
   return 0;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetVTKDataType()
 {
   return ::vtkGetVTKType(this->Type);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetDataType(int vtk_scalar_type)
 {
   if (!this->Type)
@@ -816,7 +806,7 @@ int vtkTextureObject::GetDataType(int vtk_scalar_type)
   return this->Type;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::SetDataType(unsigned int glType)
 {
   if (this->Type != glType)
@@ -826,7 +816,7 @@ void vtkTextureObject::SetDataType(unsigned int glType)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetMinificationFilterMode(int vtktype)
 {
   switch (vtktype)
@@ -848,7 +838,7 @@ unsigned int vtkTextureObject::GetMinificationFilterMode(int vtktype)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetMagnificationFilterMode(int vtktype)
 {
   switch (vtktype)
@@ -862,7 +852,7 @@ unsigned int vtkTextureObject::GetMagnificationFilterMode(int vtktype)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetWrapSMode(int vtktype)
 {
   switch (vtktype)
@@ -882,13 +872,13 @@ unsigned int vtkTextureObject::GetWrapSMode(int vtktype)
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetWrapTMode(int vtktype)
 {
   return this->GetWrapSMode(vtktype);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 unsigned int vtkTextureObject::GetWrapRMode(int vtktype)
 {
   return this->GetWrapSMode(vtktype);
@@ -897,7 +887,7 @@ unsigned int vtkTextureObject::GetWrapRMode(int vtktype)
 // 1D  textures are not supported in ES 2.0 or 3.0
 #ifndef GL_ES_VERSION_3_0
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Create1D(
   int numComps, vtkPixelBufferObject* pbo, bool shaderSupportsTextureInt)
 {
@@ -932,7 +922,7 @@ bool vtkTextureObject::Create1D(
   pbo->Bind(vtkPixelBufferObject::UNPACKED_BUFFER);
 
   // Source texture data from the PBO.
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
   glTexImage1D(target, 0, static_cast<GLint>(internalFormat),
     static_cast<GLsizei>(pbo->GetSize() / static_cast<unsigned int>(numComps)), 0, format, type,
     BUFFER_OFFSET(0));
@@ -951,7 +941,7 @@ bool vtkTextureObject::Create1D(
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Create1DFromRaw(unsigned int width, int numComps, int dataType, void* data)
 {
   assert(this->Context);
@@ -1018,6 +1008,16 @@ bool vtkTextureObject::CreateTextureBuffer(
   this->CreateTexture();
   this->Bind();
 
+  int maxSize = -1;
+  this->Context->GetState()->vtkglGetIntegerv(GL_MAX_TEXTURE_BUFFER_SIZE, &maxSize);
+  if (maxSize > 0 && static_cast<unsigned int>(maxSize) < numValues)
+  {
+    vtkErrorMacro("Attempt to use a texture buffer exceeding your hardware's limits. "
+                  "This can happen when trying to color by cell data with a large dataset. "
+                  "Hardware limit is "
+      << maxSize << " values while " << numValues << " was requested.");
+  }
+
   // Source texture data from the PBO.
   glTexBuffer(this->Target, this->InternalFormat, this->BufferObject->GetHandle());
 
@@ -1030,21 +1030,167 @@ bool vtkTextureObject::CreateTextureBuffer(
 
 #else
 
+// Emulate 1D textures as 2D. Note that the any shader code will likely
+// have to be modified as well for this to work.
+
+//------------------------------------------------------------------------------
+bool vtkTextureObject::Create1D(
+  int numComps, vtkPixelBufferObject* pbo, bool shaderSupportsTextureInt)
+{
+  assert(this->Context);
+  assert(pbo->GetContext() == this->Context.GetPointer());
+
+  GLenum target = GL_TEXTURE_2D;
+
+  // Now, determine texture parameters using the information from the pbo.
+
+  // * internalFormat depends on number of components and the data type.
+  GLenum internalFormat =
+    this->GetInternalFormat(pbo->GetType(), numComps, shaderSupportsTextureInt);
+
+  // * format depends on the number of components.
+  GLenum format = this->GetFormat(pbo->GetType(), numComps, shaderSupportsTextureInt);
+
+  // * type if the data type in the pbo
+  GLenum type = this->GetDefaultDataType(pbo->GetType());
+
+  if (!internalFormat || !format || !type)
+  {
+    vtkErrorMacro("Failed to determine texture parameters.");
+    return false;
+  }
+
+  this->Target = target;
+  this->Context->ActivateTexture(this);
+  this->CreateTexture();
+  this->Bind();
+
+  pbo->Bind(vtkPixelBufferObject::UNPACKED_BUFFER);
+
+  // Source texture data from the PBO.
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  glTexImage2D(target, 0, static_cast<GLint>(internalFormat),
+    static_cast<GLsizei>(pbo->GetSize() / static_cast<unsigned int>(numComps)), 1, 0, format, type,
+    BUFFER_OFFSET(0));
+  vtkOpenGLCheckErrorMacro("failed at glTexImage1D");
+  pbo->UnBind();
+  this->Deactivate();
+
+  this->Target = target;
+  this->Format = format;
+  this->Type = type;
+  this->Components = numComps;
+  this->Width = pbo->GetSize();
+  this->Height = 1;
+  this->Depth = 1;
+  this->NumberOfDimensions = 1;
+  return true;
+}
+
+//------------------------------------------------------------------------------
+bool vtkTextureObject::Create1DFromRaw(unsigned int width, int numComps, int dataType, void* data)
+{
+  assert(this->Context);
+
+  // Now determine the texture parameters using the arguments.
+  this->GetDataType(dataType);
+  this->GetInternalFormat(dataType, numComps, false);
+  this->GetFormat(dataType, numComps, false);
+
+  if (!this->InternalFormat || !this->Format || !this->Type)
+  {
+    vtkErrorMacro("Failed to determine texture parameters.");
+    return false;
+  }
+
+  GLenum target = GL_TEXTURE_2D;
+  this->Target = target;
+  this->Components = numComps;
+  this->Width = width;
+  this->Height = 1;
+  this->Depth = 1;
+  this->NumberOfDimensions = 1;
+  this->Context->ActivateTexture(this);
+  this->CreateTexture();
+  this->Bind();
+
+  glTexImage2D(this->Target, 0, this->InternalFormat, static_cast<GLsizei>(this->Width), 1, 0,
+    this->Format, this->Type, static_cast<const GLvoid*>(data));
+
+  vtkOpenGLCheckErrorMacro("failed at glTexImage1D");
+
+  this->Deactivate();
+  return true;
+}
+
 // Description:
 // Create a texture buffer basically a 1D texture that can be
 // very large for passing data into the fragment shader
 bool vtkTextureObject::CreateTextureBuffer(
   unsigned int numValues, int numComps, int dataType, vtkOpenGLBufferObject* bo)
 {
-  assert(this->Context);
-  vtkErrorMacro("TextureBuffers not supported in OPenGL ES");
-  // TODO: implement 1D and Texture buffers using 2D textures
-  return false;
+  return this->EmulateTextureBufferWith2DTextures(numValues, numComps, dataType, bo);
 }
 
 #endif // not ES 2.0 or 3.0
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+bool vtkTextureObject::EmulateTextureBufferWith2DTextures(
+  unsigned int numValues, int numComps, int dataType, vtkOpenGLBufferObject* bo)
+{
+  assert(this->Context);
+  auto ostate = this->GetContext()->GetState();
+  int maxSize = 0;
+  ostate->vtkglGetIntegerv(GL_MAX_TEXTURE_SIZE, &maxSize);
+  if (numValues > static_cast<unsigned int>(maxSize * maxSize))
+  {
+    vtkErrorMacro("Requested texture buffer size exceeds hardware limits. "
+                  "On the current OpenGL device, GL_MAX_TEXTURE_SIZE x GL_MAX_TEXTURE_SIZE = "
+      << maxSize << " values. However, requested size is " << numValues << ".");
+    return false;
+  }
+  else
+  {
+    unsigned int maxTexDim = maxSize;
+    int width = numValues > maxTexDim ? maxTexDim : numValues % (maxTexDim + 1);
+    int height = vtkMath::Ceil(static_cast<double>(numValues) / width);
+
+    // copy data from 'src' array buffer object to a pbo's unpacked buffer.
+    GLenum srcTarget = GL_ARRAY_BUFFER;
+    GLenum dstTarget = GL_PIXEL_UNPACK_BUFFER;
+    if (bo->GetType() == vtkOpenGLBufferObject::ElementArrayBuffer)
+    {
+      srcTarget = GL_ELEMENT_ARRAY_BUFFER;
+    }
+    GLint64 srcNumBytes = 0;
+    bo->Bind();
+    glGetBufferParameteri64v(srcTarget, GL_BUFFER_SIZE, &srcNumBytes);
+    vtkOpenGLCheckErrors("glGetBufferParameteri64v ");
+
+    // issue 3 (https://registry.khronos.org/OpenGL/extensions/ARB/ARB_pixel_buffer_object.txt)
+    // says it's alright to bind any b.o (GL_ARRAY_BUFFER, etc) to unpacked buffer
+    // and go ahead with glTexImage,
+    // however, issue 4 cautions that some driver implementations
+    // may perform sub-optimally. so let's do a b.o->b.o copy instead of shortcuts.
+    vtkNew<vtkPixelBufferObject> pbo;
+    pbo->SetContext(this->GetContext());
+    pbo->Allocate(dataType, width * height, numComps, vtkPixelBufferObject::UNPACKED_BUFFER);
+    pbo->BindToUnPackedBuffer();
+    // transfers within gpu memory space on most GL driver implementations.
+    glCopyBufferSubData(srcTarget, dstTarget, 0, 0, srcNumBytes);
+    vtkOpenGLCheckErrors("glCopyBufferSubData ");
+
+    // unbind
+    bo->Release();
+    pbo->UnBind();
+
+    // source a 2D texture with the pbo.
+    this->Create2D(width, height, numComps, pbo, false);
+    return true;
+  }
+}
+
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Create2D(unsigned int width, unsigned int height, int numComps,
   vtkPixelBufferObject* pbo, bool shaderSupportsTextureInt)
 {
@@ -1083,7 +1229,7 @@ bool vtkTextureObject::Create2D(unsigned int width, unsigned int height, int num
 
   // Source texture data from the PBO.
   pbo->Bind(vtkPixelBufferObject::UNPACKED_BUFFER);
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
   glTexImage2D(target, 0, internalFormat, static_cast<GLsizei>(width), static_cast<GLsizei>(height),
     0, format, type, BUFFER_OFFSET(0));
@@ -1105,7 +1251,7 @@ bool vtkTextureObject::Create2D(unsigned int width, unsigned int height, int num
   return true;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Create a 2D depth texture using a PBO.
 bool vtkTextureObject::CreateDepth(
@@ -1137,7 +1283,7 @@ bool vtkTextureObject::CreateDepth(
   pbo->Bind(vtkPixelBufferObject::UNPACKED_BUFFER);
 
   // Source texture data from the PBO.
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
   glTexImage2D(this->Target, 0, static_cast<GLint>(inFormat), static_cast<GLsizei>(width),
     static_cast<GLsizei>(height), 0, this->Format, this->Type, BUFFER_OFFSET(0));
   vtkOpenGLCheckErrorMacro("failed at glTexImage2D");
@@ -1146,7 +1292,7 @@ bool vtkTextureObject::CreateDepth(
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Create3D(unsigned int width, unsigned int height, unsigned int depth,
   int numComps, vtkPixelBufferObject* pbo, bool shaderSupportsTextureInt)
 {
@@ -1211,7 +1357,7 @@ bool vtkTextureObject::Create3D(unsigned int width, unsigned int height, unsigne
 #endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPixelBufferObject* vtkTextureObject::Download(unsigned int target, unsigned int level)
 {
   assert(this->Context);
@@ -1244,6 +1390,8 @@ vtkPixelBufferObject* vtkTextureObject::Download(unsigned int target, unsigned i
 #ifndef GL_ES_VERSION_3_0
   glGetTexImage(target, level, this->Format, this->Type, BUFFER_OFFSET(0));
 #else
+  (void)level;
+  (void)target;
   // you can do something with glReadPixels and binding a texture as a FBO
   // I believe for ES 2.0
 #endif
@@ -1257,13 +1405,13 @@ vtkPixelBufferObject* vtkTextureObject::Download(unsigned int target, unsigned i
   return pbo;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPixelBufferObject* vtkTextureObject::Download()
 {
   return this->Download(this->Target, 0);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Create3DFromRaw(unsigned int width, unsigned int height, unsigned int depth,
   int numComps, int dataType, void* data)
 {
@@ -1293,7 +1441,7 @@ bool vtkTextureObject::Create3DFromRaw(unsigned int width, unsigned int height,
   this->Bind();
 
   // Source texture data from the PBO.
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
   glTexImage3D(this->Target, 0, this->InternalFormat, static_cast<GLsizei>(this->Width),
     static_cast<GLsizei>(this->Height), static_cast<GLsizei>(this->Depth), 0, this->Format,
@@ -1304,9 +1452,9 @@ bool vtkTextureObject::Create3DFromRaw(unsigned int width, unsigned int height,
   return vtkOpenGLCheckErrors("Failed to allocate 3D texture.");
 }
 
-//----------------------------------------------------------------------------
-bool vtkTextureObject::AllocateProxyTexture3D(unsigned int const width, unsigned int const height,
-  unsigned int depth, int const numComps, int const dataType)
+//------------------------------------------------------------------------------
+bool vtkTextureObject::AllocateProxyTexture3D(
+  unsigned int width, unsigned int height, unsigned int depth, int numComps, int dataType)
 {
 #ifndef GL_ES_VERSION_3_0
   assert(this->Context);
@@ -1336,15 +1484,18 @@ bool vtkTextureObject::AllocateProxyTexture3D(unsigned int const width, unsigned
   vtkOpenGLCheckErrorMacro("Failed after glTexImage3D with PROXY target");
   this->Deactivate();
 
-  if (testWidth == 0)
-  {
-    return false;
-  }
-#endif
+  return testWidth != 0;
+#else
+  (void)width;
+  (void)height;
+  (void)depth;
+  (void)numComps;
+  (void)dataType;
   return true;
+#endif
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Create2DFromRaw(
   unsigned int width, unsigned int height, int numComps, int dataType, void* data)
 {
@@ -1374,7 +1525,7 @@ bool vtkTextureObject::Create2DFromRaw(
   this->Bind();
 
   // Source texture data from the PBO.
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
   glTexImage2D(this->Target, 0, this->InternalFormat, static_cast<GLsizei>(this->Width),
     static_cast<GLsizei>(this->Height), 0, this->Format, this->Type,
@@ -1386,7 +1537,7 @@ bool vtkTextureObject::Create2DFromRaw(
   return true;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::CreateCubeFromRaw(
   unsigned int width, unsigned int height, int numComps, int dataType, void* data[6])
 {
@@ -1416,7 +1567,7 @@ bool vtkTextureObject::CreateCubeFromRaw(
   this->Bind();
 
   // Source texture data from the PBO.
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
   for (int i = 0; i < 6; i++)
   {
@@ -1435,7 +1586,7 @@ bool vtkTextureObject::CreateCubeFromRaw(
   return true;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Create a 2D depth texture using a raw pointer.
 // This is a blocking call. If you can, use PBO instead.
@@ -1473,7 +1624,7 @@ bool vtkTextureObject::CreateDepthFromRaw(
   this->CreateTexture();
   this->Bind();
 
-  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+  this->Context->GetState()->vtkglPixelStorei(GL_UNPACK_ALIGNMENT, 1);
   glTexImage2D(this->Target, 0, static_cast<GLint>(this->InternalFormat),
     static_cast<GLsizei>(this->Width), static_cast<GLsizei>(this->Height), 0, this->Format,
     this->Type, raw);
@@ -1482,7 +1633,7 @@ bool vtkTextureObject::CreateDepthFromRaw(
   return true;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::AllocateDepth(unsigned int width, unsigned int height, int internalFormat)
 {
   assert("pre: context_exists" && this->GetContext() != nullptr);
@@ -1582,7 +1733,7 @@ bool vtkTextureObject::AllocateDepthStencil(unsigned int width, unsigned int hei
   return true;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 bool vtkTextureObject::Allocate1D(unsigned int width, int numComps, int vtkType)
 {
 #ifdef GL_TEXTURE_1D
@@ -1609,11 +1760,14 @@ bool vtkTextureObject::Allocate1D(unsigned int width, int numComps, int vtkType)
   this->Deactivate();
   return true;
 #else
+  (void)width;
+  (void)numComps;
+  (void)vtkType;
   return false;
 #endif
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Create a 2D color texture but does not initialize its values.
 // Internal format is deduced from numComps and vtkType.
@@ -1660,7 +1814,7 @@ bool vtkTextureObject::Allocate2D(
   return true;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Create a 3D color texture but does not initialize its values.
 // Internal format is deduced from numComps and vtkType.
@@ -1700,7 +1854,7 @@ bool vtkTextureObject::Allocate3D(
 #endif
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::CopyToFrameBuffer(vtkShaderProgram* program, vtkOpenGLVertexArrayObject* vao)
 {
   // the following math really only works when texture
@@ -1719,7 +1873,7 @@ void vtkTextureObject::CopyToFrameBuffer(vtkShaderProgram* program, vtkOpenGLVer
   this->CopyToFrameBuffer(tcoords, verts, program, vao);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::CopyToFrameBuffer(int srcXmin, int srcYmin, int srcXmax, int srcYmax,
   int dstXmin, int dstYmin, int dstSizeX, int dstSizeY, vtkShaderProgram* program,
   vtkOpenGLVertexArrayObject* vao)
@@ -1731,7 +1885,7 @@ void vtkTextureObject::CopyToFrameBuffer(int srcXmin, int srcYmin, int srcXmax,
     dstSizeX, dstSizeY, program, vao);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::CopyToFrameBuffer(int srcXmin, int srcYmin, int srcXmax, int srcYmax,
   int dstXmin, int dstYmin, int dstXmax, int dstYmax, int vtkNotUsed(dstSizeX),
   int vtkNotUsed(dstSizeY), vtkShaderProgram* program, vtkOpenGLVertexArrayObject* vao)
@@ -1821,7 +1975,7 @@ void vtkTextureObject::CopyToFrameBuffer(
   vtkOpenGLCheckErrorMacro("failed after CopyToFrameBuffer");
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Description:
 // Copy a sub-part of a logical buffer of the framebuffer (color or depth)
 // to the texture object. src is the framebuffer, dst is the texture.
@@ -1864,11 +2018,8 @@ void vtkTextureObject::CopyFromFrameBuffer(
 
     // Now blit to resolve the MSAA and get an anti-aliased rendering in
     // resolvedFBO.
-    // Note: extents are (x-min, x-max, y-min, y-max).
-    const int srcExtents[4] = { srcXmin, srcXmin + width, srcYmin, srcYmin + height };
-    const int destExtents[4] = { 0, width, 0, height };
-    vtkOpenGLFramebufferObject::Blit(
-      srcExtents, destExtents, GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+    this->Context->GetState()->vtkglBlitFramebuffer(srcXmin, srcYmin, srcXmin + width,
+      srcYmin + height, 0, 0, width, height, GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
 
     // Now make the resolvedFBO the read buffer and read from it.
     this->Context->GetState()->PushReadFramebufferBinding();
@@ -1891,7 +2042,7 @@ void vtkTextureObject::CopyFromFrameBuffer(
   vtkOpenGLCheckErrorMacro("failed at glCopyTexImage2D " << this->InternalFormat);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetMaximumTextureSize(vtkOpenGLRenderWindow* context)
 {
   int maxSize = -1;
@@ -1903,7 +2054,7 @@ int vtkTextureObject::GetMaximumTextureSize(vtkOpenGLRenderWindow* context)
   return maxSize;
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetMaximumTextureSize3D(vtkOpenGLRenderWindow* context)
 {
   GLint maxSize = -1;
@@ -1915,14 +2066,14 @@ int vtkTextureObject::GetMaximumTextureSize3D(vtkOpenGLRenderWindow* context)
   return static_cast<int>(maxSize);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkTextureObject::GetMaximumTextureSize3D()
 {
   assert("Context == nullptr" && this->Context);
   return vtkTextureObject::GetMaximumTextureSize3D(this->Context);
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::Resize(unsigned int width, unsigned int height)
 {
   if (this->Width == width && this->Height == height)
@@ -1970,7 +2121,7 @@ void vtkTextureObject::Resize(unsigned int width, unsigned int height)
   this->Deactivate();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkTextureObject::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
@@ -2026,3 +2177,4 @@ void vtkTextureObject::PrintSelf(ostream& os, vtkIndent indent)
      << DepthTextureCompareFunctionAsString[this->DepthTextureCompareFunction] << endl;
   os << indent << "GenerateMipmap: " << this->GenerateMipmap << endl;
 }
+VTK_ABI_NAMESPACE_END
