@@ -1,20 +1,11 @@
-/*=========================================================================
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
-  Program:   Visualization Toolkit
-  Module:    vtkXOpenGLRenderWindow.cxx
+// Must be included first to avoid conflicts with X11's `Status` define.
+#include "vtksys/SystemTools.hxx"
 
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-
-#include "vtkXOpenGLRenderWindow.h"
 #include "vtkOpenGLRenderer.h"
+#include "vtkXOpenGLRenderWindow.h"
 
 #include "vtk_glew.h"
 // Define GLX_GLXEXT_LEGACY to prevent glx.h from including the glxext.h
@@ -47,6 +38,7 @@ typedef ptrdiff_t GLsizeiptr;
 
 #include "vtkCommand.h"
 #include "vtkIdList.h"
+#include "vtkImageData.h"
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkOpenGLShaderCache.h"
@@ -56,14 +48,26 @@ typedef ptrdiff_t GLsizeiptr;
 #include "vtkRenderWindowInteractor.h"
 #include "vtkRendererCollection.h"
 #include "vtkStringOutputWindow.h"
-#include "vtkToolkits.h"
-#include "vtksys/SystemTools.hxx"
 
 #include <sstream>
 
+#include <X11/Xatom.h>
+#include <X11/cursorfont.h>
+#if VTK_HAVE_XCURSOR
+#include <X11/Xcursor/Xcursor.h>
+#endif
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <X11/cursorfont.h>
+
+/*
+ * Work-around to get forward declarations of C typedef of anonymous
+ * structs working. We do not want to include XUtil.h in the header as
+ * it populates the global namespace.
+ */
+VTK_ABI_NAMESPACE_BEGIN
+struct vtkXVisualInfo : public XVisualInfo
+{
+};
 
 #define GLX_CONTEXT_MAJOR_VERSION_ARB 0x2091
 #define GLX_CONTEXT_MINOR_VERSION_ARB 0x2092
@@ -219,12 +223,13 @@ GLXFBConfig vtkXOpenGLRenderWindowGetDesiredFBConfig(Display* DisplayId, vtkType
 }
 
 template <int EventType>
-int XEventTypeEquals(Display*, XEvent* event, XPointer)
+int XEventTypeEquals(Display*, XEvent* event, XPointer winptr)
 {
-  return event->type == EventType;
+  return (event->type == EventType &&
+    *(reinterpret_cast<Window*>(winptr)) == reinterpret_cast<XAnyEvent*>(event)->window);
 }
 
-XVisualInfo* vtkXOpenGLRenderWindow::GetDesiredVisualInfo()
+vtkXVisualInfo* vtkXOpenGLRenderWindow::GetDesiredVisualInfo()
 {
   XVisualInfo* v = nullptr;
 
@@ -258,7 +263,7 @@ XVisualInfo* vtkXOpenGLRenderWindow::GetDesiredVisualInfo()
       vtkErrorMacro(<< "Could not find a decent visual\n");
     }
   }
-  return (v);
+  return reinterpret_cast<vtkXVisualInfo*>(v);
 }
 
 vtkXOpenGLRenderWindow::vtkXOpenGLRenderWindow()
@@ -286,6 +291,7 @@ vtkXOpenGLRenderWindow::vtkXOpenGLRenderWindow()
   this->XCSizeSE = 0;
   this->XCSizeSW = 0;
   this->XCHand = 0;
+  this->XCCustom = 0;
 }
 
 // free up memory & close the window
@@ -391,7 +397,8 @@ void vtkXOpenGLRenderWindow::SetShowWindow(bool val)
       if (winattr.map_state == IsUnmapped)
       {
         XEvent e;
-        XIfEvent(this->DisplayId, &e, XEventTypeEquals<MapNotify>, nullptr);
+        XIfEvent(this->DisplayId, &e, XEventTypeEquals<MapNotify>,
+          reinterpret_cast<XPointer>(&this->WindowId));
       }
       this->Mapped = 1;
     }
@@ -406,7 +413,8 @@ void vtkXOpenGLRenderWindow::SetShowWindow(bool val)
       if (winattr.map_state != IsUnmapped)
       {
         XEvent e;
-        XIfEvent(this->DisplayId, &e, XEventTypeEquals<UnmapNotify>, nullptr);
+        XIfEvent(this->DisplayId, &e, XEventTypeEquals<UnmapNotify>,
+          reinterpret_cast<XPointer>(&this->WindowId));
       }
       this->Mapped = 0;
     }
@@ -431,8 +439,8 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
     xsh.y = static_cast<int>(this->Position[1]);
   }
 
-  x = ((this->Position[0] >= 0) ? this->Position[0] : 5);
-  y = ((this->Position[1] >= 0) ? this->Position[1] : 5);
+  x = this->Position[0];
+  y = this->Position[1];
   width = ((this->Size[0] > 0) ? this->Size[0] : 300);
   height = ((this->Size[1] > 0) ? this->Size[1] : 300);
 
@@ -560,7 +568,10 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
         (const GLubyte*)"glXCreateContextAttribsARB");
 
     int context_attribs[] = { GLX_CONTEXT_MAJOR_VERSION_ARB, 3, GLX_CONTEXT_MINOR_VERSION_ARB, 2,
-      // GLX_CONTEXT_FLAGS_ARB        , GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB,
+    // GLX_CONTEXT_FLAGS_ARB        , GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB,
+#ifdef GL_ES_VERSION_3_0
+      GLX_CONTEXT_PROFILE_MASK_ARB, GLX_CONTEXT_ES_PROFILE_BIT_EXT,
+#endif
       0 };
 
     if (glXCreateContextAttribsARB)
@@ -582,7 +593,12 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
 
       // we believe that these later versions are all compatible with
       // OpenGL 3.2 so get a more recent context if we can.
+      // For GLES, version 3.0 is best supported by VTK shaders.
+#ifdef GL_ES_VERSION_3_0
+      int attemptedVersions[] = { 3, 0 };
+#else
       int attemptedVersions[] = { 4, 5, 4, 4, 4, 3, 4, 2, 4, 1, 4, 0, 3, 3, 3, 2 };
+#endif
 
       // try shared context first, the fallback to not shared
       bool done = false;
@@ -650,7 +666,8 @@ void vtkXOpenGLRenderWindow::CreateAWindow()
     XMapWindow(this->DisplayId, this->WindowId);
     XSync(this->DisplayId, False);
     XEvent e;
-    XIfEvent(this->DisplayId, &e, XEventTypeEquals<MapNotify>, nullptr);
+    XIfEvent(this->DisplayId, &e, XEventTypeEquals<MapNotify>,
+      reinterpret_cast<XPointer>(&this->WindowId));
     XGetWindowAttributes(this->DisplayId, this->WindowId, &winattr);
     // if the specified window size is bigger than the screen size,
     // we have to reset the window size to the screen size
@@ -728,6 +745,10 @@ void vtkXOpenGLRenderWindow::DestroyWindow()
     {
       XFreeCursor(this->DisplayId, this->XCHand);
     }
+    if (this->XCCustom)
+    {
+      XFreeCursor(this->DisplayId, this->XCCustom);
+    }
   }
 
   this->XCCrosshair = 0;
@@ -740,6 +761,7 @@ void vtkXOpenGLRenderWindow::DestroyWindow()
   this->XCSizeSE = 0;
   this->XCSizeSW = 0;
   this->XCHand = 0;
+  this->XCCustom = 0;
 
   if (this->OwnContext && this->Internal->ContextId)
   {
@@ -784,7 +806,7 @@ void vtkXOpenGLRenderWindow::DestroyWindow()
 }
 
 // Initialize the window for rendering.
-void vtkXOpenGLRenderWindow::WindowInitialize(void)
+void vtkXOpenGLRenderWindow::WindowInitialize()
 {
   this->CreateAWindow();
 
@@ -802,7 +824,7 @@ void vtkXOpenGLRenderWindow::WindowInitialize(void)
 }
 
 // Initialize the rendering window.
-void vtkXOpenGLRenderWindow::Initialize(void)
+void vtkXOpenGLRenderWindow::Initialize()
 {
   if (!this->Internal->ContextId)
   {
@@ -811,7 +833,7 @@ void vtkXOpenGLRenderWindow::Initialize(void)
   }
 }
 
-void vtkXOpenGLRenderWindow::Finalize(void)
+void vtkXOpenGLRenderWindow::Finalize()
 {
   // clean and destroy window
   this->DestroyWindow();
@@ -915,7 +937,7 @@ void vtkXOpenGLRenderWindow::WindowRemap()
 }
 
 // Begin the rendering process.
-void vtkXOpenGLRenderWindow::Start(void)
+void vtkXOpenGLRenderWindow::Start()
 {
   this->Initialize();
 
@@ -942,20 +964,62 @@ void vtkXOpenGLRenderWindow::SetSize(int width, int height)
         this->Interactor->SetSize(width, height);
       }
 
+      // get baseline serial number for X requests generated from XResizeWindow
+      unsigned long serial = NextRequest(this->DisplayId);
+
+      // request a new window size from the X server
       XResizeWindow(this->DisplayId, this->WindowId, static_cast<unsigned int>(width),
         static_cast<unsigned int>(height));
-      // this is an async call so we wait until we know it has been resized.
+
+      // flush output queue and wait for X server to processes the request
       XSync(this->DisplayId, False);
-      XWindowAttributes attribs;
-      XGetWindowAttributes(this->DisplayId, this->WindowId, &attribs);
-      if (attribs.width != width || attribs.height != height)
+
+      // The documentation for XResizeWindow includes this important note:
+      //
+      //   If the override-redirect flag of the window is False and some
+      //   other client has selected SubstructureRedirectMask on the parent,
+      //   the X server generates a ConfigureRequest event, and no further
+      //   processing is performed.
+      //
+      // What this means, essentially, is that if this window is a top-level
+      // window, then it's the window manager (the "other client") that is
+      // responsible for changing this window's size.  So when we call
+      // XResizeWindow() on a top-level window, then instead of resizing
+      // the window immediately, the X server informs the window manager,
+      // and then the window manager sets our new size (usually it will be
+      // the size we asked for).  We receive a ConfigureNotify event when
+      // our new size has been set.
+
+      // check our override-redirect flag
+      XWindowAttributes attrs;
+      XGetWindowAttributes(this->DisplayId, this->WindowId, &attrs);
+      if (!attrs.override_redirect && this->ParentId)
       {
-        XEvent e;
-        XIfEvent(this->DisplayId, &e, XEventTypeEquals<ConfigureNotify>, nullptr);
+        // check if parent has SubstructureRedirectMask
+        XWindowAttributes parentAttrs;
+        XGetWindowAttributes(this->DisplayId, this->ParentId, &parentAttrs);
+        if ((parentAttrs.all_event_masks & SubstructureRedirectMask) == SubstructureRedirectMask)
+        {
+          // set the wait timeout to be 2 seconds from now
+          double maxtime = 2.0 + vtksys::SystemTools::GetTime();
+          // look for a ConfigureNotify that came *after* XResizeWindow
+          XEvent e;
+          while (!XCheckIfEvent(this->DisplayId, &e, XEventTypeEquals<ConfigureNotify>,
+                   reinterpret_cast<XPointer>(&this->WindowId)) ||
+            e.xconfigure.serial < serial)
+          {
+            // wait for 10 milliseconds and try again until time runs out
+            vtksys::SystemTools::Delay(10);
+            if (vtksys::SystemTools::GetTime() > maxtime)
+            {
+              vtkWarningMacro(<< "Timeout while waiting for response to XResizeWindow.");
+              return;
+            }
+          }
+          XPutBackEvent(this->DisplayId, &e);
+        }
       }
     }
-
-    this->Modified();
   }
 }
 
@@ -1086,7 +1150,16 @@ void vtkXOpenGLRenderWindow::MakeCurrent()
   }
 }
 
-// ----------------------------------------------------------------------------
+void vtkXOpenGLRenderWindow::ReleaseCurrent()
+{
+  if (this->Internal->ContextId && (this->Internal->ContextId == glXGetCurrentContext()) &&
+    this->DisplayId)
+  {
+    glXMakeCurrent(this->DisplayId, None, nullptr);
+  }
+}
+
+//------------------------------------------------------------------------------
 // Description:
 // Tells if this window is the current OpenGL context for the calling thread.
 bool vtkXOpenGLRenderWindow::IsCurrent()
@@ -1156,6 +1229,11 @@ void* vtkXOpenGLRenderWindow::GetGenericContext()
   return static_cast<void*>(gc);
 }
 
+void* vtkXOpenGLRenderWindow::GetGenericFBConfig()
+{
+  return reinterpret_cast<void*>(&(this->Internal->FBConfig));
+}
+
 vtkTypeBool vtkXOpenGLRenderWindow::GetEventPending()
 {
   XEvent report;
@@ -1196,7 +1274,7 @@ int* vtkXOpenGLRenderWindow::GetScreenSize()
 }
 
 // Get the position in screen coordinates (pixels) of the window.
-int* vtkXOpenGLRenderWindow::GetPosition(void)
+int* vtkXOpenGLRenderWindow::GetPosition()
 {
   XWindowAttributes attribs;
   int x, y;
@@ -1430,9 +1508,11 @@ void vtkXOpenGLRenderWindow::CloseDisplay()
   if (this->OwnDisplay && this->DisplayId)
   {
     XCloseDisplay(this->DisplayId);
-    this->DisplayId = nullptr;
-    this->OwnDisplay = 0;
   }
+
+  // disconnect from the display, even if we didn't own it
+  this->DisplayId = nullptr;
+  this->OwnDisplay = false;
 }
 
 vtkTypeBool vtkXOpenGLRenderWindow::IsDirect()
@@ -1471,6 +1551,50 @@ void vtkXOpenGLRenderWindow::SetWindowName(const char* cname)
   delete[] name;
 }
 
+void vtkXOpenGLRenderWindow::SetIcon(vtkImageData* img)
+{
+  int dim[3];
+  img->GetDimensions(dim);
+
+  int nbComp = img->GetNumberOfScalarComponents();
+
+  if (img->GetScalarType() != VTK_UNSIGNED_CHAR || dim[2] != 1 || nbComp < 3 || nbComp > 4)
+  {
+    vtkErrorMacro(
+      "Icon image should be 2D, have 3 or 4 components, and its type must be unsigned char.");
+    return;
+  }
+
+  unsigned char* imgScalars = static_cast<unsigned char*>(img->GetScalarPointer());
+
+  std::vector<unsigned long> pixels(2 + dim[0] * dim[1]);
+  pixels[0] = dim[0];
+  pixels[1] = dim[1];
+
+  // Convert vtkImageData buffer to X icon.
+  // We need to flip Y and use ARGB 32-bits encoded convention
+  for (int col = 0; col < dim[1]; col++)
+  {
+    for (int line = 0; line < dim[0]; line++)
+    {
+      unsigned char* inPixel = imgScalars + nbComp * ((dim[0] - col - 1) * dim[1] + line); // flip Y
+      unsigned long* outPixel = pixels.data() + col * dim[1] + line + 2;
+      if (nbComp == 4)
+      {
+        *outPixel = nbComp == 4 ? inPixel[3] : 0xff;
+      }
+      *outPixel = (*outPixel << 8) + inPixel[0];
+      *outPixel = (*outPixel << 8) + inPixel[1];
+      *outPixel = (*outPixel << 8) + inPixel[2];
+    }
+  }
+
+  Atom iconAtom = XInternAtom(this->DisplayId, "_NET_WM_ICON", False);
+  Atom typeAtom = XInternAtom(this->DisplayId, "CARDINAL", False);
+  XChangeProperty(this->DisplayId, this->WindowId, iconAtom, typeAtom, 32, PropModeReplace,
+    reinterpret_cast<unsigned char*>(pixels.data()), pixels.size());
+}
+
 // Specify the X window id to use if a WindowRemap is done.
 void vtkXOpenGLRenderWindow::SetNextWindowId(Window arg)
 {
@@ -1519,7 +1643,7 @@ void vtkXOpenGLRenderWindow::Render()
   this->vtkOpenGLRenderWindow::Render();
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXOpenGLRenderWindow::HideCursor()
 {
   static char blankBits[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -1547,7 +1671,7 @@ void vtkXOpenGLRenderWindow::HideCursor()
   }
 }
 
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkXOpenGLRenderWindow::ShowCursor()
 {
   if (!this->DisplayId || !this->WindowId)
@@ -1657,5 +1781,26 @@ void vtkXOpenGLRenderWindow::SetCurrentCursor(int shape)
       }
       XDefineCursor(this->DisplayId, this->WindowId, this->XCHand);
       break;
+    case VTK_CURSOR_CUSTOM:
+#if VTK_HAVE_XCURSOR
+      this->XCCustom = XcursorFilenameLoadCursor(this->DisplayId, this->GetCursorFileName());
+      if (!this->XCCustom)
+      {
+        vtkErrorMacro(<< "Failed to load cursor from Xcursor file: " << this->GetCursorFileName());
+        break;
+      }
+      XDefineCursor(this->DisplayId, this->WindowId, this->XCCustom);
+#else
+    {
+      static bool once = false;
+      if (!once)
+      {
+        once = true;
+        vtkWarningMacro("VTK built without Xcursor support; ignoring requests for custom cursors.");
+      }
+    }
+#endif
+      break;
   }
 }
+VTK_ABI_NAMESPACE_END
