@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkPSurfaceLICComposite.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 #include "vtkPSurfaceLICComposite.h"
 
 #include "vtkMPI.h"
@@ -66,7 +54,7 @@ using std::vector;
 #include <sstream>
 using std::ostringstream;
 using std::string;
-//----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static string mpifn(int rank, const char* fn)
 {
   ostringstream oss;
@@ -133,6 +121,7 @@ static void MPIAPI vtkPixelExtentUnion(void* in, void* out, int* len, MPI_Dataty
   }
 }
 
+VTK_ABI_NAMESPACE_BEGIN
 // Description:
 // Container for our custom MPI_Op's
 class vtkPPixelExtentOps
@@ -160,13 +149,13 @@ private:
   MPI_Op Union;
 };
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPPixelExtentOps::~vtkPPixelExtentOps()
 {
   this->DeleteOps();
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPPixelExtentOps::CreateOps()
 {
   if ((this->Union == MPI_OP_NULL) && vtkPPainterCommunicator::MPIInitialized())
@@ -175,7 +164,7 @@ void vtkPPixelExtentOps::CreateOps()
   }
 }
 
-// ---------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPPixelExtentOps::DeleteOps()
 {
   if ((this->Union != MPI_OP_NULL) && vtkPPainterCommunicator::MPIInitialized() &&
@@ -194,9 +183,10 @@ void MPITypeFree(deque<MPI_Datatype>& types)
     MPI_Type_free(&types[i]);
   }
 }
+VTK_ABI_NAMESPACE_END
 
 // ****************************************************************************
-static size_t Size(deque<deque<vtkPixelExtent> > exts)
+static size_t Size(deque<deque<vtkPixelExtent>> exts)
 {
   size_t np = 0;
   size_t nr = exts.size();
@@ -214,7 +204,7 @@ static size_t Size(deque<deque<vtkPixelExtent> > exts)
 
 #if vtkPSurfaceLICCompositeDEBUG >= 1 || defined(vtkSurfaceLICPainterTIME)
 // ****************************************************************************
-static int NumberOfExtents(deque<deque<vtkPixelExtent> > exts)
+static int NumberOfExtents(deque<deque<vtkPixelExtent>> exts)
 {
   size_t ne = 0;
   size_t nr = exts.size();
@@ -243,7 +233,7 @@ static ostream& operator<<(ostream& os, const vector<float>& vf)
 }
 
 // ****************************************************************************
-static ostream& operator<<(ostream& os, const vector<vector<float> >& vvf)
+static ostream& operator<<(ostream& os, const vector<vector<float>>& vvf)
 {
   size_t n = vvf.size();
   for (size_t i = 0; i < n; ++i)
@@ -275,13 +265,13 @@ static int ScanMPIStatusForError(vector<MPI_Status>& stat)
 }
 #endif
 
-//-----------------------------------------------------------------------------
+VTK_ABI_NAMESPACE_BEGIN
+//------------------------------------------------------------------------------
 vtkStandardNewMacro(vtkPSurfaceLICComposite);
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPSurfaceLICComposite::vtkPSurfaceLICComposite()
-  : vtkSurfaceLICComposite()
-  , PainterComm(nullptr)
+  : PainterComm(nullptr)
   , PixelOps(nullptr)
   , CommRank(0)
   , CommSize(1)
@@ -293,7 +283,7 @@ vtkPSurfaceLICComposite::vtkPSurfaceLICComposite()
   this->PixelOps = new vtkPPixelExtentOps;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 vtkPSurfaceLICComposite::~vtkPSurfaceLICComposite()
 {
   delete this->PainterComm;
@@ -301,7 +291,7 @@ vtkPSurfaceLICComposite::~vtkPSurfaceLICComposite()
   if (this->CompositeShader)
   {
     delete this->CompositeShader;
-    this->CompositeShader = 0;
+    this->CompositeShader = nullptr;
   }
   if (this->FBO)
   {
@@ -309,7 +299,7 @@ vtkPSurfaceLICComposite::~vtkPSurfaceLICComposite()
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPSurfaceLICComposite::SetCommunicator(vtkPainterCommunicator* comm)
 {
 #if DUPLICATE_COMMUNICATOR
@@ -324,7 +314,7 @@ void vtkPSurfaceLICComposite::SetCommunicator(vtkPainterCommunicator* comm)
   this->PixelOps->CreateOps();
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPSurfaceLICComposite::SetContext(vtkOpenGLRenderWindow* rwin)
 {
   if (this->Context == rwin)
@@ -362,9 +352,9 @@ void vtkPSurfaceLICComposite::SetContext(vtkOpenGLRenderWindow* rwin)
   }
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::AllGatherExtents(const deque<vtkPixelExtent>& localExts,
-  deque<deque<vtkPixelExtent> >& remoteExts, vtkPixelExtent& dataSetExt)
+  deque<deque<vtkPixelExtent>>& remoteExts, vtkPixelExtent& dataSetExt)
 {
 #if vtkPSurfaceLICCompositeDEBUG >= 2
   cerr << "=====vtkPSurfaceLICComposite::AllGatherExtents" << endl;
@@ -428,11 +418,11 @@ int vtkPSurfaceLICComposite::AllGatherExtents(const deque<vtkPixelExtent>& local
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::AllReduceVectorMax(
-  const deque<vtkPixelExtent>& originalExts,    // local data
-  const deque<deque<vtkPixelExtent> >& newExts, // all composited regions
-  float* vectors, vector<vector<float> >& vectorMax)
+  const deque<vtkPixelExtent>& originalExts,   // local data
+  const deque<deque<vtkPixelExtent>>& newExts, // all composited regions
+  float* vectors, vector<vector<float>>& vectorMax)
 {
 #if vtkPSurfaceLICCompositeDEBUG >= 2
   cerr << "=====vtkPSurfaceLICComposite::AllReduceVectorMax" << endl;
@@ -444,11 +434,11 @@ int vtkPSurfaceLICComposite::AllReduceVectorMax(
   // the true value.
   size_t nOriginal = originalExts.size();
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
-  vector<vector<float> > tmpMax(this->CommSize);
+  vector<vector<float>> tmpMax(this->CommSize);
   for (int r = 0; r < this->CommSize; ++r)
   {
     // check the intersection of each new extent with that of each
-    // original extent. data for origial extent is local.
+    // original extent. data for original extent is local.
     size_t nNew = newExts[r].size();
     tmpMax[r].resize(nNew, -VTK_FLOAT_MAX);
     for (size_t n = 0; n < nNew; ++n)
@@ -512,7 +502,7 @@ int vtkPSurfaceLICComposite::AllReduceVectorMax(
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::DecomposeExtent(
   vtkPixelExtent& in, int nPieces, list<vtkPixelExtent>& out)
 {
@@ -531,7 +521,7 @@ int vtkPSurfaceLICComposite::DecomposeExtent(
   list<vtkPixelExtent> splitExts;
 
   int dir = 0;
-  while (1)
+  while (true)
   {
     // stop when we have enough out or all out have unit size
     int nExts = static_cast<int>(out.size());
@@ -580,9 +570,9 @@ int vtkPSurfaceLICComposite::DecomposeExtent(
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::DecomposeScreenExtent(
-  deque<deque<vtkPixelExtent> >& newExts, float* vectors)
+  deque<deque<vtkPixelExtent>>& newExts, float* vectors)
 {
 #if vtkPSurfaceLICCompositeDEBUG >= 2
   cerr << "=====vtkPSurfaceLICComposite::DecomposeWindowExtent" << endl;
@@ -613,7 +603,7 @@ int vtkPSurfaceLICComposite::DecomposeScreenExtent(
   int nPer = nPieces / this->CommSize;
   int nLarge = nPieces % this->CommSize;
 
-  deque<deque<vtkPixelExtent> > tmpOut1;
+  deque<deque<vtkPixelExtent>> tmpOut1;
   tmpOut1.resize(this->CommSize);
 
   int N = static_cast<int>(tmpOut0.size());
@@ -641,9 +631,9 @@ int vtkPSurfaceLICComposite::DecomposeScreenExtent(
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::MakeDecompLocallyDisjoint(
-  const deque<deque<vtkPixelExtent> >& in, deque<deque<vtkPixelExtent> >& out)
+  const deque<deque<vtkPixelExtent>>& in, deque<deque<vtkPixelExtent>>& out)
 {
   size_t nr = in.size();
   out.clear();
@@ -651,17 +641,17 @@ int vtkPSurfaceLICComposite::MakeDecompLocallyDisjoint(
   for (size_t r = 0; r < nr; ++r)
   {
     deque<vtkPixelExtent> tmp(in[r]);
-    this->MakeDecompDisjoint(tmp, out[r]);
+    vtkPSurfaceLICComposite::MakeDecompDisjoint(tmp, out[r]);
   }
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::MakeDecompDisjoint(
-  const deque<deque<vtkPixelExtent> >& in, deque<deque<vtkPixelExtent> >& out, float* vectors)
+  const deque<deque<vtkPixelExtent>>& in, deque<deque<vtkPixelExtent>>& out, float* vectors)
 {
   // flatten
-  deque<pair<int, vtkPixelExtent> > tmpIn;
+  deque<pair<int, vtkPixelExtent>> tmpIn;
   for (int r = 0; r < this->CommSize; ++r)
   {
     const deque<vtkPixelExtent>& blocks = in[r];
@@ -677,7 +667,7 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
 
   // from largest to smallest, make it disjoint
   // to others
-  deque<pair<int, vtkPixelExtent> > tmpOut0;
+  deque<pair<int, vtkPixelExtent>> tmpOut0;
 
   while (!tmpIn.empty())
   {
@@ -720,7 +710,7 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   const deque<vtkPixelExtent>& inR = in[this->CommRank];
   size_t ni = inR.size();
 
-  deque<pair<int, vtkPixelExtent> > tmpOut1(tmpOut0);
+  deque<pair<int, vtkPixelExtent>> tmpOut1(tmpOut0);
   size_t ne = tmpOut1.size();
   for (size_t e = 0; e < ne; ++e)
   {
@@ -742,18 +732,18 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   // accumulate contrib from remote data
   size_t remSize = 4 * ne;
   vector<int> rem(remSize);
-  int* pRem = ne ? &rem[0] : nullptr;
+  int* pRem = ne ? rem.data() : nullptr;
   for (size_t e = 0; e < ne; ++e, pRem += 4)
   {
     tmpOut1[e].second.GetData(pRem);
   }
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
   MPI_Op parUnion = this->PixelOps->GetUnion();
-  MPI_Allreduce(MPI_IN_PLACE, ne ? &rem[0] : nullptr, (int)remSize, MPI_INT, parUnion, comm);
+  MPI_Allreduce(MPI_IN_PLACE, ne ? rem.data() : nullptr, (int)remSize, MPI_INT, parUnion, comm);
 
   // move from flat order back to rank indexed order and remove
   // empty extents
-  pRem = ne ? &rem[0] : nullptr;
+  pRem = ne ? rem.data() : nullptr;
   out.resize(this->CommSize);
   for (size_t e = 0; e < ne; ++e, pRem += 4)
   {
@@ -774,9 +764,9 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   return 0;
 }
 
-// ----------------------------------------------------------------------------
-int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent> >& exts,
-  deque<deque<vtkPixelExtent> >& guardExts, deque<deque<vtkPixelExtent> >& disjointGuardExts,
+//------------------------------------------------------------------------------
+int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent>>& exts,
+  deque<deque<vtkPixelExtent>>& guardExts, deque<deque<vtkPixelExtent>>& disjointGuardExts,
   float* vectors)
 {
 #if vtkPSurfaceLICCompositeDEBUG >= 2
@@ -823,7 +813,7 @@ int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent> >&
       guardExts[r] = tmpExts;
       // make sure it's disjoint
       disjointGuardExts[r].clear();
-      this->MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
+      vtkPSurfaceLICComposite::MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
     }
   }
   else
@@ -831,7 +821,7 @@ int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent> >&
     // when not normailzing during integration we need max(V) on the LIC
     // decomp. Each domain has the potential to require a unique number
     // of guard cells.
-    vector<vector<float> > vectorMax;
+    vector<vector<float>> vectorMax;
     this->AllReduceVectorMax(this->BlockExts, exts, vectors, vectorMax);
 
 #ifdef vtkSurfaceLICPainterTIME
@@ -861,7 +851,7 @@ int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent> >&
       guardExts[r] = tmpExts;
       // make sure it's disjoint
       disjointGuardExts[r].clear();
-      this->MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
+      vtkPSurfaceLICComposite::MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
     }
 #ifdef vtkSurfaceLICPainterTIME
     log->GetHeader() << "\n";
@@ -874,9 +864,9 @@ int vtkPSurfaceLICComposite::AddGuardPixels(const deque<deque<vtkPixelExtent> >&
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkPSurfaceLICComposite::EstimateCommunicationCost(
-  const deque<deque<vtkPixelExtent> >& srcExts, const deque<deque<vtkPixelExtent> >& destExts)
+  const deque<deque<vtkPixelExtent>>& srcExts, const deque<deque<vtkPixelExtent>>& destExts)
 {
   // compute the number off rank overlapping pixels, this is the
   // the number of pixels that need to be communicated. This is
@@ -919,9 +909,9 @@ double vtkPSurfaceLICComposite::EstimateCommunicationCost(
   return (static_cast<double>(overlap)) / (static_cast<double>(total));
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 double vtkPSurfaceLICComposite::EstimateDecompEfficiency(
-  const deque<deque<vtkPixelExtent> >& exts, const deque<deque<vtkPixelExtent> >& guardExts)
+  const deque<deque<vtkPixelExtent>>& exts, const deque<deque<vtkPixelExtent>>& guardExts)
 {
   // number of pixels in the domain decomp
   double ne = static_cast<double>(Size(exts));
@@ -932,7 +922,7 @@ double vtkPSurfaceLICComposite::EstimateDecompEfficiency(
   return ne / fabs(ne - nge);
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
 {
 #if vtkPSurfaceLICCompositeDEBUG >= 2
@@ -944,7 +934,7 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
 #endif
 
   // gather current geometry extents, compute the whole extent
-  deque<deque<vtkPixelExtent> > allBlockExts;
+  deque<deque<vtkPixelExtent>> allBlockExts;
   this->AllGatherExtents(this->BlockExts, allBlockExts, this->DataSetExt);
 
   if (this->Strategy == COMPOSITE_AUTO)
@@ -979,7 +969,7 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
   }
 
   // decompose the screen
-  deque<deque<vtkPixelExtent> > newExts;
+  deque<deque<vtkPixelExtent>> newExts;
   switch (this->Strategy)
   {
     case COMPOSITE_INPLACE:
@@ -1041,8 +1031,8 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
 
             if (!sharedExt.Empty())
             {
-              this->ScatterProgram.push_back(vtkPPixelTransfer(
-                srcRank, this->WindowExt, sharedExt, destRank, this->WindowExt, sharedExt, id));
+              this->ScatterProgram.emplace_back(
+                srcRank, this->WindowExt, sharedExt, destRank, this->WindowExt, sharedExt, id);
             }
             id += 1;
           }
@@ -1058,8 +1048,8 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
 #endif
 
   // add guard cells to the new decomp that prevent artifacts
-  deque<deque<vtkPixelExtent> > guardExts;
-  deque<deque<vtkPixelExtent> > disjointGuardExts;
+  deque<deque<vtkPixelExtent>> guardExts;
+  deque<deque<vtkPixelExtent>> disjointGuardExts;
   this->AddGuardPixels(newExts, guardExts, disjointGuardExts, vectors);
 
 #if vtkPSurfaceLICCompositeDEBUG >= 1
@@ -1111,10 +1101,9 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
           {
             // to move vectors for the LIC decomp
             // into a contiguous recv buffer
-            this->GatherProgram.push_back(
-              vtkPPixelTransfer(srcRank, this->WindowExt, sharedExt, destRank,
-                sharedExt, // dest ext
-                sharedExt, id));
+            this->GatherProgram.emplace_back(srcRank, this->WindowExt, sharedExt, destRank,
+              sharedExt, // dest ext
+              sharedExt, id);
           }
 
           id += 1;
@@ -1130,7 +1119,7 @@ int vtkPSurfaceLICComposite::BuildProgram(float* vectors)
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::Gather(
   void* pSendPBO, int dataType, int nComps, vtkTextureObject*& newImage)
 {
@@ -1138,7 +1127,7 @@ int vtkPSurfaceLICComposite::Gather(
   cerr << "=====vtkPSurfaceLICComposite::Composite" << endl;
 #endif
 
-  // two pipleines depending on if this process recv's or send's
+  // two pipelines depending on if this process recv's or send's
   //
   // send:
   // tex -> pbo -> mpi_send
@@ -1347,7 +1336,7 @@ int vtkPSurfaceLICComposite::Gather(
     // wait for the completion of one of the recvs
     MPI_Status stat;
     int reqId;
-    int iErr = MPI_Waitany(nRecvReqs, &mpiRecvReqs[0], &reqId, &stat);
+    int iErr = MPI_Waitany(nRecvReqs, mpiRecvReqs.data(), &reqId, &stat);
     if (iErr)
     {
       vtkErrorMacro("comm error in recv");
@@ -1420,7 +1409,7 @@ int vtkPSurfaceLICComposite::Gather(
   int nSendReqs = static_cast<int>(mpiSendReqs.size());
   if (nSendReqs)
   {
-    int iErr = MPI_Waitall(nSendReqs, &mpiSendReqs[0], MPI_STATUSES_IGNORE);
+    int iErr = MPI_Waitall(nSendReqs, mpiSendReqs.data(), MPI_STATUSES_IGNORE);
     if (iErr)
     {
       vtkErrorMacro("comm error in send");
@@ -1432,7 +1421,7 @@ int vtkPSurfaceLICComposite::Gather(
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::ExecuteShader(const vtkPixelExtent& ext, vtkTextureObject* tex)
 {
   // cell to node
@@ -1463,7 +1452,7 @@ int vtkPSurfaceLICComposite::ExecuteShader(const vtkPixelExtent& ext, vtkTexture
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int vtkPSurfaceLICComposite::Scatter(
   void* pSendPBO, int dataType, int nComps, vtkTextureObject*& newImage)
 {
@@ -1472,7 +1461,7 @@ int vtkPSurfaceLICComposite::Scatter(
 #endif
 
   int iErr = 0;
-  // two pipleines depending on if this process recv's or send's
+  // two pipelines depending on if this process recv's or send's
   //
   // send:
   // tex -> pbo -> mpi_send
@@ -1597,7 +1586,7 @@ int vtkPSurfaceLICComposite::Scatter(
   int nRecvReqs = static_cast<int>(mpiRecvReqs.size());
   if (nRecvReqs)
   {
-    iErr = MPI_Waitall(nRecvReqs, &mpiRecvReqs[0], MPI_STATUSES_IGNORE);
+    iErr = MPI_Waitall(nRecvReqs, mpiRecvReqs.data(), MPI_STATUSES_IGNORE);
     if (iErr)
     {
       vtkErrorMacro("comm error in recv");
@@ -1637,7 +1626,7 @@ int vtkPSurfaceLICComposite::Scatter(
   int nSendReqs = static_cast<int>(mpiSendReqs.size());
   if (nSendReqs)
   {
-    iErr = MPI_Waitall(nSendReqs, &mpiSendReqs[0], MPI_STATUSES_IGNORE);
+    iErr = MPI_Waitall(nSendReqs, mpiSendReqs.data(), MPI_STATUSES_IGNORE);
     if (iErr)
     {
       vtkErrorMacro("comm error in send");
@@ -1649,10 +1638,10 @@ int vtkPSurfaceLICComposite::Scatter(
   return 0;
 }
 
-// ----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 void vtkPSurfaceLICComposite::PrintSelf(ostream& os, vtkIndent indent)
 {
-  vtkObject::PrintSelf(os, indent);
+  Superclass::PrintSelf(os, indent);
   os << *this << endl;
 }
 
@@ -1708,3 +1697,4 @@ ostream& operator<<(ostream& os, vtkPSurfaceLICComposite& ss)
   }
   return os;
 }
+VTK_ABI_NAMESPACE_END
