@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkDirectionEncoder.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 /**
  * @class   vtkDirectionEncoder
@@ -36,16 +24,17 @@
 #include "vtkObject.h"
 #include "vtkRenderingVolumeModule.h" // For export macro
 
+VTK_ABI_NAMESPACE_BEGIN
 class VTKRENDERINGVOLUME_EXPORT vtkDirectionEncoder : public vtkObject
 {
 public:
-  //@{
+  ///@{
   /**
    * Get the name of this class
    */
   vtkTypeMacro(vtkDirectionEncoder, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent) override;
-  //@}
+  ///@}
 
   /**
    * Given a normal vector n, return the encoded direction
@@ -60,7 +49,7 @@ public:
   /**
    * Return the number of encoded directions
    */
-  virtual int GetNumberOfEncodedDirections(void) = 0;
+  virtual int GetNumberOfEncodedDirections() = 0;
 
   /**
    * Get the decoded gradient table. There are
@@ -68,15 +57,16 @@ public:
    * containing a normal (direction) vector. This is a flat structure -
    * 3 times the number of directions floats in an array.
    */
-  virtual float* GetDecodedGradientTable(void) = 0;
+  virtual float* GetDecodedGradientTable() = 0;
 
 protected:
-  vtkDirectionEncoder() {}
-  ~vtkDirectionEncoder() override {}
+  vtkDirectionEncoder() = default;
+  ~vtkDirectionEncoder() override = default;
 
 private:
   vtkDirectionEncoder(const vtkDirectionEncoder&) = delete;
   void operator=(const vtkDirectionEncoder&) = delete;
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
