@@ -1,22 +1,10 @@
-/*=========================================================================
-
-  Program:   DICOMParser
-  Module:    DICOMConfig.h
-  Language:  C++
-
-  Copyright (c) 2003 Matt Turek
-  All rights reserved.
-  See Copyright.txt for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-
+// SPDX-FileCopyrightText: Copyright (c) 2003 Matt Turek
+// SPDX-License-Identifier: BSD-4-Clause
 #ifndef __DICOM_CONFIG_H_
 #define __DICOM_CONFIG_H_
 
+#include "vtkABINamespace.h"
+
 //
 // CMake Hook
 //
