@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    PyVTKTemplate.cxx
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /*-----------------------------------------------------------------------
   The PyVTKTemplate was created in May 2011 by David Gobbi.
 
@@ -22,6 +10,7 @@
 -----------------------------------------------------------------------*/
 
 #include "PyVTKTemplate.h"
+#include "vtkABINamespace.h"
 #include "vtkPythonUtil.h"
 
 #include <string>
@@ -33,19 +22,19 @@
 #pragma GCC diagnostic ignored "-Wstrict-aliasing"
 #endif
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
 static const char* PyVTKTemplate_Doc =
   "A container for instantiations of class and function templates.\n\n"
   "This is a dictionary for templates, provide the template args\n"
   "in square brackets to get the desired kind of class.\n";
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Methods to help with name mangling and unmangling
 PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* arg);
 PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key);
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Methods for python
 
 static PyObject* PyVTKTemplate_HasKey(PyObject* ob, PyObject* args)
@@ -133,10 +122,8 @@ static PyObject* PyVTKTemplate_Items(PyObject* ob, PyObject* args)
       key = PyVTKTemplate_KeyFromName(ob, key);
       if (key)
       {
-        Py_INCREF(value);
-        PyObject* t = PyTuple_New(2);
-        PyTuple_SET_ITEM(t, 0, key);
-        PyTuple_SET_ITEM(t, 1, value);
+        PyObject* t = PyTuple_Pack(2, key, value);
+        Py_DECREF(key);
         PyList_Append(l, t);
         Py_DECREF(t);
       }
@@ -185,7 +172,7 @@ static PyMethodDef PyVTKTemplate_Methods[] = {
   { nullptr, nullptr, 0, nullptr }
 };
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Mapping protocol
 
 static Py_ssize_t PyVTKTemplate_Size(PyObject* ob)
@@ -233,20 +220,20 @@ static PyObject* PyVTKTemplate_GetItem(PyObject* ob, PyObject* key)
   return r;
 }
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static PyMappingMethods PyVTKTemplate_AsMapping = {
   PyVTKTemplate_Size,    // mp_length
   PyVTKTemplate_GetItem, // mp_subscript
   nullptr,               // mp_ass_subscript
 };
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static PyObject* PyVTKTemplate_Repr(PyObject* self)
 {
-  return PyString_FromFormat("<template %s>", PyModule_GetName(self));
+  return PyUnicode_FromFormat("<template %s>", PyModule_GetName(self));
 }
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 static PyObject* PyVTKTemplate_Call(PyObject*, PyObject*, PyObject*)
 {
   PyErr_SetString(PyExc_TypeError,
@@ -256,7 +243,11 @@ static PyObject* PyVTKTemplate_Call(PyObject*, PyObject*, PyObject*)
   return nullptr;
 }
 
-//--------------------------------------------------------------------
+#ifdef VTK_PYTHON_NEEDS_DEPRECATION_WARNING_SUPPRESSION
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+//------------------------------------------------------------------------------
 // clang-format off
 PyTypeObject PyVTKTemplate_Type = {
   PyVarObject_HEAD_INIT(&PyType_Type, 0)
@@ -311,7 +302,7 @@ PyTypeObject PyVTKTemplate_Type = {
   VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED };
 // clang-format on
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Generate mangled name from the given template args
 PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
 {
@@ -349,7 +340,7 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
 
   if (PyTuple_Check(key))
   {
-    nargs = PyTuple_GET_SIZE(key);
+    nargs = PyTuple_Size(key);
     multi = true;
   }
 
@@ -360,7 +351,7 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
     o = key;
     if (multi)
     {
-      o = PyTuple_GET_ITEM(key, i);
+      o = PyTuple_GetItem(key, i);
     }
 
     tname = nullptr;
@@ -368,7 +359,7 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
     {
       // if type object, get the name of the type
       Py_INCREF(o);
-      tname = ((PyTypeObject*)o)->tp_name;
+      tname = vtkPythonUtil::GetTypeName((PyTypeObject*)o);
       for (const char* cp = tname; *cp != '\0'; cp++)
       {
         if (*cp == '.')
@@ -383,16 +374,11 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
       o = PyObject_Str(o);
       if (PyBytes_Check(o))
       {
-        tname = PyBytes_AS_STRING(o);
+        tname = PyBytes_AsString(o);
       }
       else if (PyUnicode_Check(o))
       {
-#if PY_VERSION_HEX >= 0x03030000
-        tname = PyUnicode_AsUTF8(o);
-#else
-        PyObject* s = _PyUnicode_AsDefaultEncodedString(o, nullptr);
-        tname = PyBytes_AS_STRING(s);
-#endif
+        tname = PyUnicode_AsUTF8AndSize(o, nullptr);
       }
     }
 
@@ -412,7 +398,7 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
       {
         if (PyType_Check(value))
         {
-          const char* cname = ((PyTypeObject*)value)->tp_name;
+          const char* cname = vtkPythonUtil::GetTypeName((PyTypeObject*)value);
           for (const char* cp = cname; *cp != '\0'; cp++)
           {
             if (*cp == '.')
@@ -466,11 +452,6 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
               tname = "vtkStdString";
               n = 12;
             }
-            else if (n == 7 && strcmp(tname, "unicode") == 0)
-            {
-              tname = "vtkUnicodeString";
-              n = 16;
-            }
           }
           break;
         }
@@ -500,7 +481,7 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
         {
           if (PyType_Check(value))
           {
-            const char* cname = ((PyTypeObject*)value)->tp_name;
+            const char* cname = vtkPythonUtil::GetTypeName((PyTypeObject*)value);
             for (const char* cp = cname; *cp != '\0'; cp++)
             {
               if (*cp == '.')
@@ -552,31 +533,22 @@ PyObject* PyVTKTemplate_NameFromKey(PyObject* self, PyObject* key)
   // close the list of template arguments
   name.push_back('E');
 
-#ifdef VTK_PY3K
   return PyUnicode_FromStringAndSize(name.data(), name.length());
-#else
-  return PyBytes_FromStringAndSize(name.data(), name.length());
-#endif
 }
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // Generate template args by unmangling the class name
-PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* o)
+PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* arg)
 {
   // convert arg to a C string
   const char* name = nullptr;
-  if (PyBytes_Check(o))
+  if (PyBytes_Check(arg))
   {
-    name = PyBytes_AS_STRING(o);
+    name = PyBytes_AsString(arg);
   }
-  else if (PyUnicode_Check(o))
+  else if (PyUnicode_Check(arg))
   {
-#if PY_VERSION_HEX >= 0x03030000
-    name = PyUnicode_AsUTF8(o);
-#else
-    PyObject* s = _PyUnicode_AsDefaultEncodedString(o, nullptr);
-    name = PyBytes_AS_STRING(s);
-#endif
+    name = PyUnicode_AsUTF8AndSize(arg, nullptr);
   }
 
   if (!name)
@@ -637,7 +609,7 @@ PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* o)
         sign = -1;
         cp++;
       }
-      keys[i] = PyInt_FromLong(sign * strtol(cp, nullptr, 0));
+      keys[i] = PyLong_FromLong(sign * strtol(cp, nullptr, 0));
       while (*cp != 'E' && *cp != '\0')
       {
         cp++;
@@ -711,19 +683,45 @@ PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* o)
             return nullptr;
           }
         }
-        if (j == 16 && strncmp(cp, "vtkUnicodeString", 16) == 0)
-        {
-          ptype = "unicode";
-          j = 7;
-        }
-        else if (j == 12 && strncmp(cp, "vtkStdString", 12) == 0)
+        if (j == 12 && strncmp(cp, "vtkStdString", 12) == 0)
         {
           ptype = "str";
           j = 3;
         }
         else
         {
-          ptype = cp;
+          // use the type name as-is
+          if (*dp == 'I')
+          {
+            // the type name is templated
+            dp++;
+            if (*dp >= '0' && *dp <= '9')
+            {
+              size_t l = strtol(dp, &dp, 10);
+              for (size_t k = 0; k < l; k++)
+              {
+                if (*dp++ == '\0')
+                {
+                  break;
+                }
+              }
+            }
+            else if (*dp != '\0')
+            {
+              dp++;
+            }
+            if (*dp == 'E')
+            {
+              // end of template args
+              dp++;
+              ptype = cp;
+            }
+          }
+          else
+          {
+            // type name is not templated
+            ptype = cp;
+          }
         }
         cp = dp;
       }
@@ -733,7 +731,7 @@ PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* o)
         // unrecognized mangled type.
         return nullptr;
       }
-      keys[i] = PyString_FromStringAndSize(ptype, (Py_ssize_t)j);
+      keys[i] = PyUnicode_FromStringAndSize(ptype, (Py_ssize_t)j);
     }
   }
 
@@ -748,17 +746,17 @@ PyObject* PyVTKTemplate_KeyFromName(PyObject* self, PyObject* o)
     key = PyTuple_New(n);
     for (i = 0; i < n; i++)
     {
-      PyTuple_SET_ITEM(key, i, keys[i]);
+      PyTuple_SetItem(key, i, keys[i]);
     }
   }
 
   return key;
 }
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 // C API
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 PyObject* PyVTKTemplate_New(const char* name, const char* docstring)
 {
   // make sure python has readied the type object
@@ -766,16 +764,18 @@ PyObject* PyVTKTemplate_New(const char* name, const char* docstring)
   // call the allocator provided by python for this type
   PyObject* self = PyVTKTemplate_Type.tp_alloc(&PyVTKTemplate_Type, 0);
   // call the superclass init function
-  PyObject* args = PyTuple_New(2);
-  PyTuple_SET_ITEM(args, 0, PyString_FromString(name));
-  PyTuple_SET_ITEM(args, 1, PyString_FromString(docstring));
+  PyObject* pyname = PyUnicode_FromString(name);
+  PyObject* pydoc = PyUnicode_FromString(docstring);
+  PyObject* args = PyTuple_Pack(2, pyname, pydoc);
+  Py_DECREF(pyname);
+  Py_DECREF(pydoc);
   PyVTKTemplate_Type.tp_base->tp_init(self, args, nullptr);
   Py_DECREF(args);
 
   return self;
 }
 
-//--------------------------------------------------------------------
+//------------------------------------------------------------------------------
 int PyVTKTemplate_AddItem(PyObject* self, PyObject* val)
 {
   if (!PyType_Check(val))
@@ -785,14 +785,7 @@ int PyVTKTemplate_AddItem(PyObject* self, PyObject* val)
   }
 
   // get the name, but strip the namespace
-  const char* name = ((PyTypeObject*)val)->tp_name;
-  for (const char* cp = name; *cp != '\0'; cp++)
-  {
-    if (*cp == '.')
-    {
-      name = cp + 1;
-    }
-  }
+  const char* name = vtkPythonUtil::StripModuleFromType((PyTypeObject*)val);
   PyObject* dict = PyModule_GetDict(self);
   PyDict_SetItemString(dict, name, val);
 
