@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkWrapPython.c
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 
 #include "vtkWrapPythonClass.h"
 #include "vtkWrapPythonConstant.h"
@@ -21,6 +9,7 @@
 
 #include "vtkParseExtras.h"
 #include "vtkParseMain.h"
+#include "vtkParseSystem.h"
 #include "vtkWrap.h"
 
 #include <ctype.h>
@@ -98,10 +87,12 @@ static void vtkWrapPython_GenerateSpecialHeaders(
   int numTypes = 0;
   FunctionInfo* currentFunction;
   int i, j, k, n, m, ii, nn;
-  unsigned int aType;
   const char* classname;
   const char* ownincfile = "";
   ClassInfo* data;
+  ValueInfo* val;
+  const char** includedHeaders = NULL;
+  size_t nIncludedHeaders = 0;
 
   types = (const char**)malloc(1000 * sizeof(const char*));
 
@@ -122,48 +113,35 @@ static void vtkWrapPython_GenerateSpecialHeaders(
       if (currentFunction->Access == VTK_ACCESS_PUBLIC && !currentFunction->IsExcluded &&
         strcmp(currentFunction->Class, data->Name) == 0)
       {
-        classname = "void";
-        aType = VTK_PARSE_VOID;
-        if (currentFunction->ReturnValue)
-        {
-          classname = currentFunction->ReturnValue->Class;
-          aType = currentFunction->ReturnValue->Type;
-        }
-
         m = vtkWrap_CountWrappedParameters(currentFunction);
 
         for (j = -1; j < m; j++)
         {
           if (j >= 0)
           {
-            classname = currentFunction->Parameters[j]->Class;
-            aType = currentFunction->Parameters[j]->Type;
-          }
-          /* we don't require the header file if it is just a pointer */
-          if ((aType & VTK_PARSE_INDIRECT) != VTK_PARSE_POINTER)
-          {
-            if ((aType & VTK_PARSE_BASE_TYPE) == VTK_PARSE_STRING)
-            {
-              classname = "vtkStdString";
-            }
-            else if ((aType & VTK_PARSE_BASE_TYPE) == VTK_PARSE_UNICODE_STRING)
-            {
-              classname = "vtkUnicodeString";
-            }
-            else if ((aType & VTK_PARSE_BASE_TYPE) != VTK_PARSE_OBJECT)
-            {
-              classname = 0;
-            }
-            else if ((aType & VTK_PARSE_REF) != 0)
-            {
-              classname = 0;
-            }
+            val = currentFunction->Parameters[j];
           }
           else
           {
-            classname = 0;
+            val = currentFunction->ReturnValue;
+          }
+          if (vtkWrap_IsVoid(val))
+          {
+            continue;
           }
 
+          classname = 0;
+          /* the IsScalar check is used because the wrappers don't need the
+             header for objects passed via a pointer (but they need the header
+             for objects passed by reference) */
+          if (vtkWrap_IsString(val) && vtkWrap_IsScalar(val))
+          {
+            classname = val->Class;
+          }
+          else if (vtkWrap_IsObject(val) && vtkWrap_IsScalar(val) && !vtkWrap_IsRef(val))
+          {
+            classname = val->Class;
+          }
           /* we already include our own header */
           if (classname && strcmp(classname, data->Name) != 0)
           {
@@ -203,6 +181,8 @@ static void vtkWrapPython_GenerateSpecialHeaders(
     ownincfile = vtkWrapPython_ClassHeader(hinfo, data->Name);
   }
 
+  includedHeaders = (const char**)malloc(numTypes * sizeof(const char*));
+
   /* for each unique type found in the file */
   for (i = 0; i < numTypes; i++)
   {
@@ -211,6 +191,26 @@ static void vtkWrapPython_GenerateSpecialHeaders(
 
     if (incfile)
     {
+      /* make sure it hasn't been included before. */
+      size_t nHeader;
+      int uniqueInclude = 1;
+      for (nHeader = 0; nHeader < nIncludedHeaders; ++nHeader)
+      {
+        if (!strcmp(incfile, includedHeaders[nHeader]))
+        {
+          uniqueInclude = 0;
+        }
+      }
+
+      /* ignore duplicate includes. */
+      if (!uniqueInclude)
+      {
+        continue;
+      }
+
+      includedHeaders[nIncludedHeaders] = incfile;
+      ++nIncludedHeaders;
+
       /* make sure it doesn't share our header file */
       if (ownincfile == 0 || strcmp(incfile, ownincfile) != 0)
       {
@@ -219,6 +219,9 @@ static void vtkWrapPython_GenerateSpecialHeaders(
     }
   }
 
+  free((char**)includedHeaders);
+  includedHeaders = NULL;
+
   /* special case for the way vtkGenericDataArray template is used */
   if (data && strcmp(data->Name, "vtkGenericDataArray") == 0)
   {
@@ -237,12 +240,10 @@ static void vtkWrapPython_GenerateSpecialHeaders(
 /* This is the main entry point for the python wrappers.  When called,
  * it will print the vtkXXPython.c file contents to "fp".  */
 
-#define MAX_WRAPPED_CLASSES 256
-
-int main(int argc, char* argv[])
+int VTK_PARSE_MAIN(int argc, char* argv[])
 {
-  ClassInfo* wrappedClasses[MAX_WRAPPED_CLASSES];
-  unsigned char wrapAsVTKObject[MAX_WRAPPED_CLASSES];
+  ClassInfo** wrappedClasses;
+  unsigned char* wrapAsVTKObject;
   ClassInfo* data = NULL;
   NamespaceInfo* contents;
   OptionInfo* options;
@@ -276,7 +277,7 @@ int main(int argc, char* argv[])
   }
 
   /* get the output file */
-  fp = fopen(options->OutputFileName, "w");
+  fp = vtkParse_FileOpen(options->OutputFileName, "w");
 
 #ifdef _WIN32
   if (!fp)
@@ -287,7 +288,7 @@ int main(int argc, char* argv[])
     for (tries = 0; !fp && tries < 5 && errno == EACCES; tries++)
     {
       Sleep(1000);
-      fp = fopen(options->OutputFileName, "w");
+      fp = vtkParse_FileOpen(options->OutputFileName, "w");
     }
   }
 #endif
@@ -362,7 +363,6 @@ int main(int argc, char* argv[])
   fprintf(fp,
     "#include \"vtkPythonArgs.h\"\n"
     "#include \"vtkPythonOverload.h\"\n"
-    "#include \"vtkConfigure.h\"\n"
     "#include <cstddef>\n"
     "#include <sstream>\n");
 
@@ -407,7 +407,10 @@ int main(int argc, char* argv[])
   /* Wrap any enum types defined in the global namespace */
   for (i = 0; i < contents->NumberOfEnums; i++)
   {
-    vtkWrapPython_GenerateEnumType(fp, module, NULL, contents->Enums[i]);
+    if (!contents->Enums[i]->IsExcluded)
+    {
+      vtkWrapPython_GenerateEnumType(fp, module, NULL, contents->Enums[i]);
+    }
   }
 
   /* Wrap any namespaces */
@@ -421,6 +424,7 @@ int main(int argc, char* argv[])
   }
 
   /* Check for all special classes before any classes are wrapped */
+  wrapAsVTKObject = (unsigned char*)malloc(sizeof(unsigned char) * contents->NumberOfClasses);
   for (i = 0; i < contents->NumberOfClasses; i++)
   {
     data = contents->Classes[i];
@@ -452,6 +456,7 @@ int main(int argc, char* argv[])
   }
 
   /* Wrap all of the classes in the file */
+  wrappedClasses = (ClassInfo**)malloc(sizeof(ClassInfo*) * contents->NumberOfClasses);
   for (i = 0; i < contents->NumberOfClasses; i++)
   {
     data = contents->Classes[i];
@@ -518,20 +523,15 @@ int main(int argc, char* argv[])
       fprintf(fp,
         "  if (o)\n"
         "  {\n"
-        "#if PY_VERSION_HEX >= 0x03040000\n"
-        "    const char *methodname = \"values\";\n"
-        "#else\n"
-        "    char methodname[] = \"values\";\n"
-        "#endif\n"
-        "    PyObject *l = PyObject_CallMethod(o, methodname, nullptr);\n"
-        "    Py_ssize_t n = PyList_GET_SIZE(l);\n"
+        "    PyObject *l = PyObject_CallMethod(o, \"values\", nullptr);\n"
+        "    Py_ssize_t n = PyList_Size(l);\n"
         "    for (Py_ssize_t i = 0; i < n; i++)\n"
         "    {\n"
-        "      PyObject *ot = PyList_GET_ITEM(l, i);\n"
+        "      PyObject *ot = PyList_GetItem(l, i);\n"
         "      const char *nt = nullptr;\n"
         "      if (PyType_Check(ot))\n"
         "      {\n"
-        "        nt = ((PyTypeObject *)ot)->tp_name;\n"
+        "        nt = vtkPythonUtil::GetTypeName((PyTypeObject *)ot);\n"
         "      }\n"
         "      if (nt)\n"
         "      {\n"
@@ -581,6 +581,13 @@ int main(int argc, char* argv[])
   fclose(fp);
 
   free(name_from_file);
+  free(wrapAsVTKObject);
+  free(wrappedClasses);
+
+  if (hinfo)
+  {
+    vtkParseHierarchy_Free(hinfo);
+  }
 
   vtkParse_Free(file_info);
 
